--
-- PostgreSQL database dump
--

-- Dumped from database version 9.1.13
-- Dumped by pg_dump version 9.1.13
-- Started on 2016-06-05 18:56:36

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- TOC entry 7 (class 2615 OID 16395)
-- Name: global; Type: SCHEMA; Schema: -; Owner: biblivre
--

CREATE SCHEMA global;


ALTER SCHEMA global OWNER TO biblivre;

--
-- TOC entry 8 (class 2615 OID 16465)
-- Name: single; Type: SCHEMA; Schema: -; Owner: biblivre
--

CREATE SCHEMA single;


ALTER SCHEMA single OWNER TO biblivre;

--
-- TOC entry 256 (class 3079 OID 11639)
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- TOC entry 2643 (class 0 OID 0)
-- Dependencies: 256
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = global, pg_catalog;

--
-- TOC entry 268 (class 1255 OID 16396)
-- Dependencies: 7 852
-- Name: unlink(); Type: FUNCTION; Schema: global; Owner: biblivre
--

CREATE FUNCTION unlink() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	PERFORM pg_catalog.lo_unlink(OLD.blob);
	RETURN OLD;
EXCEPTION WHEN OTHERS THEN
	RETURN OLD;
END;
$$;


ALTER FUNCTION global.unlink() OWNER TO biblivre;

--
-- TOC entry 271 (class 1255 OID 16397)
-- Dependencies: 852 7
-- Name: update_translation(character varying, character varying, character varying, integer); Type: FUNCTION; Schema: global; Owner: biblivre
--

CREATE FUNCTION update_translation(character varying, character varying, character varying, integer) RETURNS integer
    LANGUAGE plpgsql
    AS $_$ 
 DECLARE 
	p_language ALIAS FOR $1; 
	p_key ALIAS FOR $2; 
	p_text ALIAS FOR $3; 
	p_user ALIAS FOR $4; 
 
	v_schema character varying; 
	v_current_value TEXT; 
	v_global_value TEXT; 
	v_user_created BOOLEAN; 
	v_query_string character varying; 
 BEGIN 
	v_schema = current_schema(); 
	 
	IF v_schema <> 'global' THEN 
		-- Get the global value for this key 
		SELECT INTO v_global_value text FROM global.translations 
		WHERE language = p_language AND key = p_key; 
 
		-- If the new text is the same as the global one, 
		-- delete it from the current schema 
		IF v_global_value = p_text THEN 
			-- Fix for unqualified schema in functions          
			EXECUTE 'DELETE FROM ' || pg_catalog.quote_ident(v_schema) || '.translations WHERE language = ' || pg_catalog.quote_literal(p_language) || ' AND key = ' || pg_catalog.quote_literal(p_key); 
			-- The code below will only work with multiple schemas after Postgresql 9.3 
			-- DELETE FROM translations WHERE language = p_language AND key = p_key; 
			RETURN 1; 
		END IF; 
	END IF; 
 
	-- Get the current value for this key 
	 
	-- Fix for unqualified schema in functions          
	EXECUTE 'SELECT text FROM ' || pg_catalog.quote_ident(v_schema) || '.translations WHERE language = ' || pg_catalog.quote_literal(p_language) || ' AND key = ' || pg_catalog.quote_literal(p_key) INTO v_current_value; 
	-- The code below will only work with multiple schemas after Postgresql 9.3 
	-- SELECT INTO v_current_value text FROM translations WHERE language = p_language AND key = p_key; 
	 
	-- If the new text is the same as the current one, 
	-- return 
	IF v_current_value = p_text THEN 
		RETURN 2; 
	END IF; 
 
	-- If the new key isn't available in the global schema, 
	-- then this is a user_created key 
	v_user_created = v_schema <> 'global' AND v_global_value IS NULL; 
 
	-- If the current value is null then there is no 
	-- current translation for this key, then we should 
	-- insert it 
	IF v_current_value IS NULL THEN     
		EXECUTE 'INSERT INTO ' || pg_catalog.quote_ident(v_schema) || '.translations (language, key, text, created_by, modified_by, user_created) VALUES (' || pg_catalog.quote_literal(p_language) || ', ' || pg_catalog.quote_literal(p_key) || ', ' || pg_catalog.quote_literal(p_text) || ', ' || pg_catalog.quote_literal(p_user) || ', ' || pg_catalog.quote_literal(p_user) || ', ' || pg_catalog.quote_literal(v_user_created) || ');'; 
 
		-- The code below will only work with multiple schemas after Postgresql 9.3 
		--INSERT INTO translations 
		--(language, key, text, created_by, modified_by, user_created) 
		--VALUES 
		--(p_language, p_key, p_text, p_user, p_user, v_user_created); 
		 
		RETURN 3; 
	ELSE 
		EXECUTE 'UPDATE ' || pg_catalog.quote_ident(v_schema) || '.translations SET text = ' || pg_catalog.quote_literal(p_text) || ', modified = now(), modified_by = ' || pg_catalog.quote_literal(p_user) || ' WHERE language = ' || pg_catalog.quote_literal(p_language) || ' AND key = ' || pg_catalog.quote_literal(p_key); 
 
		-- The code below will only work with multiple schemas after Postgresql 9.3 
		--UPDATE translations 
		--SET text = p_text, 
		--modified = now(), 
		--modified_by = p_user 
		--WHERE language = p_language AND key = p_key; 
		 
		RETURN 4; 
	END IF; 
 END; 
 $_$;


ALTER FUNCTION global.update_translation(character varying, character varying, character varying, integer) OWNER TO biblivre;

--
-- TOC entry 272 (class 1255 OID 16398)
-- Dependencies: 852 7
-- Name: update_user_value(integer, character varying, character varying, character varying); Type: FUNCTION; Schema: global; Owner: biblivre
--

CREATE FUNCTION update_user_value(integer, character varying, character varying, character varying) RETURNS integer
    LANGUAGE plpgsql
    AS $_$ 
 DECLARE 
	p_id ALIAS FOR $1; 
	p_key ALIAS FOR $2; 
	p_value ALIAS FOR $3; 
	p_ascii ALIAS FOR $4; 
 
	v_schema character varying; 
	v_current_value TEXT; 
 BEGIN 
	v_schema = current_schema(); 
 
	IF v_schema = 'global' THEN 
		-- Can't save user fields in global schema 
		RETURN 1; 
	END IF; 
 
	-- Get the current value for this key 
	EXECUTE 'SELECT value FROM ' || pg_catalog.quote_ident(v_schema) || '.users_values WHERE user_id = ' || pg_catalog.quote_literal(p_id) || ' AND key = ' || pg_catalog.quote_literal(p_key) INTO v_current_value; 
	-- SELECT INTO v_current_value value FROM users_values WHERE user_id = p_id AND key = p_key; 
 
	-- If the new value is the same as the current one, 
	-- return 
	IF v_current_value = p_value THEN 
		RETURN 2; 
	END IF; 
 
	-- If the current value is null then there is no 
	-- current value for this key, then we should 
	-- insert it 
	IF v_current_value IS NULL THEN 
		-- RAISE LOG 'inserting into schema %', v_schema; 
		EXECUTE 'INSERT INTO ' || pg_catalog.quote_ident(v_schema) || '.users_values (user_id, key, value, ascii) VALUES (' || pg_catalog.quote_literal(p_id) || ', ' || pg_catalog.quote_literal(p_key) || ', ' || pg_catalog.quote_literal(p_value) || ', ' || pg_catalog.quote_literal(p_ascii) || ');'; 
		--INSERT INTO users_values (user_id, key, value, ascii) VALUES (p_id, p_key, p_value, p_ascii); 
		 
		RETURN 3; 
	ELSE 
		EXECUTE 'UPDATE ' || pg_catalog.quote_ident(v_schema) || '.users_values SET value = ' || pg_catalog.quote_literal(p_value) || ', ascii = ' || pg_catalog.quote_literal(p_ascii) || ' WHERE user_id = ' || pg_catalog.quote_literal(p_id) || ' AND key = ' || pg_catalog.quote_literal(p_key); 
		-- UPDATE users_values SET value = p_value, ascii = p_ascii WHERE user_id = p_id AND key = p_key; 
 
		RETURN 4; 
	END IF; 
 END; 
$_$;


ALTER FUNCTION global.update_user_value(integer, character varying, character varying, character varying) OWNER TO biblivre;

SET search_path = single, pg_catalog;

--
-- TOC entry 269 (class 1255 OID 16466)
-- Dependencies: 852 8
-- Name: clear_indexing_type(); Type: FUNCTION; Schema: single; Owner: biblivre
--

CREATE FUNCTION clear_indexing_type() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	EXECUTE 'DELETE FROM "' || TG_TABLE_SCHEMA || '".' || TG_ARGV[0] || '_idx_fields WHERE indexing_group_id = ' || OLD.id;
	EXECUTE 'DELETE FROM "' || TG_TABLE_SCHEMA || '".' || TG_ARGV[0] || '_idx_sort WHERE indexing_group_id = ' || OLD.id;

	RETURN NULL;
END;
$$;


ALTER FUNCTION single.clear_indexing_type() OWNER TO biblivre;

--
-- TOC entry 270 (class 1255 OID 16467)
-- Dependencies: 852 8
-- Name: clear_record(); Type: FUNCTION; Schema: single; Owner: biblivre
--

CREATE FUNCTION clear_record() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	EXECUTE 'DELETE FROM "' || TG_TABLE_SCHEMA || '".' || TG_ARGV[0] || '_idx_fields WHERE record_id = ' || OLD.id;
	EXECUTE 'DELETE FROM "' || TG_TABLE_SCHEMA || '".' || TG_ARGV[0] || '_idx_sort WHERE record_id = ' || OLD.id;
	EXECUTE 'DELETE FROM "' || TG_TABLE_SCHEMA || '".' || TG_ARGV[0] || '_search_results WHERE record_id = ' || OLD.id;

	RETURN NULL;
END;
$$;


ALTER FUNCTION single.clear_record() OWNER TO biblivre;

SET search_path = global, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- TOC entry 166 (class 1259 OID 16419)
-- Dependencies: 2118 2119 7
-- Name: backups; Type: TABLE; Schema: global; Owner: biblivre; Tablespace: 
--

CREATE TABLE backups (
    id integer NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    path character varying,
    schemas character varying NOT NULL,
    type character varying NOT NULL,
    scope character varying NOT NULL,
    downloaded boolean DEFAULT false NOT NULL,
    steps integer,
    current_step integer
);


ALTER TABLE global.backups OWNER TO biblivre;

--
-- TOC entry 167 (class 1259 OID 16427)
-- Dependencies: 166 7
-- Name: backups_id_seq; Type: SEQUENCE; Schema: global; Owner: biblivre
--

CREATE SEQUENCE backups_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE global.backups_id_seq OWNER TO biblivre;

--
-- TOC entry 2644 (class 0 OID 0)
-- Dependencies: 167
-- Name: backups_id_seq; Type: SEQUENCE OWNED BY; Schema: global; Owner: biblivre
--

ALTER SEQUENCE backups_id_seq OWNED BY backups.id;


--
-- TOC entry 163 (class 1259 OID 16399)
-- Dependencies: 2111 2112 2113 7
-- Name: configurations; Type: TABLE; Schema: global; Owner: biblivre; Tablespace: 
--

CREATE TABLE configurations (
    key character varying NOT NULL,
    value character varying NOT NULL,
    type character varying DEFAULT 'string'::character varying NOT NULL,
    required boolean DEFAULT false NOT NULL,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE global.configurations OWNER TO biblivre;

--
-- TOC entry 164 (class 1259 OID 16408)
-- Dependencies: 2114 2115 2116 7
-- Name: logins; Type: TABLE; Schema: global; Owner: biblivre; Tablespace: 
--

CREATE TABLE logins (
    id integer NOT NULL,
    login character varying NOT NULL,
    employee boolean DEFAULT false NOT NULL,
    password text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE global.logins OWNER TO biblivre;

--
-- TOC entry 165 (class 1259 OID 16417)
-- Dependencies: 164 7
-- Name: logins_id_seq; Type: SEQUENCE; Schema: global; Owner: biblivre
--

CREATE SEQUENCE logins_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE global.logins_id_seq OWNER TO biblivre;

--
-- TOC entry 2645 (class 0 OID 0)
-- Dependencies: 165
-- Name: logins_id_seq; Type: SEQUENCE OWNED BY; Schema: global; Owner: biblivre
--

ALTER SEQUENCE logins_id_seq OWNED BY logins.id;


--
-- TOC entry 168 (class 1259 OID 16430)
-- Dependencies: 2121 7
-- Name: schemas; Type: TABLE; Schema: global; Owner: biblivre; Tablespace: 
--

CREATE TABLE schemas (
    schema character varying NOT NULL,
    name character varying,
    disabled boolean DEFAULT false NOT NULL
);


ALTER TABLE global.schemas OWNER TO biblivre;

--
-- TOC entry 169 (class 1259 OID 16437)
-- Dependencies: 2122 2123 2124 7
-- Name: translations; Type: TABLE; Schema: global; Owner: biblivre; Tablespace: 
--

CREATE TABLE translations (
    language character varying NOT NULL,
    key character varying NOT NULL,
    text text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    user_created boolean DEFAULT false NOT NULL
);


ALTER TABLE global.translations OWNER TO biblivre;

--
-- TOC entry 170 (class 1259 OID 16446)
-- Dependencies: 7
-- Name: versions; Type: TABLE; Schema: global; Owner: biblivre; Tablespace: 
--

CREATE TABLE versions (
    installed_versions character varying NOT NULL
);


ALTER TABLE global.versions OWNER TO biblivre;

SET search_path = single, pg_catalog;

--
-- TOC entry 171 (class 1259 OID 16468)
-- Dependencies: 8
-- Name: access_cards_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE access_cards_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.access_cards_id_seq OWNER TO biblivre;

--
-- TOC entry 172 (class 1259 OID 16470)
-- Dependencies: 2125 2126 2127 8
-- Name: access_cards; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE access_cards (
    id integer DEFAULT nextval('access_cards_id_seq'::regclass) NOT NULL,
    code character varying NOT NULL,
    status character varying NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.access_cards OWNER TO biblivre;

--
-- TOC entry 173 (class 1259 OID 16479)
-- Dependencies: 8
-- Name: access_control_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE access_control_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.access_control_id_seq OWNER TO biblivre;

--
-- TOC entry 174 (class 1259 OID 16481)
-- Dependencies: 2128 2129 2130 2131 8
-- Name: access_control; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE access_control (
    id integer DEFAULT nextval('access_control_id_seq'::regclass) NOT NULL,
    access_card_id integer NOT NULL,
    user_id integer NOT NULL,
    arrival_time timestamp without time zone DEFAULT now() NOT NULL,
    departure_time timestamp without time zone,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.access_control OWNER TO biblivre;

--
-- TOC entry 175 (class 1259 OID 16488)
-- Dependencies: 2132 2133 8
-- Name: authorities_brief_formats; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_brief_formats (
    datafield character(3) NOT NULL,
    format text NOT NULL,
    sort_order integer,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.authorities_brief_formats OWNER TO biblivre;

--
-- TOC entry 176 (class 1259 OID 16496)
-- Dependencies: 2134 2135 2136 2137 8
-- Name: authorities_form_datafields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_form_datafields (
    datafield character(3) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    indicator_1 character varying,
    indicator_2 character varying,
    material_type character varying,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.authorities_form_datafields OWNER TO biblivre;

--
-- TOC entry 177 (class 1259 OID 16506)
-- Dependencies: 2138 2139 2140 2141 2142 8
-- Name: authorities_form_subfields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_form_subfields (
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    autocomplete_type character varying DEFAULT 'disabled'::character varying NOT NULL
);


ALTER TABLE single.authorities_form_subfields OWNER TO biblivre;

--
-- TOC entry 178 (class 1259 OID 16517)
-- Dependencies: 8
-- Name: authorities_idx_autocomplete; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_idx_autocomplete (
    id integer NOT NULL,
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    word character varying NOT NULL,
    phrase character varying NOT NULL,
    record_id integer
);


ALTER TABLE single.authorities_idx_autocomplete OWNER TO biblivre;

--
-- TOC entry 179 (class 1259 OID 16523)
-- Dependencies: 8 178
-- Name: authorities_idx_autocomplete_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE authorities_idx_autocomplete_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.authorities_idx_autocomplete_id_seq OWNER TO biblivre;

--
-- TOC entry 2646 (class 0 OID 0)
-- Dependencies: 179
-- Name: authorities_idx_autocomplete_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE authorities_idx_autocomplete_id_seq OWNED BY authorities_idx_autocomplete.id;


--
-- TOC entry 180 (class 1259 OID 16525)
-- Dependencies: 8
-- Name: authorities_idx_fields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_idx_fields (
    record_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    word character varying NOT NULL,
    datafield integer NOT NULL
);


ALTER TABLE single.authorities_idx_fields OWNER TO biblivre;

--
-- TOC entry 181 (class 1259 OID 16531)
-- Dependencies: 8
-- Name: authorities_idx_sort; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_idx_sort (
    record_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    phrase character varying,
    ignore_chars_count integer
);


ALTER TABLE single.authorities_idx_sort OWNER TO biblivre;

--
-- TOC entry 182 (class 1259 OID 16537)
-- Dependencies: 2144 2145 2146 2147 8
-- Name: authorities_indexing_groups; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_indexing_groups (
    id integer NOT NULL,
    translation_key character varying NOT NULL,
    datafields text,
    sortable boolean DEFAULT false NOT NULL,
    default_sort boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.authorities_indexing_groups OWNER TO biblivre;

--
-- TOC entry 183 (class 1259 OID 16547)
-- Dependencies: 182 8
-- Name: authorities_indexing_groups_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE authorities_indexing_groups_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.authorities_indexing_groups_id_seq OWNER TO biblivre;

--
-- TOC entry 2647 (class 0 OID 0)
-- Dependencies: 183
-- Name: authorities_indexing_groups_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE authorities_indexing_groups_id_seq OWNED BY authorities_indexing_groups.id;


--
-- TOC entry 184 (class 1259 OID 16549)
-- Dependencies: 2149 2150 2151 8
-- Name: authorities_records; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_records (
    id integer NOT NULL,
    iso2709 text NOT NULL,
    material character varying(20),
    database character varying(10) DEFAULT 'main'::character varying NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.authorities_records OWNER TO biblivre;

--
-- TOC entry 185 (class 1259 OID 16558)
-- Dependencies: 8 184
-- Name: authorities_records_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE authorities_records_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.authorities_records_id_seq OWNER TO biblivre;

--
-- TOC entry 2648 (class 0 OID 0)
-- Dependencies: 185
-- Name: authorities_records_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE authorities_records_id_seq OWNED BY authorities_records.id;


--
-- TOC entry 186 (class 1259 OID 16560)
-- Dependencies: 8
-- Name: authorities_search_results; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_search_results (
    search_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    record_id integer NOT NULL
);


ALTER TABLE single.authorities_search_results OWNER TO biblivre;

--
-- TOC entry 187 (class 1259 OID 16563)
-- Dependencies: 2153 8
-- Name: authorities_searches; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE authorities_searches (
    id integer NOT NULL,
    parameters text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.authorities_searches OWNER TO biblivre;

--
-- TOC entry 188 (class 1259 OID 16570)
-- Dependencies: 187 8
-- Name: authorities_searches_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE authorities_searches_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.authorities_searches_id_seq OWNER TO biblivre;

--
-- TOC entry 2649 (class 0 OID 0)
-- Dependencies: 188
-- Name: authorities_searches_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE authorities_searches_id_seq OWNED BY authorities_searches.id;


--
-- TOC entry 189 (class 1259 OID 16572)
-- Dependencies: 2155 2156 8
-- Name: backups; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE backups (
    id integer NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    path character varying,
    schemas character varying NOT NULL,
    type character varying NOT NULL,
    scope character varying NOT NULL,
    downloaded boolean DEFAULT false NOT NULL,
    steps integer,
    current_step integer
);


ALTER TABLE single.backups OWNER TO biblivre;

--
-- TOC entry 190 (class 1259 OID 16580)
-- Dependencies: 189 8
-- Name: backups_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE backups_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.backups_id_seq OWNER TO biblivre;

--
-- TOC entry 2650 (class 0 OID 0)
-- Dependencies: 190
-- Name: backups_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE backups_id_seq OWNED BY backups.id;


--
-- TOC entry 191 (class 1259 OID 16582)
-- Dependencies: 2158 2159 8
-- Name: biblio_brief_formats; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_brief_formats (
    datafield character(3) NOT NULL,
    format text NOT NULL,
    sort_order integer,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.biblio_brief_formats OWNER TO biblivre;

--
-- TOC entry 192 (class 1259 OID 16590)
-- Dependencies: 2160 2161 2162 2163 8
-- Name: biblio_form_datafields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_form_datafields (
    datafield character(3) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    indicator_1 character varying,
    indicator_2 character varying,
    material_type character varying,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.biblio_form_datafields OWNER TO biblivre;

--
-- TOC entry 193 (class 1259 OID 16600)
-- Dependencies: 2164 2165 2166 2167 2168 8
-- Name: biblio_form_subfields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_form_subfields (
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    autocomplete_type character varying DEFAULT 'disabled'::character varying NOT NULL
);


ALTER TABLE single.biblio_form_subfields OWNER TO biblivre;

--
-- TOC entry 194 (class 1259 OID 16611)
-- Dependencies: 2169 2170 2171 2172 2173 8
-- Name: biblio_holdings; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_holdings (
    id integer NOT NULL,
    record_id integer NOT NULL,
    iso2709 text NOT NULL,
    database character varying(10) DEFAULT 'main'::character varying NOT NULL,
    accession_number character varying NOT NULL,
    location_d character varying,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    material character varying(20),
    availability character varying DEFAULT 'available'::character varying NOT NULL,
    label_printed boolean DEFAULT false
);


ALTER TABLE single.biblio_holdings OWNER TO biblivre;

--
-- TOC entry 195 (class 1259 OID 16622)
-- Dependencies: 194 8
-- Name: biblio_holdings_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE biblio_holdings_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.biblio_holdings_id_seq OWNER TO biblivre;

--
-- TOC entry 2651 (class 0 OID 0)
-- Dependencies: 195
-- Name: biblio_holdings_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE biblio_holdings_id_seq OWNED BY biblio_holdings.id;


--
-- TOC entry 196 (class 1259 OID 16624)
-- Dependencies: 8
-- Name: biblio_idx_autocomplete; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_idx_autocomplete (
    id integer NOT NULL,
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    word character varying NOT NULL,
    phrase character varying NOT NULL,
    record_id integer
);


ALTER TABLE single.biblio_idx_autocomplete OWNER TO biblivre;

--
-- TOC entry 197 (class 1259 OID 16630)
-- Dependencies: 196 8
-- Name: biblio_idx_autocomplete_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE biblio_idx_autocomplete_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.biblio_idx_autocomplete_id_seq OWNER TO biblivre;

--
-- TOC entry 2652 (class 0 OID 0)
-- Dependencies: 197
-- Name: biblio_idx_autocomplete_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE biblio_idx_autocomplete_id_seq OWNED BY biblio_idx_autocomplete.id;


--
-- TOC entry 198 (class 1259 OID 16632)
-- Dependencies: 8
-- Name: biblio_idx_fields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_idx_fields (
    record_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    word character varying NOT NULL,
    datafield integer NOT NULL
);


ALTER TABLE single.biblio_idx_fields OWNER TO biblivre;

--
-- TOC entry 199 (class 1259 OID 16638)
-- Dependencies: 8
-- Name: biblio_idx_sort; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_idx_sort (
    record_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    phrase character varying,
    ignore_chars_count integer
);


ALTER TABLE single.biblio_idx_sort OWNER TO biblivre;

--
-- TOC entry 200 (class 1259 OID 16644)
-- Dependencies: 2176 2177 2178 2179 8
-- Name: biblio_indexing_groups; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_indexing_groups (
    id integer NOT NULL,
    translation_key character varying NOT NULL,
    datafields text,
    sortable boolean DEFAULT false NOT NULL,
    default_sort boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.biblio_indexing_groups OWNER TO biblivre;

--
-- TOC entry 201 (class 1259 OID 16654)
-- Dependencies: 200 8
-- Name: biblio_indexing_groups_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE biblio_indexing_groups_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.biblio_indexing_groups_id_seq OWNER TO biblivre;

--
-- TOC entry 2653 (class 0 OID 0)
-- Dependencies: 201
-- Name: biblio_indexing_groups_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE biblio_indexing_groups_id_seq OWNED BY biblio_indexing_groups.id;


--
-- TOC entry 202 (class 1259 OID 16656)
-- Dependencies: 2181 2182 2183 8
-- Name: biblio_records; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_records (
    id integer NOT NULL,
    iso2709 text NOT NULL,
    material character varying(20),
    database character varying(10) DEFAULT 'main'::character varying NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.biblio_records OWNER TO biblivre;

--
-- TOC entry 203 (class 1259 OID 16665)
-- Dependencies: 202 8
-- Name: biblio_records_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE biblio_records_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.biblio_records_id_seq OWNER TO biblivre;

--
-- TOC entry 2654 (class 0 OID 0)
-- Dependencies: 203
-- Name: biblio_records_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE biblio_records_id_seq OWNED BY biblio_records.id;


--
-- TOC entry 204 (class 1259 OID 16667)
-- Dependencies: 8
-- Name: biblio_search_results; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_search_results (
    search_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    record_id integer NOT NULL
);


ALTER TABLE single.biblio_search_results OWNER TO biblivre;

--
-- TOC entry 205 (class 1259 OID 16670)
-- Dependencies: 2185 8
-- Name: biblio_searches; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE biblio_searches (
    id integer NOT NULL,
    parameters text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.biblio_searches OWNER TO biblivre;

--
-- TOC entry 206 (class 1259 OID 16677)
-- Dependencies: 8 205
-- Name: biblio_searches_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE biblio_searches_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.biblio_searches_id_seq OWNER TO biblivre;

--
-- TOC entry 2655 (class 0 OID 0)
-- Dependencies: 206
-- Name: biblio_searches_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE biblio_searches_id_seq OWNED BY biblio_searches.id;


--
-- TOC entry 207 (class 1259 OID 16679)
-- Dependencies: 2187 2188 2189 8
-- Name: configurations; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE configurations (
    key character varying NOT NULL,
    value character varying NOT NULL,
    type character varying DEFAULT 'string'::character varying NOT NULL,
    required boolean DEFAULT false NOT NULL,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.configurations OWNER TO biblivre;

--
-- TOC entry 208 (class 1259 OID 16688)
-- Dependencies: 2190 8
-- Name: digital_media; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE digital_media (
    id integer NOT NULL,
    name character varying,
    blob oid NOT NULL,
    content_type character varying,
    size bigint,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.digital_media OWNER TO biblivre;

--
-- TOC entry 209 (class 1259 OID 16695)
-- Dependencies: 208 8
-- Name: digital_media_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE digital_media_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.digital_media_id_seq OWNER TO biblivre;

--
-- TOC entry 2656 (class 0 OID 0)
-- Dependencies: 209
-- Name: digital_media_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE digital_media_id_seq OWNED BY digital_media.id;


--
-- TOC entry 210 (class 1259 OID 16697)
-- Dependencies: 2192 8
-- Name: holding_creation_counter; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE holding_creation_counter (
    id integer NOT NULL,
    user_name character varying(255) NOT NULL,
    user_login character varying(100),
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer NOT NULL
);


ALTER TABLE single.holding_creation_counter OWNER TO biblivre;

--
-- TOC entry 211 (class 1259 OID 16701)
-- Dependencies: 210 8
-- Name: holding_creation_counter_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE holding_creation_counter_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.holding_creation_counter_id_seq OWNER TO biblivre;

--
-- TOC entry 2657 (class 0 OID 0)
-- Dependencies: 211
-- Name: holding_creation_counter_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE holding_creation_counter_id_seq OWNED BY holding_creation_counter.id;


--
-- TOC entry 212 (class 1259 OID 16703)
-- Dependencies: 2194 2195 2196 2197 8
-- Name: holding_form_datafields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE holding_form_datafields (
    datafield character(3) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    indicator_1 character varying,
    indicator_2 character varying,
    material_type character varying,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.holding_form_datafields OWNER TO biblivre;

--
-- TOC entry 213 (class 1259 OID 16713)
-- Dependencies: 2198 2199 2200 2201 2202 8
-- Name: holding_form_subfields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE holding_form_subfields (
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    autocomplete_type character varying DEFAULT 'disabled'::character varying NOT NULL
);


ALTER TABLE single.holding_form_subfields OWNER TO biblivre;

--
-- TOC entry 214 (class 1259 OID 16724)
-- Dependencies: 2203 8
-- Name: lending_fines; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE lending_fines (
    id integer NOT NULL,
    lending_id integer NOT NULL,
    user_id integer NOT NULL,
    fine_value real NOT NULL,
    payment_date timestamp without time zone,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.lending_fines OWNER TO biblivre;

--
-- TOC entry 215 (class 1259 OID 16728)
-- Dependencies: 214 8
-- Name: lending_fines_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE lending_fines_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.lending_fines_id_seq OWNER TO biblivre;

--
-- TOC entry 2658 (class 0 OID 0)
-- Dependencies: 215
-- Name: lending_fines_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE lending_fines_id_seq OWNED BY lending_fines.id;


--
-- TOC entry 216 (class 1259 OID 16730)
-- Dependencies: 2205 8
-- Name: lendings; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE lendings (
    id integer NOT NULL,
    holding_id integer NOT NULL,
    user_id integer NOT NULL,
    previous_lending_id integer,
    expected_return_date timestamp without time zone,
    return_date timestamp without time zone,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.lendings OWNER TO biblivre;

--
-- TOC entry 217 (class 1259 OID 16734)
-- Dependencies: 216 8
-- Name: lendings_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE lendings_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.lendings_id_seq OWNER TO biblivre;

--
-- TOC entry 2659 (class 0 OID 0)
-- Dependencies: 217
-- Name: lendings_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE lendings_id_seq OWNED BY lendings.id;


--
-- TOC entry 218 (class 1259 OID 16736)
-- Dependencies: 2207 2208 2209 8
-- Name: logins; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE logins (
    id integer NOT NULL,
    login character varying NOT NULL,
    employee boolean DEFAULT false NOT NULL,
    password text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.logins OWNER TO biblivre;

--
-- TOC entry 219 (class 1259 OID 16745)
-- Dependencies: 8 218
-- Name: logins_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE logins_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.logins_id_seq OWNER TO biblivre;

--
-- TOC entry 2660 (class 0 OID 0)
-- Dependencies: 219
-- Name: logins_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE logins_id_seq OWNED BY logins.id;


--
-- TOC entry 220 (class 1259 OID 16747)
-- Dependencies: 2211 2212 2213 2214 8
-- Name: orders; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE orders (
    id integer NOT NULL,
    info text,
    status character varying,
    invoice_number character varying,
    receipt_date timestamp without time zone DEFAULT now(),
    total_value numeric,
    delivered_quantity integer,
    terms_of_payment character varying,
    deadline_date timestamp without time zone DEFAULT now() NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    quotation_id integer NOT NULL
);


ALTER TABLE single.orders OWNER TO biblivre;

--
-- TOC entry 221 (class 1259 OID 16757)
-- Dependencies: 8 220
-- Name: orders_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE orders_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.orders_id_seq OWNER TO biblivre;

--
-- TOC entry 2661 (class 0 OID 0)
-- Dependencies: 221
-- Name: orders_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE orders_id_seq OWNED BY orders.id;


--
-- TOC entry 222 (class 1259 OID 16759)
-- Dependencies: 8
-- Name: permissions; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE permissions (
    login_id integer NOT NULL,
    permission character varying(80) NOT NULL
);


ALTER TABLE single.permissions OWNER TO biblivre;

--
-- TOC entry 223 (class 1259 OID 16762)
-- Dependencies: 8
-- Name: quotations_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE quotations_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.quotations_id_seq OWNER TO biblivre;

--
-- TOC entry 224 (class 1259 OID 16764)
-- Dependencies: 2216 2217 2218 8
-- Name: quotations; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE quotations (
    id integer DEFAULT nextval('quotations_id_seq'::regclass) NOT NULL,
    supplier_id integer NOT NULL,
    response_date timestamp without time zone,
    expiration_date timestamp without time zone,
    delivery_time integer,
    info text,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.quotations OWNER TO biblivre;

--
-- TOC entry 225 (class 1259 OID 16773)
-- Dependencies: 8
-- Name: request_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE request_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.request_id_seq OWNER TO biblivre;

--
-- TOC entry 226 (class 1259 OID 16775)
-- Dependencies: 8
-- Name: request_quotation; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE request_quotation (
    request_id integer NOT NULL,
    quotation_id integer NOT NULL,
    quotation_quantity integer,
    unit_value numeric,
    response_quantity integer
);


ALTER TABLE single.request_quotation OWNER TO biblivre;

--
-- TOC entry 227 (class 1259 OID 16781)
-- Dependencies: 2219 2220 2221 8
-- Name: requests; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE requests (
    id integer DEFAULT nextval('request_id_seq'::regclass) NOT NULL,
    requester character varying,
    author character varying,
    item_title character varying,
    item_subtitle character varying,
    edition_number character varying,
    publisher character varying,
    info text,
    status character varying,
    quantity integer,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.requests OWNER TO biblivre;

--
-- TOC entry 228 (class 1259 OID 16790)
-- Dependencies: 2222 8
-- Name: reservations; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE reservations (
    id integer NOT NULL,
    record_id integer NOT NULL,
    user_id integer NOT NULL,
    expires timestamp without time zone,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.reservations OWNER TO biblivre;

--
-- TOC entry 229 (class 1259 OID 16794)
-- Dependencies: 8 228
-- Name: reservations_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE reservations_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.reservations_id_seq OWNER TO biblivre;

--
-- TOC entry 2662 (class 0 OID 0)
-- Dependencies: 229
-- Name: reservations_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE reservations_id_seq OWNED BY reservations.id;


--
-- TOC entry 230 (class 1259 OID 16796)
-- Dependencies: 8
-- Name: supplier_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE supplier_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.supplier_id_seq OWNER TO biblivre;

--
-- TOC entry 231 (class 1259 OID 16798)
-- Dependencies: 2224 2225 2226 8
-- Name: suppliers; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE suppliers (
    id integer DEFAULT nextval('supplier_id_seq'::regclass) NOT NULL,
    trademark character varying NOT NULL,
    supplier_name character varying,
    supplier_number character varying NOT NULL,
    vat_registration_number character varying,
    address character varying,
    address_number character varying,
    address_complement character varying,
    area character varying,
    city character varying,
    state character varying,
    country character varying,
    zip_code character varying,
    telephone_1 character varying,
    telephone_2 character varying,
    telephone_3 character varying,
    telephone_4 character varying,
    contact_1 character varying,
    contact_2 character varying,
    contact_3 character varying,
    contact_4 character varying,
    info character varying,
    url character varying,
    email character varying,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.suppliers OWNER TO biblivre;

--
-- TOC entry 232 (class 1259 OID 16807)
-- Dependencies: 2227 2228 2229 8
-- Name: translations; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE translations (
    language character varying NOT NULL,
    key character varying NOT NULL,
    text text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    user_created boolean DEFAULT false NOT NULL
);


ALTER TABLE single.translations OWNER TO biblivre;

--
-- TOC entry 233 (class 1259 OID 16816)
-- Dependencies: 2230 2231 2232 8
-- Name: users; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE users (
    id integer NOT NULL,
    name character varying NOT NULL,
    type integer,
    photo_id character varying,
    status character varying NOT NULL,
    login_id integer,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    user_card_printed boolean DEFAULT false,
    name_ascii character varying
);


ALTER TABLE single.users OWNER TO biblivre;

--
-- TOC entry 234 (class 1259 OID 16825)
-- Dependencies: 2234 2235 2236 2237 8
-- Name: users_fields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE users_fields (
    key character varying NOT NULL,
    type character varying NOT NULL,
    required boolean DEFAULT false NOT NULL,
    max_length integer DEFAULT 0 NOT NULL,
    sort_order integer,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.users_fields OWNER TO biblivre;

--
-- TOC entry 235 (class 1259 OID 16835)
-- Dependencies: 8 233
-- Name: users_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE users_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.users_id_seq OWNER TO biblivre;

--
-- TOC entry 2663 (class 0 OID 0)
-- Dependencies: 235
-- Name: users_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE users_id_seq OWNED BY users.id;


--
-- TOC entry 236 (class 1259 OID 16837)
-- Dependencies: 2238 2239 2240 8
-- Name: users_types; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE users_types (
    id integer NOT NULL,
    name character varying NOT NULL,
    description character varying,
    lending_limit integer,
    reservation_limit integer,
    lending_time_limit integer,
    reservation_time_limit integer,
    fine_value real DEFAULT 0.00 NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.users_types OWNER TO biblivre;

--
-- TOC entry 237 (class 1259 OID 16846)
-- Dependencies: 236 8
-- Name: users_types_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE users_types_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.users_types_id_seq OWNER TO biblivre;

--
-- TOC entry 2664 (class 0 OID 0)
-- Dependencies: 237
-- Name: users_types_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE users_types_id_seq OWNED BY users_types.id;


--
-- TOC entry 238 (class 1259 OID 16848)
-- Dependencies: 8
-- Name: users_values; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE users_values (
    user_id integer NOT NULL,
    key character varying NOT NULL,
    value character varying NOT NULL,
    ascii character varying
);


ALTER TABLE single.users_values OWNER TO biblivre;

--
-- TOC entry 255 (class 1259 OID 17216)
-- Dependencies: 8
-- Name: versions; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE versions (
    installed_versions character varying NOT NULL
);


ALTER TABLE single.versions OWNER TO biblivre;

--
-- TOC entry 239 (class 1259 OID 16854)
-- Dependencies: 2242 2243 8
-- Name: vocabulary_brief_formats; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_brief_formats (
    datafield character(3) NOT NULL,
    format text NOT NULL,
    sort_order integer,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.vocabulary_brief_formats OWNER TO biblivre;

--
-- TOC entry 240 (class 1259 OID 16862)
-- Dependencies: 2244 2245 2246 2247 8
-- Name: vocabulary_form_datafields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_form_datafields (
    datafield character(3) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    indicator_1 character varying,
    indicator_2 character varying,
    material_type character varying,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.vocabulary_form_datafields OWNER TO biblivre;

--
-- TOC entry 241 (class 1259 OID 16872)
-- Dependencies: 2248 2249 2250 2251 2252 8
-- Name: vocabulary_form_subfields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_form_subfields (
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    collapsed boolean DEFAULT false NOT NULL,
    repeatable boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer,
    autocomplete_type character varying DEFAULT 'disabled'::character varying NOT NULL
);


ALTER TABLE single.vocabulary_form_subfields OWNER TO biblivre;

--
-- TOC entry 242 (class 1259 OID 16883)
-- Dependencies: 8
-- Name: vocabulary_idx_autocomplete; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_idx_autocomplete (
    id integer NOT NULL,
    datafield character(3) NOT NULL,
    subfield character(1) NOT NULL,
    word character varying NOT NULL,
    phrase character varying NOT NULL,
    record_id integer
);


ALTER TABLE single.vocabulary_idx_autocomplete OWNER TO biblivre;

--
-- TOC entry 243 (class 1259 OID 16889)
-- Dependencies: 242 8
-- Name: vocabulary_idx_autocomplete_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE vocabulary_idx_autocomplete_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.vocabulary_idx_autocomplete_id_seq OWNER TO biblivre;

--
-- TOC entry 2665 (class 0 OID 0)
-- Dependencies: 243
-- Name: vocabulary_idx_autocomplete_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE vocabulary_idx_autocomplete_id_seq OWNED BY vocabulary_idx_autocomplete.id;


--
-- TOC entry 244 (class 1259 OID 16891)
-- Dependencies: 8
-- Name: vocabulary_idx_fields; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_idx_fields (
    record_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    word character varying NOT NULL,
    datafield integer NOT NULL
);


ALTER TABLE single.vocabulary_idx_fields OWNER TO biblivre;

--
-- TOC entry 245 (class 1259 OID 16897)
-- Dependencies: 8
-- Name: vocabulary_idx_sort; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_idx_sort (
    record_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    phrase character varying,
    ignore_chars_count integer
);


ALTER TABLE single.vocabulary_idx_sort OWNER TO biblivre;

--
-- TOC entry 246 (class 1259 OID 16903)
-- Dependencies: 2254 2255 2256 2257 8
-- Name: vocabulary_indexing_groups; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_indexing_groups (
    id integer NOT NULL,
    translation_key character varying NOT NULL,
    datafields text,
    sortable boolean DEFAULT false NOT NULL,
    default_sort boolean DEFAULT false NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.vocabulary_indexing_groups OWNER TO biblivre;

--
-- TOC entry 247 (class 1259 OID 16913)
-- Dependencies: 8 246
-- Name: vocabulary_indexing_groups_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE vocabulary_indexing_groups_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.vocabulary_indexing_groups_id_seq OWNER TO biblivre;

--
-- TOC entry 2666 (class 0 OID 0)
-- Dependencies: 247
-- Name: vocabulary_indexing_groups_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE vocabulary_indexing_groups_id_seq OWNED BY vocabulary_indexing_groups.id;


--
-- TOC entry 248 (class 1259 OID 16915)
-- Dependencies: 2259 2260 2261 8
-- Name: vocabulary_records; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_records (
    id integer NOT NULL,
    iso2709 text NOT NULL,
    material character varying(20),
    database character varying(10) DEFAULT 'main'::character varying NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer,
    modified timestamp without time zone DEFAULT now() NOT NULL,
    modified_by integer
);


ALTER TABLE single.vocabulary_records OWNER TO biblivre;

--
-- TOC entry 249 (class 1259 OID 16924)
-- Dependencies: 8 248
-- Name: vocabulary_records_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE vocabulary_records_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.vocabulary_records_id_seq OWNER TO biblivre;

--
-- TOC entry 2667 (class 0 OID 0)
-- Dependencies: 249
-- Name: vocabulary_records_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE vocabulary_records_id_seq OWNED BY vocabulary_records.id;


--
-- TOC entry 250 (class 1259 OID 16926)
-- Dependencies: 8
-- Name: vocabulary_search_results; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_search_results (
    search_id integer NOT NULL,
    indexing_group_id integer NOT NULL,
    record_id integer NOT NULL
);


ALTER TABLE single.vocabulary_search_results OWNER TO biblivre;

--
-- TOC entry 251 (class 1259 OID 16929)
-- Dependencies: 2263 8
-- Name: vocabulary_searches; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE vocabulary_searches (
    id integer NOT NULL,
    parameters text NOT NULL,
    created timestamp without time zone DEFAULT now() NOT NULL,
    created_by integer
);


ALTER TABLE single.vocabulary_searches OWNER TO biblivre;

--
-- TOC entry 252 (class 1259 OID 16936)
-- Dependencies: 8 251
-- Name: vocabulary_searches_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE vocabulary_searches_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.vocabulary_searches_id_seq OWNER TO biblivre;

--
-- TOC entry 2668 (class 0 OID 0)
-- Dependencies: 252
-- Name: vocabulary_searches_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE vocabulary_searches_id_seq OWNED BY vocabulary_searches.id;


--
-- TOC entry 253 (class 1259 OID 16938)
-- Dependencies: 2265 8
-- Name: z3950_addresses; Type: TABLE; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE TABLE z3950_addresses (
    id integer NOT NULL,
    name character varying NOT NULL,
    url character varying NOT NULL,
    port integer NOT NULL,
    collection character varying DEFAULT 'default'::character varying NOT NULL
);


ALTER TABLE single.z3950_addresses OWNER TO biblivre;

--
-- TOC entry 254 (class 1259 OID 16945)
-- Dependencies: 253 8
-- Name: z3950_addresses_id_seq; Type: SEQUENCE; Schema: single; Owner: biblivre
--

CREATE SEQUENCE z3950_addresses_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE single.z3950_addresses_id_seq OWNER TO biblivre;

--
-- TOC entry 2669 (class 0 OID 0)
-- Dependencies: 254
-- Name: z3950_addresses_id_seq; Type: SEQUENCE OWNED BY; Schema: single; Owner: biblivre
--

ALTER SEQUENCE z3950_addresses_id_seq OWNED BY z3950_addresses.id;


SET search_path = global, pg_catalog;

--
-- TOC entry 2120 (class 2604 OID 16429)
-- Dependencies: 167 166
-- Name: id; Type: DEFAULT; Schema: global; Owner: biblivre
--

ALTER TABLE ONLY backups ALTER COLUMN id SET DEFAULT nextval('backups_id_seq'::regclass);


--
-- TOC entry 2117 (class 2604 OID 16452)
-- Dependencies: 165 164
-- Name: id; Type: DEFAULT; Schema: global; Owner: biblivre
--

ALTER TABLE ONLY logins ALTER COLUMN id SET DEFAULT nextval('logins_id_seq'::regclass);


SET search_path = single, pg_catalog;

--
-- TOC entry 2143 (class 2604 OID 16947)
-- Dependencies: 179 178
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY authorities_idx_autocomplete ALTER COLUMN id SET DEFAULT nextval('authorities_idx_autocomplete_id_seq'::regclass);


--
-- TOC entry 2148 (class 2604 OID 16948)
-- Dependencies: 183 182
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY authorities_indexing_groups ALTER COLUMN id SET DEFAULT nextval('authorities_indexing_groups_id_seq'::regclass);


--
-- TOC entry 2152 (class 2604 OID 16949)
-- Dependencies: 185 184
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY authorities_records ALTER COLUMN id SET DEFAULT nextval('authorities_records_id_seq'::regclass);


--
-- TOC entry 2154 (class 2604 OID 16950)
-- Dependencies: 188 187
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY authorities_searches ALTER COLUMN id SET DEFAULT nextval('authorities_searches_id_seq'::regclass);


--
-- TOC entry 2157 (class 2604 OID 16951)
-- Dependencies: 190 189
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY backups ALTER COLUMN id SET DEFAULT nextval('backups_id_seq'::regclass);


--
-- TOC entry 2174 (class 2604 OID 16952)
-- Dependencies: 195 194
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_holdings ALTER COLUMN id SET DEFAULT nextval('biblio_holdings_id_seq'::regclass);


--
-- TOC entry 2175 (class 2604 OID 16953)
-- Dependencies: 197 196
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_idx_autocomplete ALTER COLUMN id SET DEFAULT nextval('biblio_idx_autocomplete_id_seq'::regclass);


--
-- TOC entry 2180 (class 2604 OID 16954)
-- Dependencies: 201 200
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_indexing_groups ALTER COLUMN id SET DEFAULT nextval('biblio_indexing_groups_id_seq'::regclass);


--
-- TOC entry 2184 (class 2604 OID 16955)
-- Dependencies: 203 202
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_records ALTER COLUMN id SET DEFAULT nextval('biblio_records_id_seq'::regclass);


--
-- TOC entry 2186 (class 2604 OID 16956)
-- Dependencies: 206 205
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_searches ALTER COLUMN id SET DEFAULT nextval('biblio_searches_id_seq'::regclass);


--
-- TOC entry 2191 (class 2604 OID 16957)
-- Dependencies: 209 208
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY digital_media ALTER COLUMN id SET DEFAULT nextval('digital_media_id_seq'::regclass);


--
-- TOC entry 2193 (class 2604 OID 16958)
-- Dependencies: 211 210
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY holding_creation_counter ALTER COLUMN id SET DEFAULT nextval('holding_creation_counter_id_seq'::regclass);


--
-- TOC entry 2204 (class 2604 OID 16959)
-- Dependencies: 215 214
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lending_fines ALTER COLUMN id SET DEFAULT nextval('lending_fines_id_seq'::regclass);


--
-- TOC entry 2206 (class 2604 OID 16960)
-- Dependencies: 217 216
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lendings ALTER COLUMN id SET DEFAULT nextval('lendings_id_seq'::regclass);


--
-- TOC entry 2210 (class 2604 OID 16961)
-- Dependencies: 219 218
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY logins ALTER COLUMN id SET DEFAULT nextval('logins_id_seq'::regclass);


--
-- TOC entry 2215 (class 2604 OID 16962)
-- Dependencies: 221 220
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY orders ALTER COLUMN id SET DEFAULT nextval('orders_id_seq'::regclass);


--
-- TOC entry 2223 (class 2604 OID 16963)
-- Dependencies: 229 228
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY reservations ALTER COLUMN id SET DEFAULT nextval('reservations_id_seq'::regclass);


--
-- TOC entry 2233 (class 2604 OID 16964)
-- Dependencies: 235 233
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY users ALTER COLUMN id SET DEFAULT nextval('users_id_seq'::regclass);


--
-- TOC entry 2241 (class 2604 OID 16965)
-- Dependencies: 237 236
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY users_types ALTER COLUMN id SET DEFAULT nextval('users_types_id_seq'::regclass);


--
-- TOC entry 2253 (class 2604 OID 16966)
-- Dependencies: 243 242
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY vocabulary_idx_autocomplete ALTER COLUMN id SET DEFAULT nextval('vocabulary_idx_autocomplete_id_seq'::regclass);


--
-- TOC entry 2258 (class 2604 OID 16967)
-- Dependencies: 247 246
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY vocabulary_indexing_groups ALTER COLUMN id SET DEFAULT nextval('vocabulary_indexing_groups_id_seq'::regclass);


--
-- TOC entry 2262 (class 2604 OID 16968)
-- Dependencies: 249 248
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY vocabulary_records ALTER COLUMN id SET DEFAULT nextval('vocabulary_records_id_seq'::regclass);


--
-- TOC entry 2264 (class 2604 OID 16969)
-- Dependencies: 252 251
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY vocabulary_searches ALTER COLUMN id SET DEFAULT nextval('vocabulary_searches_id_seq'::regclass);


--
-- TOC entry 2266 (class 2604 OID 16970)
-- Dependencies: 254 253
-- Name: id; Type: DEFAULT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY z3950_addresses ALTER COLUMN id SET DEFAULT nextval('z3950_addresses_id_seq'::regclass);


SET search_path = global, pg_catalog;

--
-- TOC entry 2546 (class 0 OID 16419)
-- Dependencies: 166 2636
-- Data for Name: backups; Type: TABLE DATA; Schema: global; Owner: biblivre
--

COPY backups (id, created, path, schemas, type, scope, downloaded, steps, current_step) FROM stdin;
\.


--
-- TOC entry 2670 (class 0 OID 0)
-- Dependencies: 167
-- Name: backups_id_seq; Type: SEQUENCE SET; Schema: global; Owner: biblivre
--

SELECT pg_catalog.setval('backups_id_seq', 1, false);


--
-- TOC entry 2543 (class 0 OID 16399)
-- Dependencies: 163 2636
-- Data for Name: configurations; Type: TABLE DATA; Schema: global; Owner: biblivre
--

COPY configurations (key, value, type, required, modified, modified_by) FROM stdin;
general.default_language	pt-BR	string	t	2013-04-13 13:37:22.871407	\N
search.results_per_page	25	integer	t	2013-04-13 13:37:22.871407	\N
search.result_limit	6000	integer	t	2013-04-13 13:37:22.871407	\N
general.currency	R$	string	t	2014-02-22 15:20:28.594713	\N
cataloging.accession_number_prefix	Bib	string	t	2014-02-22 15:20:56.235706	\N
search.distributed_search_limit	100	integer	t	2014-02-22 15:21:15.676016	\N
general.business_days	2,3,4,5,6	string	t	2014-02-22 15:22:11.189584	\N
general.uid		string	f	2014-05-21 21:46:46.702	0
general.multi_schema	false	boolean	t	2014-06-14 18:32:29.586269	1
general.psql_path		string	f	2014-06-21 11:40:03.8973	1
general.pg_dump_path		string	f	2014-06-21 11:40:03.8973	1
general.backup_path		string	f	2014-06-21 11:40:03.8973	1
general.title	Biblivre IV	string	t	2014-06-21 11:42:07.150326	1
general.subtitle	Software Livre para Gestão de Bibliotecas	string	f	2014-06-21 11:42:07.150326	1
\.


--
-- TOC entry 2544 (class 0 OID 16408)
-- Dependencies: 164 2636
-- Data for Name: logins; Type: TABLE DATA; Schema: global; Owner: biblivre
--

COPY logins (id, login, employee, password, created, created_by, modified, modified_by) FROM stdin;
1	admin	t	C4wx3TpMHnSwdk1bUQ/V6qwAQmw=	2013-04-13 13:38:46.652058	\N	2014-06-21 11:40:36.422497	1
\.


--
-- TOC entry 2671 (class 0 OID 0)
-- Dependencies: 165
-- Name: logins_id_seq; Type: SEQUENCE SET; Schema: global; Owner: biblivre
--

SELECT pg_catalog.setval('logins_id_seq', 2, false);


--
-- TOC entry 2548 (class 0 OID 16430)
-- Dependencies: 168 2636
-- Data for Name: schemas; Type: TABLE DATA; Schema: global; Owner: biblivre
--

COPY schemas (schema, name, disabled) FROM stdin;
single	Biblivre IV	f
\.


--
-- TOC entry 2549 (class 0 OID 16437)
-- Dependencies: 169 2636
-- Data for Name: translations; Type: TABLE DATA; Schema: global; Owner: biblivre
--

COPY translations (language, key, text, created, created_by, modified, modified_by, user_created) FROM stdin;
pt-BR	multi_schema.configuration.description.general.title	Nomo que será exibido quando a página principal deste grupo de bibliotecas for acessada. Esta página listará todas as bibliotecas cadastradas neste grupo (gerenciadas pelo mesmo Biblivre 4).	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	multi_schema.configuration.title.general.title	Nome deste Grupo de Bibliotecas	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	multi_schema.configurations.page_help	A rotina de Configurações de Multi-bibliotecas permite alterar configurações globais do grupo de bibliotecas e configurações padrão que serão usadas pelas bibliotecas cadastradas. Todas as configurações marcadas com um asterisco (*) serão usadas por padrão em novas bibliotecas cadastradas neste grupo, mas podem ser alteradas internamente pelos administradores, através da opção <em>"Administração"</em>, <em>"Configurações"</em>, no menu superior.	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	menu.multi_schema_translations	Traduções	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	multi_schema.translations.page_help	<p>O módulo de <strong>"Traduções"</strong> de Multi-bibliotecas funciona de forma análoga a sua versão de uma única biblioteca, porém, textos alterados por aqui serão aplicados a todas as bibliotecas do grupo, desde que estas não tenham alterado o valor original de cada tradução.</p>\n<p>Por exemplo, se você alterar a tradução da chave <strong>"menu.search"</strong> de "Pesquisa" para "Busca" pelo módulo de traduções multi-bibliotecas, todas as bibliotecas deste grupo verão a nova tradução. Porém, se um dos administradores de uma destas bibliotecas alterar, através do módulo de <strong>"Traduções"</strong> de sua biblioteca, a mesma chave para "Procurar", esta tradução interna terá prioridade, apenas para esta biblioteca.</p>\n<p>Para adicionar um novo idioma, baixe o arquivo de idioma em Português, faça a tradução dos textos e depois faça o envio do arquivo. Lembre-se que apenas os <strong>textos</strong> (depois do sinal de igual) devem ser alterados.  Não altere as chaves, ou o Biblivre 4 não conseguirá localizar o texto</p>\n<p>Exemplo: digamos que você queira alterar o texto no menu principal de <i>Pesquisa</i> para <i>Busca</i>.  Você deverá então baixar o arquivo do idioma e alterar a seguinte linha:</p>\n<p><strong>*menu.search</strong> = Pesquisa</p>\n<p>Para:</p>\n<p><strong>*menu.search</strong> = Busca</p>\n<p>E então fazer o Envio do arquivo de idiomas. O Biblivre 4 irá processar o arquivo, e alterar o texto do menu.</p>	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	multi_schema.configuration.title.general.subtitle	Subtítulo deste Grupo de Bibliotecas	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	multi_schema.configuration.description.general.subtitle	Subtítulo que será exibido quando a página principal deste grupo de bibliotecas for acessada. Esta página listará todas as bibliotecas cadastradas neste grupo (gerenciadas pelo mesmo Biblivre 4).	2014-06-21 11:54:49.572182	1	2014-06-21 11:54:49.572182	1	f
pt-BR	menu.administration_access_cards	Cartões de Acesso	2014-06-21 12:23:05.099501	1	2014-06-21 12:23:05.099501	1	f
pt-BR	multi_schema.manage.disable	Desabilitar biblioteca	2014-06-21 17:04:41.838396	1	2014-06-21 17:35:14.546952	1	f
pt-BR	multi_schema.manage.enable	Habilitar biblioteca	2014-06-21 17:04:41.838396	1	2014-06-21 17:35:14.546952	1	f
pt-BR	circulation.user_reservation.page_help	<p>Para realizar uma reserva, você deverá selecionar o registro que será reservado. Para encontrar o registro, realize uma pesquisa similar à pesquisa bibliográfica.</p>	2014-07-05 11:47:02.155561	1	2014-07-05 11:47:02.155561	1	f
pt-BR	warning.download_site	Ir para o site de downloads	2014-07-05 11:47:02.155561	1	2014-07-05 11:47:02.155561	1	f
pt-BR	administration.configurations.error.invalid	O valor especificado para uma das configurações não é valido, verifique os erros abaixo	2014-06-14 19:34:08.805257	1	2014-07-05 11:47:02.155561	1	f
pt-BR	menu.circulation_user_reservation	Reservas do Leitor	2014-07-05 11:47:02.155561	1	2014-07-05 11:47:02.155561	1	f
pt-BR	administration.permissions.items.circulation_user_reservation	Efetuar Reserva para si mesmo	2014-07-05 11:47:02.155561	1	2014-07-05 11:47:02.155561	1	f
pt-BR	administration.configuration.title.logged_in_text	Texto inicial para usuários logados	2014-07-12 11:21:42.419959	1	2014-07-12 11:21:42.419959	1	f
pt-BR	warning.new_version	Já está disponível uma atualização para o Biblivre 4<br/>Versão instalada: {0}. Versão mais recente: {1}	2014-07-05 11:47:02.155561	1	2014-07-05 17:20:32.670746	1	f
pt-BR	administration.configuration.title.logged_out_text	Texto inicial para usuários não logados	2014-07-12 11:21:42.419959	1	2014-07-12 11:21:42.419959	1	f
pt-BR	multi_schema.manage.new_schema.field.subtitle	Subtítulo da biblioteca	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.page_help	A tela de multi-bibliotecas permite cadastrar diversas bibliotecas para serem gerenciadas por um único Biblivre. A partir do momento que você habilitar o sistema de multi-bibliotecas, a lista de bibliotecas cadastradas será exibida sempre que alguém entrar no endereço padrão do Biblivre 4.	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
es	marc.bibliographic.datafield.700.subfield.b	Numeración que sigue al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.error.save	Falla al guardar la cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.subfield.e	Relación con el documento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding.holding_acquisition_type	Tipo de Adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.type	Tipo de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.title.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.1.1	Genera entrada para el título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.1.0	No genera entrada para el título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.680.subfield.a	Nota de alcance	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field_count.description	<p>Luego de seleccionar el campo Marc y la Ordenación, realice la búsqueda bibliográfica que servirá de base para el Informe, o haga click en <strong>Emitir Informe</strong> para utilizar toda la base bibliográfica.</p>\n<p><strong>Atención:</strong> Este Informe puede llevar algunos minutos para ser generado, dependiendo del tamaño de la base bibliográfica.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.end_number	Número final	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.modified_between	Alterado entre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.form.hidden_subfields_singular	Exhibir subcampo oculto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	acquisition.request.field.author_numeration	Numeração que segue o prenome	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.maintenance.reinstall.confirm.description	Deseja ir para a tela de restauração e reconfiguração? Você poderá restaurar um backup do Biblivre 4, apagar os dados da sua biblioteca ou refazer uma migração.	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.setup.cancel	Cancelar	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.maintenance.reinstall.title	Restauração e Reconfiguração	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.setup.cancel.description	Clique no botão abaixo para desistir de restaurar esta instalação do Biblivre 4 e retornar à sua biblioteca.	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.maintenance.reinstall.button	Ir para a tela de restauração e reconfiguração	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.maintenance.reinstall.description	Use esta opção caso você queira restaurar um backup do Biblivre 4, apagar os dados da sua biblioteca ou refazer a migração do Biblivre 3. Você será enviado à tela inicial de instalação do Biblivre, onde poderá cancelar caso desista de fazer alterações.	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	acquisition.request.field.author_title	Título e outras palavras associadas ao nome	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	search.bibliographic.select_item_button	Selecionar registro	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.maintenance.reinstall.confirm.title	Ir para a tela de restauração e reconfiguração	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	acquisition.request.field.author_type	Tipo de Autor	2014-06-21 14:25:12.053902	1	2014-06-21 14:25:12.053902	1	f
pt-BR	administration.maintenance.reinstall.confirm.question	Atenção: Todas as opções farão com que os dados de sua biblioteca sejam apagados em favor dos dados recuperados. Recomenda-se fazer um backup antes de iniciar esta ação. Deseja continuar?	2014-06-21 14:25:12.053902	1	2014-06-21 17:04:41.838396	1	f
pt-BR	multi_schema.manage.error.cant_disable_last_library	Não é possível desabilitar todas as bibliotecas deste grupo. Ao menos uma deve ficar habilitada.	2014-06-21 17:35:14.546952	1	2014-06-21 17:35:14.546952	1	f
pt-BR	multi_schema.manage.error.toggle	Erro ao trocar estado da biblioteca.	2014-06-21 17:35:14.546952	1	2014-06-21 17:35:14.546952	1	f
pt-BR	multi_schema.configurations.error.disable_multi_schema_schema_count	Não é possível desabilitar o sistema de multi-bibliotecas enquanto houver mais de uma biblioteca habilitada.	2014-06-21 17:35:14.546952	1	2014-06-21 17:35:14.546952	1	f
pt-BR	multi_schema.configurations.error.disable_multi_schema_outside_global	Não é possível desabilitar o sistema de multi-bibliotecas de dentro de uma biblioteca.	2014-06-21 17:35:14.546952	1	2014-06-21 17:35:14.546952	1	f
pt-BR	cataloging.bibliographic.automatic_holding_help	<p>Utilize os campos abaixo para acelerar o processo de catalogação de exemplares. O preenchimento é opcional e nenhum exemplar será criado caso nenhum campo seja preenchido. Neste caso, você poderá criar exemplares manualmente, com o formulário completo, pela aba <em>Exemplares</em>.</p><p>Caso seja do seu interesse cadastrar exemplares agora, o único campo que precisa sempre ser preenchido é o Número de Exemplares. Para cada volume da obra serão criados esta quantidade selecionada de exemplares, portanto, se o registro bibliográfico possuir 3 volumes e você preencher o Número de Exemplares com o número 2 e o Número de Volumes da Obra com o número 3, serão criados 6 exemplares, 2 para o Volume 1, 2 para o Volume 2 e 2 para o Volume 3. Caso os exemplares sejam de apenas um volume, preencha o campo Número do Volume, e, caso a obra não tenha volumes, deixe ambos os campo em branco.</p>	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding.holding_count	Número de Exemplares	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding_title	Exemplares Automáticos	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding.holding_acquisition_date	Data de aquisição	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding.holding_library	Biblioteca Depositária	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	menu.self_circulation	Reservas	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding.holding_acquisition_type	Tipo de Aquisição	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding.holding_volume_number	Número do Volume	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	cataloging.bibliographic.automatic_holding.holding_volume_count	Quantidade de volumes da Obra	2014-07-05 17:20:32.670746	1	2014-07-05 17:20:32.670746	1	f
pt-BR	administration.configuration.description.logged_out_text	Texto que será exibido na tela inicial do Biblivre, para usuários que não tenham entrado com login e senha. Você pode usar tags HTML, mas cuidado para não quebrar o layout do Biblivre 4. Atenção: esta configuração está relacionada com o sistema de traduções. Alterações feitas nesta tela afetarão somente o idioma atual. Para alterar em outros idiomas, use a tela de traduções ou acesse o Biblivre usando o idioma a ser alterado.	2014-07-12 11:21:42.419959	1	2014-07-12 11:21:42.419959	1	f
pt-BR	administration.configuration.description.logged_in_text	Texto que será exibido na tela inicial do Biblivre, para usuários que tenham entrado com login e senha. Você pode usar tags HTML, mas cuidado para não quebrar o layout do Biblivre 4. O termo {0} será substituído pelo nome do usuário logado. Atenção: esta configuração está relacionada com o sistema de traduções. Alterações feitas nesta tela afetarão somente o idioma atual. Para alterar em outros idiomas, use a tela de traduções ou acesse o Biblivre usando o idioma a ser alterado.	2014-07-12 11:21:42.419959	1	2014-07-12 11:22:49.880351	1	f
es	administration.z3950.error.save	Falla al guardar el servidor z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_access_cards	Tarjetas de Acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.quantity	Cantidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_order_save	Guardar registro de pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_restore	Recuperar copia de seguridad de la base de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.id_rg	Identidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.download.button	Descargar el idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_user_reservation	Efectuar Reserva para sí mismo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	multi_schema.manage.error	Erro	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	multi_schema.manage.new_schema.title	Criação de Nova Biblioteca	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.new_schema.field.schema	Atalho da Biblioteca	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.new_schema.description	Para criar uma nova biblioteca, preencha abaixo seu nome e um subtítulo opcional. Você também precisará de um nome reduzido para a biblioteca, chamado de atalho, que será usado no endereço Web de acesso ao Biblivre 4, permitindo diferenciar as diversas bibliotecas instaladas no sistema. Este atalho deve conter apenas letras, números e o caractere _. Para facilitar, o Biblivre 4 irá sugerir um atalho automaticamente, baseado no nome da biblioteca.	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	menu.multi_schema_configurations	Configurações	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	menu.multi_schema_manage	Gerência de Bibliotecas	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.new_schema.field.title	Nome da biblioteca	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.new_schema.button.create	Criar Biblioteca	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	text.multi_schema.select_library	Lista de Bibliotecas	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	menu.multi_schema	Multi-bibliotecas	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.schemas.description	Abaixo estão todas as bibliotecas cadastradas neste Biblivre 4. Caso queira alterar um nome ou subtítulo, acesse a tela de configurações da biblioteca.	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
pt-BR	multi_schema.manage.schemas.title	Lista de Bibliotecas deste Servidor	2014-06-14 19:50:04.110972	1	2014-06-14 19:50:04.110972	1	f
es	cataloging.bibliographic.button.edit	Editar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.label_digital_media_only	Backup de archivos digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.reservation_time_limit	Plazo de reserva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	format.datetime_user_friendly	DD/MM/AAAA hh:mm	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_supplier_save	Guardar registro de proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_delete_record_title.inactive	Marcar usuario como "inactivo"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.operator	Operador	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.t	Título de la obra junto a la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.q	Forma completa del nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_delete_record_question.forever	¿Usted realmente desea excluir este registro de solicitud?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_710	Autor secundario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.record_will_be_ignored	Este registro no será importado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_711	Autor secundario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.d	Fechas asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.value_must_be_numeric	El valor de este campo debe ser un número	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.summary	Informe de Sumario del Catálogo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.550	TG (Término genérico)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.a	Apellido y/o nombre del autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.field.status	Situación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.id	Matrícula	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.b	Numeración que sigue al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.c	Título y otras palabras asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_remove_attachment_description	¿Usted desea excluir este archivo digital?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.simple_term_title	Rellene el Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	warning.reindex_database	Usted precisa reindizar las bases de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.groups.cataloging	Catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.user.select_item_button	Seleccionar registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.advanced_search	Búsqueda Bibliográfica Avanzada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.error.description	Lamentablemente ocurrió un error al restaurar este backup de Biblivre 4. Verifique la próxima pantalla por el log de errores y, en caso necesario, entre en el fórum Biblivre para obtener ayuda.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.amount	Cantidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.users_without_user_card	Listar solamente Usuarios que nunca tuvieron tarjeta impresa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_remove_attachment	Excluir archivo digital	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_delete_record_question	¿Usted realmente desea excluir este registro de solicitud?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.error.accession_number_unavailable	Este sello patrimonial ya está en uso por otro ejemplar. Por favor, rellene otro valor o deje en blanco para que el sistema calcule uno automáticamente.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_delete_record_title.forever	Excluir registro de solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.author_type.100	Persona	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.button.add	Agregar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.title.uncancel	Recuperar Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	menu.multi_schema_backup	Backup e Restauração	2014-07-19 11:28:35.848301	1	2014-07-19 11:28:35.848301	1	f
es	cataloging.bibliographic.button.export_records	Exportar registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_delete_record_title.forever	Excluir registro de proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation_user	Registro de Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	text.main.noscript		2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.dewey	Informe de Clasificación Dewey	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_reports	Informes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.digits	Dígitos significativos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.object_3d	Objeto 3D	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.cancel	Cancelar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.supplier	Proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.022.subfield.a	Número de ISSN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.title	Nombre de la biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013.subfield.e	Estado de la patente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.error.record_not_found	Registro no encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013.subfield.d	Fecha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013.subfield.f	Parte de un documento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_cancel_editing.2	Todas las alteraciones serán perdidas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de Pedido?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.256.subfield.a	Características del archivo de computadora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.date_from	De	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.date	Fecha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.button_exclude_digital_media	Crear backup sin archivos digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.psql_path	Camino para el programa psql	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging	Catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_913	Código Regional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013.subfield.a	Número	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013.subfield.b	País	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013.subfield.c	Tipo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.0	Ningún carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.description	Use esta opción en caso que usted quiera restaurar e importar un backup existente del Biblivre 3.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.upload_button	Enviar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.search.distributed_search_limit	Límite de resultados para búsquedas distribuidas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.default	Seleccione...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.490.indicator.1	Política de desdoblamiento de serie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.title.unit_value	Valor Unitario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.users_who_have_login_access	Listar solo Usuarios que poseen login de acceso al Biblivre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.email	Email	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation_user_cards	Impresión de Carnets	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.attachment.alias	Digite un nombre para este archivo digital	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.fieldset.title_info	Datos de la Obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.indicator.1.2	apellido compuesto (obsoleto)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.indicator.1.3	nombre de familia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.created	Fecha del Pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_730	Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.records_found_plural	{0} registros encontrados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	circulation.lending.receipt.lendings	Empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	cataloging.holding.error.shouldnt_delete_because_holding_is_or_was_lent	Este ejemplar está o ya fue prestado y no debe ser excluido. En caso que no este más disponible, el procedimiento correcto es cambiar su disponibilidad para No disponible. Si desea igualmente excluir este ejemplar, presione el botón <b>"Forzar Exclusión"</b>.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.no_permission	Usted no tiene permiso para ejecutar esta acción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.new	Nuevo usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding_help	<p>Utilice los campos abajo para acelerar el proceso de catalogación de ejemplares. El rellenado es opcional y no se creará ningún ejemplar en caso de no se rellene ningún campo. En este caso, usted podrá crear ejemplares manualmente, con el formulario completo, por la pestaña <em>Exemplares</em>.</p><p>En caso de ser de su interés registrar ejemplares ahora, el único campo que precisa ser rellenado siempre es el Número de Ejemplares. Para cada volumen de la obra se creará esta cantidad seleccionada de ejemplares, por lo tanto si el registro bibliográfico posee 3 volúmenes y usted rellena el Número de Ejemplares con el número 2 y el Número de Volúmenes de la Obra con el número 3, se crearán 6 ejemplares, 2 para el Volumen 1, 2 para el Volumen 2 y 2 para el Volumen 3. En caso de que los ejemplares sean de solamente un volumen, rellene el campo Número del Volumen, y, en caso de que la obra no tenga volúmenes, deje ambos campos en blanco.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.indicator.1.0	nombre simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.indicator.1.1	apellido simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.082	Clasificación Decimal Dewey	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.080	Clasificación Decimal Universal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.title_last_backups	Últimos Backups	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.lendings	Préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.indicator.1.8	No generar constante en la exhibición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.marc_popup.title	Editar Registro MARC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.arrival_time	Fecha de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.success.update	Registro alterado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.dewey	Clasificación Dewey	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.title.requisition	Solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.indicator.1.0	Índice remisivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.save	Guardar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.1.0	No genera entrada para el título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.1.1	Genera entrada para el título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.save	Guardar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_z3950_delete	Excluir registro de servidor z3950	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.fine_value	Valor de la multa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.095	Área de conocimiento de CNPq	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.error.no_users_found	Ningún usuario encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.090	Número de llamada - Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_delete_record_title	Excluir registro de cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.card_unavailable	Tarjeta no disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.simple_term_title	Rellena el Código de la Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.invalid_restore_path	El directorio configurado para la restauración de los archivos de backup no es válido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.pg_dump_path	Camino para el programa pg_dump	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.add_one_card	Registrar Nueva Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_z3950_save	Guardar registro de servidor z3950	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_move_record_description_plural	¿Usted realmente desea mover estos {0} registros?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.button.select_item	Seleccionar ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.isbn	ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.backup_path	Camino de destino de las copias de seguridad (Backups)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_300	Descripción física	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload.button	Enviar el idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.340.subfield.e	Soporte	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este usuario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.340.subfield.c	Materiales aplicados a la superficie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.340.subfield.d	Técnica en que se registra la información	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_306	Tiempo de duración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.340.subfield.a	Base y configuración del material	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.340.subfield.b	Dimensiones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.invalid_method_call	Llamada con método inválido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2._	ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_411	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_410	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.cataloging_bibliographic	Catálogo Bibliográfico y de Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore	Restaurar un Backup del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.issn	ISSN (incluyendo guiones)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.field.url	URL	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.2	Tesauro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.1	Nivel del Asunto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.help_manual	Manual	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.id	N&ordm; del registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.all_users	Informe de Todos los Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.invoice_number	N&ordm; de la Factura	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.indexing_groups.te_term	Término Específico (TE)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.450.subfield.a	Término tópico no usado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.description_last_backups_1	Abajo están los enlaces para download de los últimos backups realizados. Es importante guardarlos en un lugar seguro, pues esta es la única forma de recuperar sus datos, en caso de que sea necesario.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.description_last_backups_2	Estos archivos están guardados en el directorio especificado en la configuración del Biblivre (<em>"Administración"</em>, <em>"Configuraciones"</em>, en el menú superior). En caso que este directorio no esté disponible para la escritura en el momento del backup, un directorio temporal será usado en su lugar. Por este motivo, algunos de los backups pueden no estar disponibles luego de cierto tiempo. <span class="attention">Recomendamos siempre hacer un download del backup y guardarlo en un lugar seguro.</span>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.users.title	Buscar Lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.040.subfield.e	Fuentes convencionales de descripciones de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.logged_in_text	Texto inicial para usuarios logueados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.040.subfield.d	Agencia que alteró el registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.1.3	nombre de familia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.040.subfield.c	Agencia que transcribió el registro en formato legible por máquina	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.040.subfield.b	Idioma de la catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.040.subfield.a	Código de la Agencia Catalogadora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.1.0	nombre simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.1.1	apellido simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.invalid_json	El Biblivre no fue capaz de entender los datos recibidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.1.2	apellido compuesto (obsoleto)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	aquisition.request.error.request_not_found	No fue posible encontrar la requerimiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.database	Base	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.description.4	El Backup solamente de archivos digitales es una copia de todos los archivos de medio digital que fueron grabados en el Biblivre, sin ningún otro dato o información, como usuarios, base catalográfica, etc.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.description.3	El Backup sin archivos digitales es una copia de todos los datos e informaciones del Biblivre 4, <strong>excluyendo</strong> los archivos de medio digital. Por excluir los archivos de medio digital, el proceso tanto de backup cuanto de recuperación es más rápido, y el archivo de backup es menor.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.id_cpf	CPF	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.description.1	El Backup es un proceso donde ejecutamos la copia de informaciones para guardarlas en caso de algún problema en el sistema. Es una copia de los registros e informaciones del Biblivre. El Biblivre 4 posee 3 tipos de backup:	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.description.2	El Backup completo es una copia de todos los datos e informaciones del Biblivre 4, incluyendo los archivos de medio digital, como fotos de los usuarios, archivos digitales de los registros bibliográficos, etc.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.success.block	Tarjeta bloqueada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.error.delete	Falla al excluir el servidor z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.upload_popup.processing	Procesando...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.search.results_per_page	Esta configuración representa la cantidad máxima de resultados que serán exhibidos en una única página en las búsquedas del sistema. Un número muy grande podrá dejar el sistema más lento.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.d	Fecha de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.a	Nombre de la entidad o del lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.b	Unidades subordinadas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.password	Contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_name	Nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.button_digital_media_only	Crear backup de archivos digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.n	Número de la parte - sección de la obra - orden del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_status.active	Activo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.save	No fue posible guardar las traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.k	Subencabezamiento. (enmiendas, protocolos, selección, etc)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.g	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_400	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.subfield.t	Título de la obra junto a la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.confirm_description	¿Usted realmente desea restaurar este Backup?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.2	Tipo de entrada secundaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_move_record_title	Mover registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.custom_count	Informe de recuento del campo Marc	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_signup	Fecha de Matrícula	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.550.subfield.z	Subdivisión geográfica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.550.subfield.x	Subdivisión general adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.550.subfield.y	Subdivisión cronológica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.progress_popup.processing	El Biblivre de esta biblioteca está en manutención. Aguarde hasta que la misma sea concluida.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.dates	Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.page_help	<p>El módulo de <strong>"Migración de Datos"</strong> permite importar los datos que están en una base de datos del Biblivre 3 existente para la base de datos vacía del Biblivre 4.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.362.subfield.z	Fuente de información	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.error.user_not_found	Usuario no encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.users	Usuarios, Logins de acceso y Tipos de Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.step_1_description	En este paso, usted puede importar un archivo conteniendo registros en los formatos MARC, XML y ISO2709 o realizar una búsqueda en otras bibliotecas. Seleccione abajo el modo de importación deseado, seleccionando el archivo o rellenando los términos de la búsqueda. En el paso siguiente, usted podrá seleccionar cuales registros deberán ser importados.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_delete_record_question	¿Usted realmente desea excluir este registro de vocabulario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	header.law	Ley de Incentivo a la Cultura	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.printer_type.printer_24_columns	Impresora 24 columnas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.book	Libro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.database_count	Total de Registros en las Bases en el Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.913.subfield.a	Código Lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.acquisition	Fecha de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.source_file_subtitle	Seleccione un archivo conteniendo los registros a ser importados. El formato de este archivo puede ser <strong>texto</strong>, <strong>XML</strong> o <strong>ISO2709</strong>, desde que la catalogación original sea compatible con MARC.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_delete_record_question.forever	¿Usted realmente desea excluir este usuario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.670	Origen de las informaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.default_language	Idioma estándar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.default_language	Esta configuración representa el idioma padrón para la exhibición del Biblivre.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.1	Genera entrada secundaria en la ficha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.java_locale_not_available	No existe un identificador de idioma java para el archivo de traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.circulation.lending_receipt.printer.type	Esta configuración representa el tipo de impresora que será utilizada para la impresión de recibos de préstamos.  Los valores posibles son: impresora de 40 columnas, de 80 columnas, o impresora común (chorro de tinta).	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.685	Nota de historial o glosario (GLOSS)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.0	Parte del título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.field.port	Puerta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload.field.upload_file	Archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.680	Nota de alcance (NE)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.new_schema.field.subtitle	Subtítulo de la biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.invalid_language	Seleccione un idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.label.author_count	Cantidad de registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.5	Título adicional en carátula secundaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.6	Título de partida	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.7	Título corriente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.8	Título del lomo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.1	Título paralelo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.loading	Cargando	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.2	Título específico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.3	Otro título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2.4	Título de la tapa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.step_2_description	En este paso, verifique los registros que serán importados e impórtelos individualmente o en conjunto, a través de los botones disponibles al final de la página. El Biblivre detecta automáticamente si el registro es bibliográfico, autoridades o vocabulario, sin embargo permite que el usuario corrija antes de la importación. <strong>Importante:</strong> Los registros importados serán agregados a la Base de Trabajo y deberán ser corregidos y ajustados antes de ser movidos para la Base Principal. Eso evita que registros incorrectos sean agregados directamente a la base de datos final.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.terms_of_payment	Forma de pago	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_310	Peridiocidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.450	UP (remisiva para TE no usado)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.reserve_failure	Falla al reservar la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.550.subfield.a	Término tópico adoptado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.summary	Sumario del Catálogo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.dewey	Clasificación Decimal Dewey	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_reservation.page_help	<p>Para realizar una reserva, usted deberá selecionar el registro a ser reservado. Para encontrar el registro, realice una búsqueda similar a la búsqueda bibliográfica.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.040	Fuente de la Catalogación (NR)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.362.subfield.a	Información de Fechas de Publicación y/o Volumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.success.update	Proveedor guardado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.button.show_log	Exhibir log	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.page_help	<p>El módulo de <strong>"Traducciones"</strong> permite agregar nuevos idiomas al Biblivre 4 o alterar los textos ya existentes.</p>\n<p><strong>Atención: Este módulo realiza configuraciones avanzadas del Biblivre 4, y debe ser utilizado solamente por Usuarios avanzados, con experiencia en informática.</strong>.</p>\n<p>Para agregar un nuevo idioma, baje el archivo de idioma en portugués, haga la traducción de los textos y después envíe el archivo. Recuerde que solamente los <strong>textos</strong> (después del signo igual) deben ser alterados.  No altere las llaves, caso contrario el Biblivre 4 no conseguirá localizar el texto</p>\n<p>Ejemplo: digamos que usted quiera alterar el texto en el menú principal de <i>Búsqueda</i> para <i>Buscar</i>.  Usted deberá entonces bajar el archivo del idioma y alterar la siguiente línea:</p>\n<p><strong>*menu.search</strong> = Búsqueda</p>\n<p>Para:</p>\n<p><strong>*menu.search</strong> = Busca</p>\n<p>Y entonces hacer el envío del archivo de idiomas. El Biblivre 4 procesará el archivo, y alterará el texto del menú.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.current_password	Contraseña actual	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.subfield.v	Número del volumen o designación secuencial de la serie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.0	Clasificación de la LC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.error.select_reader_first	Para reservar un registro usted precisa, primeramente, seleccionar un lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.2	National Library of Medicine Classification	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.1	CDD	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.4	Localización fija	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.3	Superintendent of Documents classification	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.6	En parte separado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.description	Fue detectada una instalación del Biblivre 3 en esta computadora. Usted podrá importar estos datos para el Biblivre 4 seleccionando los items de interés y haciendo click en el botón abajo. Luego de la importación, <strong>usted deberá reindizar las tres bases: Bibliográfica, Autoridades y Vocabulario</strong>, a través de la pantalla <strong>"Manutención"</strong> em <strong>"Administración"</strong> y <strong>seleccionar nuevamente las autorizaciones de los empleados con acceso al Biblivre</strong>, a través de la pantalla <strong>"Logins y Permisos"</strong> en <strong>"Administración"</strong>.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.operator.and_not	y no	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.5	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.7	Clasificación específica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1.8	Otro esquema	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.periodic	Periódico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.subfield.a	Título Uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.edition	Edición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.name	Nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.all_users	Informe General de Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.949.subfield.a	Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.dewey	CDD	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.author_numeration	Numeración que sigue el prenombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.popup.title	Formato de las etiquetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.isbn_already_in_database	Ya existe un registro con este ISBN en la base de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.090.subfield.a	Clasificación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.success.delete	Registro excluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.090.subfield.b	Código del autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.090.subfield.c	Edición - volumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_040	Fuente de catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.090.subfield.d	Número del Ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.holdings_lent	Prestados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.search.result_limit	Esta configuración representa la cantidad máxima de resultados que serán encontrados en una búsqueda catalográfica. Este límite es importante para evitar lentitudes en el Biblivre en bibliotecas que posean una gran cantidad de registros. En caso de que la cantidad de resultados de la búsqueda del usuario exceda este límite, será recomendado que se mejoren los filtros de búsqueda.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.indicator.1._	Índice	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.record_imported_successfully	Registro importado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.buttons.dismiss_fine	Abonar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.returned_lendings	Préstamos devueltos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.257.subfield.a	País de la entidad productora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.back_to_search	Regresar a la búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_450	Término Use Para	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.invalid_database		2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.button.edit_marc	Editar MARC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.success.save	Servidor z39.50 guardado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.wait	Aguarde	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1._	Ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.music	Música	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630	Asunto - Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.success.delete	Servidor z39.50 excluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.t	Título de la obra junto a la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.n	Número de orden del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.status	Situación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_362	Fecha de la primera publicación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	language_code	es	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.e	Nombre de las subunidades del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.d	Fecha de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.670.subfield.b	Información encontrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.subfield.a	Nombre del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.fine_popup.title	Devolución atrasada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.670.subfield.a	Nombre retirado de	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.lending_date	Fecha de Préstamo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.buttons.pay_fine	Pagar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reinstall.confirm.description	¿Desea ir a la pantalla de restauración y reconfiguración? Usted podrá restaurar un backup del Biblivre 4, borrar los datos de su biblioteca o rehacer una migración.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.410.subfield.a	Nombre de la entidad o del lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.cataloging_vocabulary	Catálogo de Vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.page_help	<p>La rutina de Permisos permite la creación de Login y Contraseña para un usuario, así como la definición de sus permisos de acceso o utilización de las diversas rutinas del Biblivre.</p>\n<p>La búsqueda tratará de encontrar los Usuarios ya registrados en el Biblivre, y funciona de la misma manera que la búsqueda simplificada de la rutina de Registro de Usuarios.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.all	Cualquier campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.651	Asunto - Nombre geográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.650	Asunto - Tópico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.confirm_delete_record.forever	La Tarjeta será excluida permanentemente del sistema y no podrá ser recuperada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.help_faq	Preguntas Frecuentes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.subject	Asunto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.clean_install.description	En caso que usted no tenga o no desee restaurar un backup, esta opción permitirá iniciar el uso del Biblivre 4 con una base de datos vacía. Luego de entrar en el Biblivre 4 por primera vez, utilice el login <strong>admin</strong> y la contraseña <strong>abracadabra</strong> para entrar al sistema y configurar su nueva biblioteca.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.success.save	Tarjeta incluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	warning.download_site	Ir para el sitio de descargas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.acquisition_order	Pedidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_852	Notas públicas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.load	No fue posible leer el archivo de traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload_popup.title	Enviando Archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.id	Nro. Registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.error.no_request_found	No fue posible encontrar ninguna Solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_bibliographic_save	Guardar registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.original_value	Valor original	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.photo	Foto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_supplier_delete	Excluir registro de proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.confirm_delete_record_question.forever	¿Usted realmente desea excluir este Servidor Z39.50?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3migration.description	Fue detectada una instalación de Biblivre 3 en esta computadora. Usted podrá importar estos datos para el Biblivre 4 seleccionando los items de interés y haciendo click en el botón abajo. Luego de la importación, <strong>usted deberá reindizar las tres bases: Bibliográfica, Autoridades y Vocabulario</strong>, a través de la pantalla <strong>"Manutención"</strong> en <strong>"Administración"</strong> y <strong>seleccionar nuevamente las autorizaciones de los empleados con acceso al Biblivre</strong>, a través de la pantalla <strong>"Logins y Permisos"</strong> en <strong>"Administración"</strong>.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.z	Nota estándar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.q	Descripción del índice en multimedio	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.p	Descripción de la colección en multimedio	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.o	Descripción del índice en microfilm	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_830	Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.n	Descripción de la colección en microfilm	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.u	Descripción del índice en otros soportes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.pamphlet	Panfleto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.t	Descripción de la colección en otros soportes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.s	Descripción del índice en braile	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.r	Descripción de la colección en braile	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.i	Descripción del índice con acceso on-line	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.f	Código de la biblioteca en el CCN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.g	Descripción del índice de colección impresa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.l	Descripción de la colección en microficha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.m	Descripción del índice en microficha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.j	Descripción de la colección en CD-ROM	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.2	Tesauro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.issn	ISSN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.k	Descripción del índice en CD-ROM	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.1	Nivel del Asunto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.search_authorities	Autoridades	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610	Asunto - Entidad Colectiva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.a	Sigla de la biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.psql_path	Atención: Esta es una configuración avanzada, pero importante. El Biblivre intentará encontrar automáticamente el camino para el programa <strong>psql</strong> y, excepto en casos donde sea exhibido un error abajo, usted no precisará alterar esta configuración. Esta configuración representa el camino, en el servidor donde el Biblivre está instalado, para lo ejecutable <strong>psql</strong> que es distribuído junto al PostgreSQL. En caso que esta configuración estuviera inválida, el Biblivre no será capaz de generar y restaurar copias de seguridad.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611	Asunto - Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.d	Año de la última adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.e	Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.b	Descripción de la colección impresa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947.subfield.c	Tipo de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding.holding_volume_number	Número del Volumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	common.open	Abrir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	administration.maintenance.backup.error.no_schema_selected	Ninguna biblioteca seleccionada.	2014-07-19 11:28:46.69376	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.configuration.description.general.title	Nombre que será exhibido cuando se accede a la página principal de este grupo de bibliotecas. Esta página listará todas las bibliotecas registradas en este grupo (administradas por el mismo Biblivre 4).	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.card_in_use	Tarjeta en uso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.field_count	Recuento por campo Marc	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.041.subfield.b	Código de idioma del sumario o resumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.041.subfield.a	Código del idioma de texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_delete_record_question	¿Usted realmente desea excluir este registro de ejemplar?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.error.description	Infelizmente ocurrió un error al restaurar este backup del Biblivre 3. Verifique la próxima pantalla por el log de errores y, en caso necesario, entre en el fórum Biblivre para obtener ayuda.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.button_bibliographic	Reindizar base bibliográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.database.main	Principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600	Asunto - Nombre personal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.status	Situación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.041.subfield.h	Código de idioma del documento original	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.indicator.1.0	Fecha - período únicos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.indicator.1.2	Extensión de fechas - períodos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.indicator.1.1	Fecha - período múltiples	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.subject	Asunto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_delete_record.inactive	Saldrá de la lista de búsquedas y solo podrá ser encontrado a través de la "búsqueda avanzada", de donde podrá ser excluido permanentemente o recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.address_complement	Complemento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_bibliographic_private_database_access	Acceso a la Base Privada.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.150.subfield.z	Subdivisión geográfica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.150.subfield.y	Subdivisión cronológica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.place	Lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.150.subfield.x	Subdivisión general adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.isrc	ISRC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.lendings	Préstamos activos, historia de préstamos y multas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.150.subfield.a	Término tópico adoptado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.subfield.d	Escala de Longitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.subfield.c	Escala de Latitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.error.save	Falla al guardar el Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.acquisition	Adquisiciones (Proveedor, Requerimiento, Cotización y Pedido)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.trash_full	Papelera de Reciclaje	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.status.any	Cualquier	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.users.title	Buscar Lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.confirm_delete_record_question.forever	¿Usted realmente desea excluir esta Tarjeta?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	field.error.invalid	Este valor no es válido para este campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.150.subfield.i	Calificador	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.subfield.a	Nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.subfield.b	Unidad de las Coordenadas o Unidad de la Distancia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_usertype_save	Guardar registro de tipo de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.page_help	La pantalla de multibibliotecas permite registrar diversas bibliotecas para ser administradas por un único Biblivre. A partir del momento que usted habilita el sistema de multi-bibliotecas, la lista de bibliotecas registradas será exhibida siempre que alguien entre en la dirección estándar del Biblivre 4.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access.user.search	Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.indexing_groups.all	Cualquier campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_876	Nota de acceso restricto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.question.unblock	¿Desea realmente desbloquear esta Tarjeta?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.indicator.1.3	nombre de familia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.movie	Película	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.indicator.1.1	apellido simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.cataloging_authorities	Catálogo de Autoridades	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.indicator.1.2	nombre compuesto (obsoleto)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.indicator.1.0	nombre simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.holdings	Informe de Registro de Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding.holding_count	Número de Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	common.save	Salvar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	acquisition.quotation.field.unit_value	Valor Unitario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.0	Ningún carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.cancel	Cancelar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_usertype_delete	Excluir registro de tipo de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.indicator.2.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.open	Abrir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.status.in_use	En uso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.save_as_new	Guardar como Nuevo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.void		2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.670	Orígen de las informaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.info	Observaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.status.cancelled	Cancelado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.invalid_backup_type	El modo de backup seleccionado no existe	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.operator.or	o	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110	Autor - Entidad colectiva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111	Autor - Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.author	Búsqueda por Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.b	Complemento del título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.lending_limit	Límite de préstamos simultáneos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	label.username	Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.error.delete.user_has_lendings	Este usuario posee préstamos activos.  Realice la devolución antes de excluir este usuario.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.a	Título/título abreviado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.user_has_card	Usuario ya posee tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.select_card	Seleccionar Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.g	Miscelánea	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.f	Información de volumen/número de fascículo y/o fecha de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.no_backups_found	Ningún backup encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.warning	Este proceso puede demorar algunos minutos, dependiendo de la configuración de hardware de su servidor.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.i	Exhibir texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.h	Medio físico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.504.subfield.a	Notas de bibliografía	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.expected_return_date	Fecha para devolución	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.field.name	Nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.invalid_backup_path	Camino inválido. Este directorio no existe o el Biblivre no posee permiso de escritura.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.n	Número de la parte/sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.subfield.p	Nombre de la parte/sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100	Autor - Nombre personal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.logged_out_text	Texto inicial para usuarios no logueados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.new_value	Nuevo valor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.page_help	<p>O <strong>"Control de Acceso"</strong> permite administrar la entrada y permanencia de los lectores en las instalaciones de la biblioteca. Seleccione el lector a través de una búsqueda por nombre o matrícula y digite el número de una tarjeta de acceso disponible para vincular aquella tarjeta al lector.</p>\n<p>En el momento de la salida del lector, usted podrá desvincular la tarjeta procurando por el código del mismo</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.2.2	entrada analítica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.title	Título Principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.total	Total	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.marc_field	Valor del campo Marc	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.computer_legible	Archivo de Computadora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.1	Genera entrada secundaria en la ficha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.usertype.confirm_delete_record.forever	El Tipo de Usuario será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload.title	Enviar archivo de idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_datamigration	Importar datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130	Obra anónima	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.save	Falla al guardar la Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.address	Dirección	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.page_help	<p>La búsqueda distribuida permite recuperar informaciones sobre registros en acervos de otras bibliotecas, que colocan a disposición sus registros para la búsqueda y catalogación colaborativa.</p>\n<p>Para realizar una búsqueda, rellene los términos de la búsqueda, seleccionando el campo de interés. En seguida, seleccione una o más bibliotecas donde se deberán localizar los registros. <span class="warn">Atención: seleccione pocas bibliotecas para evitar que la búsqueda distribuida sea muy lenta, entendiendo que ella depende de la comunicación entre las bibliotecas y el tamaño de cada acervo.</span></p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.save	Guardar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.printer_type.printer_common	Impresora común	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.number_of_titles	Número de Títulos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.button.continue_to_biblivre	Ir para el Biblivre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_count_by_type	Totales por Tipos de Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.step_2_title	Seleccionar registros para importación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.employee	Empleado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.current_value	Valor actual	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.uncancel	Recuperar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.title_found_backups	Backups Encontrados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.error.delete	Falla al excluir el Registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_cancel_editing_title	Cancelar edición de registro de Pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permission.error.delete	Falla al excluir el login	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_status.blocked	Bloqueado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.success.description	Backup restaurado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.start_date	Fecha Inicial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.680.subfield.a	Nota de alcance	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.return	Devolver	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_cancel_editing_title	Cancelar edición de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.095.subfield.a	Área de conocimiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_cancel_editing.2	Se perderán todas las alteraciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de vocabulario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.import_as	Importar como:	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_authorities_save	Guardar registro de autoridad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.thesis	Tesis	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.import_popup.importing	Importando registros, por favor, aguarde	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.fieldset.title.values	Valores	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.150	TE	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.acquisition_request	Requerimientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.1.0	Ningún nivel especificado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.1.1	Asunto primario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.1.2	Asunto secundario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.download.description	Seleccione abajo el idioma que desea descargar.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.zip_code	Código Postal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.delete	Excluir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.z3950_servers	Servidores Z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.lending_date	Fecha del préstamo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.info	Observaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.trademark	Nombre de Fantasía	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.remove_item_button	Excluir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.new_schema.title	Creación de Nueva Biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.indicator.1._	Subcampos |b o |c no están presentes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.other_name	Otra Forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	aquisition.supplier.error.supplier_not_found	No fue posible encontrar el proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.button.print_user_cards	Imprimir carnets	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.indexing_groups.tg_term	Término General (TG)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.description.6	En caso que el usuario pierda su contraseña, deberá igualmente entrar en contacto con el Administrador o Bibliotecario responsable por el Biblivre, que podrá proveer una nueva contraseña.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3migration.button	Importar datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.issn_already_in_database	Ya existe un registro con este ISSN en la base de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.a	Título uniforme atribuido al documento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.550.subfield.y	Subdivisión cronológica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.delete	Falla al excluir la Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.550.subfield.z	Subdivisión geográfica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.d	Fecha que aparece junto al título uniforme en la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.address_zip	CEP	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.l	Idioma del texto. Idioma del texto por extenso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.f	Fecha de edición del ítem que está siendo procesado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.button.show_log	Exhibir log	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.g	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.913.subfield.a	Código Lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.return_date	Fecha de devolución	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.description.1	El cambio de contraseña es el proceso por el cual un usuario puede alterar su contraseña actual por una nueva. Por cuestiones de seguridad, sugerimos que el usuario realice este procedimiento periódicamente.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.error.move	Falla al mover los Registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_datamigration	Migración de Datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.description.3	Mezcle letras, símbolos especiales y números en su contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.description.2	La única regla para creación de contraseñas en el Biblivre es la cantidad mínima de 3 caracteres. Sin embargo, sugerimos seguir las siguientes directivas:	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.p	Nombre de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.page_help	<p>La importación de registros permite expandir su base de datos sin que haya necesidad de catalogación manual. Nuevos registros pueden ser importados a través de búsquedas Z39.50 o a partir de archivos exportados por otros sistemas de biblioteconomía.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.description.5	Use una cantidad de caracteres superior al recomendado.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.description.4	Use letras mayúsculas y minúsculas; y	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.550.subfield.a	Término tópico adoptado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.multi_schema	Esta configuración permite que se habilite el sistema de múltiples bibliotecas en esta instalación del Biblivre 4.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.block	Bloquear	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.949.subfield.a	Sello patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.subfield.a	Término tópico adoptado en el tesauro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.410.subfield.a	Nombre de la entidad o del lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.log_header	[Log de creación de nueva biblioteca del Biblivre 4]	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.550.subfield.x	Subdivisión general adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.renew_success	Préstamo renovado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging_vocabulary	Vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.labels.never_printed	Listar solamente ejemplares que nunca tuvieron etiquetas impresas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.user_total_lending_list	Historial de préstamos a este lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.manuscript	Manuscrito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.operator.and	y	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.step	Paso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_authorities_delete	Excluir registro de autoridad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.question.cancel	¿Desea realmente cancelar esta Tarjeta?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reinstall.title	Restauración y Reconfiguración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.cancel	Cancelar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.success.generate	Informe generado con éxito. El mismo será abierto en otra página.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.selected_records_singular	{0} ejemplar seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.502.subfield.a	Notas de disertación o tesis	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.auto_download	Backup realizado, descargando automáticamente en algunos segundos...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.groups.acquisition	Adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.record_deleted	Registro excluido definitivamente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.040.subfield.c	Agencia que transcribió el registro en formato legible por máquina	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.040.subfield.b	Lenguaje de la catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.040.subfield.e	Fuentes convencionales de descripciones de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.040.subfield.d	Agencia que alteró el registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.040.subfield.a	Código de la agencia catalogadora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.searches_by_date	Informe de Total de Búsquedas por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.runtime_error	Error inesperado durante la ejecución de la tarea	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.subtitle	Títulos paralelos/subtítulo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.cancel.description	Cliquee en el botón abajo para desistir de restaurar esta instalación del Biblivre 4 y volver a su biblioteca.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.success.save	Proveedor incluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.indicator.1	Tipo de período cronológico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_backup	Realizar copia de seguridad de la base de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.form.hidden_subfields_plural	Exhibir {0} subcampos ocultos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.page_help	<p>Para realizar una reserva usted deberá seleccionar el lector para el cual la reserva será realizada y, en seguida, seleccionar el registro que será reservado. La búsqueda por el lector puede hacerse por nombre, matrícula u otro campo previamente registrado. Para encontrar el registro, realice una búsqueda similar a la búsqueda bibliográfica.</p>\n<p>Los cancelamientos pueden hacerse seleccionando el lector que posee la reserva.</p><p>La duración de la reserva se calcula de acuerdo con el tipo de usuario, configurado por el menú <strong>Administración</strong> y definido durante el registro del lector.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.users_with_pending_fines	Listar solo Usuarios con multas pendientes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_delete_record_title	Excluir registro de proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.acquisition	Informe de Pedidos de Adquisición Efectuados Por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.button.search	Buscar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.confirm_delete_record.forever	Tanto el Login del Usuario como sus permisos serán excluidos permanentemente del sistema y no podrán ser recuperados.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.return_success	Ejemplar devuelto con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.search_count	{current} / {total}	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.administration.z3950.server.active	Esta configuración indica si el servidor z39.50 Lugar estará activo. En los casos de instalaciones multi-biblioteca, el nombre de la Colección del servidor z39.50 será igual al nombre de cada biblioteca. Por ejemplo, el nombre de la colección para esta instalación es "{0}".	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.printer_type.printer_80_columns	Impresora 80 columnas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.invalid	El valor especificado para una de las configuraciones no es válido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.search_z3950	Distribuida	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.400	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.user.name_or_id	Nombre o Matrícula	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.start_less_than_or_equals_end	El Número inicial debe ser menor o igual al Número final	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.success.update	Usuario guardado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.user.field	Campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.title	Copia de Seguridad (Backup)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.error.invalid_marc	Falla al leer el Registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_cancel_editing_title	Cancelar edición de registro de vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.no_fines	Este usuario no posee multas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.410	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.button.generate_report	Emitir Informe	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.subfield.d	Fecha de la realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.subfield.b	Unidades subordinadas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.accession_number	Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de ejemplar?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.return.success	Tarjeta devuelta con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.title	Importación de Registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.subfield.l	Lenguaje de texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.in_this_library	En esta biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.subfield.n	Número de la parte sección de la obra orden del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.usertype.confirm_delete_record_question.forever	¿Usted realmente desea excluir este Tipo de Usuario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.success.delete	Usuario excluido permanentemente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	label.logout	Salir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.quotation	Cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.success	Restauración de Backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.requisition_select	Seleccione una Solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.holdings	Informe de Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	warning.create_backup	Hace más de 3 días que usted está sin generar una copia de seguridad (backup)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.new_schema.field.schema	Atajo de la Biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.user.remove_item_button	Excluir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.subfield.a	Nombre de la entidad o del lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_status	Situación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.580	Nota de Enlace	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.subfield.a	Título adicional - Título analítico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.1.1	Generar nota y entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.1.0	Generar nota, no generar entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.usertype.confirm_delete_record_title.forever	Excluir Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_quotation_delete	Excluir registro de cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.switch_to	Cambiar para	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.1.3	No generar nota, generar entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.1.2	No generar nota ni entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.psql_not_found	PSQL no encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.common.digital_files	Archivos Digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.subfield.n	Número de la parte - Sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.dewey	Estadística por Clasificación Dewey	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.subfield.p	Nombre de la parte - Sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_delete_record.trash	Será movido para la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.page_help	<p>El módulo <strong>"Impresión de Etiquetas"</strong> permite generar las etiquetas de identificación interna y de lomo para los ejemplares de la biblioteca.</p>\n<p>Es posible Generar las etiquetas de uno o más ejemplares en una única impresión, utilizando la búsqueda abajo. Este atento al detalle de que el resultado de esta búsqueda es una lista de ejemplares y no de registros bibliográficos.</p>\n<p>Luego de encontrar el(los) ejemplar(es) de interés, use el botón <strong>"Seleccionar ejemplar"</strong> para agregarlos a la lista de impresión de etiquetas. Usted podrá hacer diversas búsquedas, sin perder la selección hecha anteriormente. Cuando finalmente este satisfecho con la selección, cliquee en el botón <strong>"Imprimir etiquetas"</strong>. Será posible seleccionar cual modelo de la hoja de etiquetas se utilizará y en qué posición iniciar.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.024.indicator.1.2	International Standard Music Number (ISMN)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.024.indicator.1.0	International Standard Recording Code/ (ISRC)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.accession_number	Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.user_has_no_card	No hay tarjeta asociada a este usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.date_to	a	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.deleted	Excluido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.in_these_libraries	En estas bibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.configuration.title.general.title	Nombre de este Grupo de Bibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging_import	Importación de Registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.590	Notas locales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.yes	Sí	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.595	Notas para inclusión en bibliografías	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.download.title	Descargar archivo de idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.button.import_this_record	Importar este registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.status.in_use_and_blocked	En uso y bloqueado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.lendings_late	Total de Libros atrasados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_delete_record_question	¿Usted realmente desea excluir este registro de proveedor?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.select_item	Seleccionar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.450.subfield.a	Término tópico no usado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.error.save	Falla al inscribir al Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2	Dimensiones de referencia geoespacial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.580.subfield.a	Nota de Enlace	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.1	Dimensiones de referencia geoespacial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_returned_lendings	Historial de Devoluciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.new_schema.description	Para crear una nueva biblioteca, rellene abajo con su nombre y un subtítulo opcional. Usted también precisará de un nombre reducido para la biblioteca, llamado de atajo, que será usado en la dirección Web de acceso al Biblivre 4, permitiendo diferenciar las diversas bibliotecas instaladas en el sistema. Este atajo debe contener solamente letras, números y/o caracteres _. Para facilitar, el Biblivre 4 sugerirá un atajo automáticamente, basado en el nombre de la biblioteca.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_z3950_search	Listar servidores z3950	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.password.success	Contraseña alterada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	label.password	Contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.button.select_item	Seleccionar usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.select_marc_field	Seleccione un campo Marc	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.button	Restaurar backup seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.simple_search	Búsqueda Bibliográfica Simplificada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore	Restaurar un Backup del Biblivre 4	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.holding_id	Nro. Registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.form.repeat	Repetir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.0	Ningún carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_cancel_editing_title	Cancelar edición de registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.subfield.a	Término tópico adoptado en el tesauro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.topographic	Informe Topográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_status.pending_issues	Posee pendencias	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.error.no_records_found	Ningún registro encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.returns	Devoluciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.today	Hoy	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.lendings	Informe de Préstamos por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_360	Término Asociado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.form_invalid_values	Fueron encontrados errores en el rellenado del formulario abajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding_title	Ejemplares Automáticos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.user	Informe por Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	field.error.max_length	Este campo debe poseer como máximo {0} caracteres	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555	Nota de Índice Acumulativo o Remisivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.isbn	ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.status.blocked	Bloqueado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.inactive_users_only	Listar solo Usuarios inactivos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reinstall.button	Ir a la pantalla de restauración y reconfiguración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.page_help	<p>La rutina de Configuraciones permite la configuración de diversos parámetros utilizados por el Biblivre, como por ejemplo el Título de la Biblioteca, el Idioma Estándar o la Moneda a ser utilizada. Cada configuración posee un texto explicativo para facilitar su utilización.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.lendings_by_date	Informe de Préstamos por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.last_backup	Último Backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.log_header	[Log de importación de datos del Biblivre 3 para el Biblivre 4]	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.edit	Editar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.550	TG (Término genérico)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_243	Título uniforme colectivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.delete	Excluir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.2.2	Numeración alternada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.360	Remisiva VT (ver también) y TA (Término relacionado o asociado)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	warning.change_password	Usted todavia no modificó la contraseña estándar de administrador	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.total	Total	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_240	Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.2.1	Numeración primaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.2.0	No numerada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.525	Nota de Suplemento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.print_return_receipt	Imprimir recibo de devolución	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.success	Importación de datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.popup.description	Seleccione en qué etiqueta desea iniciar la impresión	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.error.delete	Falla al excluir la Solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.521	Notas de público meta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_accesscards_list	Listar tarjetas de acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.024.indicator.1	Tipo de número o código normalizado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_245	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.520	Notas de resumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.250.subfield.b	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.error.type_has_users	Este Tipo de Usuario posee Usuarios registrados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.250.subfield.a	Indicación de la edición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.error.delete	Falla al excluir el Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.indicator.2._	Título llave abreviado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.add_multiple_cards	Registrar Secuencia de Tarjetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.page_help	<p>La búsqueda bibliográfica permite recuperar informaciones sobre los registros del acervo de esta biblioteca, enlistando sus ejemplares, campos catalográficos y archivos digitales.</p>\n<p>La forma más simple es usar la <strong>búsqueda simplificada</strong>, que tratará de encontrar cada uno de los términos digitados en los siguientes campos: <em>{0}</em>.</p>\n<p>Las palabras son buscadas en su forma completa, pero es posible usar el caracter asterisco (*) para buscar por palabras incompletas, de modo que la búsqueda <em>'brasil*'</em> encuentre registros que contengan <em>'brasil'</em>, <em>'brasilia'</em> y <em>'brasilero'</em>, por ejemplo. Los pares de comillas pueden ser usados para encontrar dos palabras en secuencia, de modo que la búsqueda <em>"mi amor"</em> encuentre registros que contengan las dos palabras juntas, pero no encuentre registros con el texto <em>'mi primer amor'</em>.</p>\n<p>La <strong>búsqueda avanzada</strong> otorga un mayor control sobre los registros localizados, permitiendo, por ejemplo, buscar por fecha de catalogación o exactamente en el campo deseado.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.error.invalid_photo_extension	La extensión del archivo seleccionado no es válida para la foto del usuario. Use archivos .png, .jpg, .jpeg o .gif	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.indicator.1._	ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.private_full	Base Privada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.534	Notas de facsímile	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.creation_date	Fecha Inclusión;	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.530	Notas de disponibilidad de forma física	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reinstall.description	Use esta opción en caso que usted desee restaurar un backup del Biblivre 4, borrar los datos de su biblioteca o rehacer la migración del Biblivre 3. Usted será enviado a la pantalla inicial de instalación del Biblivre, donde podrá cancelar en caso que desista de hacer alteraciones.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750	Término tópico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.2._	Ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.vocabulary.page_help	<p>La búsqueda de vocabulario permite recuperar informaciones sobre los términos presentes en el acervo de esta biblioteca, caso catalogados.</p>\n<p>La búsqueda tratará de encontrar cada uno de los términos digitados en los siguientes campos: <em>{0}</em>.</p>\n<p>Las palabras son buscadas en su forma completa, pero es posible usar el carácter asterisco (*) para buscar por palabras incompletas, de modo que la búsqueda <em>'brasil*'</em> encuentre registros que contengan <em>'brasil'</em>, <em>'brasilia'</em> y <em>'brasilero'</em>, por ejemplo. Los pares de comillas pueden ser usados para encontrar dos palabras en secuencia, de modo que la búsqueda <em>"mi amor"</em> encuentre registros que contengan las dos palabras juntas, pero no encuentre registros con el texto <em>'mi primer amor'</em>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.show_all	Mostrar todos los {0} backups	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.response_date	Fecha de Llegada de la Cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.bibliography	Informe de Bibliografía por Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.author_title	Título y otras palabras asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_260	Imprenta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.simple_search	Búsqueda Simplificada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_bibliographic_delete	Excluir registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permission.success.delete	Login excluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.500	Notas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.501	Notas iniciadas con la palabra "con"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.502	Notas de disertación o tesis	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.504	Notas de bibliografía	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.505	Notas de contenido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_password	Cambio de Contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.indicator.1.1	no confidencial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.indicator.1.0	confidencial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.buttons.apply_fine	Multar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lendings.holding_list_lendings	Listar solamente ejemplares prestados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_250	Edición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.datafield	Campo MARC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_255	Escala	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_256	Características del archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.error.description	Infelizmente ocurrió un error al importar los datos del Biblivre 3. Verifique la próxima pantalla por el log de errores y, en caso necesario, entre en el fórum Biblivre para obtener ayuda.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_257	Lugar de producción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.success.update	Cotización guardada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_258	Información sobre el material	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.location	Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.photo	Foto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.empty_login	El campo login no puede estar vacío	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.515	Nota de Peculiaridad en la Numeración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.selected_records_plural	{0} registros seleccionados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.clear_search	Limpiar términos de la búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.biblio	Bibliográficos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.backup_not_complete	Backup no terminado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.error.no_supplier_found	No fue posible encontrar ningún proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_cancel_editing_title	Cancelar edición de registro de cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.success.disable	Éxito al marcar usuario como inactivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	digitalmedia.error.file_not_found	El archivo especificado no fue encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.error.delete	Falla al exluir la cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	warning.fix_now	Resolver este problema	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.availability.available	Disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_delete_record_title	Excluir registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.holding.availability	Disponibilidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.status.available	Disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.address_city	Ciudad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.empty_new_password	El campo "nueva contraseña" no puede estar vacío	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.return_date	Fecha de la devolución	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.subfield.c	Indicación de responsabilidad de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.subfield.a	Título principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_vocabulary_move	Mover registro de vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.subfield.b	Títulos paralelos/subtítulos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.confirm_title	Restaurar Backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.popup.description	Seleccione en cuál etiqueta desea iniciar la impresión	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.button.delete	Excluir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.subfield.p	Nombre de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.email	Email	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.country	País	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.subfield.n	Número de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.indicator.1.0	nombre invertido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.multi_schema_configurations	Configuraciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.indicator.1.1	nombre de la jurisdicción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.subfield.h	Medio	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_reservation_list	Listar reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.indicator.1.2	nombre en orden directo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_bibliographic_move	Mover registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.type.biblio	Registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.cancel	La Tarjeta será cancelada y estará indisponible para su uso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_status.blocked	Bloqueado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.order	Ordenar por	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.file_not_found	Archivo no encontrado.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.source_search_title	Importar registros a partir de una búsqueda Z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.expiration_date	Fecha de expiración de la reserva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.state	Estado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.subtitle	Subtítulo de la biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.upload_popup.uploading	Enviando archivo...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.error.save	Falla al guardar el proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.670.subfield.a	Nota de origen del Término	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.upload_popup.title	Abriendo Archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.main_full	Base Principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.page_help	<p>La rutina de Pedidos permite el registro y búsqueda de pedidos (compras) realizados con los proveedores registrados. Para registrar un nuevo Pedido, se debe seleccionar un Proveedor y una Cotización previamente registrados, así como entrar datos tales como Fecha de Vencimiento y datos de la Factura.</p>\n<p>La búsqueda tratará de encontrar cada uno de los términos digitados en los campos <em>Número de Registro de Pedido, Nombre de Fantasía del Proveedor, y Autor o Título de la Solicitud</em>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.subfield.3	Materiales especificados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.multi_schema	Habilitar Multibibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.couldnt_restore_backup	No fue posible restaurar el backup seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_configurations	Administrar configuraciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.holdings_available	Disponibles	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.group.custom	Informe Personalizado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.biblio_reservation	Reservas por registro bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_request_save	Guardar registro de requerimiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.return.error	Falla al devolver la Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.fine.failure_pay_fine	Falla al pagar multa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.2.2	entrada analítica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation_access	Control de Acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.login_change_password	Cambiar contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210	Título Abreviado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.multi_schema_manage	Gerencia de Bibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.select_file	Seleccione un archivo de backup primero	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.856.subfield.y	Link en texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	field.error.date	El valor rellenado no tiene una fecha válida. Utilice el formato {0}	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.856.subfield.u	URI	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.lend.error	Falla al vincular la Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.login	Login	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.856.subfield.d	Camino	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.upload_popup.processing	Procesando...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.subfield.a	Nota de índice acumulativo y remisivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.new_schema.field.title	Nombre de la biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.subfield.b	Fuente disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_status.active	Activo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.success.update	Servidor z39.50 actualizado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.856.subfield.f	Nombre del archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.subfield.c	Grado de control	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.subfield.d	Referencia bibliográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.reserved.warning	Todos los ejemplares disponibles de este registro están reservados para otros lectores. El préstamo puede ser efectuado, sin embargo verifique las informaciones de reservas.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.321.subfield.b	Fechas de la periodicidad anterior	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.phone_cel	Celular	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.321.subfield.a	Periodicidad Anterior	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.type.authorities	Autoridades	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.subfield.u	Identificador uniforme de recursos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.new_schema.button.create	Crear Biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.searches	Informe de Total de Búsquedas por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.open_item_button	Abrir registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_configurations	Configuraciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.041.indicator.1.0	El ítem no es y no incluye traducción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.tabs.reservations	Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.cancel	Cancelar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	field.error.min_length	Este campo debe poseer como mínimo {0} caracteres	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	circulation.user_field.short_type	Tipo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	marc.bibliographic.datafield.041.indicator.1.1	El ítem es e incluye traducción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.2._	ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.isbn	ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging_labels	Impresión de Etiquetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	text.multi_schema.select_library	Lista de Bibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.publication_year	Año de publicación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.856.subfield.y	Link en el texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.printer_type.printer_40_columns	Impresora 40 columnas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.no_backups_found	Ningún backup encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.page_help	<p>El módulo <strong>"Impresión de Carnets"</strong> permite Generar las etiquetas de identificación de los lectores de la biblioteca.</p>\n<p>Es posible generar los carnets de uno o más lectores en una única impresión, utilizando la búsqueda abajo.</p>\n<p>Luego de encontrar el(los) lector(es), use el botón <strong>"Seleccionar usuario"</strong> para agregarlos a la lista de impresión de carnets. Usted podrá realizar diversas búsquedas, sin perder la selección hecha anteriormente. Cuando este satisfecho con la selección, cliquee en el botón <strong>"Imprimir carnets"</strong>. Será posible seleccionar la posición del primer carnet en la hoja de etiquetas.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_save	Guardar registro de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.info	Observaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.no_attachments	Este registro no posee archivos digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.error.save	Falla al guardar la Solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.505.subfield.a	Notas de contenido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_delete_record_title	Excluir registro de ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.print_lending_receipt	Imprimir recibo de préstamo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.quotation_date	Fecha del Pedido de Cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.lending.error.holding_is_lent	El ejemplar seleccionado ya está prestado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.trash	Papelera de Reciclaje	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.lendings_top	Libros más prestados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.address_number	Número	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.id	N&ordm; del registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.250	Edición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.255	Dato matemático cartográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.256	Características del archivo de computadora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.2.0	Library of Congress Subject Heading	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.obs	Observaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.help	Ayuda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.258	Información sobre material filatélico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.257	País de la entidad productora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.articles	Artículo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.user_not_found	No fue posible encontrar el usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.150.subfield.y	Subdivisión cronológica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.150.subfield.x	Subdivisión general adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750.indicator.2.4	Source not specified	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.title.unit_value	Valor Unitario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.lending.error.holding_unavailable	El ejemplar seleccionado no está disponible para préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.150.subfield.z	Subdivisión geográfica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.indexing_groups.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.button_full	Crear backup completo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.accession_number.full	Informe completo de Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.start_number	Número inicial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240	Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243	Título Convencional Para Archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245	Título principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.database_work	Trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246	Forma Variante de Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_lendings	Préstamos Activos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.page_help	<p>La rutina de Cotizaciones permite el registro y búsqueda de cotizaciones (presupuestos) realizadas con los proveedores registrados. Para registar una nueva Cotización, se debe seleccionar un Proveedor y una Solicitud previamente registrados, así como entrar datos como el valor y la cantidad de obras cotizadas.</p>\n<p>La búsqueda tratará de encontrar cada uno de los términos digitados en los campos <em>Número de Registro de Cotización o Nombre Fantasía del Proveedor</em>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.bind_card	Vincular Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.search.distributed_search_limit	Esta configuración representa la cantidad máxima de resultados que serán encontrados en una búsqueda distribuida. Evite el uso de límite muy elevado pues las búsquedas distribuidas llevarán mucho tiempo para volver a los resultados encontrados.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_delete_record_question.forever	¿Usted realmente desea excluir este registro de proveedor?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.success.update	Tarjeta guardada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation_user_reservation	Reservas del Lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.856.subfield.u	URI	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.856.subfield.d	Camino	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_delete	Excluir registro de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.515.subfield.a	Nota de Peculiaridad en la Numeración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.856.subfield.f	Nombre del archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.name	Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.949	Sello patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.947	Información de la Colección	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.611.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	text.main.logged_in	<p>Hola {0},</p>\n<p>Sea bienvenido a la <strong>Biblioteca Libre (Biblivre) versión 4.0</strong>.</p>\n<p>Usted podrá hacer búsquedas por registros bibliográficos, autoridades y vocabulario con la opción <em>"Búsqueda"</em> en el menú superior. Esta es la misma <em>"Búsqueda"</em> que los lectores podrán usar al accesar al <strong>Biblivre</strong>, sin necesidad de usuario y contraseña, para buscar por registros en la Base Principal.</p>\n<p>Para registrar lectores, realizar préstamos, devoluciones y reservas, controlar el acceso a la biblioteca e imprimir carnets, use la opción <em>"Circulación"</em>, también en el menú superior.</p>\n<p>En la opción <em>"Catalogación"</em>, usted podrá controlar el acervo de la biblioteca, catalogando obras y ejemplares, y efectuar el control de autoridades y de vocabulario. A través de esta opción también es posible imprimir las etiquetas usadas en los ejemplares, mover registros entre las bases de datos (Principal, Trabajo, Privada y Papelera de reciclaje), importar y exportar registros y agregar archivos digitales a los registros existentes.</p>\n<p>El <strong>Biblivre</strong> también posee un sistema simple de control del proceso de adquisición, para auxiliar la compra y recibimiento de publicaciones, a través de la opción <em>"Adquisición"</em>.</p>\n<p>En <em>"Administración"</em>, usted podrá cambiar la contraseña de acceso, configurar recursos del <strong>Biblivre</strong> como campos de los formularios, traducciones y tipos de usuario, registrar tarjetas de acceso, generar informes y realizar la manutención de la base de datos, que incluye la generación de la copia de seguridad (backup), y la Reindización de la base de datos, que debe ser usada cuando algunos registros no pueden ser encontrados a través de la búsqueda.</p>\n<p>En caso que precise de más informaciones sobre el <strong>Biblivre</strong>, accese a la opción <em>"Ayuda"</em> y lea el Manual del programa o las preguntas frecuentes, en <a href="http://biblivre.org.br/forum" target="_blank">Fórum</a>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.groups.circulation	Circulación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.150.subfield.a	Término tópico adoptado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.move_records	Mover Registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.holding.accession_number	Sello patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.page_help	¡Bienvenido! Esta pantalla es el último paso antes de iniciar el uso del Biblivre IV y a través de ella usted podrá escoger si restaurará las informaciones de otra instalación del biblivre (a través de un backup o de la migración del Biblivre 3) o si desea iniciar una biblioteca nueva. Lea atentamente cada una de las opciones abajo y seleccione la más apropiada.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.150.subfield.i	Calificador	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.payment_date	Fecha de Pago	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.status	Situación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.error.no_valid_terms	La búsqueda especificada no contiene términos válidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_print_user_cards	Imprimir carnets	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.users_with_late_lendings	Listar solo Usuarios con préstamos en atraso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.delivered_quantity	Cantidad recibida	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.holdings_full	Informe completo de Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.page_help	<p>Para realizar un préstamo usted deberá seleccionar el lector para el cual el préstamo será realizado y, en seguida, seleccionar el ejemplar que será prestado. La búsqueda por el lector puede ser hecha por nombre, matrícula u otro campo previamente registrado. Para encontrar el ejemplar, utilize su Sello Patrimonial.</p><p>Las devoluciones pueden ser hechas a través del lector seleccionado o directamente por el Sello Patrimonial del ejemplar que está siendo devuelto o renovado.</p><p>El plazo para la devolución se calcula de acuerdo con el tipo de usuario, configurado por el menu <strong>Administración</strong> y definido durante el registro del lector.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.fine_value	Valor de la Multa por atrasos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.distributed_search	Búsqueda Distribuida	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging_authorities	Autoridades	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import	Importar datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_quotation_list	Listar cotizaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.welcome	Sea bienvenido al Biblivre IV	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.paper_description	{paper_size} {count} etiquetas ({height} mm x {width} mm)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.order	Ordenación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.selected_records_plural	{0} Valores Agregados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.670.subfield.b	Información encontrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.670.subfield.a	Nombre retirado de	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	circulation.lending.button.renew	Renovar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	marc.bibliographic.datafield.700.indicator.2	Tipo de entrada secundaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_field.short_type	Tipo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.0	Ningún caracter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.availability.unavailable	No disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.group.circulation	Circulación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.title.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.indicator.1.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.delivery_time	Plazo de entrega (Prometido)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.currency	Esta configuración representa la moneda que será utilizada en multas y en el módulo de adquisición.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.database_main	Principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.success.move	Registros movidos con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.acquisition_quotation	Cotizaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.availability	Disponibilidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.delete_success	Reserva excluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.029.subfield.a	Número de ISMN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.created_between	Catalogado entre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_delete_record_title.forever	Excluir registro de cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260	Publicación, edición. Etc.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_delete_record_question.forever	¿Usted realmente desea excluir este registro de Pedido?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.fieldset.title.values	Valores	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.913	Código Lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.simple_term_title	Rellene los términos de la búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.title	Reindización de la Base de Datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.lending.error.blocked_user	El lector seleccionado está bloqueado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.records_found_singular	{0} registro encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.2._	ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.error.delete	Falla al excluir el proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.type.do_not_import	No importar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.2	Tipo de entrada secundaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.error.delete.user_has_accesscard	Este usuario posee tarjeta de acceso en uso.  Realice la devolución de la tarjeta antes de excluir este usuario.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.created_by	Responsable	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_130	Obra Anónima	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	language_name	Español (Internacional)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_534	Notas de facsímil	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.360.subfield.z	Subdivisión geográfica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.360.subfield.y	Subdivisión cronológica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.logged_in_text	Texto a ser exhibido en la pantalla inicial del Biblivre, para usuarios que tengan ingresado con login y contraseña. Usted puede utilizar tags HTML, pero cuidado de no quebrar el diseño del Biblivre 4. El término {0} será sustituido por el nombre del usuario logueado. Atención: esta configuración se relaciona con el sistema de traducciones. Las alteraciones realizadas en esta pantalla afectarán solamente el idioma actual. Para alterar en otros idiomas, utilice la pantalla de traducciones o acceda al Biblivre usando el idioma a ser alterado.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_delete_record_title	Excluir registro de Pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.360.subfield.x	Subdivisión general adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	warning.new_version	Ya está disponible una actualización para el Biblivre 4<br/>Versión instalada: {0}. Versión más reciente: {1}	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.upload_popup.uploading	Enviando archivo...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.reservations	Informe de Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.progress_popup.title	Manutención del Biblivre 4	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.reservation_date	Fecha de la Reserva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.term.up	Término Use Para (UP)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_520	Notas de resumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.411.subfield.a	Nombre del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_521	Notas de público meta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.title.quantity	Cantidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.multi_schema	Multibibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	z3950.adresses.list.no_address_found	Ningún Servidor Z39.50 encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.page_help	<p>La rutina de Informes permite la generación e impresión de diversos Informes puestos a disposición por el Biblivre. Los Informes disponibles se dividen entre las rutinas de Adquisición, Catalogación y Circulación.</p>\n<p>Algunos de los Informes disponibles poseen filtros, como Base Bibliográfica, o Período, por ejemplo. Para otros, basta seleccionar el Informe y cliquear en "Emitir Informe".</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_110	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.tabs.form	Registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_111	Autor Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.indicator.1.1	apellido simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.indicator.1.2	apellido compuesto (anticuado)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.indicator.1.3	nombre de la familia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.configurations.page_help	La rutina de Configuraciones de Multi-bibliotecas permite alterar configuraciones globales del grupo de bibliotecas y configuraciones estándar que serán usadas por las bibliotecas registradas. Todas las configuraciones marcadas con un asterisco (*) serán usadas como estándar en nuevas bibliotecas registradas en este grupo, pero pueden ser alteradas internamente por los administradores, a través de la opción <em>"Administración"</em>, <em>"Configuraciones"</em>, en el menú superior.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.holdings_count	Cantidad de Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.clear	Limpiar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.indicator.1.0	nombre simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.selected_records_singular	{0} Valor Agregado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.term.tg	Término General (TG)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.term.te	Término Específico (TE)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.preview	Pre visualización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_delete_record_title	Excluir registro de vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.490	Indicación de serie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.term.ta	Término Asociado (VT / TA)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.search	Búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.modified	Actualizado en	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.521.subfield.a	Notas de público meta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.phone_home	Teléfono Residencial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.unclassified	<No clasificado>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_translations	Administrar traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.501.subfield.a	Notas iniciadas con la palabra "con"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260.subfield.b	Nombre del editor, publicador, etc.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260.subfield.c	Fecha de publicación, distribución, etc.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.user.search	Digite el nombre o matrícula del Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260.subfield.e	Nombre del impresor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.error.invalid_search_parameters	Los parámetros de esta búsqueda no están correctos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.author_type.select_author_type	Seleccione el tipo de autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.search.results_per_page	Resultados por página	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260.subfield.a	Lugar de publicación, distribución, etc.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.biblivre_is_locked_please_wait	Este Biblivre está en mantenimiento. Por favor, intente nuevamente en algunos minutos.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_500	Notas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_delete_record.trash	Será movido a la base de datos "papelera de reciclaje"	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260.subfield.f	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_502	Nota de tesis	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.260.subfield.g	Fecha de impresión	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_505	Notas de contenido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_504	Notas de bibliografía	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_506	Notas de acceso restricto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_lending_list	Listar préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.520.subfield.a	Notas de resumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.record_reserved_to_the_following_readers	Este registro está reservado para los siguientes lectores	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.new_password	Nueva contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.password_not_matching	Los campos "nueva contraseña" y "repita la nueva contraseña" deben ser iguales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.subfield.b	Unidades subordinadas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.subfield.d	Fecha de la realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.subject	Asunto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.save.success	Configuraciones alteradas con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.search_limit	La búsqueda realizada encontró {0} registros, no obstante solamente los {1} primeros serán exhibidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.subfield.n	Número de la parte - sección de la obra - orden del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.error.generate	Falla al Generar el Informe. Verifique el rellenado del formulario.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.renew	Renovar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.error.save	Falla al guardar el Registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_100	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.user.open_item_button	Abrir registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.success.unblock	Usuario desbloqueado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.vocabulary.simple_search	Búsqueda de Vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.subfield.a	Nombre de la entidad o del lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.unblock	Falla al desbloquear la Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_order_delete	Excluir registro de pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.ok	Ok	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de solicitud?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.button	Restaurar backup seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.indexing_groups.total	Total	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_670	Nombre retirado de	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.confirm_cancel_editing_title	Cancelar edición del Servidor Z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.field_count	Recuento del campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.362.indicator.1.1	Nota no formateada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.error.invalid_file	Archivo inválido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.362.indicator.1.0	Estilo formateado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.no	No	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.search_button	Buscar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este Servidor Z39.50?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.success	Restauración de Backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_access_control_bind	Administrar control de acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de proveedor?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_print_labels	Imprimir etiquetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.080.subfield.2	Número de edición de la CDU	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.indicator.1.0	nombre simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_cancel_editing.2	Todas las alteraciones serán perdidas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.indicator.1.3	nombre de familia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.popup.title	Formato de las etiquetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.indicator.1.1	apellido simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.log_header	[Log de restauración de backup del Biblivre 4]	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.indicator.1.2	apellido compuesto (obsoleto)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.button_authorities	Reindizar base de autoridades	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.authorities.simple_search	Búsqueda de Autoridades	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.520.subfield.u	URI	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.user_current_lending_list	Ejemplares prestados a este lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.subfield.b	Calificador	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.subfield.a	Título Abreviado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.255.subfield.a	Escala	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging_label	Etiquetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_680	Nota sobre Alcance	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_700	Autor secundario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_685	Nota de Historial o Glosario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.clean_install	Nueva Biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_order_list	Listar pedidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.access_control	Tarjetas de acceso y Control de acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.query_placeholder	Rellene los términos de la búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.any	Cualquier	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.confirm_title	Restaurar Backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.description	Descripción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.lend.success	Tarjeta vinculada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.title.unblock	Desbloquear Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.inactive	Marcar como inactivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.2	Tipo de entrada secundaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.error.description	Falla al crear nueva biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.topographic	Informe Topográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.title.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	text.main.logged_out	<p>El programa <strong>Biblioteca Libre (Biblivre) versión 4.0</strong> es un aplicativo que permite la inclusión digital del ciudadano en la sociedad de la información. Sepa más sobre el proyecto en <em>"Sobre"</em>, en la opción <em>"Ayuda"</em> en el menú superior.</p>\n<p>Se trata de un programa para catalogación y difusión de acervos de bibliotecas públicas y privadas, de variados portes, además de posibilitar la circulación y el compartir contenidos de información, tales como, textos, músicas, imágenes y películas o cualquier otro tipo de objeto digital.</p>\n<p>Hoy, el <strong>Biblivre</strong> es un éxito en todo Brasil, así como en el exterior y, por su extrema relevancia cultural, se viene asentando como el aplicativo de elección para la inclusión digital del ciudadano.</p>\n<p>Si desea solamente buscar el catálogo y accesar a las obras disponibles digitalmente, utilize la opción <em>"Búsqueda"</em> en el menú superior, sin la necesidad de usuario y contraseña.</p>\n<p>Para otros servicios, tales como circulación, catalogación, adquisición y administración, es necesario un nombre de <strong>usuario</strong> y <strong>contraseña</strong>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload_popup.processing	Procesando...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.indexing_groups.up_term	Término Use Para (UP)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.2.4	Source not specified	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.select_item_button	Seleccionar registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.block	Bloquear	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.button_vocabulary	Reindizar base de vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.error	Error al importar datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.400	Otra Forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_accesscards_delete	Excluir tarjetas de acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.download.field.languages	Idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.block	Falla al bloquear Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.subfield.d	Fechas asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_670	Orígen de las Informaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.subfield.c	Título y otras palabras asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.410	Otra Forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.tabs.fines	Multas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.subfield.q	Forma completa de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.expected_date	Fecha prevista	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.success.delete	Tarjeta excluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.unavailable	No disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.630.indicator.1	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.private	Privado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	digitalmedia.error.file_could_not_be_saved	El archivo enviado no puede ser guardado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_id	Matrícula	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.411	Otra Forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.2.0	Library of Congress Subject Headings	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.subfield.a	Apellido y/o nombre del autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.100.subfield.b	Numeración que sigue al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_590	Notas locales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.field.upload_file	Seleccionar archivo de backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.indicator.1.0	nombre simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.daily_fine	Multa diaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.indicator.1.1	apellido simple o compuesto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.indicator.1.2	apellido compuesto (obsoleto)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.600.indicator.1.3	nombre de familia	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.advanced_search	Búsqueda Avanzada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.title	Esta configuración representa el nombre de la biblioteca, que será exhibido al inicio de las páginas del Biblivre y en los informes.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.label_full	Backup completo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.search.result_limit	Límite de resultados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.error	Error al restaurar backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.gender	Género	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.empty_lending_list	Este lector no posee ejemplares prestados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.acquisition_supplier	Proveedores	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.card_not_found	Tarjeta no encontrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.multi_schema_backup	Backup y Restauración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.usertype.confirm_cancel_editing_title	Cancelar edición del Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.confirm_cancel_editing_title	Cancelar inclusión de Tarjetas de Acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.no_servers	No es posible realizar una búsqueda Z39.50 pues no existen bibliotecas remotas registradas. Para solucionar este problema, registre los servidores Z39.50 de las bibliotecas de interés en la opción <em>"Servidores Z39.50"</em> dentro de <em>"Administración"</em> en el menu superior. Para esto es necesario un nombre de <strong>usuario</strong> y <strong>contraseña</strong>.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.editor	Editora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.source_file_title	Importar registros a partir de un archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.year	Año	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.groups.digitalmedia	Medio Digital	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.reservation_limit	Límite de reservas simultáneas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.description	Use esta opción en caso que usted quiera restaurar un backup existente del Biblivre 4. En caso que el Biblivre encuentre backups guardados en sus documentos, usted podrá restaurarlos directamente de la lista abajo. En caso contrario, usted deberá enviar un archivo de backup (extensión <strong>.b4bz</strong>) a través del formulario.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.failure.unblock	Falla al desbloquear al Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.expiration_date	Fecha de Validez de la Cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.submit_button	Cambiar contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.field.upload_file	Seleccionar archivo de backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.work	Trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.reader	Lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding.holding_acquisition_date	Fecha de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.1	Genera entrada secundaria en la ficha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.failure.block	Falla al bloquear al Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.450	UP (remisiva para TE no usado)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.subfield.b	Período de tiempo formateado de 9999 a.C en adelante	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.subfield.a	Código del período de tiempo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	digitalmedia.error.no_file_uploaded	Ningún archivo fue enviado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045.subfield.c	Período de tiempo formateado anterior a 9999 a.C.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.indicator.2.0	Otro título abreviado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.days_late	Días de atraso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.error.order_not_found	No fue posible encontrar el pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.holding_lent_to_the_following_reader	Este ejemplar está prestado para el lector abajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_555	Notas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.650.subfield.a	Asunto tópico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.sort_by	Ordenar por	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.accesscards.unbind_card	Devolver Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permission.error.create_login	Error al crear login de usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.indicator.1.0	No generar entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.field.collection	Colección	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.delete	Excluir	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.migrate.error	Falla al importar los datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_status.pending_issues	Posee pendencias	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.indicator.1.1	Generar entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title	Informes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.wait	Dependiendo del tamaño de la base de datos, esta operación podrá demorar. El Biblivre quedará indisponible durante el proceso, que puede durar hasta 15 minutos.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.deadline_date	Fecha de Vencimiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_651	Asunto geográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852	Informaciones sobre la localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_650	Asunto tópico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.database.work	Trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration	Administración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.856	Localización de obras por medio electrónico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.login_already_exists	Este login ya existe. Escoja otro nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.success.description	Backup restaurado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.requester	Solicitante	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	format.datetime	dd/MM/yyyy HH:mm	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.new_holding	Nuevo ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.publisher	Editora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.no_card_found	Ninguna tarjeta encontrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.650.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.650.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.650.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.access_denied	Acceso denegado. Usuario o contraseña inválidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.success	Reindización concluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.534.subfield.a	Notas de facsímile	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.p	Nombre de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.success.block	Usuario bloqueado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_lending_lend	Realizar préstamos de obras	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.n	Número de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.confirm_delete_record_question.forever	¿Usted realmente desea excluir el Login de Usuario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.411	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.error.select_reader_first	Para prestar un ejemplar usted precisa, primeramente, seleccionar un lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.indexing_groups.all	Cualquier campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.button.print_labels	Imprimir etiquetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.g	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.f	Fecha de edición del ítem que está siendo procesado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.year	Año	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.d	Fecha que aparece junto al título uniforme en la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.130.subfield.a	Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_630	Asunto título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_indexing	Administrar indización de la base de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.685.subfield.i	Texto explicativo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.save_as_new	Guardar como nuevo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.reserve_success	Reserva efectuada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.page_help	<p>La rutina de Servidores Z39.50 permite el registro y búsqueda de los Servidores utilizados por la rutina de Búsqueda Distribuida. Para realizar el registro serán necesarios los datos de la Colección Z39.50, así como la dirección URL y puerta de acceso.</p>\n<p>Al accesar a esa rutina, el Biblivre listará automáticamente todos los Servidores previamente registrados. Usted podrá entonces filtrar esa lista, digitando el <em>Nombre</em> de un Servidor que quiera encontrar.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload.description	Seleccione abajo el archivo de idioma que desea enviar para procesamiento por el Biblivre 4.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tabs.form	Formulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding.holding_library	Biblioteca Depositaria	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.value_must_be_boolean	El valor de este campo debe ser verdadero o falso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.indicator.1.2	nombre en orden directo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.title	Cambio de contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.invalid_password	El campo "contraseña actual" no es compatible con su contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_delete_record_question	¿Usted realmente desea excluir este registro de autoridad?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.indicator.1.0	nombre invertido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.110.indicator.1.1	nombre de la jurisdicción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.490.indicator.1.0	Título no desdoblado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.3	Especificaciones del material	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.490.indicator.1.1	Título desdoblado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.590.subfield.a	Notas locales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_request_list	Listar requerimientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.invalid_pg_dump_path	Camino inválido. El Biblivre no será capaz de generar backups ya que el archivo <strong>pg_dump</strong> no fue encontrado.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.holdings.title	Buscar Ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.accession_number	Informe de Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.confirm_title	Importar datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.user	Búsqueda de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.t	Título de la obra junto a la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.490.subfield.a	Título de la serie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.cataloging.accession_number_prefix	El sello patrimonial es el campo que identifica únicamente un ejemplar. En el Biblivre, la regla de formación para el sello patrimonial depende del año de adquisición del ejemplar, de la cantidad de ejemplares adquiridos en el año y del prefijo del sello patrimonial. Este prefijo es el término que será incluido antes de la numeración de año, en el formato <prefijo>.<año>.<contador> (Ex: Bib.2014.7).	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.indicator.1.1	nombre de la jurisdicción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.indicator.1.2	nombre en el orden directo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.indicator.1.0	nombre invertido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.previous	Anterior	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_usertype_list	Listar tipos de Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.button.select_page	Seleccionar usuarios de esta página	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_user_types	Tipos de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_610	Asunto entidad colectiva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_611	Asunto evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select_report	Seleccione un Informe	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.680	Nota de alcance (NE)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.business_days	Esta configuración representa los días de funcionamiento de la biblioteca y será usada por los módulos de préstamo y reserva. El principal uso de esta configuración es evitar que la devolución de un ejemplar sea marcada para un día en que la biblioteca está cerrada.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.wait	Aguarde	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.users	Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.685	Nota de historial o glosario (GLOSS)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation	Circulación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.user_deleted	Usuario excluido del sistema	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.cataloging_bibliographic	Bibliográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.cataloging	Búsqueda Bibliográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.supplier_number	CNPJ/CUIT	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.670	Nota de origen del Término	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.error.invalid_record_type	Tipo de registro en blanco o desconocido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.existing_card	La Tarjeta ya existe	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.authorities.page_help	<p>La búsqueda de autoridades permite recuperar informaciones sobre los autores presentes en el acervo de esta biblioteca, caso catalogados.</p>\n<p>La búsqueda tratará de encontrar cada uno de los términos digitados en los siguientes campos: <em>{0}</em>.</p>\n<p>Las palabras son buscadas en su forma completa, pero es posible usar el caracter asterisco (*) para buscar por palabras incompletas, de modo que la búsqueda <em>'brasil*'</em> encuentre registros que contengan <em>'brasil'</em>, <em>'brasilia'</em> y <em>'brasilero'</em>, por ejemplo. Los pares de comillas pueden ser usados para encontrar dos palabras en secuencia, de modo que la búsqueda <em>"mi amor"</em> encuentre registros que contengan las dos palabras juntas, pero no encuentre registros con el texto <em>'mi primer amor'</em>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.add_field	Agregar Término	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_750	Término Tópico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.goodbye	Hasta luego	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.error.no_user_type_found	Ningún Tipo de Usuario encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.button.select_page	Seleccionar ejemplares de esta página	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.field.lending_time_limit	Plazo de préstamo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.tabs.lendings	Préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tabs.marc	MARC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_600	Asunto persona	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.groups.login	Login	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.subtitle	Esta configuración representa un subtítulo para la biblioteca, que será exhibido al inicio de las páginas del Biblivre, luego abajo del <strong>Nombre de la biblioteca</strong>. Esta configuración es opcional.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.360.subfield.y	Subdivisión cronológica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.360.subfield.x	Subdivisión general adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.360.subfield.z	Subdivisión geográfica adoptada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.selected_records_singular	{0} Valor Agregado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.map	Mapa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.e	Nombre de subunidades del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.g	Informaciones adicionales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.a	Nombre del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.selected_records_singular	{0} usuario seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.d	Fecha de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.n	Número de orden del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.490.subfield.v	Número de volumen o designación secuencial de la serie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.080.subfield.a	Número de Clasificación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830.indicator.2	Número de caracteres a ser despreciados en la alfabetización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.value_is_required	El rellenado de este campo es obligatorio	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.360.subfield.a	Término tópico adoptado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.area	Barrio	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.success.create	Nueva biblioteca creada con éxito.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.success.save	Solicitud incluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.group.cataloging	Catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_list_by_type	Lista de Usuarios Por Tipo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reinstall.confirm.title	Ir a la pantalla de restauración y reconfiguración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.button.import_all	Importar todas las páginas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.registered_between	Registrado entre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.lendings_count	Total de Libros prestados en el período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.reservation	Informe de Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.end_date	Fecha Final	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.indicator.1.0	Ningún carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.p	Nombre de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.clean_install.button	Iniciar como una nueva biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.411.subfield.a	Nombre del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.repeat_password	Repetir contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_delete_record_title.forever	Excluir registro de Pedido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.help	Ayuda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.error.you_cannot_delete_yourself	Usted no puede excluirse o marcarse como inactivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.self_circulation	Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.button.list_all	Listar Todos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.1.0	No genera entrada para el título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.prefix	Prefijo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.1.1	Genera entrada para el título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.custom_count	Recuento de Registros Bibliográficos por Campo Marc	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.invalid_handler	No fue posible encontrar un handler para esta acción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.containing_text	Conteniendo el texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.material_type	Tipo de material	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.button.migrate	Importar datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.expected_return_date	Fecha prevista para devolución	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.041.indicator.1	Indicación de traducción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_vocabulary_delete	Excluir registro de vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.work_full	Base de Trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tabs.holdings	Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.paper_description	{paper_size} {count} etiquetas ({height} mm x {width} mm)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.search_bibliographic	Bibliográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.b	Fecha que aparece junto al título uniforme en la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.a	Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.success.delete	Solicitud excluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.page_help	<p>La rutina de Proveedores permite el registro y búsqueda de Proveedores. La búsqueda tratará de encontrar cada uno de los términos digitados en los campos <em>Nombre Fantasía, Razón Social o CNPJ</em>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.g	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.f	Fecha del trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.530.subfield.a	Notas de disponibilidad de forma física	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_maintenance	Manutención	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.requester	Solicitante	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.multi_schema.enabled	El sistema de multi-bibliotecas ya está habilitado para esta instalación del Biblivre 4. El administrador del sistema podrá deshabilitar esa opción en el menú de configuración de multibibliotecas.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.n	Número de la parte - sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.no_lendings	Este usuario no posee préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.title.author	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.id	N&ordm; del registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.a	Nombre del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_cancel_editing_title	Cancelar edición de registro de autoridad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_reservation_reserve	Realizar reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_699	Asunto lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.access_control.card_available	Esta tarjeta está disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.400.subfield.a	Apellido y/o Nombre del Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	label.login	Entrar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.title	Permisos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.button.import_this_page	Importar registros de esta página	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.invalid_writable_path	Camino inválido. Este directorio no existe o el Biblivre no posee permiso de escritura.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.d	Fecha de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.e	Número atribuido a la adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.b	Dirección	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.c	Forma de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.a	Nombre de la fuente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.description.4	Problemas en la búsqueda, donde no se encuentran registros inscritos.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.0	Ningún carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.f	Propietario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.h	Precio de compra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.o	Tipo de unidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.description.2	Alteración en la configuración de campos aptos a ser buscados;	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.subfield.n	Cantidad de items adquiridos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	search.bibliographic.holdings_reserved	Reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	administration.accesscards.change_status.uncancel	La Tarjeta será recuperada y estará disponible para su uso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.description.3	Importación de registros de versiones antiguas del Biblivre; y	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.830	Entrada secundaria - Serie - Título Uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.1.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.fine.pending	Pendiente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_080	CDU	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.description.1	La Reindización de la base de datos es el proceso en el cual el Biblivre analiza cada registro inscrito, creando índices en ciertos campos para que la búsqueda en ellos sea posible. Es un proceso demorado y que debe ser ejecutado solo en los casos específicos abajo:<br/>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.306.subfield.a	Tiempo de duración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.active_lendings	Préstamos activos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.button.remove_login	Remover Login	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.a	Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.button.select_reader	Seleccionar lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.b	Sub-localización o colección	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.c	Localización en el estante	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configurations.error.save	No fue posible guardar las configuraciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.e	Código postal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.label.example	ex.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.button.reserve	Reservar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.500.subfield.a	Notas generales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.quantity	Cantidad de ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_z3950_servers	Servidores Z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.title.quantity	Cantidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.same_password	La nueva contraseña debe ser diferente de la contraseña actual	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.usertype.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este Tipo de Usuario?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.usertype.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.field.code	Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.success.save	Tipo de Usuario incluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.suffix	Sufijo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.400.subfield.a	Apellido y/o Nombre del autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.360.subfield.a	Término tópico adoptado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.late_lendings	Informe de Préstamos en Atraso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.z	Nota pública	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.856	Localización de obras por medio electrónico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.2.2	entrada analítica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.indexing_groups.other_name	Otras formas del nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.currency	Moneda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.q	Condición física de la parte	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.x	Nota interna	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.delivered	Pedido recibido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.u	URI	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.group.acquisition	Adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.supplier_select	Seleccione un Proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.multi_schema_translations	Traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.j	Número de control en el estante	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.select_page	Seleccionar registros de esta página	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.on_the_field	En el campo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.subfield.n	Código del País	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.e	Nombre de subunidades del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.material_type	Tipo de material	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.d	Fecha de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.fieldset.contact	Contactos/Teléfonos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.g	Informaciones adicionales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.n	Número de orden del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111.subfield.k	Sub-encabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.labels.selected_records_plural	{0} ejemplares seleccionados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_400	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.common.button.upload	Enviar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.362	Información de Fechas de Publicación y/o Volumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.360	Remisiva VT (ver también) y TA (Término relacionado o asociado)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.supplier_select	Seleccione un Proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.shelf_location	Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.indicator.2._	ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_delete_record_question.inactive	¿Usted realmente desea marcar este usuario como "inactivo"?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.upload.field.user_created	Cargar traducciones creadas por el usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.logged_out_text	Texto a ser exhibido en la pantalla del Biblivre, para usuarios que no tengan ingresado con login y contraseña. Usted puede utilizar tags HTML, pero cuidado de no quebrar el diseño del Biblivre 4. Atención: esta configuración se relaciona con el sistema de traducciones. Las alteraciones realizadas en esta pantalla afectarán solamente el idioma actual. Para alterar en otros idiomas, utilice la pantalla de traducciones o acceda al Biblivre utilizando el idioma a ser alterado.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.dump	No fue posible generar el archivo de traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.couldnt_unzip_backup	No fue posible descompactar el backup seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_delete_record_title	Excluir registro de solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.error.invalid_database	Base de datos inexistente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.created	Registrado en	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.362.indicator.1	Formato de la fecha	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.page_help	<p>La rutina de Tarjetas de Acceso permite el registro y búsqueda de las Tarjetas utilizadas por la rutina de Control de Acceso. Para realizar el registro el Biblivre ofrece dos opciones:</p>\n<ul><li>Registrar Nueva Tarjeta: utilice para registrar solo una tarjeta de acceso;</li><li>Registrar Secuencia de Tarjetas: utilice para registrar más de una tarjeta de acceso, en secuencia. Utilize el campo "Previsualización" para verificar como serán las numeraciones de las tarjetas incluidas.</li></ul>\n<p>Al accesar a esa rutina, el Biblivre alistará automáticamente todos las Tarjetas de Acceso previamente registradas.  Usted podrá entonces filtrar esa lista, digitando el <em>Código</em> de una Tarjeta de Acceso que quiera encontrar.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.confirm_delete_record_question	¿Usted realmente desea excluir este registro de Pedido?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_reports	Generar Informes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.classification	Clasificación (CDD)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.url	URL	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.error.no_record_found	Ningún Registro válido encontrado en el archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.record_count	Registros en esta base: <strong>{0}</strong>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.holdings.title	Buscar Registro Bibliográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_delete_record_title	Excluir registro de autoridad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_delete_record_question	¿Usted realmente desea excluir este registro bibliográfico?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	format.date_user_friendly	DD/MM/AAAA	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.holdings_creation_by_date	Informe del Total de Inclusiones de Obras por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.birthday	Fecha de Nacimiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.complement	Complemento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.750	Término tópico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_type	Tipo de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.fine_popup.description	Esta devolución está atrasada y está sujeta al pago de multa. Verifique abajo las informaciones presentadas y confirme si la multa será agregada al registro del usuario para ser pagada en el futuro (Multar), si ella fue pagada en el momento de la devolución (Pagar) o si ella será abonada (Abonar).	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.340	Soporte físico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permission.success.permissions_saved	Permisos alterados con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.343	Datos de coordenada plana	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_013	Información del control de patentes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342	Datos de referencia geoespacial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.added_to_list	Agregado a la lista	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.marc_popup.description	Use la caja abajo para alterar el MARC de este registro antes de importarlo.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.1.2	nombre en el orden directo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.1.0	nombre invertido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.confirm	¿Desea confirmar la reindización de la base?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.indicator.1.1	nombre de la jurisdicción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.090.subfield.b	Código del autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.090.subfield.a	Clasificación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.search_vocabulary	Vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.modified	Fecha Cancelamiento/Alteración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740	Entrada secundaria - Título Adicional - Analítico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_410	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_411	Otra forma de nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.090.subfield.d	Número de ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.090.subfield.c	Edición / volumen	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.error	Error al restaurar backup	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_020	ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_024	ISRC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.print_receipt	Imprimir recibo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_022	ISSN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.0	Ningún caracter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.240.indicator.2.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.form.remove	Remover	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_quotation_save	Guardar registro de cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3migration	Importar datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.info	Observaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.orders_by_date	Informe de Pedidos por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.lend_success	Ejemplar prestado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.holding_reservation	Reservas por serie del ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.edit	Editar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de cotización?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.confirm_cancel_editing.1	¿Usted desea cancelar la inclusión de Tarjetas de Acceso?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_cancel_editing.2	Todas las alteraciones serán perdidas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.label_exclude_digital_media	Backup sin archivos digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_permissions	Logins y Autorizaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541.indicator.1	Privacidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_list	Listar Usuarios	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.isrc_already_in_database	Ya existe un registro con este ISRC en la base de datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.address_state	Estado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.save_as_new	Guardar como nuevo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.610.indicator.1	Forma de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.isrc	ISRC	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.select.default	Seleccione una opción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.help_about_biblivre	Sobre el Biblivre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.save.success	Registros importados con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.confirm_cancel_editing_title	Cancelar edición de registro de proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.upload_popup.uploading	Enviando archivo...	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	field.error.required	El rellenado de este campo es obligatorio	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.created	Fecha de registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.reserve_date	Fecha de reserva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permission.success.create_login	Login y permisos creados con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.file_not_found	Archivo no encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.issn	ISSN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.043.subfield.a	Código del área geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.reservation_count	Registros reservados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.help_about_library	Sobre la Biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.administration.z3950.server.active	Servidor z39.50 Lugar activo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.indexing_groups.entity	Entidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.success.save	Usuario incluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.310.subfield.a	Periodicidad Corriente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.holdings_reserved	Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.310.subfield.b	Fecha de la periodicidad corriente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.090	Número de llamada / Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_request_delete	Excluir registro de requerimiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.indexing_groups.vt_ta_term	Término Asociado (VT / TA)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.newest_backup	Backup más reciente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.corrupted_backup_file	El backup seleccionado no es un archivo válido o está corrompido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.schemas.description	Abajo están todas las bibliotecas registradas en este Biblivre 4. En caso que quiera alterar un nombre o subtítulo, accese a la pantalla de configuraciones de la biblioteca.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre4restore.description_found_backups_1	Abajo están los backups encontrados en los documentos de su computadora. Para restaurar uno de estos backups, cliquee sobre su nombre.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.150	TE	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_lending_return	Realizar devoluciones de obras	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.failure.delete	Falla al excluir usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_cancel_editing_title	Cancelar edición de registro de solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.add_cards	Agregar Tarjetas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_490	Serie	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.1.0	Ningún nivel especificado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.1.1	Asunto primario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.pg_dump_path	Atención: Esta es una configuración avanzada, pero importante. El Biblivre intentará encontrar automáticamente el camino para el programa <strong>pg_dump</strong> y, excepto en casos donde sea exhibido un error abajo, usted no precisará alterar esta configuración. Esta configuración representa el camino, en el servidor donde el Biblivre está instalado, para lo ejecutable <strong>pg_dump</strong> que es distribuido junto al PostgreSQL. En caso que esta configuración estuviera inválida, el Biblivre no será capaz de generar copias de seguridad.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_authorities_move	Mover registro de autoridad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_move_record_description_singular	¿Usted realmente desea mover este registro?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.title.cancel	Cancelar Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.reservations	Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reindex.warning	Este proceso puede demorar algunos minutos, dependiendo de la configuración de hardware de su servidor. Durante este tiempo, el Biblivre no estará disponible para la búsqueda de registros, pero retornará cuando la indización termine.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.user.simple_term_title	Rellene los términos de la búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.paid_value	Valor Total Pago	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.delete_failure	Falla al excluir la reserva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.082.subfield.a	Número de Clasificación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.lend	Prestar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.acquisition	Adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.913	Código Lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_150	Término Específico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_delete_record_question	¿Usted realmente desea excluir este registro de cotización?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3restore.confirm_description	¿Usted realmente desea restaurar este Backup?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.fieldset.database	Base de Datos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.clear_simple_search	Limpiar resultados de la búsqueda	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.source_search_subtitle	Seleccione una biblioteca remota y rellene los términos de la búsqueda. La búsqueda devolverá un límite de {0} registros. En caso que no encuentre el registro de interés, refine su búsqueda.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.vocabulary_550	Término Genérico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.phone_work_extension	Ramal del Teléfono Comercial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.confirm_delete_record_title.forever	Excluir usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro bibliográfico?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.holding.confirm_cancel_editing_title	Cancelar edición de registro de ejemplar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.late_lendings_count	Total de Préstamos en Atraso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.a	Título uniforme atribuido al documento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.no_records_found	Ningún registro encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.d	Fecha que aparece junto al título uniforme de entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.receipt_date	Fecha de recepción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.user	Informe por Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.p	Nombre de la parte - Sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.number_of_holdings	Número de Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.main	Principal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.f	Fecha de edición del ítem que está siendo procesado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.g	Informaciones adicionales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.page_help	<p>La rutina de Solicitudes permite el registro y búsqueda de solicitudes de obras. Una solicitud es un registro de alguna obra que la Biblioteca desea adquirir, y puede ser utilizada para realizar Cotizaciones con los Proveedores previamente registrados.</p>\n<p>La búsqueda tratará de encontrar cada uno de los términos digitados en los campos <em>Solicitante, Autor o Título</em>.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.no_reserves	Este usuario no posee reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.l	Idioma del texto. Idioma del texto por extenso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.no_language_code_specified	El archivo de traducciones enviado no posee el identificador de idioma: <strong>*language_code</strong>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.082.subfield.2	Número de edición de la CDD	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.confirm_delete_record_question.forever	¿Usted realmente desea excluir este registro de cotización?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.indicator.1	Entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.210.indicator.2	Tipo de Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.distributed.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permission.success.password_saved	Contraseña alterada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.750.indicator.1.2	Asunto secundario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.confirm_delete_record.forever	El Servidor Z39.50 será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_status.inactive	Inactivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.name	Razón Social	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.unavailable	Backup no disponible	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.translations.page_help	<p>El módulo de <strong>"Traducciones"</strong> de Multibibliotecas funciona de forma análoga a su versión de una única biblioteca, no obstante, los textos alterados aquí se aplicarán a todas las bibliotecas del grupo, siempre que estas no hayan alterado el valor original de cada traducción.</p>\n<p>Por ejemplo, si usted altera la traducción de la llave <strong>"menu.search"</strong> de "Búsqueda" para "Busca" por el módulo de traducciones multibibliotecas, todas las bibliotecas de este grupo verán la nueva traducción. Sin embargo, si uno de los administradores de una de estas bibliotecas alterara, a través del módulo de <strong>"Traducciones"</strong> de su biblioteca, la misma llave para "Procurar", esta traducción interna tendrá prioridad, solamente para esta biblioteca.</p>\n<p>Para agregar un nuevo idioma, baje el archivo de idioma en Portugués, realice la traducción de los textos y después envíe el archivo. Recuerde que solamente los <strong>textos</strong> (después del signo igual) deben ser alterados.  No altere las llaves, o el Biblivre 4 no conseguirá localizar el texto</p>\n<p>Ejemplo: digamos que usted quiera alterar el texto en el menú principal de <i>Búsqueda</i> para <i>Busca</i>.  Usted deberá entonces bajar el archivo de idioma y alterar la siguiente línea:</p>\n<p><strong>*menu.search</strong> = Búsqueda</p>\n<p>Para:</p>\n<p><strong>*menu.search</strong> = Busca</p>\n<p>Y entonces hacer el Envío de archivo de idiomas. El Biblivre 4 procesará el archivo, y alterará el texto del menú.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.digitalmedia_upload	Enviar medio digital	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.fine.success_pay_fine	Multa paga con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation_lending	Préstamos y Devoluciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.holdings_count	Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.subfield.a	Apellido y/o nombre del autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.step_1_title	Seleccionar origen de los datos de la importación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.subfield.b	Numeración que sigue al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.651.subfield.y	Subdivisión cronológica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.cataloging.accession_number_prefix	Prefijo del sello patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.651.subfield.x	Subdivisión general	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.reservation.record_list_reserved	Listar solo registros reservados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.651.subfield.z	Subdivisión geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.indexing_groups.event	Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.javascript_locale_not_available	No existe un identificador de idioma javascript para el archivo de traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.321	Periodicidad Anterior	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.no_server_found	Ningún servidor z39.50 encontrado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.invalid_user	Usuario inválido o inexistente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_late_lendings	Préstamos en Atraso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.description	Seleccione abajo qué items desea importar de la base de datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.error	Error	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.total_value	Valor total	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.supplier	Proveedor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.selected_records_singular	{0} registro seleccionado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.020.subfield.a	Número de ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.020.subfield.c	Modalidad de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.confirm_description	¿Usted realmente desea importar los datos del Biblivre 3?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.button.select_reader	Seleccionar lector	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.score	Partitura	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.2	Tipo de ordenación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.groups.digital_media	Medios Digitales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.address_number	Número	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.subfield.q	Forma completa del nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.error.no_quotation_found	Ninguna cotización encontrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.marc_field	Campo Marc	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.subfield.d	Fechas asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100.subfield.c	Título y otras palabras asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.852.indicator.1	Esquema de clasificación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.delivery_time	Plazo de entrega (Prometido)	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.address	Dirección	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_100	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.biblivre_report_header	Informes Biblivre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.all_digits	Todos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	field.error.digits_only	Este campo debe ser rellenado con números	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300	Descripción física	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.change_password.repeat_password	Repita la nueva contraseña	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.306	Tiempo de duración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.card_not_found	Ningúna Tarjeta encontrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.question.block	¿Desea realmente bloquear esta Tarjeta?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.z3950.confirm_delete_record_title.forever	Excluir Servidor Z39.50	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.title.block	Bloquear Tarjeta	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.button.select_user	Seleccionar Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.confirm_delete_record_title.forever	Excluir Tarjeta de Acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.1.0	Sistema de coordenada horizontal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.651.subfield.a	Nombre geográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.unblock	La Tarjeta será desbloqueada y estará disponible para su uso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.block	La Tarjeta será bloqueada y estará indisponible para uso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.310	Periodicidad Corriente	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.1.1	Sistema de coordenada Vertical	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.circulation_access_control_list	Listar control de acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.success.delete	Tipo de Usuario excluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.title	Base de datos seleccionada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.cataloging_vocabulary_save	Guardar registro de vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.error.existing_cards	Las siguientes Tarjetas ya existen:	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.subfield.a	Título del trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.holdings_by_date	Informe de Registro de Ejemplares	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.0	Geográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.next	Próximo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.1	Proyección de mapa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.field.quotation_select	Seleccione una Cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.2	Sistema de coordenadas en grid	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.3	Lugar planear	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	administration.setup.biblivre4restore.confirm_description	Você realmente deseja restaurar este Backup?	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.progress_popup.processing	O Biblivre desta biblioteca está em manutenção. Aguarde até que a mesma seja concluída.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.clean_install.description	Caso você não tenha ou não queira restaurar um backup, esta opção permitirá iniciar o uso do Biblivre 4 com uma base de dados vazia. Após entrar no Biblivre 4 pela primeira vez, utilize o login <strong>admin</strong> e senha <strong>abracadabra</strong> para acessar o sistema e configurar sua nova biblioteca.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.permissions.select.default	Selecione uma opção	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.button	Importar dados do Biblivre 3	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
es	marc.bibliographic.datafield.342.indicator.2.4	Lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_110	Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.subfield.g	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.5	Modelo geodésico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.lendings_current	Total de Libros en préstamo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.authorities_111	Autor Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.6	Altitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.invalid_psql_path	Camino inválido. El Biblivre no será capaz de generar y restaurar backups ya que el archivo <strong>psql</strong> no fue encontrado.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.7	A especificar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	administration.setup.biblivre3migration.description	Foi detectada uma instalação do Biblivre 3 neste computador. Você poderá importar estes dados para o Biblivre 4 selecionando os itens de interesse e clicando no botão abaixo. Após a importação, <strong>você deverá reindexar as três bases: Bibliográfica, Autoridades e Vocabulário</strong>, através da tela <strong>"Manutenção"</strong> em <strong>"Administração"</strong> e <strong>selecionar novamente as permissões dos funcionários com acesso ao Biblivre</strong>, através da tela <strong>"Logins e Permissões"</strong> em <strong>"Administração"</strong>.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.button.continue_to_biblivre	Ir para o Biblivre	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.title_found_backups	Backups Encontrados	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.success.description	Backup restaurado com sucesso	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre3migration.button	Importar dados do Biblivre 3	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.button.show_log	Exibir log	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.maintenance.backup.error.psql_not_found	PSQL não encontrado	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore	Restaurar um Backup do Biblivre 4	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre3import.log_header	[Log de importação de dados do Biblivre 3 para o Biblivre 4]	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.confirm_title	Restaurar Backup	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.page_help	Seja bem-vindo! Esta tela é o último passo antes de iniciar o uso do Biblivre IV e através dela você poderá escolher se irá restaurar as informações de outra instalação do biblivre (através de um backup ou da migração do Biblivre 3) ou se deseja iniciar uma biblioteca nova. Leia atentamente cada uma das opções abaixo e selecione a mais apropriada.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.progress_popup.title	Manutenção do Biblivre 4	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	error.biblivre_is_locked_please_wait	Este Biblivre está em manutenção. Por favor, tente novamente em alguns minutos.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.button	Restaurar backup selecionado	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.success	Restauração de Backup	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.log_header	[Log de restauração de backup do Biblivre 4]	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.clean_install	Nova Biblioteca	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.field.upload_file	Selecionar arquivo de backup	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.description	Use esta opção caso você queira restaurar um backup existente do Biblivre 4. Caso o Biblivre encontre backups salvos em seus documentos, você poderá restaurá-los diretamente da lista abaixo. Caso contrário, você deverá enviar um arquivo de backup (extensão <strong>.b4bz</strong>) através do formulário.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.migration.migrate.error	Falha ao importar os dados	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.clean_install.button	Iniciar como uma nova biblioteca	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.error	Erro ao restaurar backup	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre3migration	Importar dados do Biblivre 3	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.newest_backup	Backup mais recente	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.description_found_backups_1	Abaixo estão os backups encontrados nos documentos do seu computador. Para restaurar um destes backups, clique sobre o seu nome.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.setup.biblivre4restore.error.description	Infelizmente ocorreu um erro ao restaurar este backup do Biblivre 4. Verifique a próxima tela pelo log de erros e, caso necessário, entre no fórum Biblivre para obter ajuda.	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	administration.migration.migrate.success	Dados importados com sucesso	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	common.calculating	Calculando	2014-05-21 21:47:27.923	1	2014-05-21 21:47:27.923	1	f
pt-BR	text.main.noscript		2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.description	Use esta opção caso você queira restaurar e importar um backup existente do Biblivre 3.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore	Restaurar um Backup do Biblivre 3	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.maintenance.backup.description.4	O Backup somente de arquivos digitais é uma cópia de todos os arquivos de mídia digital que foram gravados no Biblivre, sem nenhum outro dado ou informação, como usuários, base catalográfica, etc.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.maintenance.backup.description.3	O Backup sem arquivos digitais é uma cópia de todos os dados e informações do Biblivre 4, <strong>excluindo</strong> os arquivos de mídia digital. Por excluir os arquivos de mídia digital, o processo tanto de backup quanto de recuperação é mais rápido, e o arquivo de backup é menor.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.id_cpf	CPF	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.maintenance.backup.description.1	O Backup é um processo onde executamos a cópia de informações para salvaguardá-las em caso de algum problema no sistema. É uma cópia dos registros e informações do Biblivre. O Biblivre 4 possui 3 tipos de backup:	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.maintenance.backup.description.2	O Backup completo é uma cópia de todos os dados e informações do Biblivre 4, incluindo os arquivos de mídia digital, como fotos dos usuários, arquivos digitais dos registros bibliográficos, etc.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.upload_popup.processing	Processando...	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	multi_schema.manage.button.show_log	Exibir log	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	multi_schema.manage.error.create	Falha ao criar nova biblioteca.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	cataloging.bibliographic.button.export_records	Exportar registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.setup.biblivre3import.description	Foi detectada uma instalação do Biblivre 3 neste computador. Você poderá importar estes dados para o Biblivre 4 selecionando os itens de interesse e clicando no botão abaixo. Após a importação, <strong>você deverá reindexar as três bases: Bibliográfica, Autoridades e Vocabulário</strong>, através da tela <strong>"Manutenção"</strong> em <strong>"Administração"</strong> e <strong>selecionar novamente as permissões dos funcionários com acesso ao Biblivre</strong>, através da tela <strong>"Logins e Permissões"</strong> em <strong>"Administração"</strong>.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.error.description	Infelizmente ocorreu um erro ao restaurar este backup do Biblivre 3. Verifique a próxima tela pelo log de erros e, caso necessário, entre no fórum Biblivre para obter ajuda.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.address_complement	Complemento	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.permissions.items.cataloging_bibliographic_private_database_access	Acesso à Base Privada.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.no_backups_found	Nenhum backup encontrado	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	marc.bibliographic.datafield.013.subfield.d	Data	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.warning	Este processo pode demorar alguns minutos, dependendo da configuração de hardware do seu servidor.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.address	Endereço	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.address_zip	CEP	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.configuration.description.general.multi_schema	Esta configuração permite que se habilite o sistema de múltiplas bibliotecas nesta instalação do Biblivre 4.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	multi_schema.manage.log_header	[Log de criação de nova biblioteca do Biblivre 4]	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.success	Restauração de Backup	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.button	Restaurar backup selecionado	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.success	Importação de dados do Biblivre 3	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.error.description	Infelizmente ocorreu um erro ao importar os dados do Biblivre 3. Verifique a próxima tela pelo log de erros e, caso necessário, entre no fórum Biblivre para obter ajuda.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.address_city	Cidade	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.configuration.title.general.multi_schema	Habilitar Multi-bibliotecas	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.select_file	Selecione um arquivo de backup primeiro	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.lending.reserved.warning	Todos os exemplares disponíveis deste registro estão reservados para outros leitores. O empréstimo pode ser efetuado, porém verifique as informações de reservas.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.phone_cel	Celular	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import	Importar dados do Biblivre 3	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.upload_popup.uploading	Enviando arquivo...	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.phone_home	Telefone Residencial	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.confirm_title	Restaurar Backup	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	multi_schema.manage.error.description	Falha ao criar nova biblioteca	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.error	Erro ao importar dados	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.error	Erro ao restaurar backup	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.permissions.groups.digitalmedia	Mídia Digital	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.field.upload_file	Selecionar arquivo de backup	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.permissions.reader	Leitor	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.success.description	Backup restaurado com sucesso	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.confirm_title	Importar dados do Biblivre 3	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	multi_schema.manage.success.create	Nova biblioteca criada com sucesso.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.configuration.description.multi_schema.enabled	O sistema de multi-bibliotecas já está habilitado para esta instalação do Biblivre 4. O administrador do sistema poderá desabilitar essa opção no menu de configuração de multi-bibliotecas.	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.birthday	Data de Nascimento	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.address_state	Estado	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.select.default	Selecione uma opção	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3restore.confirm_description	Você realmente deseja restaurar este Backup?	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.phone_work_extension	Ramal do Telefone Comercial	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.permissions.items.digitalmedia_upload	Enviar mídia digital	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.confirm_description	Você realmente deseja importar os dados do Biblivre 3?	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.address_number	Número	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.gender.1	Masculino	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.gender.2	Feminino	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.id_rg	Identidade	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	circulation.custom.user_field.phone_work	Telefone Comercial	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.upload_popup.title	Abrindo Arquivo	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	administration.setup.biblivre3import.success.description	Dados importados com sucesso	2014-06-14 19:32:35.338749	1	2014-06-14 19:32:35.338749	1	f
pt-BR	acquisition.supplier.confirm_delete_record_title.forever	Excluir registro de fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.circulation_user	Cadastro de Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.dewey	Relatório de Classificação Dewey	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_reports	Relatórios	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.digits	Dígitos significativos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.object_3d	Objeto 3D	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.error.invalid_data	Não foi possível processar a operação. Por favor, tente novamente.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.cancel	Cancelar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.supplier	Fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.022.subfield.a	Número do ISSN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.title	Nome da biblioteca	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.013.subfield.e	Estado da patente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.error.record_not_found	Registro não encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.013.subfield.f	Parte de um documento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de Pedido?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.256.subfield.a	Características do arquivo de computador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.date_from	De	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.date	Data	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.button_exclude_digital_media	Gerar backup sem arquivos digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.psql_path	Caminho para o programa psql	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging	Catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_913	Código Local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.013.subfield.a	Número	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.013.subfield.b	País	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.013.subfield.c	Tipo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.upload_button	Enviar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.search.distributed_search_limit	Limite de resultados para buscas distribuídas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.default	Selecione...	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.490.indicator.1	Política de desdobramento de série	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.users_who_have_login_access	Listar apenas usuários que possuem login de acesso ao Biblivre	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.title.unit_value	Valor Unitário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.email	Email	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.circulation_user_cards	Impressão de Carteirinhas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.attachment.alias	Digite um nome para este arquivo digital	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.fieldset.title_info	Dados da Obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.indicator.1.2	sobrenome composto (obsoleto)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.indicator.1.3	nome de família	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.indicator.1.0	prenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.indicator.1.1	sobrenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.082	Classificação Decimal Dewey	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.080	Classificação Decimal Universal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.indicator.1.8	Não gerar constante na exibição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.title_last_backups	Últimos Backups	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.marc_popup.title	Editar Registro MARC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.arrival_time	Data de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.success.update	Registro alterado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.indicator.1.0	Índice remissivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.dewey	Classificação Dewey	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.title.requisition	Requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.save	Salvar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.1.0	Não gera entrada para o título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.1.1	Gera entrada para o título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.save	Salvar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.095	Área do conhecimento do CNPq	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_z3950_delete	Excluir registro de servidor z3950	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.fine_value	Valor da multa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.error.no_users_found	Nenhum usuário encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.090	Número de chamada - Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_delete_record_title	Excluir registro de cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.card_unavailable	Cartão indisponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.subject	Assunto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.simple_term_title	Preencha o Código do Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.error.invalid_restore_path	O diretório configurado para restauração dos arquivos de backup não é valido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.pg_dump_path	Caminho para o programa pg_dump	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.add_one_card	Cadastrar Novo Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_z3950_save	Salvar registro de servidor z3950	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_move_record_description_plural	Você realmente deseja mover estes {0} registros?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.button.select_item	Selecionar exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.isbn	ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.backup_path	Caminho de destino das cópias de segurança (Backups)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_300	Descrição física	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload.button	Enviar o idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.340.subfield.e	Suporte	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_cancel_editing.1	Você deseja cancelar a edição deste usuário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.340.subfield.c	Materiais aplicados à superfície	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.340.subfield.d	Técnica em que se registra a informação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_306	Tempo de duração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.340.subfield.a	Base e configuração do material	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.340.subfield.b	Dimensões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2._	nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.invalid_method_call	Chamada a método inválido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_411	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_410	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.cataloging_bibliographic	Catálogo Bibliográfico e de Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.issn	ISSN (incluindo hífens)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.no_permission	Você não tem permissão para executar esta ação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.new	Novo usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.2	Tesauro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.1	Nível do assunto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.help_manual	Manual	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.id	N&ordm; do registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.all_users	Relatório de Todos os Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.invoice_number	N&ordm; da Nota Fiscal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.indexing_groups.te_term	Termo Específico (TE)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.description_last_backups_1	Abaixo estão os links para download dos últimos backups realizados. É importante guardá-los em um local seguro, pois esta é a única forma de recuperar seus dados, caso necessário.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.450.subfield.a	Termo tópico não usado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.description_last_backups_2	Estes arquivos estão guardados no diretório especificado na configuração do Biblivre (<em>"Administração"</em>, <em>"Configurações"</em>, no menu superior). Caso este diretório não esteja disponível para escrita no momento do backup, um diretório temporário será usado em seu lugar. Por este motivo, alguns dos backups podem não estar disponíveis após certo tempo. <span class="attention">Recomendamos sempre fazer o download do backup e guardá-lo em um local seguro.</span>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.users.title	Pesquisar Leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.040.subfield.e	Fontes convencionais de descrições de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.1.3	nome de família	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.040.subfield.d	Agência que alterou o registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.040.subfield.c	Agência que transcreveu o registro em formato legível por máquina	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.040.subfield.b	Idioma da catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.040.subfield.a	Código da Agência Catalogadora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.1.0	prenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.invalid_json	O Biblivre não foi capaz de entender os dados recebidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.1.1	sobrenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	aquisition.request.error.request_not_found	Não foi possível encontrar a requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.1.2	sobrenome composto (obsoleto)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.database	Base	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.success.block	Cartão bloqueado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.error.delete	Falha ao excluir o servidor z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.search.results_per_page	Esta configuração representa a quantidade máxima de resultados que serão exibidas em uma única página nas pesquisas do sistema. Um número muito grande poderá deixar o sistema mais lento.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.a	Nome da entidade ou do lugar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.password	Senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.b	Unidades subordinadas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_name	Nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.button_digital_media_only	Gerar backup de arquivos digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.n	Número da parte - seção da obra - ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_status.active	Ativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.save	Não foi possível salvar as traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.k	Subcabeçalho. (emendas, protocolos, seleção, etc)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_400	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.subfield.t	Título da obra junto à entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.2	Tipo de entrada secundária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_move_record_title	Mover registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.custom_count	Relatório de contagem do campo Marc	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_signup	Data de Matrícula	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.550.subfield.z	Subdivisão geográfica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.550.subfield.x	Subdivisão geral adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.550.subfield.y	Subdivisão cronológica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.dates	Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.page_help	<p>O módulo de <strong>"Migração de Dados"</strong> permite importar os dados constantes de uma base de dados do Biblivre 3 existente para a base de dados vazia do Biblivre 4.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.362.subfield.z	Fonte de informação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.error.user_not_found	Usuário não encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.users	Usuários, Logins de acesso e Tipos de Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	header.law	Lei de Incentivo à Cultura	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.step_1_description	Neste passo, você pode importar um arquivo contendo registros nos formatos MARC, XML e ISO2709 ou fazer uma pesquisa em outras bibliotecas. Selecione abaixo o modo de importação desejado, selecionando o arquivo ou preenchendo os termos da pesquisa. No passo seguinte, você poderá selecionar quais registros deverão ser importados.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_delete_record_question	Você realmente deseja excluir este registro de vocabulário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.printer_type.printer_24_columns	Impressora 24 colunas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.book	Livro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.database_count	Total de Registros nas Bases no Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.913.subfield.a	Código local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.acquisition	Data de aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.source_file_subtitle	Selecione um arquivo contendo os registros a serem importados. O formato deste arquivo pode ser <strong>texto</strong>, <strong>XML</strong> ou <strong>ISO2709</strong>, desde que a catalogação original seja compatível com MARC.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_delete_record_question.forever	Você realmente deseja excluir este usuário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.670	Origem das informações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.default_language	Idioma padrão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.default_language	Esta configuração representa o idioma padrão para exibição do Biblivre.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.1	Gera entrada secundária na ficha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.java_locale_not_available	Não existe um identificador de idioma java para o arquivo de traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.circulation.lending_receipt.printer.type	Esta configuração representa o tipo de impressora que será utilizada para a impressão de recibos de empréstimos.  Os valores possíveis são: impressora de 40 colunas, de 80 colunas, ou impressora comum (jato de tinta).	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.0	Parte do título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.685	Nota de histórico ou glossário (GLOSS)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.field.port	Porta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload.field.upload_file	Arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.680	Nota de escopo (NE)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.5	Título adicional em página de rosto secundária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.label.author_count	Quantidade de registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.invalid_language	Selecione um idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.6	Título de partida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.7	Título corrente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.8	Título da lombada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.1	Título paralelo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.2	Título específico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.loading	Carregando	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.3	Outro título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2.4	Título da capa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.step_2_description	Neste passo, confira os registros que serão importados e importe-os individualmente ou em conjunto, através dos botões disponíveis no final da página. O Biblivre detecta automaticamente se o regristo é bibliográfico, autoridades ou vocabulário, porém permite que o usuário corrija antes da importação. <strong>Importante:</strong> Os registros importados serão adicionados à Base de Trabalho e deverão ser corrigidos e ajustados antes de serem movidos para a Base Principal. Isso evita que registros incorretos sejam adicionados diretamente à base de dados final.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.terms_of_payment	Forma de pagamento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_310	Peridiocidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.450	UP (remissiva para TE não usado)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.reserve_failure	Falha ao reservar a obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.550.subfield.a	Termo tópico adotado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.summary	Sumário do Catálogo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.dewey	Classificação Decimal Dewey	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.362.subfield.a	Informação de Datas de Publicação e/ou Volume	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.040	Fonte da Catalogação (NR)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.success.update	Fornecedor salvo com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.n	Número de ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_362	Data da primeira publicação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	language_code	pt-BR	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.e	Nome das subunidades do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.a	Nome do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.page_help	<p>O módulo de <strong>"Traduções"</strong> permite adicionar novos idiomas ao Biblivre 4 ou alterar os textos já existentes.</p>\n<p><strong>Atenção: Este módulo realiza configurações avançadas do Biblivre 4, e deve ser utilizado apenas por Usuários avançados, com experiência em informática.</strong>.</p>\n<p>Para adicionar um novo idioma, baixe o arquivo de idioma em Português, faça a tradução dos textos e depois faça o envio do arquivo. Lembre-se que apenas os <strong>textos</strong> (depois do sinal de igual) devem ser alterados.  Não altere as chaves, ou o Biblivre 4 não conseguirá localizar o texto</p>\n<p>Exemplo: digamos que você queira alterar o texto no menu principal de <i>Pesquisa</i> para <i>Busca</i>.  Você deverá então baixar o arquivo do idioma e alterar a seguinte linha:</p>\n<p><strong>*menu.search</strong> = Pesquisa</p>\n<p>Para:</p>\n<p><strong>*menu.search</strong> = Busca</p>\n<p>E então fazer o Envio do arquivo de idiomas. O Biblivre 4 irá processar o arquivo, e alterar o texto do menu.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.current_password	Senha atual	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.subfield.v	Número do volume ou designação sequencial da série	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.error.select_reader_first	Para reservar um registro você precisa, primeiramente, selecionar um leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.0	Classificação da LC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.2	National Library of Medicine Classification	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.1	CDD	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.4	Localização fixa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.3	Superintendent of Documents classification	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.6	Em parte separado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.5	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.operator.and_not	e não	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.user.field	Campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.7	Classificação específica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1.8	Outro esquema	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.periodic	Periódico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.subfield.a	Título Uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.edition	Edição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_field.name	Nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.all_users	Relatório Geral de Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.dewey	CDD	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.949.subfield.a	Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.090.subfield.a	Classificação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.isbn_already_in_database	Já existe um registro com este ISBN na base de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.090.subfield.b	Código do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.success.delete	Registro excluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.090.subfield.c	Edição - volume	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.090.subfield.d	Número do Exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_040	Fonte de catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.indicator.1._	Índice	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.holdings_lent	Emprestados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.search.result_limit	Esta configuração representa a quantidade máxima de resultados que serão encontrados em uma pesquisa catalográfica. Este limite é importante para evitar lentidões no Biblivre em bibliotecas que possuam uma grande quantidade de registros. Caso a quantidade de resultados da pesquisa do usuário exceda este limite, será recomendado que ele melhore os filtros da pesquisa.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.record_imported_successfully	Registro importado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.buttons.dismiss_fine	Abonar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.returned_lendings	Empréstimos devolvidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.257.subfield.a	País da entidade produtora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.back_to_search	Retornar à pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.invalid_database		2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_450	Termo Use Para	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.button.edit_marc	Editar MARC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.wait	Aguarde	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.success.save	Servidor z39.50 salvo com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1._	Nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630	Assunto - Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.music	Música	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.success.delete	Servidor z39.50 excluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.t	Título da obra junto à entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.status	Situação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.670.subfield.b	Informações encontradas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.fine_popup.title	Devolução em atraso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.670.subfield.a	Nome retirado de	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.lending_date	Data de Empréstimo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.buttons.pay_fine	Pagar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.410.subfield.a	Nome da entidade ou do lugar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.cataloging_vocabulary	Catálogo de Vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.e	Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.b	Descrição da coleção impressa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.c	Tipo de aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.page_help	<p>A rotina de Permissões permite a criação de Login e Senha para um usuário, assim como a definição de suas permissões de acesso ou utilização das diversas rotinas do Biblivre.</p>\n<p>A pesquisa buscará os usuários já cadastrados no Biblivre, e funciona da mesma forma que a pesquisa simplificada da rotina de Cadastro de Usuários.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.all	Qualquer campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.651	Assunto - Nome geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.650	Assunto - Tópico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.confirm_delete_record.forever	O Cartão será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.help_faq	Perguntas Frequentes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.success.save	Cartão incluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_852	Notas públicas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.acquisition_order	Pedidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.load	Não foi possível ler o arquivo de traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload_popup.title	Enviando Arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.id	Nro. Registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.error.no_request_found	Não foi possível encontrar nenhuma Requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_bibliographic_save	Salvar registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.original_value	Valor original	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.photo	Foto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_supplier_delete	Excluir registro de fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.confirm_delete_record_question.forever	Você realmente deseja excluir este Servidor Z39.50?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.z	Nota padrão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.q	Descrição do índice em multimeio	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.p	Descrição da coleção em multimeio	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.o	Descrição do índice em microfilme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_830	Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.n	Descrição da coleção em microfilme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.u	Descrição do índice em outros suportes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.t	Descrição da coleção em outros suportes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.pamphlet	Panfleto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.s	Descrição do índice em braile	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.r	Descrição da coleção em braile	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.i	Descrição do índice com acesso on-line	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.f	Código da biblioteca no CCN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.g	Descrição do índice de coleção impressa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.l	Descrição da coleção em microficha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.m	Descrição do índice em microficha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.j	Descrição da coleção em CD-ROM	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.2	Tesauro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.k	Descrição do índice em CD-ROM	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.issn	ISSN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.1	Nível do assunto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610	Assunto - Entidade Coletiva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.search_authorities	Autoridades	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.a	Sigla da biblioteca	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.psql_path	Atenção: Esta é uma configuração avançada, porém importante. O Biblivre tentará encontrar automaticamente o caminho para o programa <strong>psql</strong> e, exceto em casos onde seja exibido um erro abaixo, você não precisará alterar esta configuração. Esta configuração representa o caminho, no servidor onde o Biblivre está instalado, para o executável <strong>psql</strong> que é distribuído junto do PostgreSQL. Caso esta configuração estiver inválida, o Biblivre não será capaz de gerar e restaurar cópias de segurança.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611	Assunto - Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947.subfield.d	Ano da última aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.card_in_use	Cartão em uso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.field_count	Contagem por campo Marc	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041.subfield.b	Código do idioma do sumário ou resumo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041.subfield.a	Código do idioma do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_delete_record_question	Você realmente deseja excluir este registro de exemplar?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.button_bibliographic	Reindexar base bibliográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.database.main	Principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600	Assunto - Nome pessoal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.indicator.1.0	Data - período únicos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041.subfield.h	Código do idioma do documento original	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.status	Situação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.edit	Editar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.indicator.1.2	Extensão de datas - períodos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.indicator.1.1	Data - período múltiplos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.subject	Assunto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_delete_record.inactive	Ele sairá da lista de pesquisas e só poderá ser encontrado através da "pesquisa avançada", de onde poderá ser excluído permanentemente ou recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.150.subfield.z	Subdivisão geográfica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.place	Local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.150.subfield.y	Subdivisão cronológica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.150.subfield.x	Subdivisão geral adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.isrc	ISRC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.lendings	Empréstimos ativos, histórico de empréstimos e multas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.150.subfield.a	Termo tópico adotado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.subfield.d	Escala da Longitude	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.subfield.c	Escala da Latitude	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.error.save	Falha ao salvar o Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.acquisition	Aquisições (Fornecedor, Requisição, Cotação e Pedido)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.trash_full	Lixeira	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.users.title	Pesquisar Leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.status.any	Qualquer	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.confirm_delete_record_question.forever	Você realmente deseja excluir este Cartão?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	field.error.invalid	Este valor não é válido para este campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.150.subfield.i	Qualificador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.subfield.a	Nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.subfield.b	Unidade das Coordenadas ou Unidade da Distância	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_usertype_save	Salvar registro de tipo de usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access.user.search	Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.indexing_groups.all	Qualquer campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_876	Nota de acesso restrito	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.indicator.1.3	nome de família	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.question.unblock	Deseja realmente desbloquear este Cartão?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.indicator.1.1	sobrenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.movie	Filme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.cataloging_authorities	Catálogo de Autoridades	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.indicator.1.2	sobrenome composto (obsoleto)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.indicator.1.0	prenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.holdings	Relatório de Cadastro de Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.unit_value	Valor Unitário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_usertype_delete	Excluir registro de tipo de usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.2.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.status.in_use	Em uso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.save_as_new	Salvar como Novo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.void		2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.670	Origem das informações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.info	Observações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.status.cancelled	Cancelado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.error.invalid_backup_type	O modo de backup selecionado não existe	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.operator.or	ou	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110	Autor - Entidade coletiva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111	Autor - Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.b	Complemento do título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.author	Pesquisa por Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.lending_limit	Limite de empréstimos simultâneos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	label.username	Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.a	Título/título abreviado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.error.delete.user_has_lendings	Este usuário possui empréstimos ativos.  Realize a devolução antes de excluir este usuário.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.user_has_card	Usuário já possui um cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.g	Miscelânea	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.select_card	Selecionar Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.f	Informação de volume/número de fascículo e/ou data da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.i	Exibir texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.h	Meio físico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.504.subfield.a	Notas de bibliografia	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.expected_return_date	Data para devolução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.field.name	Nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.n	Número da parte/seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.invalid_backup_path	Caminho inválido. Este diretório não existe ou o Biblivre não possui permissão de escrita.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.subfield.p	Nome da parte/seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100	Autor - Nome pessoal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.new_value	Novo valor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.page_help	<p>O <strong>"Controle de Acesso"</strong> permite gerenciar a entrada e permanência dos leitores nas instalações da biblioteca. Selecione o leitor através de uma pesquisa por nome ou matrícula e digite o número de um cartão de acesso disponível para vincular aquele cartão ao leitor.</p>\n<p>No momento da saída do leitor, você poderá desvincular o cartão procurando pelo código do mesmo</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.2.2	entrada analítica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.title	Título Principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.total	Total	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.marc_field	Valor do campo Marc	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.1	Gera entrada secundária na ficha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.computer_legible	Arquivo de Computador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.usertype.confirm_delete_record.forever	O Tipo de Usuário será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload.title	Enviar arquivo de idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_datamigration	Importar dados do Biblivre 3	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130	Obra anônima	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.save	Falha ao salvar o Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.page_help	<p>A pesquisa distribuída permite recuperar informações sobre registros em acervos de outras bibliotecas, que disponibilizam seus registros para pesquisa e catalogação colaborativa.</p>\n<p>Para realizar uma pesquisa, preencha os termos da pesquisa, selecionando o campo de interesse. Em seguida, selecione uma ou mais bibliotecas onde os registros deverão ser localizados. <span class="warn">Atenção: selecione poucas bibliotecas para evitar que a busca distribuída fique muito lenta, visto que ela depende da comunicação entre as bibliotecas e o tamanho de cada acervo.</span></p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.printer_type.printer_common	Impressora comum	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.number_of_titles	Número de Títulos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_count_by_type	Totais por Tipos de Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.login_data	Dados para acesso ao sistema	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.employee	Funcionário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.step_2_title	Selecionar registros para importação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.uncancel	Recuperar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.current_value	Valor atual	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.error.delete	Falha ao exluir o Registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_cancel_editing_title	Cancelar edição de registro de Pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permission.error.delete	Falha ao excluir o login	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_status.blocked	Bloqueado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.start_date	Data Inicial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.680.subfield.a	Nota de escopo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.return	Devolver	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.095.subfield.a	Área do conhecimento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_cancel_editing_title	Cancelar edição de usuáro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de vocabulário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.import_as	Importar como:	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_authorities_save	Salvar registro de autoridade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.thesis	Tese	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.import_popup.importing	Importando registros, por favor, aguarde	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.fieldset.title.values	Valores	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.150	TE	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.acquisition_request	Requisições	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.1.0	Nenhum nível especificado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.1.1	Assunto primário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.1.2	Assunto secundário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.download.description	Selecione abaixo o idioma que deseja baixar.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.zip_code	CEP	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.delete	Excluir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.z3950_servers	Servidores Z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.lending_date	Data do empréstimo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.info	Observações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.trademark	Nome Fantasia	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.remove_item_button	Excluir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.indicator.1._	Subcampos |b ou |c não estão presentes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	aquisition.supplier.error.supplier_not_found	Não foi possível encontrar o fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.other_name	Outra Forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.button.print_user_cards	Imprimir carteirinhas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.indexing_groups.tg_term	Termo Geral (TG)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.description.6	Caso o usuário perca a sua senha, o mesmo deverá entrar em contato com o Administrador ou Bibliotecário responsável pelo Biblivre, que poderá fornecer uma nova senha.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.issn_already_in_database	Já existe um registro com este ISSN na base de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.a	Título uniforme atribuído ao documento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.field.url	URL	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.delete	Falha ao exluir o Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.550.subfield.y	Subdivisão cronológica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.d	Data que aparece junto ao título uniforme na entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.550.subfield.z	Subdivisão geográfica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.l	Língua do texto. Idioma do texto por extenso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.f	Data da edição do item que está sendo processado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.913.subfield.a	Código local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.return_date	Data de devolução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.description.1	A troca de senha é o processo no qual um usuário pode alterar a sua senha atual por uma nova. Por questões de segurança, sugerimos que o usuário realize este procedimento periodicamente.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.error.move	Falha ao mover os Registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_datamigration	Migração de Dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.button.search	Pesquisar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.description.3	Misture letras, símbolos especiais e números na sua senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.description.2	A única regra para criação de senhas no Biblivre é a quantidade mínima de 3 caracteres. No entanto, sugerimos seguir as seguintes diretivas:	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.page_help	<p>A importação de registros permite expandir sua base de dados sem que haja necessidade de catalogação manual. Novos registros podem ser importados através de pesquisas Z39.50 ou a partir de arquivos exportados por outros sistemas de biblioteconomia.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.description.5	Use uma quantidade de caracteres superior ao recomendado.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.p	Nome da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.description.4	Use letras maiúsculas e minúsculas; e	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.550.subfield.a	Termo tópico adotado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.subfield.z	Subdivisão geográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.subfield.y	Subdivisão cronológica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.block	Bloquear	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.949.subfield.a	Tombo patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.subfield.a	Termo tópico adotado no tesauro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.410.subfield.a	Nome da entidade ou do lugar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.550.subfield.x	Subdivisão geral adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.renew_success	Empréstimo renovado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging_vocabulary	Vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.labels.never_printed	Listar apenas exemplares que nunca tiveram etiquetas impressas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.user_total_lending_list	Histórico de empréstimos a este leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.manuscript	Manuscrito	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.step	Passo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.operator.and	e	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_authorities_delete	Excluir registro de autoridade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.question.cancel	Deseja realmente cancelar este Cartão?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.cancel	Cancelar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.success.generate	Relatório gerado com sucesso. O mesmo será aberto em outra página.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.selected_records_singular	{0} exemplar selecionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.502.subfield.a	Notas de dissertação ou tese	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.groups.acquisition	Aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.auto_download	Backup realizado, baixando automaticamente em alguns segundos...	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.record_deleted	Registro excluído definitivamente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.040.subfield.c	Agência que transcreveu o registro em formato legível por máquina	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.040.subfield.b	Língua da catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.040.subfield.e	Fontes convencionais de descrições de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.040.subfield.d	Agência que alterou o registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.040.subfield.a	Código da agência catalogadora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.searches_by_date	Relatório de Total de Pesquisas por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.runtime_error	Erro inesperado durante a execução da tarefa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.subtitle	Títulos paralelos/subtítulo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.indicator.1	Tipo do período cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.success.save	Fornecedor incluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_backup	Realizar cópia de segurança da base de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.form.hidden_subfields_plural	Exibir {0} subcampos ocultos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.page_help	<p>Para realizar uma reserva você deverá selecionar o leitor para o qual a reserva será realizada e, em seguida, selecionar o registro que será reservado. A pesquisa pelo leitor pode ser feita por nome, matrícula ou outro campo previamente cadastrado. Para encontrar o registro, realize uma pesquisa similar à pesquisa bibliográfica.</p>\n<p>Cancelamentos podem ser feitos selecionando o leitor que possui a reserva.</p><p>A duração da reserva é calculada de acordo com o tipo de usuário, configurado pelo menu <strong>Administração</strong> e definido durante o cadastro do leitor.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.users_with_pending_fines	Listar apenas usuários com multas pendentes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_delete_record_title	Excluir registro de fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.acquisition	Relatório de Pedidos de Aquisição Efetuados Por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.confirm_delete_record.forever	Tanto o Login do Usuário quanto suas Permissões serão excluídos permanentemente do sistema e não poderão ser recuperados.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.return_success	Exemplar devolvido com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.search_count	{current} / {total}	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.printer_type.printer_80_columns	Impressora 80 colunas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.administration.z3950.server.active	Esta configuração representa se o servidor z39.50 local estará ativo. Nos casos de instalações multi-biblioteca, o nome da Coleção do servidor z39.50 será igual ao nome de cada biblioteca. Por exemplo, o nome da coleção para esta instalação é "{0}".	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.search_z3950	Distribuída	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.400	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.user.name_or_id	Nome ou Matrícula	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.start_less_than_or_equals_end	O Número inicial deve ser menor ou igual ao Número final	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.success.update	Usuário salvo com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.title	Cópia de Segurança (Backup)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.error.invalid_marc	Falha ao ler o Registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_cancel_editing_title	Cancelar edição de registro de vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.no_fines	Este usuário não possui multas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.410	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.button.generate_report	Emitir Relatório	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.subfield.b	Unidades subordinadas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.accession_number	Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de exemplar?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.return.success	Cartão devolvido com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.title	Importação de Registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.in_this_library	Nesta biblioteca	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.subfield.n	Número da parte seção da obra ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.usertype.confirm_delete_record_question.forever	Você realmente deseja excluir este Tipo de Usuário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.success.delete	Usuário excluído permanentemente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	label.logout	Sair	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.quotation	Cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.requisition_select	Selecione uma Requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.holdings	Relatório de Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	warning.create_backup	Você está a mais de 3 dias sem gerar uma cópia de segurança (backup)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.user.remove_item_button	Excluir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.subfield.a	Nome da entidade ou do lugar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.580	Nota de Ligação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_status	Situação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_status.active	Ativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.1.1	Gerar nota e entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.subfield.a	Título adicional - Título analítico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.1.0	Gerar nota, não gerar entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.database_work	Trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.usertype.confirm_delete_record_title.forever	Excluir Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_quotation_delete	Excluir registro de cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.switch_to	Trocar para	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.1.3	Não gerar nota, gerar entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.1.2	Não gerar nota nem entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.common.digital_files	Arquivos Digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.dewey	Estatística por Classificação Dewey	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.subfield.n	Número da parte - Seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.subfield.p	Nome da parte - Seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.country	País	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.page_help	<p>O módulo <strong>"Impressão de Etiquetas"</strong> permite gerar as etiquetas de identificação interna e de lombada para os exemplares da biblioteca.</p>\n<p>É possível gerar as etiquetas de um ou mais exemplares em uma única impressão, utilizando a pesquisa abaixo. Fique atento ao detalhe de que o resultado desta pesquisa é uma lista de exemplares e não de registros bibliográficos.</p>\n<p>Após encontrar o(s) exemplare(s) de interesse, use o botão <strong>"Selecionar exemplar"</strong> para adicioná-los à lista de impressão de etiquetas. Você poderá fazer diversas pesquisas, sem perder a seleção feita anteriormente. Quando finalmente estiver satisfeito com a seleção, clique no botão <strong>"Imprimir etiquetas"</strong>. Será possível selecionar qual modelo da folha de etiquetas a ser usado e de qual posição iniciar.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.024.indicator.1.2	International Standard Music Number (ISMN)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.024.indicator.1.0	International Standard Recording Code (ISRC)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.accession_number	Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.user_has_no_card	Não há cartão associado a este usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.date_to	a	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.deleted	Excluído	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.in_these_libraries	Nestas bibliotecas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging_import	Importação de Registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.590	Notas locais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.yes	Sim	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.595	Notas para inclusão em bibliografias	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.download.title	Baixar arquivo de idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.button.import_this_record	Importar este registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.status.in_use_and_blocked	Em uso e bloqueado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.lendings_late	Total de Livros atrasados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_delete_record_question	Você realmente deseja excluir este registro de fornecedor?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.select_item	Selecionar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.450.subfield.a	Termo tópico não usado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.error.save	Falha ao gravar o Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2	Dimensões de referência geospacial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.580.subfield.a	Nota de Ligação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.1	Dimensões de referência geospacial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_returned_lendings	Histórico de Devoluções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_z3950_search	Listar servidores z3950	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.password.success	Senha alterada com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	label.password	Senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.button.select_item	Selecionar usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.select_marc_field	Selecione um campo Marc	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.simple_search	Pesquisa Bibliográfica Simplificada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.holding_id	Nro. Registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.form.repeat	Repetir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_cancel_editing_title	Cancelar edição de registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246	Forma Variante de Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.subfield.a	Termo tópico adotado no tesauro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.topographic	Relatório Topográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_status.pending_issues	Possui pendências	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.returns	Devoluções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.error.no_records_found	Nenhum registro encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.today	Hoje	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.indicator.1.0	nome invertido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.lendings	Relatório de Empréstimos por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_360	Termo Associado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.form_invalid_values	Foram encontrados erros no preenchimento do formulário abaixo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.user	Relatório por Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	field.error.max_length	Este campo deve possuir no máximo {0} caracteres	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555	Nota de Índice Cumulativo ou Remissivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.isbn	ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.status.blocked	Bloqueado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.inactive_users_only	Listar apenas usuários inativos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.page_help	<p>A rotina de Configurações permite a configuração de diversos parâmetros utilizados pelo Biblivre, como por exemplo o Título da Biblioteca, o Idioma Padrão ou a Moeda a ser utilizada. Cada configuração possui um texto explicativo para facilitar a sua utilização.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.lendings_by_date	Relatório de Empréstimos por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.last_backup	Último Backup	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.550	TG (termo genérico)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_243	Título uniforme coletivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.delete	Excluir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.2.2	Numeração alternada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.360	Remissiva VT (ver também) e TA (termo relacionado ou associado)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	warning.change_password	Você ainda não mudou a senha padrão de administrador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.total	Total	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_240	Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.2.1	Numeração primária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.2.0	Não numerada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.525	Nota de Suplemento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.print_return_receipt	Imprimir recibo de devolução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.popup.description	Selecione em qual etiqueta deseja iniciar a impressão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.error.delete	Falha ao exluir a Requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.521	Notas de público alvo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.024.indicator.1	Tipo do número ou código normalizado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_accesscards_list	Listar cartões de acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_245	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.520	Notas de resumo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.250.subfield.b	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.250.subfield.a	Indicação da edição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.error.type_has_users	Este Tipo de Usuário possui Usuários cadastrados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.error.delete	Falha ao exluir o Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.indicator.2._	Título chave abreviado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.add_multiple_cards	Cadastrar Sequência de Cartões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	digitalmedia.error.file_not_found	O arquivo especificado não foi encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.error.delete	Falha ao exluir a cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	warning.fix_now	Resolver este problema	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.availability.available	Disponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_delete_record_title	Excluir registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.status.available	Disponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.holding.availability	Disponibilidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.subfield.c	Indicação de responsabilidade da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.return_date	Data da devolução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.subfield.a	Título principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.page_help	<p>A pesquisa bibliográfica permite recuperar informações sobre os registros do acervo desta biblioteca, listando seus exemplares, campos catalográficos e arquivos digitais.</p>\n<p>A forma mais simples é usar a <strong>pesquisa simplificada</strong>, que buscará cada um dos termos digitados nos seguintes campos: <em>{0}</em>.</p>\n<p>As palavras são pesquisadas em sua forma completa, porém é possível usar o caractere asterisco (*) para buscar por palavras incompletas, de modo que a pesquisa <em>'brasil*'</em> encontre registros que contenham <em>'brasil'</em>, <em>'brasilia'</em> e <em>'brasileiro'</em>, por exemplo. Aspas duplas podem ser usadas para encontrar duas palavras em sequência, de modo que a pesquisa <em>"meu amor"</em> encontre registros que contenham as duas palavras juntas, mas não encontre registros com o texto <em>'meu primeiro amor'</em>.</p>\n<p>A <strong>pesquisa avançada</strong> confere um maior controle sobre os registros localizados, permitindo, por exemplo, buscar por data de catalogação ou exatamente no campo desejado.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.error.invalid_photo_extension	A extensão do arquivo selecionado não é válida para a foto do usuário. Use arquivos .png, .jpg, .jpeg ou .gif	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.indicator.1._	nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.private_full	Base Privativa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.534	Notas de fac-símile	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.creation_date	Data Inclusão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.530	Notas de disponibilidade de forma física	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750	Termo tópico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.2._	Nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.vocabulary.page_help	<p>A pesquisa de vocabulário permite recuperar informações sobre os termos presentes no acervo desta biblioteca, caso catalogados.</p>\n<p>A pesquisa buscará cada um dos termos digitados nos seguintes campos: <em>{0}</em>.</p>\n<p>As palavras são pesquisadas em sua forma completa, porém é possível usar o caractere asterisco (*) para buscar por palavras incompletas, de modo que a pesquisa <em>'brasil*'</em> encontre registros que contenham <em>'brasil'</em>, <em>'brasilia'</em> e <em>'brasileiro'</em>, por exemplo. Aspas duplas podem ser usadas para encontrar duas palavras em sequência, de modo que a pesquisa <em>"meu amor"</em> encontre registros que contenham as duas palavras juntas, mas não encontre registros com o texto <em>'meu primeiro amor'</em>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.show_all	Mostrar todos os {0} backups	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.response_date	Data de Chegada da Cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.bibliography	Relatório de Bibliografia por Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_260	Imprenta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_bibliographic_delete	Excluir registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.simple_search	Pesquisa Simplificada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.500	Notas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permission.success.delete	Login excluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.501	Notas iniciadas com a palavra "com"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.502	Notas de dissertação ou tese	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.504	Notas de bibliografia	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.505	Notas de conteúdo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.indicator.1.1	não confidencial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_password	Troca de Senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.indicator.1.0	confidencial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lendings.holding_list_lendings	Listar apenas exemplares emprestados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.buttons.apply_fine	Multar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_250	Edição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.datafield	Campo MARC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_255	Escala	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_256	Características do arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_257	Local de produção	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_258	Informação sobre o material	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.success.update	Cotação salva com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.location	Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_field.photo	Foto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.empty_login	O campo login não pode ser vazio	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.515	Nota de Peculiaridade na Numeração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.selected_records_plural	{0} registros selecionados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.clear_search	Limpar termos da pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.biblio	Bibliográficos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.backup_not_complete	Backup não finalizado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.error.no_supplier_found	Não foi possível encontrar nenhum fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_cancel_editing_title	Cancelar edição de registro de cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.success.disable	Sucesso ao marcar usuário como inativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.empty_new_password	O campo "nova senha" não pode ser vazio	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245	Título principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.subfield.b	Títulos paralelos/subtítulos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_vocabulary_move	Mover registro de vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.popup.description	Selecione em qual etiqueta deseja iniciar a impressão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.button.delete	Excluir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.subfield.p	Nome da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.custom.user_field.email	Email	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.subfield.n	Número da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.subfield.h	Meio	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.indicator.1.1	nome da jurisdição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.indicator.1.2	nome na ordem direta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_reservation_list	Listar reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_bibliographic_move	Mover registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.type.biblio	Registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.cancel	O Cartão será cancelado e estará indisponível para uso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_status.blocked	Bloqueado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.order	Ordenar por	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.error.file_not_found	Arquivo não encontrado.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.source_search_title	Importar registros a partir de uma pesquisa Z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.expiration_date	Data de expiração da reserva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.state	Estado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.subtitle	Subtítulo da biblioteca	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.upload_popup.uploading	Enviando arquivo...	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.error.save	Falha ao salvar o fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.670.subfield.a	Nota de origem do termo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.upload_popup.title	Abrindo Arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.main_full	Base Principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.page_help	<p>A rotina de Pedidos permite o cadastramento e pesquisa de pedidos (compras) realizados com os fornecedores cadastrados. Para cadastrar um novo Pedido, deve-se selecionar um Fornecedor e uma Cotação previamente cadastrados, assim como entrar dados como Data de Vencimento e dados da Nota Fiscal.</p>\n<p>A pesquisa buscará cada um dos termos digitados nos campos <em>Número do Registro do Pedido, Nome Fantasia do Fornecedor, e Autor ou Título da Requisição</em>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.subfield.3	Materiais especificados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.error.couldnt_restore_backup	Não foi possível restaurar o backup selecionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_configurations	Gerenciar configurações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.holdings_available	Disponíveis	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.group.custom	Relatório Personalizado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.biblio_reservation	Reservas por registro bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_request_save	Salvar registro de requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.return.error	Falha ao devolver o Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.fine.failure_pay_fine	Falha ao pagar multa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.2.2	entrada analítica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.circulation_access	Controle de Acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.login_change_password	Trocar senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210	Título Abreviado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.856.subfield.y	Link em texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	field.error.date	O valor preenchido não é uma data válida. Utilize o formato {0}	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.856.subfield.u	URI	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.lend.error	Falha ao vincular o Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_field.login	Login	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.856.subfield.d	Caminho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.upload_popup.processing	Processando...	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.no_data	Não existem dados para gerar este relatório	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.subfield.a	Nota de índice cumulativo e remissivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.subfield.b	Fonte disponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.success.update	Servidor z39.50 atualizado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.subfield.c	Grau de controle	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.856.subfield.f	Nome do arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.subfield.d	Referência bibliográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.321.subfield.b	Datas da periodicidade anterior	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.321.subfield.a	Peridiocidade Anterior	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.type.authorities	Autoridades	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.subfield.u	Identificador uniforme de recursos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.searches	Relatório de Total de Pesquisas por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.open_item_button	Abrir registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_configurations	Configurações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041.indicator.1.0	Item não é e não inclui tradução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.tabs.reservations	Reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.cancel	Cancelar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	field.error.min_length	Este campo deve possuir no mínimo {0} caracteres	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041.indicator.1.1	Item é ou inclui tradução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.2._	nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging_labels	Impressão de Etiquetas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.isbn	ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.page_help	<p>O módulo <strong>"Impressão de Carteirinhas"</strong> permite gerar as etiquetas de identificação dos leitores da biblioteca.</p>\n<p>É possível gerar as carteirinhas de um ou mais leitores em uma única impressão, utilizando a pesquisa abaixo.</p>\n<p>Após encontrar o(s) leitor(es), use o botão <strong>"Selecionar usuário"</strong> para adicioná-los à lista de impressão de carteirinhas. Você poderá fazer diversas pesquisas, sem perder a seleção feita anteriormente. Quando estiver satisfeito com a seleção, clique no botão <strong>"Imprimir carteirinhas"</strong>. Será possível selecionar a posição da primeira carteirinha na folha de etiquetas.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_save	Salvar registro de usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.info	Observações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.no_attachments	Este registro não possui arquivos digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.error.save	Falha ao salvar a Requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.subfield.z	Subdivisão geográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.505.subfield.a	Notas de conteúdo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.subfield.y	Subdivisão cronológica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_delete_record_title	Excluir registro de exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.print_lending_receipt	Imprimir recibo de empréstimo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.quotation_date	Data do Pedido de Cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.lending.error.holding_is_lent	O exemplar selecionado já está emprestado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.trash	Lixeira	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.lendings_top	Livros mais emprestados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.id	N&ordm; do registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.address_number	Número	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.250	Edição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.255	Dado matemático cartográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.256	Características do arquivo de computador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.custom.user_field.obs	Observações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.2.0	Library of Congress Subject Heading	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.help	Ajuda	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.258	Informação sobre material filatélico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.257	País da entidade produtora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.articles	Artigo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.user_not_found	Não foi possível encontrar o usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.150.subfield.y	Subdivisão cronológica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.150.subfield.x	Subdivisão geral adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.title.unit_value	Valor Unitário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750.indicator.2.4	Source not specified	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.150.subfield.z	Subdivisão geográfica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.lending.error.holding_unavailable	O exemplar selecionado está indisponível para empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.indexing_groups.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.button_full	Gerar backup completo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.accession_number.full	Relatório completo de Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.start_number	Número inicial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240	Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243	Título Convencionado Para Arquivamento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_lendings	Empréstimos Ativos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.page_help	<p>A rotina de Cotações permite o cadastramento e pesquisa de cotações (orçamentos) realizadas com os fornecedores cadastrados. Para cadastrar uma nova Cotação, deve-se selecionar um Fornecedor e uma Requisição previamente cadastrados, assim como entrar dados como o valor e a quantidade de obras cotadas.</p>\n<p>A pesquisa buscará cada um dos termos digitados nos campos <em>Número do Registro de Cotação ou Nome Fantasia do Fornecedor</em>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.bind_card	Vincular Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.search.distributed_search_limit	Esta configuração representa a quantidade máxima de resultados que serão encontrados em uma pesquisa distribuída. Evite o uso de um limite muito elevado pois as buscas distribuídas levarão muito tempo para retornar os resultados pesquisados.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.indicator.1.3	nome de família	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_delete_record_question.forever	Você realmente deseja excluir este registro de fornecedor?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.success.update	Cartão salvo com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.856.subfield.u	URI	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.856.subfield.y	Link em texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.publication_year	Ano de publicação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.no_backups_found	Nenhum backup encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.printer_type.printer_40_columns	Impressora 40 colunas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.856.subfield.d	Caminho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.515.subfield.a	Nota de Peculiaridade na Numeração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_delete	Excluir registro de usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.name	Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.856.subfield.f	Nome do arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.949	Tombo patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.947	Informação da Coleção	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.611.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	text.main.logged_in	<p>Olá {0},</p>\n<p>Seja bem-vindo ao <strong>Biblioteca Livre (Biblivre) versão 4.0</strong>.</p>\n<p>Você poderá fazer pesquisas por registros bibliográficos, autoridades e vocabulário pela opção <em>"Pesquisa"</em> no menu superior. Esta é a mesma <em>"Pesquisa"</em> que os leitores poderão usar ao acessar o <strong>Biblivre</strong>, sem necessidade de usuário e senha, para pesquisar por registros na Base Principal.</p>\n<p>Para cadastrar leitores, realizar empréstimos, devoluções e reservas, controlar o acesso à biblioteca e imprimir carteirinhas, use a opção <em>"Circulação"</em>, também no menu superior.</p>\n<p>Na opção <em>"Catalogação"</em>, você poderá controlar o acervo da biblioteca, catalogando obras e exemplares, e efetuar o controle de autoridades e do vocabulário. Através desta opção tambem é possível imprimir as etiquetas usadas nos exemplares, mover registros entre as bases de dados (Principal, Trabalho, Privada e Lixeira), importar e exportar registros e adicionar arquivos digitais aos registros existentes.</p>\n<p>O <strong>Biblivre</strong> também possui um sistema simples de controle do processo de aquisição, para auxiliar a compra e recebimento de publicações, através da opção <em>"Aquisição"</em>.</p>\n<p>Em <em>"Administração"</em>, você poderá trocar a senha de acesso, configurar recursos do <strong>Biblivre</strong> como campos dos formulários, traduções e tipos de usuário, cadastrar cartões de acesso, gerar relatórios e realizar a manutenção da base de dados, que inclui a geração da cópia de segurança (backup), e a reindexação da base de dados, que deve ser usada quando alguns registros não puderem ser encontrados através da pesquisa.</p>\n<p>Caso precise de mais informações sobre o <strong>Biblivre</strong>, acesse a opção <em>"Ajuda"</em> e leia o Manual do programa ou as perguntas frequentes, no <a href="http://biblivre.org.br/forum" target="_blank">Fórum</a>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.groups.circulation	Circulação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.150.subfield.a	Termo tópico adotado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.move_records	Mover Registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.holding.accession_number	Tombo patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.150.subfield.i	Qualificador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.payment_date	Data de Pagamento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_field.status	Situação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_print_user_cards	Imprimir carteirinhas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.error.no_valid_terms	A pesquisa especificada não contém termos validos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.users_with_late_lendings	Listar apenas usuários com empréstimos em atraso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.delivered_quantity	Quantidade recebida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.holdings_full	Relatório completo de Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.page_help	<p>Para realizar um empréstimo você deverá selecionar o leitor para o qual o empréstimo será realizado e, em seguida, selecionar o exemplar que será emprestado. A pesquisa pelo leitor pode ser feita por nome, matrícula ou outro campo previamente cadastrado. Para encontrar o exemplar, utilize seu Tombo Patrimonial.</p><p>Devoluções podem ser feitas através do leitor selecionado ou diretamente pelo Tombo Patrimonial do exemplar que está sendo devolvido ou renovado.</p><p>O prazo para devolução é calculado de acordo com o tipo de usuário, configurado pelo menu <strong>Administração</strong> e definido durante o cadastro do leitor.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.fine_value	Valor da Multa por atrasos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.distributed_search	Pesquisa Distribuída	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging_authorities	Autoridades	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_quotation_list	Listar cotações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.welcome	Seja bem-vindo ao Biblivre IV	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.paper_description	{paper_size} {count} etiquetas ({height} mm x {width} mm)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.order	Ordenação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.selected_records_plural	{0} Valores Adicionados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.670.subfield.b	Informações encontradas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.670.subfield.a	Nome retirado de	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.2	Tipo de entrada secundária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.group.circulation	Circulação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.availability.unavailable	Indisponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.title.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.delivery_time	Prazo de entrega (Prometido)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.currency	Esta configuração representa a moeda que será utilizada em multas e no módulo de aquisição.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.database_main	Principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.success.move	Registros movidos com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.acquisition_quotation	Cotações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.availability	Disponibilidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.delete_success	Reserva excluída com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.029.subfield.a	Número do ISNM	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.created_between	Catalogado entre	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_delete_record_title.forever	Excluir registro de cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260	Publicação, edição. Etc.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_delete_record_question.forever	Você realmente deseja excluir este registro de Pedido?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.fieldset.title.values	Valores	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.913	Código local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.title	Reindexação da Base de Dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.simple_term_title	Preencha os termos da pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.lending.error.blocked_user	O leitor selecionado está bloqueado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.records_found_singular	{0} registro encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.2._	nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.error.delete	Falha ao exluir o fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.type.do_not_import	Não importar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.2	Tipo de entrada secundária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.error.delete.user_has_accesscard	Este usuário possui cartão de acesso em uso.  Realize a devolução do cartão antes de excluir este usuário.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.created_by	Responsável	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_130	Obra Anônima	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	language_name	Português (Brasil)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_534	Notas de fac-símile	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.360.subfield.z	Subdivisão geográfica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.360.subfield.y	Subdivisão cronológica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_delete_record_title	Excluir registro de Pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.360.subfield.x	Subdivisão geral adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.reservations	Relatório de Reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.reservation_date	Data da Reserva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.term.up	Termo Use Para (UP)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_520	Notas de resumo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.411.subfield.a	Nome do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_521	Notas de público alvo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.title.quantity	Quantidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.page_help	<p>A rotina de Relatórios permite a geração e impressão de diversos relatórios disponibilizados pelo Biblivre. Os relatórios disponíveis se dividem entre as rotinas de Aquisição, Catalogação e Circulação.</p>\n<p>Alguns dos relatórios disponíveis possuem filtros, como Base Bibliográfica, ou Período, por exemplo. Para outros, basta selecionar o relatório e clicar em "Emitir Relatório".</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_110	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.tabs.form	Cadastro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_111	Autor Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.indicator.1.1	sobrenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.indicator.1.2	sobrenome composto (obsoleto)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.holdings_count	Qtdd. Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.clear	Limpar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.indicator.1.0	prenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.selected_records_singular	{0} Valor Adicionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.term.tg	Termo Geral (TG)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.term.te	Termo Específico (TE)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.preview	Pré visualização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.490	Indicação de série	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_delete_record_title	Excluir registro de vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.term.ta	Termo Associado (VT / TA)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.modified	Atualizado em	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.521.subfield.a	Notas de público alvo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.search	Pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.unclassified	<Não classificado>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_translations	Gerenciar traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.501.subfield.a	Notas iniciadas com a palavra "com"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260.subfield.b	Nome do editor, publicador, etc.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260.subfield.c	Data de publicação, distribuição, etc.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.user.search	Digite o nome ou matrícula do Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260.subfield.e	Nome do impressor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.error.invalid_search_parameters	Os parâmetros desta pesquisa não estão corretos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.search.results_per_page	Resultados por página	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.author_type.select_author_type	Selecione o tipo de autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260.subfield.a	Local de publicação, distribuição, etc.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_500	Notas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260.subfield.f	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.260.subfield.g	Data de impressão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_502	Nota de tese	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_505	Notas de conteúdo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_504	Notas de bibliografia	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_506	Notas de acesso restrito	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_lending_list	Listar empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.520.subfield.a	Notas de resumo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.record_reserved_to_the_following_readers	Este registro está reservado para os seguintes leitores	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.new_password	Nova senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.password_not_matching	Os campos "nova senha" e "repita a nova senha" devem ser iguais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.subfield.b	Unidades subordinadas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.subject	Assunto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.save.success	Configurações alteradas com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	z3950.adresses.list.no_address_found	Nenhum Servidor Z39.50 encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.search_limit	A pesquisa realizada encontrou {0} registros, porém apenas os {1} primeiros serão exibidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.subfield.n	Número da parte - seção da obra - ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.error.generate	Falha ao gerar o relatório. Verifique o preenchimento do formulário.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.error.save	Falha ao salvar o Registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_100	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.success.unblock	Usuário desbloqueado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.user.open_item_button	Abrir cadastro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.vocabulary.simple_search	Pesquisa de Vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.subfield.a	Nome da entidade ou do lugar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.unblock	Falha ao desbloquear o Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_order_delete	Excluir registro de pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.ok	Ok	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de requisição?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.indexing_groups.total	Total	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_670	Nome retirado de	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.field_count	Contagem do campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.confirm_cancel_editing_title	Cancelar edição do Servidor Z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.362.indicator.1.1	Nota não formatada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.362.indicator.1.0	Estilo formatado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.error.invalid_file	Arquivo inválido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.no	Não	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.search_button	Pesquisar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.confirm_cancel_editing.1	Você deseja cancelar a edição deste Servidor Z39.50?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_access_control_bind	Gerenciar controle de acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.080.subfield.2	Número de edição da CDU	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_print_labels	Imprimir etiquetas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de fornecedor?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.indicator.1.0	prenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.popup.title	Formato das etiquetas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.indicator.1.3	nome de família	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.indicator.1.1	sobrenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.indicator.1.2	sobrenome composto (obsoleto)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.button_authorities	Reindexar base de autoridades	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.authorities.simple_search	Pesquisa de Autoridades	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.520.subfield.u	URI	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.user_current_lending_list	Exemplares emprestados a este leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.subfield.b	Qualificador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.subfield.a	Título Abreviado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.255.subfield.a	Escala	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging_label	Etiquetas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_680	Nota de Escopo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_700	Autor secundário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_685	Nota de Histórico ou Glossário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_order_list	Listar pedidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.access_control	Cartões de acesso e Controle de acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.query_placeholder	Preencha os termos da pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.any	Qualquer	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.description	Descrição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.lend.success	Cartão vinculado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.title.unblock	Desbloquear Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.inactive	Marcar como inativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.2	Tipo de entrada secundária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.topographic	Relatório Topográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.title.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.year	Ano	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	text.main.logged_out	<p>O programa <strong>Biblioteca Livre (Biblivre) versão 4.0</strong> é um aplicativo que permite a inclusão digital do cidadão na sociedade da informação. Saiba mais sobre o projeto em <em>"Sobre"</em>, na opção <em>"Ajuda"</em> no menu superior.</p>\n<p>Trata-se de um programa para catalogação e difusão de acervos de bibliotecas públicas e privadas, de variados portes, além de possibilitar a circulação e o compartilhamento de conteúdos de informação, tais como, textos, músicas, imagens e filmes ou qualquer outro tipo de objeto digital.</p>\n<p>Hoje, o <strong>Biblivre</strong> é sucesso em todo o Brasil, assim como no exterior e, por sua extrema relevância cultural, vem se firmando como o aplicativo de escolha para a inclusão digital do cidadão.</p>\n<p>Se desejar somente pesquisar o catálogo e acessar as obras disponíveis digitalmente, utilize a opção <em>"Pesquisa"</em> no menu superior, sem a necessidade de usuário e senha.</p>\n<p>Para outros serviços, tais como circulação, catalogação, aquisição e administração, é necessário um nome de <strong>usuário</strong> e <strong>senha</strong>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload_popup.processing	Processando...	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.indexing_groups.up_term	Termo Use Para (UP)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.2.4	Source not specified	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.block	Bloquear	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.button_vocabulary	Reindexar base de vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.400	Outra Forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_accesscards_delete	Excluir cartões de acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.download.field.languages	Idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.block	Falha ao bloquear o Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.subfield.d	Datas associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.subfield.c	Título e outras palavras associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_670	Origem das Informações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.410	Outra Forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.tabs.fines	Multas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.subfield.q	Forma completa do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.expected_date	Data prevista	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.success.delete	Cartão excluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.unavailable	Indisponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.630.indicator.1	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	digitalmedia.error.file_could_not_be_saved	O arquivo enviado não pôde ser salvo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.private	Privativa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_id	Matrícula	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.411	Outra Forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.2.0	Library of Congress Subject Headings	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.subfield.a	Sobrenome e/ou prenome do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.subfield.b	Numeração que segue o prenome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_590	Notas locais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.indicator.1.0	prenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.daily_fine	Multa diária	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.indicator.1.1	sobrenome simples ou composto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.indicator.1.2	sobrenome composto (obsoleto)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.indicator.1.3	nome de família	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.advanced_search	Pesquisa Avançada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.label_full	Backup completo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.title	Esta configuração representa o nome da biblioteca, que será exibido no topo das páginas do Biblivre e nos relatórios.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.search.result_limit	Limite de resultados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.custom.user_field.gender	Gênero	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.empty_lending_list	Este leitor não possui exemplares emprestados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.acquisition_supplier	Fornecedores	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.card_not_found	Cartão não encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.usertype.confirm_cancel_editing_title	Cancelar edição do Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.confirm_cancel_editing_title	Cancelar inclusão de Cartões de Acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.confirm_delete_record_question.forever	Você realmente deseja excluir o Login do Usuário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.no_servers	Não é possível realizar uma pesquisa Z39.50 pois não existem bibliotecas remotas cadastradas. Para solucionar este problema, cadastre os servidores Z39.50 das bibliotecas de interesse na opção <em>"Servidores Z39.50"</em> dentro de <em>"Administração"</em> no menu superior. Para isto é necessário um nome de <strong>usuário</strong> e <strong>senha</strong>.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.editor	Editora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.source_file_title	Importar registros a partir de um arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.reservation_limit	Limite de reservas simultâneas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.failure.unblock	Falha ao desbloquear o Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.expiration_date	Data de Validade da Cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.submit_button	Trocar Senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.work	Trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.1	Gera entrada secundária na ficha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.failure.block	Falha ao bloquear o Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.450	UP (remissiva para TE não usado)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.subfield.b	Período de tempo formatado de 9999 a.C em diante	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.subfield.a	Código do período de tempo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	digitalmedia.error.no_file_uploaded	Nenhum arquivo foi enviado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045.subfield.c	Período de tempo formatado anterior a 9999 a.C.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.indicator.2.0	Outro título abreviado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.days_late	Dias de atraso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.error.order_not_found	Não foi possível encontrar o pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.holding_lent_to_the_following_reader	Este exemplar está emprestado para o leitor abaixo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_555	Notas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.650.subfield.a	Assunto tópico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.accesscards.unbind_card	Devolver Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.sort_by	Ordenar por	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permission.error.create_login	Erro ao criar login de usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.indicator.1.0	Não gerar entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.field.collection	Coleção	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.delete	Excluir	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_status.pending_issues	Possui pendências	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.490.indicator.1.1	Título desdobrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.indicator.1.1	Gerar entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title	Relatórios	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.wait	Dependendo do tamanho da base de dados, esta operação poderá demorar. O biblivre ficará indisponível durante o processo, que pode durar até 15 minutos.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.deadline_date	Data de Vencimento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_651	Assunto geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_650	Assunto tópico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852	Informações sobre a localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.database.work	Trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration	Administração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.login_already_exists	Este login já existe. Escolha outro nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.856	Localização de obras por meio eletrônico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.requester	Requerente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	format.datetime	dd/MM/yyyy HH:mm	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.new_holding	Novo exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.publisher	Editora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.no_card_found	Nenhum cartão encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.650.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.650.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.access_denied	Acesso negado. Usuário ou senha inválidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.650.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.success	Reindexação concluída com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.534.subfield.a	Notas de fac-símile	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.p	Nome da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.success.block	Usuário bloqueado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_lending_lend	Realizar empréstimos de obras	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.n	Número da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.411	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.error.select_reader_first	Para emprestar um exemplar você precisa, primeiramente, selecionar um leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.indexing_groups.all	Qualquer campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.button.print_labels	Imprimir etiquetas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.f	Data de edição do item que está sendo processado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.year	Ano	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.d	Data que aparece junto ao título uniforme na entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.subfield.a	Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_630	Assunto título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_indexing	Gerenciar indexação da base de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.685.subfield.i	Texto explicativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.save_as_new	Salvar como novo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.reserve_success	Reserva efetuada com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload.description	Selecione abaixo o arquivo de idioma que deseja enviar para processamento pelo Biblivre 4.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.page_help	<p>A rotina de Servidores Z39.50 permite o cadastramento e pesquisa dos Servidores utilizados pela rotina de Pesquisa Distribuída. Para realizar o cadastramento serão necessários os dados da Coleção Z39.50, assim como endereço URL e porta de acesso.</p>\n<p>Ao acessar essa rotina, o Biblivre listará automaticamente todos os Servidores previamente cadastrados.  Você poderá então filtrar essa lista, digitando o <em>Nome</em> de um Servidor que queira encontrar.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tabs.form	Formulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.error.value_must_be_boolean	O valor deste campo deve ser verdadeiro ou falso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.indicator.1.2	nome na ordem direta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.invalid_password	O campo "senha atual" não confere com a sua senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.title	Troca de Senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_delete_record_question	Você realmente deseja excluir este registro de autoridade?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.indicator.1.0	nome invertido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.110.indicator.1.1	nome da jurisdição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.490.indicator.1.0	Título não desdobrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.3	Especificações do material	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.590.subfield.a	Notas locais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_request_list	Listar requisições	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.invalid_pg_dump_path	Caminho inválido. O Biblivre não será capaz de gerar backups já que o arquivo <strong>pg_dump</strong> não foi encontrado.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.holdings.title	Pesquisar Exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.accession_number	Relatório de Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.cataloging.accession_number_prefix	O tombo patrimonial é o campo que identifica unicamente um exemplar. No Biblivre, a regra de formação para o tombo patrimonial depende do ano de aquisição do exemplar, da quantidade de exemplares adquiridos no ano e do prefixo do tombo patrimonial. Este prefixo é o termo que será inserido antes da numeração de ano, no formato <prefixo>.<ano>.<contador> (Ex: Bib.2014.7).	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.indicator.1.1	nome da jurisdição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.indicator.1.2	nome na ordem direta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.indicator.1.0	nome invertido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.previous	Anterior	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_usertype_list	Listar tipos de usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.button.select_page	Selecionar usuários desta página	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_610	Assunto entidade coletiva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_user_types	Tipos de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_611	Assunto evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select_report	Selecione um Relatório	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.680	Nota de escopo (NE)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.business_days	Esta configuração representa os dias de funcionamento da biblioteca e será usada pelos módulos de empréstimo e reserva. O principal uso desta configuração é evitar que a devolução de um exemplar seja agendada para um dia em que a biblioteca está fechada.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.wait	Aguarde	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.685	Nota de histórico ou glossário (GLOSS)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.users	Usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.circulation	Circulação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.user_deleted	Usuário excluído do sistema	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.cataloging_bibliographic	Bibliográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.cataloging	Pesquisa Bibliográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.supplier_number	CNPJ	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.670	Nota de origem do termo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.error.invalid_record_type	Tipo de registro em branco ou desconhecido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.existing_card	O Cartão ja existe	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.authorities.page_help	<p>A pesquisa de autoridades permite recuperar informações sobre os autores presentes no acervo desta biblioteca, caso catalogados.</p>\n<p>A pesquisa buscará cada um dos termos digitados nos seguintes campos: <em>{0}</em>.</p>\n<p>As palavras são pesquisadas em sua forma completa, porém é possível usar o caractere asterisco (*) para buscar por palavras incompletas, de modo que a pesquisa <em>'brasil*'</em> encontre registros que contenham <em>'brasil'</em>, <em>'brasilia'</em> e <em>'brasileiro'</em>, por exemplo. Aspas duplas podem ser usadas para encontrar duas palavras em sequência, de modo que a pesquisa <em>"meu amor"</em> encontre registros que contenham as duas palavras juntas, mas não encontre registros com o texto <em>'meu primeiro amor'</em>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.add_field	Adicionar termo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_750	Termo Tópico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.goodbye	Até logo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.button.select_page	Selecionar exemplares desta página	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.error.no_user_type_found	Nenhum Tipo de Usuário encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.lending_time_limit	Prazo de empréstimo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.tabs.lendings	Empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tabs.marc	MARC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_600	Assunto pessoa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.groups.login	Login	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.subtitle	Esta configuração representa um subtítulo para a biblioteca, que será exibido no topo das páginas do Biblivre, logo abaixo do <strong>Nome da biblioteca</strong>. Esta configuração é opcional.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.360.subfield.y	Subdivisão cronológica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.360.subfield.x	Subdivisão geral adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.selected_records_singular	{0} Valor Adicionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.360.subfield.z	Subdivisão geográfica adotada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.map	Mapa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.e	Nome de subunidades do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.a	Nome do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.selected_records_singular	{0} usuário selecionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.n	Número de ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.user	Pesquisa de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.subfield.t	Título da obra junto a entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.490.subfield.a	Título da série	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.490.subfield.v	Número do volume ou designação sequencial da série	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.080.subfield.a	Número de Classificação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830.indicator.2	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.error.value_is_required	O preenchimento deste campo é obrigatório	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.360.subfield.a	Termo tópico adotado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.area	Bairro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.success.save	Requisição incluída com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.group.cataloging	Catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_list_by_type	Lista de Usuários Por Tipo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.button.import_all	Importar todas as páginas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.lendings_count	Total de Livros emprestados no período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.registered_between	Cadastrado entre	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.reservation	Relatório de Reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.end_date	Data Final	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.indicator.1.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.p	Nome da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.411.subfield.a	Nome do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.repeat_password	Repetir senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_delete_record_title.forever	Excluir registro de Pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.help	Ajuda	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.error.you_cannot_delete_yourself	Você não pode excluir-se ou marcar-se como inativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.1.0	Não gera entrada para o título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.button.list_all	Listar Todos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.1.1	Gera entrada para o título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.prefix	Prefixo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.custom_count	Contagem de Registros Bibliográficos por Campo Marc	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.invalid_handler	Não foi possível encontrar um handler para esta ação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.material_type	Tipo de material	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.containing_text	Contendo o texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.button.migrate	Importar dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.expected_return_date	Data prevista para devolução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041.indicator.1	Indicação de tradução	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_vocabulary_delete	Excluir registro de vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.work_full	Base de Trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tabs.holdings	Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.paper_description	{paper_size} {count} etiquetas ({height} mm x {width} mm)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.b	Data que aparece junto ao título uniforme na entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.search_bibliographic	Bibliográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.a	Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.success.delete	Requisição excluída com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.page_help	<p>A rotina de Fornecedores permite o cadastramento e pesquisa de fornecedores. A pesquisa buscará cada um dos termos digitados nos campos <em>Nome Fantasia, Razão Social ou CNPJ</em>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.f	Data do trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.530.subfield.a	Notas de disponibilidade de forma física	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.requester	Requerente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_maintenance	Manutenção	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.n	Número da parte - seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.no_lendings	Este usuário não possui empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.title.author	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.id	N&ordm; do registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.a	Nome do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_reservation_reserve	Realizar reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_699	Assunto local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_cancel_editing_title	Cancelar edição de registro de autoridade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.access_control.card_available	Este cartão está disponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.400.subfield.a	Sobrenome e/ou Prenome do Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	label.login	Entrar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.title	Permissões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.button.import_this_page	Importar registros desta página	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.error.invalid_writable_path	Caminho inválido. Este diretório não existe ou o Biblivre não possui permissão de escrita.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.d	Data da aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.e	Número atribuído a aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.b	Endereço	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.c	Forma de aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.a	Nome da fonte	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.success.save	Usuário incluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.description.4	Problemas na pesquisa, onde registros cadastrados não são encontrados.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.f	Proprietário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.h	Preço de compra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.description.2	Alteração na configuração de campos buscáveis;	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.o	Tipo de unidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.830	Entrada secundária - Série - Título Uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.description.3	Importação de registros de versões antigas do Biblivre; e	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.uncancel	O Cartão será recuperado e estará disponível para uso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.subfield.n	Quantidade de itens adquiridos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.description.1	A reindexação da base de dados é o processo no qual o Biblivre analisa cada registro cadastrado, criando índices em certos campos para que a pesquisa neles seja possível. É um processo demorado e que deve ser executado apenas nos casos específicos abaixo:<br/>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.306.subfield.a	Tempo de duração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.1.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.active_lendings	Empréstimos ativos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.button.remove_login	Remover Login	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.button.select_reader	Selecionar leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.a	Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.b	Sub-localização ou coleção	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.c	Localização na estante	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.error.save	Não foi possível salvar as configurações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.e	Endereço postal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.label.example	ex.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.button.reserve	Reservar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.500.subfield.a	Notas gerais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.quantity	Quantidade de exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_z3950_servers	Servidores Z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.title.quantity	Quantidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.same_password	A nova senha deve ser diferente da senha atual	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.usertype.confirm_cancel_editing.1	Você deseja cancelar a edição deste Tipo de Usuário?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.usertype.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.field.code	Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.success.save	Tipo de Usuário incluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.400.subfield.a	Sobrenome e/ou Prenome do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.suffix	Sufixo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.360.subfield.a	Termo tópico adotado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.late_lendings	Relatório de Empréstimos em Atraso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.z	Nota pública	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.856	Localização de obras por meio eletrônico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.2.2	entrada analítica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.indexing_groups.other_name	Outras formas do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.currency	Moeda	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.q	Condição física da parte	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.x	Nota interna	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.delivered	Pedido recebido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.group.acquisition	Aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.u	URI	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.supplier_select	Selecione um Fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.j	Número de controle na estante	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.select_page	Selecionar registros desta página	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.on_the_field	No campo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.subfield.n	Código do País	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.e	Nome de subunidades do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.material_type	Tipo de material	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.fieldset.contact	Contatos/Telefones	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.n	Número de ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.selected_records_plural	{0} exemplares selecionados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_400	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.common.button.upload	Enviar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.362	Informação de Datas de Publicação e/ou Volume	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.360	Remissiva VT (ver também) e TA (termo relacionado ou associado)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.supplier_select	Selecione um Fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.shelf_location	Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.indicator.2._	nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_delete_record_question.inactive	Você realmente deseja marcar este usuário como "inativo"?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.error.couldnt_unzip_backup	Não foi possível descompactar o backup selecionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.dump	Não foi possível gerar o arquivo de traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_delete_record_title	Excluir registro de requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.error.invalid_database	Base de dados inexistente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.created	Cadastrado em	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_quotation_save	Salvar registro de cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.info	Observações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.orders_by_date	Relatório de Pedidos por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.lend_success	Exemplar emprestado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.page_help	<p>A rotina de Cartões de Acesso permite o cadastramento e pesquisa dos Cartões utilizados pela rotina de Controle de Acesso. Para realizar o cadastramento o Biblivre oferece duas opções:</p>\n<ul><li>Cadastrar Novo Cartão: utilize para cadastrar apenas um cartão de acesso;</li><li>Cadastrar Sequência de Cartões: utilize para cadastrar mais de um cartão de acesso, em sequência. Utilize o campo "Pré visualização" para verificar como serão as numerações dos cartões incluídos.</li></ul>\n<p>Ao acessar essa rotina, o Biblivre listará automaticamente todos os Cartões de Acesso previamente cadastrados.  Você poderá então filtrar essa lista, digitando o <em>Código</em> de um Cartão de Acesso que queira encontrar.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.confirm_delete_record_question	Você realmente deseja excluir este registro de Pedido?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_reports	Gerar Relatórios	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.classification	Classificação (CDD)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.url	URL	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.error.no_record_found	Nenhum Registro válido encontrado no arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.holdings.title	Pesquisar Registro Bibliográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.record_count	Registros nesta base: <strong>{0}</strong>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_delete_record_title	Excluir registro de autoridade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_delete_record_question	Você realmente deseja excluir este registro bibliográfico?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	format.date_user_friendly	DD/MM/AAAA	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.holdings_creation_by_date	Relatório de Total de Inclusões de Obras por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.complement	Complemento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.750	Termo tópico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_type	Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.340	Suporte físico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.fine_popup.description	Esta devolução está em atraso e está sujeita a pagamento de multa. Verifique abaixo as informações apresentadas e confirme se a multa será adicionada ao cadastro do usuário para ser paga futuramente (Multar), se ela foi paga no momento da devolução (Pagar) ou se ela será abonada (Abonar).	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permission.success.permissions_saved	Permissões alteradas com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.343	Dados de coordenada plana	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342	Dados de referência geospacial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_013	Informação do controle de patentes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.added_to_list	Adicionado à lista	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.marc_popup.description	Use a caixa abaixo para alterar o MARC deste registro antes de importá-lo.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.1.2	nome na ordem direta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.confirm	Deseja confirmar a reindexação da base?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.1.0	nome invertido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.indicator.1.1	nome da jurisdição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.090.subfield.b	Código do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.090.subfield.a	Classificação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.search_vocabulary	Vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.modified	Data Cancelamento/Alteração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740	Entrada secundária - Título Adicional - Analítico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_410	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_411	Outra forma do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.090.subfield.d	Número do exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.090.subfield.c	Edição / volume	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_020	ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_024	ISRC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.print_receipt	Imprimir recibo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_022	ISSN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.362.indicator.1	Formato da data	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.240.indicator.2.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.form.remove	Remover	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.holding_reservation	Reservas por serial do exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.edit	Editar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de cotação?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.confirm_cancel_editing.1	Você deseja cancelar a inclusão de Cartões de Acesso?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.label_exclude_digital_media	Backup sem arquivos digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_permissions	Logins e Permissões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_list	Listar usuários	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541.indicator.1	Privacidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.isrc_already_in_database	Já existe um registro com este ISRC na base de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.save_as_new	Salvar como novo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.610.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.isrc	ISRC	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.help_about_biblivre	Sobre o Biblivre	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.save.success	Registros importados com successo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_cancel_editing_title	Cancelar edição de registro de fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	field.error.required	O preenchimendo deste campo é obrigatório	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.upload_popup.uploading	Enviando arquivo...	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.reserve_date	Data da reserva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.created	Data de cadastro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permission.success.create_login	Login e permissões criados com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.file_not_found	Arquivo não encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.043.subfield.a	Código de área geográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.issn	ISSN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.reservation_count	Registros reservados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.help_about_library	Sobre a Biblioteca	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.administration.z3950.server.active	Servidor z39.50 local ativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.indexing_groups.entity	Entidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.310.subfield.a	Periodicidade Corrente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.310.subfield.b	Data da periodicidade corrente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_request_delete	Excluir registro de requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.090	Número de chamada / Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.indexing_groups.vt_ta_term	Termo Associado (VT / TA)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.150	TE	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_lending_return	Realizar devoluções de obras	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.failure.delete	Falha ao excluir usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_cancel_editing_title	Cancelar edição de registro de requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.add_cards	Adicionar Cartões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_authorities_move	Mover registro de autoridade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.pg_dump_path	Atenção: Esta é uma configuração avançada, porém importante. O Biblivre tentará encontrar automaticamente o caminho para o programa <strong>pg_dump</strong> e, exceto em casos onde seja exibido um erro abaixo, você não precisará alterar esta configuração. Esta configuração representa o caminho, no servidor onde o Biblivre está instalado, para o executável <strong>pg_dump</strong> que é distribuído junto do PostgreSQL. Caso esta configuração estiver inválida, o Biblivre não será capaz de gerar cópias de segurança.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.title.cancel	Cancelar Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_move_record_description_singular	Você realmente deseja mover este registro?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.reservations	Reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.reindex.warning	Este processo pode demorar alguns minutos, dependendo da configuração de hardware do seu servidor. Durante este tempo, o Biblivre não estará disponível para a pesquisa de registros, mas voltará assim que a indexação terminar.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.user.simple_term_title	Preencha os termos da pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.delete_failure	Falha ao excluir a reserva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.paid_value	Valor Total Pago	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.082.subfield.a	Número de Classificação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.lend	Emprestar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.913	Código local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.acquisition	Aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_150	Termo Específico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_delete_record_question	Você realmente deseja excluir este registro de cotação?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.fieldset.database	Base de Dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.source_search_subtitle	Selecione uma biblioteca remota e preencha os termos da pesquisa. A pesquisa retornará um limite de {0} registros. Caso não encontre o registro de interesse, refine sua pesquisa.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.clear_simple_search	Limpar resultados da pesquisa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.vocabulary_550	Termo Genérico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_delete_record_title.forever	Excluir usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro bibliográfico?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.late_lendings_count	Total de Empréstimos em Atraso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.confirm_cancel_editing_title	Cancelar edição de registro de exemplar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.a	Título uniforme atribuído ao documento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.no_records_found	Nenhum registro encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.d	Data que aparece junto ao título uniforme de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.receipt_date	Data do recebimento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.user	Relatório por Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.p	Nome da parte - Seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.number_of_holdings	Número de Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.main	Principal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.f	Data da edição do item que está sendo processado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.address	Endereço	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.page_help	<p>A rotina de Requisições permite o cadastramento e pesquisa de requisições de obras. Uma requisição é um registro de alguma obra que a Biblioteca deseja adquirir, e pode ser utilizada para se realizar Cotações com os Fornecedores previamente cadastrados.</p>\n<p>A pesquisa buscará cada um dos termos digitados nos campos <em>Requerente, Autor ou Título</em>.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.no_reserves	Este usuário não possui reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.l	Língua do texto. Idioma do texto por extenso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.no_language_code_specified	O arquivo de traduções enviado não possui o identificador de idioma: <strong>*language_code</strong>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.082.subfield.2	Número de edição da CDD	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.confirm_delete_record_question.forever	Você realmente deseja excluir este registro de cotação?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.indicator.1	Entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.210.indicator.2	Tipo de Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_data	Dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.distributed.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permission.success.password_saved	Senha alterada com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_490	Série	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.1.0	Nenhum nível especificado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.1.1	Assunto primário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.confirm_delete_record.forever	O Servidor Z39.50 será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.750.indicator.1.2	Assunto secundário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_status.inactive	Inativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.name	Razão Social	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.unavailable	Backup não disponível	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.fine.success_pay_fine	Multa paga com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.circulation_lending	Empréstimos e Devoluções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.subfield.a	Sobrenome e/ou prenome do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.holdings_count	Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.subfield.b	Numeração que segue o prenome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.step_1_title	Selecionar origem dos dados da importação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.651.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.cataloging.accession_number_prefix	Prefixo do tombo patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.651.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.reservation.record_list_reserved	Listar apenas registros reservados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.651.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.indexing_groups.event	Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.321	Peridiocidade Anterior	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.javascript_locale_not_available	Não existe um identificador de idioma javascript para o arquivo de traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.no_server_found	Nenhum servidor z39.50 encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.invalid_user	Usuário inválido ou inexistente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_late_lendings	Empréstimos em Atraso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.description	Selecione abaixo quais items deseja importar da base de dados do Biblivre 3	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.total_value	Valor total	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.supplier	Fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.020.subfield.a	Número do ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.selected_records_singular	{0} registro selecionado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.020.subfield.c	Modalidade de aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.button.select_reader	Selecionar leitor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.2	Tipo de ordenação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.score	Partitura	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.groups.digital_media	Mídias Digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.subfield.q	Forma completa do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.error.no_quotation_found	Nenhuma cotação encontrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.marc_field	Campo Marc	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.subfield.d	Datas associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100.subfield.c	Título e outras palavras associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.852.indicator.1	Esquema de classificação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.delivery_time	Prazo de entrega (Prometido)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_100	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.biblivre_report_header	Relatórios Biblivre	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.all_digits	Todos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	field.error.digits_only	Este campo deve ser preenchido com números	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300	Descrição física	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.change_password.repeat_password	Repita a nova senha	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.306	Tempo de duração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.card_not_found	Nenhum Cartão encontrado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.question.block	Deseja realmente bloquear este Cartão?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.confirm_delete_record_title.forever	Excluir Servidor Z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.button.select_user	Selecionar Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.title.block	Bloquear Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.confirm_delete_record_title.forever	Excluir Cartão de Acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.1.0	Sistema de coordenada horizontal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.unblock	O Cartão será desbloqueado e estará disponível para uso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.651.subfield.a	Nome geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.block	O Cartão será bloqueado e estará indisponível para uso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.310	Periodicidade Corrente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.1.1	Sistema de coordenada Vertical	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.circulation_access_control_list	Listar controle de acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.success.delete	Tipo de Usuário excluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.title	Base de dados selecionada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.cataloging_vocabulary_save	Salvar registro de vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.subfield.a	Título do trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.error.existing_cards	Os seguintes Cartões já existem:	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.holdings_by_date	Relatório de Cadastro de Exemplares	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.0	Geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.1	Projeção de mapa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.next	Próximo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.quotation_select	Selecione uma Cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.2	Sistema de coordenadas em grid	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.3	Local planar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.4	Local	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.5	Modelo geodésico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_110	Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.lendings_current	Total de Livros ainda emprestados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.6	Altitude	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.authorities_111	Autor Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.7	A especificar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.invalid_psql_path	Caminho inválido. O Biblivre não será capaz de gerar e restaurar backups já que o arquivo <strong>psql</strong> não foi encontrado.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.success.delete	Fornecedor excluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.342.indicator.2.8	Profundidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.question.uncancel	Deseja realmente recuperar este Cartão?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.subfield.f	Data do trabalho	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.import_popup.title	Importando Registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.258.subfield.b	Denominação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.t	Título da obra junto à entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.258.subfield.a	Jurisdição emissora	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_supplier_list	Listar fornecedores	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.q	Forma completa do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.groups.admin	Administração	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.unit_value	Valor Unitário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.author_type	Tipo de autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.records	Relatório de Inclusões de Obras por Período	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_accesscards_save	Incluir cartões de acesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.c	Título e outras palavras associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.d	Datas associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.a	Sobrenome e-ou prenome do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.b	Numeração que segue o prenome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.error.save	Falha ao salvar a cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700.subfield.e	Relação com o documento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_field.type	Tipo de usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.1.1	Gera entrada para o título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.title.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.243.indicator.1.0	Não gera entrada para o título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.680.subfield.a	Nota de escopo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.130.indicator.1	Número de caracteres a serem desprezados na alfabetação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field_count.description	<p>Após selecionar o campo Marc e a Ordenação, realize a pesquisa bibliográfica que servirá de base para o relatório, ou clique em <strong>Emitir Relatório</strong> para utilizar toda a base bibliográfica.</p>\n<p><strong>Atenção:</strong> Este relatório pode levar alguns minutos para ser gerado, dependendo do tamanho da base bibliográfica.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.end_number	Número final	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.modified_between	Alterado entre	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.form.hidden_subfields_singular	Exibir subcampo oculto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.z3950.error.save	Falha ao salvar o servidor z39.50	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.confirm_delete_record.trash	Ele será movido para a base de dados "lixeira"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_restore	Recuperar cópia de segurança da base de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_order_save	Salvar registro de pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.quantity	Quantidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.download.button	Baixar o idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.edit	Editar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.label_digital_media_only	Backup de arquivos digitais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.field.reservation_time_limit	Prazo de reserva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	format.datetime_user_friendly	DD/MM/AAAA hh:mm	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.acquisition_supplier_save	Salvar registro de fornecedor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.confirm_delete_record_title.inactive	Marcar usuário como "inativo"	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.t	Título da obra junto a entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.operator	Operador	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.q	Forma completa do nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_delete_record_question.forever	Você realmente deseja excluir este registro de requisição?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_710	Autor secundário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.record_will_be_ignored	Este registro não será importado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_711	Autor secundário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configurations.error.value_must_be_numeric	O valor deste campo deve ser um número	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.d	Datas associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.summary	Relatório de Sumário do Catálogo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.field.status	Situação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.a	Sobrenome e-ou prenome do autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.550	TG (termo genérico)	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_field.id	Matrícula	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.b	Numeração que segue o prenome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.c	Título e outras palavras associadas ao nome	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_remove_attachment_description	Você deseja excluir esse arquivo digital?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.simple_term_title	Preencha o Tipo de Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	warning.reindex_database	Você precisa reindexar as bases de dados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.groups.cataloging	Catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.user.select_item_button	Selecionar cadastro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.advanced_search	Pesquisa Bibliográfica Avançada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.z	Subdivisão geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.amount	Quantidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.x	Subdivisão geral	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.600.subfield.y	Subdivisão cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.users_without_user_card	Listar apenas usuários que nunca tiveram carteirinha impressa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.confirm_remove_attachment	Excluir arquivo digital	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_delete_record_question	Você realmente deseja excluir este registro de requisição?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.041	Código da língua	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.error.accession_number_unavailable	Este tombo patrimonial já está em uso por outro exemplar. Por favor, preencha outro valor ou deixe em branco para que o sistema calcule um automaticamente.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_delete_record_title.forever	Excluir registro de requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.author_type.100	Pessoa	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.button.add	Adicionar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.change_status.title.uncancel	Recuperar Cartão	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.field.created	Data do Pedido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_730	Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.records_found_plural	{0} registros encontrados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.100.indicator.1	Forma de entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_080	CDU	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.upload.field.user_created	Carregar traduções criadas pelo usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.holding.error.shouldnt_delete_because_holding_is_or_was_lent	Este exemplar está ou já foi emprestado e não deve ser excluído. Caso ele não esteja mais disponível, o procedimento correto é mudar sua disponibilidade para Indisponível. Se desejar mesmo assim excluir este exemplar, pressione o botão <b>"Forçar Exclusão"</b>.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.page_help	<p>O <strong>"Cadastro de Usuários"</strong> permitirá guardar informações sobre os leitores e funcionários da biblioteca para que seja possível realizar empréstimos, reservas e controlar o acesso destes usuários à biblioteca.</p>\n<p>Antes de cadastrar um usuário é recomendado verificar se ele já está cadastrado, através da <strong>pesquisa simplificada</strong>, que buscará cada um dos termos digitados no campo selecionado ou através da <strong>pesquisa avançada</strong>, que confere um maior controle sobre os usuários localizados, permitindo, por exemplo, buscar usuários com multas pendentes.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.order.selected_records_plural	{0} Valores Adicionados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.author_type.110	Entidade Coletiva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.button.unblock	Desbloquear	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.author_type.111	Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.a	Nome da entidade ou do lugar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.b	Unidades subordinadas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.field.edition	Número da edição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.city	Cidade	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.d	Data de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	aquisition.quotation.error.quotation_not_found	Não foi possível encontrar a cotação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.l	Língua do texto	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_740	Título analítico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.n	Número da parte - Seção da obra	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.success.save	Arquivo de idiomas processado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.indicator.1.1	nome da jurisdição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.indicator.1.0	nome invertido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.administration_translations	Traduções	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.isbn	ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110.indicator.1.2	nome na ordem direta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710.subfield.t	Título da obra junto a entrada	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.type.vocabulary	Vocabulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.b	Material Ilustrativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	menu.circulation_reservation	Reservas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.a	Número de volumes e/ou paginação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.c	Dimensões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.2	Tipo de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.option.location	Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.246.indicator.1	Controle de nota/entrada secundária de título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.record.success.save	Registro incluído com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.user_type.success.update	Tipo de Usuário salvo com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.e	Material adicional	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.f	Tipo de unidade de armazenamento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.g	Tamanho da unidade de armazenamento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.users.failure.disable	Falha ao marcar usuário como inativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_090	Localização	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.bibliographic.id	N&ordm; do registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.library	Biblioteca	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.2.2	entrada analítica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.estimated_fine	Multa estimada para devolução hoje	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.040	Fonte de catalogação	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.043	Código de área geográfica	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	search.common.button.filter	Filtrar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.045	Código do período cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.backup_never_downloaded	Este backup nunca foi baixado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_cancel_editing.1	Você deseja cancelar a edição deste registro de autoridade?	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.confirm_cancel_editing.2	Todas as alterações serão perdidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_082	CDD	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.authorities.indexing_groups.total	Total	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user.fine.pending	Pendente	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.error.corrupted_backup_file	O backup selecionado não é um arquivo válido ou está corrompido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.labels.popup.title	Formato das etiquetas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.6	6 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.7	7 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.300.subfield.3	Especificação Material adicional	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.8	8 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.9	9 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.2	2 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.general.business_days	Dias de funcionamento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.3	3 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.4	4 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.555.indicator.1	Controle de constante na exibição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.5	5 caracteres a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.migration.title	Migração de dados do Biblivre 3	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	cataloging.bibliographic.indexing_groups.title	Título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.0	Nenhum caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.245.indicator.2.1	1 caractere a desprezar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.select.option.bibliography	Relatório de Bibliografia do Autor	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.supplier.field.vat_registration_number	Inscrição Estadual	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.receipt.renews	Renovações	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.database.record_moved	Registro movido para a {0}	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tabs.brief	Resumo Catalográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.vocabulary.datafield.685.subfield.i	Texto explicativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_095	Área do conhecimento do CNPq	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.button.new	Novo registro	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.029	ISNM	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.user_status.inactive	Inativo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.022	ISSN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.nonmusical_sound	Som não musical	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.024	Outros números ou códigos normalizados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.595.subfield.b	Notas de Bibliografia, índices e/ou apêndices	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.595.subfield.a	Código da bibliografia	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.020	ISBN	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.343.subfield.a	Método de codificação da coordenada plana	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.343.subfield.b	Unidade de distância plana	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.title.circulation.lending_receipt.printer.type	Tipo de impressora para recibo de empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.n	Número de ordem do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.k	Subcabeçalhos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	login.error.user_has_login	Este usuário já possui um login	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.close	Fechar	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.indicator.1.2	nome na ordem direta	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.e	Nome de subunidades do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.indicator.1.1	nome da jurisdição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.d	Data da realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_041	Idioma	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711.indicator.1.0	nome invertido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.c	Local de realização do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.translations.error.invalid_file	Arquivo inválido	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_043	Código geográfico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.request.success.update	Requisição salva com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.import.save.failed	Falha ao importar os Registros	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_045	Código cronológico	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.g	Informações adicionais	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.upload_popup.title	Enviando Arquivo	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.form	Formulário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	format.date	dd/MM/yyyy	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.111.subfield.a	Nome do evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	acquisition.supplier.success.delete	Proveedor excluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.342.indicator.2.8	Profundidad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.change_status.question.uncancel	¿Desea realmente recuperar esta Tarjeta?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.243.subfield.f	Fecha del trabajo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
pt-BR	administration.user_type.page_help	<p>A rotina de Tipos de Usuários permite o cadastramento e pesquisa dos Tipos de Usuários utilizados pela rotina de Cadastro de Usuários. Aqui são definidas informações como Limite de Empréstimos simultâneos, prazos para devolução de empréstimos e valores de multas diárias para cada tipo de usuário separadamente.</p>\n<p>Ao acessar essa rotina, o Biblivre listará automaticamente todos os Tipos de Usuários previamente cadastrados.  Você poderá então filtrar essa lista, digitando o <em>Nome</em> de um Tipo de Usuário que queira encontrar.</p>	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.accesscards.success.unblock	Cartão desbloqueado com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.013	Informação do controle de patentes	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.110	Autor - Entidade coletiva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.111	Autor - Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.login	Login	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.730	Entrada secundária - Título uniforme	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.949	Tombo Patrimonial	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.525.subfield.a	Nota de Suplemento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	error.invalid_parameters	O Biblivre não foi capaz de entender os parâmetros recebidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.bibliographic.indexing_groups.title	Título	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.success.save	Cotação incluída com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.items.administration_permissions	Gerenciar permissões	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.late_lendings	Relatório de Empréstimos Atrasados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.configuration.description.general.backup_path	Esta configuração representa o caminho, no servidor onde o Biblivre está instalado, para a pasta onde deverão ser guardados as cópias de segurança do Biblivre. Caso esta configuração estiver vazia, as cópias de segurança serão gravadas no diretório <strong>Biblivre</strong> dentro da pasta do usuário do sistema.<br>Recomendamos que este caminho esteja associado a algum tipo de backup automático em núvem, como os serviços <strong>Dropbox</strong>, <strong>SkyDrive</strong> ou <strong>Google Drive</strong>. Caso o Biblivre não consiga guardar os arquivos no caminho especificado, os mesmos serão guardados em um diretório temporário e poderão ficar indisponíveis com o tempo. Lembre-se, um backup é a única forma de recuperar os dados inseridos no Biblivre.	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.lending.lending_count	Exemplares emprestados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.permissions.confirm_delete_record_title.forever	Excluir Login do Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.holding.datafield.541	Nota sobre a fonte de aquisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.authorities.datafield.100	Autor - Nome pessoal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.title.user_creation_count	Total de Inclusões Por Usuário	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.700	Entrada secundária - Nome pessoal	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	common.unblock	Desbloquear	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.maintenance.backup.error.invalid_schema	A lista de backup possui uma ou mais bibliotecas inválidas	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.material_type.all	Todos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.field.requisition	Requisição	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.710	Entrada secundária - Entidade Coletiva	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.711	Entrada secundária - Evento	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.vocabulary.confirm_delete_record.forever	Ele será excluído permanentemente do sistema e não poderá ser recuperado	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	acquisition.quotation.success.delete	Cotação excluída com sucesso	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	marc.bibliographic.datafield.740.indicator.2._	nenhuma informação fornecida	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	circulation.user_cards.selected_records_plural	{0} usuários selecionados	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	administration.reports.field.lendings	Empréstimos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
pt-BR	cataloging.lending.error.limit_exceeded	O leitor selecionado ultrapassou o limite de empréstimos permitidos	2014-06-14 19:34:08.805257	1	2014-06-14 19:34:08.805257	1	f
es	marc.bibliographic.datafield.700.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.import_popup.title	Importando Registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.subfield.t	Título de la obra junto a la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.258.subfield.b	Denominación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.acquisition_supplier_list	Listar Proveedores	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.258.subfield.a	Jurisdicción emisora	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.subfield.q	Forma completa del nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.gender.1	Masculino	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.gender.2	Femenino	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.groups.admin	Administración	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.unit_value	Valor Unitario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.author_type	Tipo de autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.records	Informe de Inclusiones de Obras por Período	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_accesscards_save	Incluir tarjetas de acceso	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.subfield.c	Título y otras palabras asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.subfield.d	Fechas asociadas al nombre	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700.subfield.a	Apellido y/o nombre de autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.page_help	<p>El <strong>"Registro de Usuarios"</strong> permitirá guardar información sobre los lectores y empleados de la biblioteca para que sea posible realizar préstamos, reservas y controlar el acceso de estos Usuarios a la biblioteca.</p>\n<p>Antes de registrar un usuario es recomendable verificar si el ya está registrado, a través de la <strong>búsqueda simplificada</strong>, que buscará cada uno de los términos digitados en el campo seleccionado o a través de la <strong>búsqueda avanzada</strong>, que otorga un mayor control sobre los Usuarios localizados, permitiendo, por ejemplo, buscar Usuarios con multas pendientes.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.author_type.110	Entidad Colectiva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.order.selected_records_plural	{0} Valores Agregados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.author_type.111	Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user.button.unblock	Desbloquear	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.a	Nombre de la entidad o del lugar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.b	Unidades subordinadas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.edition	Número de la edición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.city	Ciudad	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.d	Fecha de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.g	Informaciones adicionales	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	aquisition.quotation.error.quotation_not_found	No fue posible encontrar la cotización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.l	Idioma del texto	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_740	Título analítico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.n	Número de la parte - Sección de la obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.success.save	Archivo de idiomas procesado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.indicator.1.1	nombre de la jurisdicción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.administration_translations	Traducciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.indexing_groups.isbn	ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.indicator.1.0	nombre invertido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710.subfield.t	Título de la obra junto a la entrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110.indicator.1.2	nombre en el orden directo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.type.vocabulary	Vocabulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	menu.circulation_reservation	Reservas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.b	Material Ilustrativo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.a	Número de volumenes y/o paginación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.c	Dimensiones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.option.location	Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.2	Tipo de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.246.indicator.1	Control de nota/entrada secundaria de título	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.record.success.save	Registro incluido con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.success.update	Tipo de Usuario guardado con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.custom.user_field.phone_work	Teléfono Comercial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.e	Material adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.f	Tipo de unidad de almacenamiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.g	Tamaño de la unidad de almacenamiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.users.failure.disable	Falla al marcar usuario como inactivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_090	Localización	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.bibliographic.id	N&ordm; de registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.library	Biblioteca	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.upload_popup.title	Abriendo Archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.2.2	entrada analítica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.schemas.title	Lista de Bibliotecas de este Servidor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.estimated_fine	Multa estimada para devolución hoy	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.migrate.success	Datos importados con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.041	Código del lenguaje	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.040	Fuente de catalogación	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	search.common.button.filter	Filtrar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.043	Código de área geográfica	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.backup_never_downloaded	Este backup nunca fue descargado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.045	Código de período cronológico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_cancel_editing.1	¿Usted desea cancelar la edición de este registro de autoridad?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.confirm_cancel_editing.2	Todas las alteraciones se perderán	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_082	CDD	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.authorities.indexing_groups.total	Total	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.6	6 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.7	7 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.8	8 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.300.subfield.3	Especificación Material adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.9	9 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.general.business_days	Días de funcionamiento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.2	2 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.3	3 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.4	4 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.5	5 caracteres a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.555.indicator.1	Control de constante en la exhibición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.migration.title	Migración de datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.0	Ningún carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.success.description	Datos importados con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.245.indicator.2.1	1 carácter a despreciar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.select.option.bibliography	Informe de Bibliografía del Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.supplier.field.vat_registration_number	Inscripción Estatal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.database.record_moved	Registro movido para la {0}	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.receipt.renews	Renovaciones	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tabs.brief	Resumen Catalográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.vocabulary.datafield.685.subfield.i	Texto explicativo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.reinstall.confirm.question	Atención. Todas las opciones harán con que los datos de su biblioteca sean borrados a favor de los datos recuperados. Se recomienda hacer un backup antes de iniciar esta acción. ¿Desea continuar?	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.select.default	Seleccione una opción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_095	Área de conocimiento de CNPq	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.button.new	Nuevo registro	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.029	ISNM	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.user_status.inactive	Inactivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.nonmusical_sound	Sonido no musical	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.022	ISSN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.024	Otros números o códigos normalizados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.595.subfield.b	Notas de Bibliografía, índices y/o apéndices	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.595.subfield.a	Código de la bibliografía	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.020	ISBN	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.343.subfield.a	Método de codificación de la coordenada plana	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.setup.biblivre3import.button	Importar datos del Biblivre 3	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.343.subfield.b	Unidad de distancia plana	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.title.circulation.lending_receipt.printer.type	Tipo de impresora para recibo de préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.n	Número de orden de evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	login.error.user_has_login	Este usuario ya posee un login	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.k	Subencabezamientos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.indicator.1.2	nombre en el orden directo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.close	Cerrar	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.indicator.1.1	nombre de la jurisdicción	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.e	Nombre de subunidades del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711.indicator.1.0	nombre invertido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_041	Idioma	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.d	Fecha de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.c	Lugar de realización del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.translations.error.invalid_file	Archivo inválido	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_043	Código geográfico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.import.save.failed	Falla al importar los Registros	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.success.update	Solicitud guardada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.tab.record.custom.field_label.biblio_045	Código cronológico	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.g	Información adicional	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.upload_popup.title	Enviando Archivo	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.form	Formulario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	format.date	dd/MM/aaaa	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.111.subfield.a	Nombre del evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.user_type.page_help	<p>La rutina de Tipos de Usuarios permite el registro y búsqueda de los Tipos de Usuarios utilizados por la rutina de Registro de Usuarios. Aquí están definidas las informaciones como Límite de Préstamos simultáneos, plazos para devolución de préstamos y valores de multas diarias para cada tipo de usuario separadamente.</p>\n<p>Al accesar a esa rutina, el Biblivre listará automáticamente todos los Tipos de Usuarios previamente registrados. Usted podrá entonces filtrar esa lista, digitando el <em>Nombre</em> de un Tipo de Usuario que quiera encontrar.</p>	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.accesscards.success.unblock	Tarjeta desbloqueada con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.110	Autor - Entidad colectiva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.013	Información de control de patentes	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.111	Autor - Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.login	Login	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.configuration.title.general.subtitle	Subtítulo de este Grupo de Bibliotecas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.730	Entrada secundaria - Título uniforme	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.949	Sello Patrimonial	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	error.invalid_parameters	El Biblivre no fue capaz de entender los parámetros recibidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.525.subfield.a	Nota de Suplemento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.success.save	Cotización incluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.items.administration_permissions	Administrar permisos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.late_lendings	Informe de Préstamos Atrasados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.configuration.description.general.backup_path	Esta configuración representa el camino, en el servidor donde el Biblivre está instalado, para la carpeta donde deberán guardarse las copias de seguridad del Biblivre. En caso que esta configuración este vacía, las copias de seguridad serán grabadas en el directorio <strong>Biblivre</strong> dentro de la carpeta del usuario del sistema.<br>Recomendamos que este camino esté asociado a algún tipo de backup automático en nube, como los servicios <strong>Dropbox</strong>, <strong>SkyDrive</strong> ou <strong>Google Drive</strong>. En caso que el Biblivre no consiga guardar los archivos en el camino especificado, los mismos serán guardados en un directorio temporario y podrán quedar indisponibles con el tiempo. Recuerde, un backup es la única forma de recuperar los datos incluidos en el Biblivre.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.request.field.author_type	Tipo de Autor	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.lending.lending_count	Ejemplares prestados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.permissions.confirm_delete_record_title.forever	Excluir Login de Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.holding.datafield.541	Nota sobre la fuente de adquisición	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.authorities.datafield.100	Autor - Nombre personal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.title.user_creation_count	Total de Inclusiones Por Usuario	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.700	Entrada secundaria - Nombre personal	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.unblock	Desbloquear	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.maintenance.backup.error.invalid_schema	La lista de backup posee una o más bibliotecas inválidas	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	common.calculating	Calculando	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.material_type.all	Todos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.field.requisition	Solicitud	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.bibliographic.automatic_holding.holding_volume_count	Cantidad de volúmenes de la Obra	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.manage.error.create	Falla al crear nueva biblioteca.	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.710	Entrada secundaria - Entidad Coletiva	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.711	Entrada secundaria - Evento	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.vocabulary.confirm_delete_record.forever	Será excluido permanentemente del sistema y no podrá ser recuperado	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	multi_schema.configuration.description.general.subtitle	Subtítulo que será exhibido cuando se accede a la página principal de este grupo de bibliotecas. Esta página listará todas las bibliotecas registradas en este grupo (administradas por el mismo Biblivre 4).	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	acquisition.quotation.success.delete	Cotización excluida con éxito	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	marc.bibliographic.datafield.740.indicator.2._	ninguna información suministrada	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	administration.reports.field.lendings	Préstamos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	circulation.user_cards.selected_records_plural	{0} usuarios seleccionados	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.lending.error.limit_exceeded	El lector seleccionado excedió el límite de préstamos permitidos	2014-07-19 11:28:46.69376	1	2014-07-19 11:28:46.69376	1	f
es	cataloging.error.invalid_data	No fue posible procesar la operación. Por favor, intente nuevamente.	2014-07-19 11:35:18.227701	1	2014-07-19 11:35:18.227701	1	f
es	administration.permissions.login_data	Datos para el acceso al sistema	2014-07-19 11:35:18.227701	1	2014-07-19 11:35:18.227701	1	f
es	administration.reports.field.no_data	No existen datos para Generar este Informe	2014-07-19 11:35:18.227701	1	2014-07-19 11:35:18.227701	1	f
es	administration.reports.field.user_data	Datos	2014-07-19 11:35:18.227701	1	2014-07-19 11:35:18.227701	1	f
pt-BR	multi_schema.select_restore.description_found_backups	Abaixo estão os backups encontrados na pasta <strong>{0}</strong> do servidor Biblivre. Clique sobre o backup para ver a lista de opções de restauração disponíveis.	2014-07-19 13:48:01.039737	1	2014-07-19 13:48:01.039737	1	f
pt-BR	multi_schema.restore.dont_restore	Não restaurar esta biblioteca	2014-07-19 13:48:01.039737	1	2014-07-19 13:48:01.039737	1	f
pt-BR	multi_schema.restore.restore_complete_backup.title	Restaurar todas as informações do Backup, substituindo todas as bibliotecas deste Biblivre	2014-07-19 13:48:01.039737	1	2014-07-19 13:48:01.039737	1	f
pt-BR	multi_schema.select_restore.library_list_inside_backup	Bibliotecas neste backup	2014-07-19 13:48:01.039737	1	2014-07-19 13:48:01.039737	1	f
pt-BR	multi_schema.backup.schemas.title	Cópia de Segurança (Backup) de Múltiplas Bibliotecas	2014-07-19 13:50:48.346587	1	2014-07-19 13:50:48.346587	1	f
pt-BR	multi_schema.select_restore.title	Restauração de Backup de Múltiplas Bibliotecas	2014-07-19 13:50:48.346587	1	2014-07-19 13:50:48.346587	1	f
pt-BR	multi_schema.select_restore.description	Use esta opção caso você queira restaurar um backup existente do Biblivre 4. Caso o Biblivre encontre backups salvos em seus documentos, você poderá restaurá-los diretamente da lista abaixo. Caso contrário, você deverá enviar um arquivo de backup (extensão <strong>.b4bz</strong>) através do formulário.	2014-07-19 13:50:48.346587	1	2014-07-19 13:50:48.346587	1	f
pt-BR	multi_schema.backup.schemas.description	Selecione abaixo todas as bibliotecas que farão parte do backup. Mesmo que um backup possua diversas bibliotecas, você poderá escolher quais deseja restaurar quando precisar.	2014-07-19 13:50:48.346587	1	2014-07-19 13:50:48.346587	1	f
pt-BR	multi_schema.restore.title	Opções de Restauração de Backup	2014-07-19 14:05:42.310014	1	2014-07-19 14:05:42.310014	1	f
pt-BR	multi_schema.restore.warning_overwrite	Atenção: já existe uma biblioteca cadastrada com o endereço acima. Se você fizer a restauração com esta opção selecionada, o conteúdo da biblioteca existente será substituído pelo conteúdo do Backup.	2014-07-19 13:48:01.039737	1	2014-07-19 14:05:42.310014	1	f
pt-BR	multi_schema.restore.restore_with_original_schema_name	Restaurar esta biblioteca usando seu endereço original	2014-07-19 13:48:01.039737	1	2014-07-19 14:05:42.310014	1	f
pt-BR	multi_schema.restore.restore_with_new_schema_name	Restaurar esta biblioteca usando um novo endereço	2014-07-19 13:48:01.039737	1	2014-07-19 14:05:42.310014	1	f
en-US	cataloging.bibliographic.attachment.alias	Insert a name for this digital file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.fieldset.title_info	Information on Work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
pt-BR	multi_schema.restore.restore_complete_backup.description	Caso você deseje restaurar todo o conteúdo deste backup, use o botão abaixo. Atenção: Isso substituirá TODO o conteúdo do seu Biblivre, inclusive substituindo todas as bibliotecas existentes pelas que estão no backup. Use esta opção apenas se desejar voltar completamente no tempo, até a data do backup.	2014-07-19 13:48:01.039737	1	2014-07-19 14:11:39.121566	1	f
pt-BR	multi_schema.restore.restore_partial_backup.title	Restaurar bibliotecas de acordo com os critérios acima	2014-07-19 13:48:01.039737	1	2014-07-19 14:11:39.121566	1	f
pt-BR	administration.maintenance.backup.error.no_schema_selected	Nenhuma biblioteca selecionada	2014-06-14 19:34:08.805257	1	2014-07-19 17:20:20.928313	1	f
pt-BR	administration.maintenance.backup.error.invalid_destination_schema	O atalho de destino é inválido	2014-07-19 17:20:20.928313	1	2014-07-19 17:20:20.928313	1	f
pt-BR	administration.maintenance.backup.error.backup_file_not_found	Arquivo de backup não encontrado	2014-07-19 17:20:20.928313	1	2014-07-19 17:20:20.928313	1	f
pt-BR	administration.maintenance.backup.error.invalid_origin_schema	O Backup não possui a biblioteca selecionada	2014-07-19 17:20:20.928313	1	2014-07-19 17:20:20.928313	1	f
pt-BR	administration.maintenance.backup.error.duplicated_destination_schema	Não é possível restaurar duas bibliotecas para um único atalho	2014-07-19 17:20:20.928313	1	2014-07-19 17:20:20.928313	1	f
en-US	cataloging.bibliographic.button.export_records	Export records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_delete_record_title.forever	Delete supplier record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.circulation_user	User Registry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	text.main.noscript		2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.dewey	Dewey Classification Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_reports	Reports	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.digits	Significant digits	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.object_3d	Object 3D	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.error.invalid_data	It was not possible to process the operation. Please try again.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.cancel	Cancel	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.supplier	Supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.022.subfield.a	ISSN number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.title	Library title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013.subfield.e	Patent status	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.error.record_not_found	Record not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013.subfield.d	Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013.subfield.f	Part of a document	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_cancel_editing.2	Modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_cancel_editing.1	Do you wish to cancel editing this acquisition order?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.256.subfield.a	Characteristics of the computer file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.date_from	from	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.date	Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.button_exclude_digital_media	Create backup without digital files	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.psql_path	Path for the program psql	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging	Cataloging	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_913	Local Code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013.subfield.a	Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013.subfield.b	Country	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013.subfield.c	Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.description	Use this option if you wish to restore and import a Biblivre3 existing backup.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.upload_button	Send	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.search.distributed_search_limit	Limit of results for distributed searches	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.default	Select...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.490.indicator.1	Policy for serial split	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.title.unit_value	Unit Value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.users_who_have_login_access	List only users having a Biblivre access login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.title	Backup Restoring Options	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.email	Email	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.circulation_user_cards	Printing of User Cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.indicator.1.2	compound surname (obsolete)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.indicator.1.3	family name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.indicator.1.0	simple or compound name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.indicator.1.1	simple or compound surname	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.082	Dewey Decimal Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.080	Universal Decimal Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.title_last_backups	Last Backups	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.lendings	Loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.indicator.1.8	Do not generate constant in the exhibition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.marc_popup.title	Edit MARC Record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.arrival_time	Arrival time	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.success.update	Record successfully modified	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.dewey	Dewey Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.title.requisition	Requisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.indicator.1.0	Remissive index	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.save	Save	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.1.0	Does not generate entry for the Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.1.1	Generates entry for the title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.save	Save	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_z3950_delete	Delete z3950 server record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.fine_value	Fine value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.095	Area of knowledge of the CNPq	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.error.no_users_found	No user found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.090	Call number - Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_delete_record_title	Delete quotation record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.card_unavailable	Card unavailable	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.simple_term_title	Fill in Card Code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.invalid_restore_path	The configured directory for restoring backup files is not valid	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.pg_dump_path	Path for the program pg_dump	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.add_one_card	Register New Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_z3950_save	Save server z3950 record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_move_record_description_plural	Do you really wish to move these {0} records?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.button.select_item	Select item	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.isbn	ISBN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.backup_path	Destination path for safety copies (backups)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_300	Physical description	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload.button	Send language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.340.subfield.e	Carrier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.confirm_cancel_editing.1	Do you wish to cancel editing this user?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.success.block	Card successfully blocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.select_restore.description_found_backups	Below the backups found in the folder <strong>{0}</strong> of the Biblivre server. Click on backup to see the restoring list of options available.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.340.subfield.c	Materials applied to surface	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.340.subfield.d	Technique in which the information is recorded	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_306	Duration (time)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.340.subfield.a	Basis and configuration of material	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.340.subfield.b	Dimensions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.invalid_method_call	Invalid method call	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2._	no information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_411	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_410	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.cataloging_bibliographic	Bibliographic and Units Catalogue	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore	Restore a Biblivre 3 Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.issn	ISSN (including hyphens)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.warning_overwrite	Beware!:  There is already a library registered with the address above. If you restore using the option selected, the content of the existing library will be replaced by the Backup content.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.no_permission	You have no permission to execute this action	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.new	New user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.confirm_delete_record.forever	He will be excluded from the system forever and cannot be retrieved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.2	Thesaurus	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.1	Subject level	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.help_manual	Manual	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.id	Record Id	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.all_users	All-Users Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.invoice_number	Invoice No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.indexing_groups.te_term	Narrower Term (NT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.450.subfield.a	Topical term not used	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.description_last_backups_1	Links for downloading the last backups made below. It is important to keep them in a safe place, as this is the only way to recover data, if necessary.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.description_last_backups_2	These files are kept in the directory specified in Biblivre configuration (<em>"Administration"</em>, <em>"Configurations"</em>, in the upper menu). Should this directory be unavailable for writing when the backup is made, a temporary directory will be used as an alternative. For that reason, some backups may not be available after a certain date. <span class="attention">we recommend downloading backups and keeping them in a safe place.</span>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.users.title	Search Reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.040.subfield.e	Convential sources of data description	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.040.subfield.d	Agency that modified the record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.1.3	family name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.040.subfield.c	Agency that transcribed the record in legible format by machine	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.040.subfield.b	Cataloging Language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.040.subfield.a	Code of Cataloging Agency	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.1.0	simple or compound name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.1.1	simple or compound surname	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.invalid_json	Biblivre could not understand data received	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.1.2	compound surname (obsolete)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	aquisition.request.error.request_not_found	It was not possible to find the request	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.database	Base	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.description.4	Backup of just digital files is a copy of all the digital media files save in Biblivre, without any other data or information, such as users, catalographic basis, and so on.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.description.3	Backup without digital files is a copy of all the Biblivre4 data and information, <strong>excluding</strong> digital media files. In view of the exclusion of digital media files, the backup and retrieval processes are faster, and the backup file is smaller.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.id_cpf	Taxpayer No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.description.1	Backup is a process where we copy information in order to secure them in case of problems in the system. It is a copy of the Biblivre  records and information. Biblivre 4 has 3 types of backups:	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.description.2	Complete Backup is a copy of all the Biblivre 4 data and information, including digital media files, such as user photos, digital files of bibliographic records and so on.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.error.delete	Error in deleting Z39.50 Server	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.upload_popup.processing	Processing...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.c	Venue of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.search.results_per_page	This configuration represents the highest number of results to be exhibited on a single page in the searches of the system. A very high number may lead to slow operating system.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.a	Name of entity or of place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.b	Subordinated units	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.password	Password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_name	Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.button_digital_media_only	Create digital files backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.n	Number of part - section of the work - order of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_status.active	Active	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.save	It was not possible to save the translations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.k	Subheading. (amendments, protocols, selection, etc.)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.back_to_search	Return to search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_400	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.subfield.t	Title of the work close to entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.confirm_description	Do you really wish to restore this Backup?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.2	Type of secondary entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_move_record_title	Move records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.custom_count	Marc field counting report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_signup	Date of user signup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.550.subfield.z	Geographical subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.550.subfield.x	General subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.550.subfield.y	Chronological subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.progress_popup.processing	Biblivre in this library is under maintenance. Please wait until maintenance is concluded.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.dates	Period / Term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.page_help	<p>The  <strong>"Data Migration"</strong> module allows importing data from an existing Biblivre 3 database to the empty Biblivre 4  database 4.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.362.subfield.z	Information source	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.error.user_not_found	User not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.users	Users, access Logins and Users Types	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.step_1_description	At this stage, you can import a file with records in MARC, XML and ISO2709 formats of conduct a search in other libraries. Select below the import arrangement you wish, selecting the file or filling in the search terms. The next step will be to select which records should be imported.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.confirm_delete_record_question	Do you really wish to delete this vocabulary record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	header.law	Law for the Promotion of Culture	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.printer_type.printer_24_columns	24 column printer	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.book	Book	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.database_count	Total Base Records in the Term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.913.subfield.a	Local code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.acquisition	Acquisition Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.source_file_subtitle	Select a file with the records to be imported. This file´s format can be <strong>text</strong>, <strong>XML</strong> or <strong>ISO2709</strong>, provided original cataloging is compatible with MARC.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.confirm_delete_record_question.forever	Do you really wish to delete this user?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.670	Origin of information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.default_language	Default language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.default_language	This configuration represents the default language in the case of Biblivre exhibition.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.1	Generates secondary entry in sheet	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.java_locale_not_available	There no identifier of java language for the translations file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.circulation.lending_receipt.printer.type	This configuration represent the type of printer to be used for printing loan receipts. Possible values are: 40 column printer, 80 column printer, or common printers (ink jet).	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.685	Historical or glossary note (GLOSS)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.0	Part of title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.field.port	Port	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload.field.upload_file	File	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.680	Scope note (SN)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.new_schema.field.subtitle	Library subtitle	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.invalid_language	Select a language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.label.author_count	Number of records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.5	Additional title in secondary cover sheet	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.6	Batch Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.7	Normal title*marc.bibliographic.datafield.246.indicator.2.8 = Spine title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.1	Parallel title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.loading	Loading	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.2	Specific title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.3	Another title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2.4	Cover title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_450	Use for Term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.invalid_database		2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.step_2_description	In this case, please check the records to be imported and import them individually or altogether, through the buttons available at the end of the page. Biblivre automatically detects if the record is a bibliographic one, or authorities or vocabulary, but it allows the user to correct the importation beforehand. <strong>Important:</strong> Imported record will be added to the Work base and must be corrected and adjusted before moving them to the Main Base. This avoids incorrect records added directly to the final database.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.terms_of_payment	Payment terms	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_310	Periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.450	UF (remissive for unused NT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.reserve_failure	Work reservation failure	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.550.subfield.a	Topical term adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.summary	Catalogue Summary	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.dewey	Dewey Decimal Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.040	Cataloging Source (NR)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.362.subfield.a	Information on Publishing Date and/or Volume	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.success.update	Supplier successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.button.show_log	Show log	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.page_help	<p> The module <strong>"Translations"</strong> allows adding new languages to Biblivre 4 or modifying existing texts.</p>\n<p><strong>Attention: this module performs advanced configurations in Biblivre 4, and needs to be used solely by advanced Users, experienced in IT.</strong>.</p>\n<p>To add a new language, please download the Portuguese language file, do the translation of the texts and then send the file. Remember that only the <strong>texts</strong> (after the = sign) must be translated. Do not modify the keys; if you do so, Biblivre 4 will not be able to find the text </p>\n<p>Example: let´s imagine that you wish to modify the text in the main menu of <i>Search</i> to <i>Look for</i>. You will then have to download the language file and modify the following line:</p>\n<p><strong>*menu.search</strong> = Search</p>\n<p>To:</p>\n<p><strong>*menu.search</strong> = Loo for</p>\n<p>And then deliver the language file. Biblivre 4 will process the file and will modify the menu text.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.current_password	Current password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.subfield.v	Number of volume of sequence designation of the series	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.0	LC Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.error.select_reader_first	To reserve a record you need, first of all, to select a reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.2	National Library of Medicine Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.1	CDD	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.4	Steady location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.3	Superintendent of Documents classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.6	Partly separated	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.operator.and_not	and not	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.5	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.7	Specific classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1.8	Another scheme	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.periodic	Periodical	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.subfield.a	Uniform title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.edition	Edition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.name	Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.all_users	Users General Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.949.subfield.a	Asset cataloging reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.dewey	CDD	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.author_numeration	Numeration after First Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.isbn_already_in_database	There is already a record with that ISBN in the database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.090.subfield.a	Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.success.delete	Record successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.090.subfield.b	Author code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.090.subfield.c	Edition - volume	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_040	Cataloging source	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.090.subfield.d	Copy (unit) Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.holdings_lent	Lent	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.search.result_limit	This configuration represents the maximum quantity of results to be found in catalographic searches. This limit is relevant to avoid slow Biblivre operations in libraries with a large number of records. Should the quantity of results of the search exceed the limit, the recommendation will be to improve search filters.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.indicator.1._	Index	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.record_imported_successfully	Record successfully imported	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.buttons.dismiss_fine	Dismiss fine	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.returned_lendings	Lendings returned	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.257.subfield.a	Country of producing entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.button.edit_marc	Edit MARC	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.success.save	Z39.50 Server successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.wait	Please wait	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1._	No information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.music	Music	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630	Subject - Uniform title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.success.delete	Z39.50 Server successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.t	Title of the work close to entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.n	Order number of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.status	Status	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_362	Date of first publication	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	language_code	en-US	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.e	Name of event subunits	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.c	Venue of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.670.subfield.b	Information found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.subfield.a	Name of event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.fine_popup.title	Late Return	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.670.subfield.a	Name taken from	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.lending_date	Loan date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.buttons.pay_fine	Pay	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reinstall.confirm.description	Do you wish to go to the restoration and reconfiguration screen? You will be able to restore a Biblivre 4 backup, delete data in your library or redo a migration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.410.subfield.a	Name of the entity or of the place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.cataloging_vocabulary	Vocabulary Catalogue	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.page_help	<p> The permissions routine allows the user to create a Login and Password, as well as the definition of the access permissions or use of the various Biblivre routines.</p>\n<p>The search will search Biblivre registered users and will work in the same manner of the User Registration Simple search routine.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_delete_record.trash	It will be moved to the recycle bin database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.all	Any field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.651	Subject - Geographical name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.650	Subject - Topic	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.confirm_delete_record.forever	Card will be permanently deleted from system and cannot be recovered	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.backup.schemas.title	Backup copy of Multiple Libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.help_faq	Frequently Asked Questions - FAQ	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.subject	Subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.clean_install.description	If you do not have or do not wish to restore a backup, this option will allow start using Biblivre 4 with an empty database. When entering Biblivre 4 for the first time, use the <strong>admin</strong> and password <strong>abracadabra</strong> to access the system and configure your new library.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.success.save	Card successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.acquisition_order	Orders	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_852	Public Notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.load	It was not possible to read the translations file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload_popup.title	Sending File	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.error.no_request_found	It was not possible to find any requisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_delete_record.forever	It will be permanently deleted from the system and cannot be retrieved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.no_schema_selected	No library selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_bibliographic_save	Save bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.original_value	Original value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.photo	Photograph	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_supplier_delete	Delete supplier record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.confirm_delete_record_question.forever	Do you really wish to delete this Z39.50 Server?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.address_complement	Complement	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_bibliographic_private_database_access	Access to Private Database.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.150.subfield.z	Geographical subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.150.subfield.y	Chronological subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3migration.description	A Biblivre 3 installation was detected in this computer. You may wish to import these data for Biblivre 4 by selecting the items you are interested in and pressing the button below. After importation, <strong>you will have to reindex the three bases: the Bibliographic ones, Authorities and Vocabulary </strong>, through the <strong>"Maintenance"</strong> screen in <strong>"Administration"</strong> and <strong>select again the permissions of employees able to access Biblivre</strong>, through the <strong>"Logins and Permissions"</strong> screen in <strong>"Administration"</strong>.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.z	Standard note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.q	Description of index in multimedia	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.p	Description of collection in multimedia	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.invalid_destination_schema	Invalid destination shortcut	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.o	Description of index in microfilm	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_830	Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.n	Description of collection microfilm	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.u	Description of index in other carriers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.pamphlet	Pamphlet	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.t	Description of collection in other carriers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.s	Description of index in Braille	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.r	Description of collection in Braille	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.i	Index description with online access	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.f	Library code at CCN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.g	Description of index of printed collection	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.l	Description of collection in microfiche	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.m	Description of index in microfiche	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.j	Description of collection in CD-ROM	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.2	Thesaurus	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.issn	ISSN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.k	Description of index CD-ROM	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.1	Subject level	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.search_authorities	Authorities	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610	Subject - Collective Entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.a	Library acronym	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.psql_path	Attention: This is an advanced configuration, but an important one. Biblivre will try to find automatically the path for the program <strong>psql</strong> and except in cases where an error is show down below, you will not need to modify this configuration. This configuration represents the path on the server where Biblivre is installed, for the executable <strong>psql</strong> which id distributed with the PostgreSQL. Should this configuration be invalid, Biblivre will not be able to create safety copies.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611	Subject - Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.d	Year of last acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.e	Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.b	Description of printed collection	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947.subfield.c	Type of acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configuration.description.general.title	Nome to be shown when the main page of the library group is accessed. o que será exibido quando a página principal deste grupo de bibliotecas for acessada. This page will list all the registered libraries in this group (managed by the same Biblivre 4).	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.card_in_use	Card in use	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.field_count	Count by Marc field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041.subfield.b	Language code of summary or abstract	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041.subfield.a	Language code of text	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.confirm_delete_record_question	Do you really wish to delete this unit record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.error.description	Regretably an error occurred when restoring Biblivre3 backup. Check the next screen by error log and, if necessary go to the Biblivre forum for assistance\n.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.button_bibliographic	Reindex bibliographic base	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.database.main	Main	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600	Subject - Personal name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.status	Status	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041.subfield.h	Language code of original document	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.indicator.1.0	Date - sole period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.indicator.1.2	Date extension - periods	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.indicator.1.1	Date - multiple period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.subject	Subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.place	Local	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.150.subfield.x	General subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.isrc	ISRC	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.lendings	Active loans, loan and fine historical record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.150.subfield.a	Topical term adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.subfield.d	Longitude Scale	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.subfield.c	Latitude Scale	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.error.save	Error saving User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.acquisition	Acquisitions (Supplier, Requisition, Quotation and Order)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.status.any	Any	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.users.title	Search Reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.confirm_delete_record_question.forever	Do you really wish to delete this Card?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.select_restore.title	Backup restoring of Multiple Libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.restore_with_original_schema_name	Restore this library using the original address	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	field.error.invalid	This value is not valid for this field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.150.subfield.i	Qualifier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.subfield.a	Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.subfield.b	Coordinate Unit or Distance Unit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_usertype_save	Save user type record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.page_help	The multi-libraries screen allows registering several libraries to be managed by a single Biblivre. Since the moment the multi-libraries system is in action, the list of registered libraries will be shown when the person accesses the standard Biblivre 4 address.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access.user.search	Users	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.indexing_groups.all	Any field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_876	Restricted access notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.question.unblock	Do you really wish to unblock this Card?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.indicator.1.3	family name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.movie	Film	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.indicator.1.1	simple or compound surname	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.cataloging_authorities	Authorities Catalogue	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.indicator.1.2	compound surname (obsolete)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.indicator.1.0	simple or compound name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.holdings	Unit Registry Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.unit_value	Unit Value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.indicator.1	Form of entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.cancel	Cancel	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_usertype_delete	Delete user type record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.2.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.open	Open	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.status.in_use	In use	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.save_as_new	Save as New	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.void		2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.error.cant_disable_last_library	Cannot disable all the libraries in this group. At least one should be enabled.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.670	Origin of information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.info	Remarks	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.status.cancelled	Cancelled	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.invalid_backup_type	This is an invalid backup type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.operator.or	or	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110	Author - Collective entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111	Author - Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.author	Search by Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.b	Title complement	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.lending_limit	Limit for simultaneous loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	label.username	User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.error.delete.user_has_lendings	This user has active lendings. Return items before deleting this user.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.a	Title/abbreviated title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.user_has_card	User already has a card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.select_card	Select Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.g	Miscellaneous	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.f	Information on volume /fascicle number and/or date of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.no_backups_found	No backup found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.warning	This process may take some minutes, depending on the hardware configuration of your server.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.i	Show text	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.h	Physical means	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.504.subfield.a	Bibliography notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.expected_return_date	Return date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.field.name	Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.invalid_backup_path	Invalid path. This directory does not exist or Biblivre is not authorized to write.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.n	Number of the part / section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.subfield.p	Name of the part / section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100	Author - Personal name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.new_value	New value valor	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.page_help	<p> The <strong>"Access Control "</strong> allows managing the entry and permanence of readers in the library facilities. Select the reader through a search by name or Enrollment Number and insert the number of an access card available to bind that card to the reader.</p>\n<p>When the reader is leaving, you will be able to unbind the card looking for its code </p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.2.2	analytical entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.title	Main Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.total	Total	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.marc_field	Marc field Value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.computer_legible	Computer file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.1	Generates secondary entry in the sheet	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.usertype.confirm_delete_record.forever	User Type will be permanently deleted from system and cannot be restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload.title	Send language file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_datamigration	Import Biblivre 3 data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130	Anonymous work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.save	Error when saving Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.address	Address	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.page_help	<p> Distributed searches allow retrieving information on records in contents from other libraries, which make their records available for collaborative searches and cataloging.</p>\n<p>In order to conduct a search please fill in the terms of the search, selecting your field of interest. Right afterwards, select one or more libraries where the records can be traced.. <span class="warn">Attention: select just a few libraries in order to prevent the Distributed Search from running too slowly, as this depends on the communication between libraries and on the size of each collection.</span></p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.save	Save	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.printer_type.printer_common	Common printer	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.number_of_titles	Number of Titles	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.button.continue_to_biblivre	Go to Biblivre	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_count_by_type	Total by User Types	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.login_data	Data for accessing the system	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.step_2_title	Select records for importation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.employee	Employee	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.current_value	Current value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.uncancel	Restore	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.title_found_backups	Backups Found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.error.delete	Error deleting Record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_cancel_editing_title	Cancel editing of order record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permission.error.delete	Login deletion error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_status.blocked	Blocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.success.description	Backup successfully restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.start_date	Starting Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.680.subfield.a	Scope note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.return	Return	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.confirm_cancel_editing_title	Cancel user editing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.095.subfield.a	Subject areas	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.confirm_cancel_editing.1	Do you wish to cancel editing this vocabulary record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.import_as	Import as:	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_authorities_save	Save authority record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_delete_record.forever	Record will be deleted forever and cannot be recovered	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.thesis	Thesis	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.import_popup.importing	Importing records, please wait	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.fieldset.title.values	Values	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.150	NT	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.acquisition_request	Requests	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.1.0	No specified level	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.1.1	Primary subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.1.2	Secondary subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.download.description	Select below the language you wish to download.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.zip_code	ZIP Code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.delete	Delete	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.z3950_servers	Z39.50 Servers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.lending_date	Lending date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.info	Remarks	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.trademark	Fancy Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.remove_item_button	Remove	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.new_schema.title	Creation of New Library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.indicator.1._	Subfields |b or |c are not present	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.other_name	Other name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	aquisition.supplier.error.supplier_not_found	It was not possible to find the supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.button.print_user_cards	Print user cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.indexing_groups.tg_term	Broader Term (BT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.description.6	If the user losses his/her password, he / she must contact the Administrator or the Librarian in charge of Biblivre, and they may furnish a new password.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3migration.button	Import Biblivre 3 data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.issn_already_in_database	There is already a record with this ISSN in the database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.a	Uniform title given to the document	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.field.url	URL	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.550.subfield.y	Chronological subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.delete	Error when deleting Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.550.subfield.z	Geographical subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.d	Date that appears close to the uniform entry title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.address_zip	ZI P Code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.l	Text language. Text language in full	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.f	Date of edition of the item that is being processed	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.button.show_log	Show log	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.913.subfield.a	Local code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.return_date	Return date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.description.1	Password change means the process in which the user may modify current password with a new one. For security reasons, we suggest users to do this periodically.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.error.move	Error moving Records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_datamigration	Data Migration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.description.3	Use letter, special characters and numbers if your password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.description.2	A three-digit password is the only rule to create passwords in Biblivre. However, we suggest following these guidelines:	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.p	Name of part - Section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.page_help	<p>Record import allows expanding your database without any need of manual cataloging. New records can be imported through Z39.50 searches or from files exported by other librarianship systems.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.description.5	Use a larger number of digits than recommended.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.description.4	Use Capital and small letters; and	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.550.subfield.a	Topical term adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.multi_schema	This configuration allows setting up the multiple library system in this Biblivre 4 installation.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.block	Block	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.949.subfield.a	Asset cataloging reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.subfield.a	Topical term adopted by Thesaurus	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.410.subfield.a	Name of entity or name of place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.log_header	[New Biblivre 4 Library Log]	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.550.subfield.x	General subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.renew_success	Loan renewed successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging_vocabulary	Vocabulary	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.labels.never_printed	List only the copies that never had printed labels	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.user_total_lending_list	Background information on loans to this reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.manuscript	Manuscript	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.operator.and	and	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.step	Step	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_authorities_delete	Delete authority record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.question.cancel	Do you really wish to cancel this Card?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reinstall.title	Restoration and Reconfiguration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.cancel	Cancel	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.success.generate	Report successfully generated. It will open on another page.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.selected_records_singular	{0} unit (copy/item) selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.502.subfield.a	Dissertation or thesis notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.auto_download	Backup made, automatic download in a few seconds…	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.groups.acquisition	Acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.record_deleted	Record deleted for ever	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.040.subfield.c	Agency that transcribed the record in legible format per machine	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.040.subfield.b	Cataloging language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.040.subfield.e	Conventional sources for data description	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.040.subfield.d	Agency that modified the record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.040.subfield.a	Code of cataloging agency	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.searches_by_date	Report on the Total Number of Searches by Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.runtime_error	Unexpected error during runtime	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.subtitle	Parallel titles/subtitle	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.cancel.description	Press the button below to desist restoring this bb4 installation and return to your library.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.success.save	Supplier successfully included	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.indicator.1	Type of chronological period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_backup	Obtain a backup of the database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.form.hidden_subfields_plural	Show {0} hidden subfields	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.page_help	<p>To make a reservation you will need to select the reader in the name of whom the reservation is made and, right afterwards, you will have to select the record to be reserved. Search by reader can be made  by name, user number or other field previously registered. In order to find registration, you have to carry out a search similar to the bibliographic search.</p>\n<p>Cancellations can be made selecting the reader with the reservation.</p><p>The duration of the reserve is calculated according to the User Type, configured by the <strong>Administration</strong> menu and defined during the reader´s registration.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.users_with_pending_fines	List only users with pending fines	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_delete_record_title	Delete supplier record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.acquisition	Acquisition Order Report for the Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.button.search	Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.confirm_delete_record.forever	User Login and permissions will be deleted forever from the system and cannot be restored.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.return_success	Unit returned successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.search_count	{current} / {total}	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.administration.z3950.server.active	This configuration is showing whether local server z39.50 will be active. In case of multiple libraries, the name of the Server z39.50 Collection will be identical to the name of each library. For example, the name of the collection for this installation is "{0}".	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.printer_type.printer_80_columns	80-column printer	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.invalid	The value specified for one of the configurations is invalid	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.search_z3950	Distributed	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.400	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.user.name_or_id	Name or User Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.start_less_than_or_equals_end	Initial number must be less or equal to end number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.success.update	User successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.user.field	Field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.title	Safety Copy (Backup)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.error.invalid_marc	Error reading Record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.confirm_cancel_editing_title	Cancel editing of vocabulary record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.no_fines	This user has no fines	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.410	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.button.generate_report	Generate Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.subfield.c	Venue for the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.subfield.b	Subordinated units	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.accession_number	Asset Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.confirm_cancel_editing.1	Do you wish to cancel editing this unit record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.return.success	Card successfully returned	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.title	Records Importation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.in_this_library	In this library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.subfield.n	Number of the part of the section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.2.0	Not numbered	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.usertype.confirm_delete_record_question.forever	Do you really wish to delete this User Type?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.success.delete	User deleted forever	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	label.logout	Logout	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.quotation	Quotation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.success	Backup restoration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.requisition_select	Select a Requisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.holdings	Asset Cataloging Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	warning.create_backup	You have not created a backup copy in more than 3 days	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.new_schema.field.schema	Library shortcut	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.user.remove_item_button	Remove	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.subfield.a	Name of entity or place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_status	Status	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.580	Linkage Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.subfield.a	Additional title - analytical title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.1.1	Generate note and secondary title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.1.0	Generate note, do not generate secondary title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.usertype.confirm_delete_record_title.forever	Delete User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_quotation_delete	Delete quotation record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.switch_to	Switch to	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.1.3	Do not generate note, generate secondary title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.1.2	Do not generate note nor secondary title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.psql_not_found	PSQL not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.common.digital_files	Digital Files	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.subfield.n	Number of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.dewey	Dewey Classification Statistic	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.subfield.p	Name of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_delete_record.trash	It will be moved to the trash database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.topographic	Topographic Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_status.pending_issues	Pending issues	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.page_help	<p>The module <strong>"Label Printing "</strong> allows creating internal and spine (back) identifications for the book in the case of library copies.</p>\n<p>Labels for one or more titles can be created in a single printing, using the search below. Please remember the details, as the result of this search is a list of copies (units) and not of bibliographic records.</p>\n<p> After finding the copy(ies) you are interested in, use the button <strong>"Select copy (or unit) "</strong> to add it to the list of labels to be printed. You may carry out several searches, without losing the previous selection. When you are finally satisfied with the selection, press the button <strong>"Print labels "</strong>. You may choose which model of the labels page you will use and the initial position.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.024.indicator.1.2	International Standard Music Number (ISMN)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.024.indicator.1.0	International Standard Recording Code (ISRC)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.accession_number	Asset reference number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.user_has_no_card	No card is associated to this user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.date_to	to	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.deleted	Deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.in_these_libraries	In these libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configuration.title.general.title	Name of this Group of Libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging_import	Record Importation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.590	Local notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.yes	Yes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.595	Notes for inclusion in bibliographies	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.download.title	Download language file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.button.import_this_record	Import this record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.status.in_use_and_blocked	In use and blocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.backup_file_not_found	Backup file not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.lendings_late	Total number of late books	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_delete_record_question	Do you really wish to delete this supplier record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.select_item	Select	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.450.subfield.a	Topical term not used	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.error.save	Failure fixing User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2	Geo-spatial reference dimensions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.580.subfield.a	Linkage note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.1	Geo-spatial reference dimensions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_returned_lendings	Returns Record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.new_schema.description	To create a new library, please fill in below your name and an optional subtitle. You will also need a short name for the library, which is called shortcut, to be used in the web address for accessing Biblivre 4, which allows differentiation among different libraries installed in the system. This shortcut must contain only letters, numbers and the character _. To make things easier, Biblivre 4 will automatically suggest a shortcut, based on the library name.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_z3950_search	List z3950 Servers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.password.success	Password successfully modified	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	label.password	Password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.button.select_item	Select user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_delete_record.forever	It will be deleted from the system forever and cannot be restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.select_marc_field	Select a Marc field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.button	Restore selected backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.simple_search	Simplified Bibliographic Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore	Restore a Biblivre 4 Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.holding_id	Record No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.form.repeat	Repeat	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_cancel_editing_title	Cancel edition of bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.subfield.a	Topical term adopted by Thesaurus	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.error.no_records_found	No records found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.returns	Returns	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.today	Today	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.lendings	Report on Loans during Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_360	Associated term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.form_invalid_values	Errors were found in the filling in of the form below	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.user	Report by User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	field.error.max_length	This field must have {0} characters maximum	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555	Note of Cumulative or Remissive Index	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.isbn	ISBN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.status.blocked	Blocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.inactive_users_only	List solely inactive users	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reinstall.button	Go to the reinstall and reconfiguration screen	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.page_help	<p>The Configurations routine allows configurations in several parameters used by Biblivre, for example Library Title, Default Language or Currency to be used. Each configuration has an explanatory text in order to facilitate usage.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.lendings_by_date	Report on Loans by Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.last_backup	Last Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.log_header	[Import data log from Biblivre 3 to Biblivre 4]	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.edit	Edit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.550	BT (broader term)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.dont_restore	Do not restore this library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_243	Collective Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.delete	Delete	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.2.2	Alternate numbering	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.360	Remissive VT (see also) and AT (related or associated term)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	warning.change_password	You have not changed the standard administrator password yet	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.total	Total	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_240	Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.2.1	Primary numbering	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.525	Supplementary Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.print_return_receipt	Print return receipt	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.success	Import of Biblivre 3 data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.popup.description	Select in which label you wish to start printing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.error.delete	Error when deleting Requisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.521	Target public notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_accesscards_list	List access cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.024.indicator.1	Number type or standardized code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_245	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.520	Summary notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.250.subfield.b	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.error.type_has_users	This User Type has Users registered	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.250.subfield.a	Indication on the edition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.error.delete	Error when deleting User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.indicator.2._	Key abbreviated Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.add_multiple_cards	Register Card Sequence	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.page_help	<p>The bibliographic search allows retrieving information on the records of this library, listing the volumes, catalographic fields and digital files.</p>\n<p>The simplest way is using the <strong>Simple search </strong>, that will search each one of the terms typed in the following fields: <em>{0}</em>.</p>\n<p>Terms are sought in its full form, however it is possible to use the asterisk (*) to look for incomplete terms, so that the serarch in <em>'brasil*'</em> may find, for example, records containing <em>'brasil'</em>, <em>'brasilia'</em> and in <em>'brasileiro'</em>. Double quotation marks can be used to find terms in sequence, so that search  <em>"my love"</em> may find records containing the two terms together, but shall not find records such as  in the text <em>'my first love'</em>.</p>\n<p>The <strong>advanced search</strong> provides a higher control on the records traced, allowing, for example, searches by cataloging date or exactly in the desired field.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.error.invalid_photo_extension	The extension of the filed selected is not valid for the photo of the user. Use fields such as.png, .jpg, .jpeg or .gif	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.indicator.1._	no information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.private_full	Private Base	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.534	Fac-simile notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.creation_date	Date of Inclusion	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.530	Notes on availability of physical form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reinstall.description	Use this option if you wish to restore a Biblivre 4 backup, or to delete data in your library or to redo Biblivre 3 migration. You will be taken to the Biblivre install initial screen, and you may cancel the operation if you do not wish to make modifications.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750	Topical term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.2._	No information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.vocabulary.page_help	<p> Vocabulary searches can retrieve information on the terms in the coolection of this library, if and when they are cataloged.</p>\n<p>Search will look for each one of the terms typed in the following fields: <em>{0}</em>.</p>\n<p> Terms are sought in its full form, however it is possible to use the asterisk (*) to look for incomplete terms, so that the search in <em>'brasil*'</em> may find records containing, for example, <em>'brasil'</em>, <em>'brasilia'</em> and in <em>'brasileiro'</em>. Double quotation marks can be used to find terms in sequence, so that search  <em>"my love"</em> may find records containing the two terms together, but shall not find records such as  in the text <em>'my first love'</em>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.show_all	Show all the {0} backups	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.response_date	Quotation arrival date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.bibliography	Bibliography Report by Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.author_title	Title and other terms associated to name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_260	Printer	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.simple_search	Simple Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_bibliographic_delete	Delete bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permission.success.delete	Login successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.500	Notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.502	Notes of dissertation or thesis	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.504	Bibliography Notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.505	Content notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.indicator.1.1	non confidential	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.indicator.1.0	confidential	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.buttons.apply_fine	Fine	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lendings.holding_list_lendings	List only copies lent	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_password	Change Password	2014-07-26 10:56:18.338867	1	2014-07-26 13:42:51.201768	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_250	Edition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.restore_complete_backup.description	Should you wish to restore all the contente in this backup, use the button below. Beware! This will replace ALL the content of your Biblivre, also replacing all the existing libraries for those in the backup. Use this option only if you wish to go back in time, until backup date.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.datafield	MARC field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_255	Scale	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_256	File characteristics	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.error.description	Regretably there was an error when importing Biblivre 3 data. Please check the next screen by the error log and, if necessary, go to the Biblivre forum for assistance.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_257	Production place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.success.update	Quotation successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_258	Information on the material	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.location	Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.photo	Photograph	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.empty_login	The field login cannot be empty	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.515	Numeration Peculiarity Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.selected_records_plural	{0} records selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.clear_search	Clear search terms	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.biblio	Bibliographic	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.backup_not_complete	Backup not complete	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.error.no_supplier_found	It was not possible to find a supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_cancel_editing_title	Cancel quotation record editing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.success.disable	Success in marking user as inactive	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	digitalmedia.error.file_not_found	The specified file was not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.error.delete	Error when deleting quotation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	warning.fix_now	Solve this problem	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.availability.available	Available	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_delete_record_title	Delete bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.holding.availability	Availability	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.status.available	Available	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.address_city	City	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.empty_new_password	The field "new password" cannot be empty	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.return_date	Return date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.subfield.c	Indication on responsibility for the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.subfield.a	Main Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_vocabulary_move	Move Vocabulary record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.subfield.b	Parallel Titles /subtitles	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.confirm_title	Restore Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.popup.description	Select in which label you wish to start printing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.button.delete	Delete	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.subfield.p	Name of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.email	Email	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.country	Country	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.subfield.n	Number of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.indicator.1.0	Inverted name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.multi_schema_configurations	Configurations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.indicator.1.1	Name of jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.subfield.h	Means	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.indicator.1.2	Name in the direct order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_bibliographic_move	Move bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.type.biblio	Bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.cancel	Card will be canceled and will not be available for use	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_status.blocked	Blocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.order	Sort by	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.file_not_found	File not found.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.source_search_title	Import records from a Z39.50 search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.expiration_date	Reservation expiration date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.state	State	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.subtitle	Library subtitle	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.upload_popup.uploading	Sending file...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.error.save	Supplier saving error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.670.subfield.a	Note on origin of the term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.upload_popup.title	Opening File	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.main_full	Main Base	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.page_help	<p>Order routine allows order registration and research (purchases) with registered suppliers. To register a new order, a previously registered Supplier and a Quotation must be chosen, in addition to providing information such as Validation Date and Invoice information.</p>\n<p> Each search will look for each of the terms entered in the fields<em>Number of Order Registration, Fancy Name of Supplier and Author or Title of Request</em>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.subfield.3	Specified materials	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.multi_schema	Set up Multi-libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.couldnt_restore_backup	The selected backup could not be restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_configurations	Manage configurations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.holdings_available	Available	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.group.custom	Customized Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_request_save	Save requests record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.return.error	Card return error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.fine.failure_pay_fine	Fine payment failure	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.2.2	analytical entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.circulation_access	Access Control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.login_change_password	Change password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210	Abbreviated Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.multi_schema_manage	Libraries Management	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.select_file	Select a backup file first	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.856.subfield.y	Text link	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	field.error.date	The Value filled in is not a valid date. Use the format {0}	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.856.subfield.u	URI	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.lend.error	Binding Card Error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.login	Login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.856.subfield.d	Path	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.upload_popup.processing	Processing...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.no_data	No data available for creating this report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.subfield.a	Cumulative and remissive index note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.new_schema.field.title	Library name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.subfield.b	Source available	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_status.active	Active	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.success.update	Z39.50 Server successfully updated	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.856.subfield.f	File name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.subfield.c	Degree of control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.subfield.d	Bibliographical reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.reserved.warning	All the copies (units) available of this record are reserved for other readers. Loans can be made, however, please see the reservation information.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.321.subfield.b	Dates of previous periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.phone_cel	Mobile phone No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.321.subfield.a	Previous periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.type.authorities	Authorities	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.subfield.u	Resource uniform identifier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.new_schema.button.create	Create Library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.searches	Report on Total Searches during Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.open_item_button	Open record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_configurations	Configurations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041.indicator.1.0	Item is not and does not include translation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.tabs.reservations	Reservations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.cancel	Cancel	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	field.error.min_length	This field must have {0} characters minimum	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041.indicator.1.1	Item is or incluldes translation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.isbn	ISBN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging_labels	Label Printing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.publication_year	Year of publication	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_save	Save user record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.info	Remarks	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.no_attachments	This record does not have digital files	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.error.save	Error when saving Requisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.505.subfield.a	Content notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.confirm_delete_record_title	Delete unit record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.print_lending_receipt	Print lending receipt	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.quotation_date	Quotation requisition date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.lending.error.holding_is_lent	The item selected is already on loan	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.lendings_top	Top lending books	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.address_number	Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.id	Registration order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.250	Edition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.255	Cartographical Mathematical Datum	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.256	Characteristics of computer file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.2.0	Library of Congress Subject Heading	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.obs	Remarks	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.help	Help	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.258	Information about philatelic material	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.257	Country of producing entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.articles	Article	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.restore_partial_backup.title	Restore libraries in accordance with the criteria above	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.user_not_found	User not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.150.subfield.y	Chronological subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.150.subfield.x	General subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750.indicator.2.4	Source not specified	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.title.unit_value	Unit Value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.lending.error.holding_unavailable	The item selected is not available for loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.150.subfield.z	Geographical subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.indexing_groups.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.button_full	Create complete  backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.accession_number.full	Full Report of Asset Cataloging Reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.start_number	Start number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240	Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243	Agreed Title for Filing Purposes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245	Title principal	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.database_work	Work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246	Variant Form of Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_lendings	Active loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.page_help	<p>Quotation routine allows quotation registration search conducted with registered suppliers. To register a new Quotation, you must select a Supplier and a previously registered Acquisition; data such as value and quantity of works quoted are should also be included.</p>\n<p>Search will look for every single term inserted in fields <em>Quotation Registration Number or Supplier Fancy Name </em>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.bind_card	Associate (bind) Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.search.distributed_search_limit	This configuration represents the maximum number of results to be found on a research already distributed.  The use of a very high limit should be avoided, because searches distributed would take a long time in providing the results of the search.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_delete_record_question.forever	Do you really wish to delete this supplier record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.success.update	Card successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.856.subfield.u	URI	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	text.multi_schema.select_library	List of Libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.856.subfield.y	Link in text	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.printer_type.printer_40_columns	40-column printer	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.no_backups_found	No backups found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.856.subfield.d	Path	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_delete	Delete user record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.515.subfield.a	Numeration Peculiarity Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.856.subfield.f	File name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.name	User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.949	Asset cataloging reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.947	Information on the Collection	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.611.indicator.1	Form of entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	text.main.logged_in	<p>Hello {0},</p>\n<p>Welcome to the <strong>Free Library (Biblivre) version 4.0</strong>.</p>\n<p>You may conduct searches by Bibliographic Records, Authorities and Vocabulary through the option <em>"Search"</em> in the upper menu. This is the same <em>"Search"</em> that readers may use when accessing <strong>Biblivre</strong>, without the need of username and password when searching for records in the Main Base.</p>\n<p>In order to register readers, make loans, returns and reservations, and also to control access to the library and print user cards, please use the option <em>"Circulation"</em>, also in the upper menu.</p>\n<p>In the option <em>"Cataloging"</em>, you will be able to control the collections of the library, and to catalog Works and copies, and also carry out controls on Authorities and Vocabulary. Also through this option you can print labels used in copies or units, and move records among databases (Main, Work, Private and Recycle Bin), import and export records and add digital files to the existing records.</p>\n<p> <strong>Biblivre</strong> also has a control system for the acquisition process, in order to assist in the purchase and reception of publication, through the option <em>"Acquisition"</em>.</p>\n<p>In <em>"Administration"</em>, you will be able to change access passwords, configure <strong>Biblivre</strong> resources, such as forms fields, translations and user types, register access cards, create reports and conduct maintenance services in the database, which include the generation of backups and the reindexing of the database, which must be used when some records cannot be found in the searches.</p>\n<p>Should you need additional information on  <strong>Biblivre</strong>, please go to the option <em>"Help"</em> and read the Manual of the program or the FAQs, in <a href="http://biblivre.org.br/forum" target="_blank">Forum</a>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.groups.circulation	Circulation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.150.subfield.a	Topical term adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.move_records	Move Records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.holding.accession_number	Asset cataloging reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.page_help	Welcome! This screen is the last one before starting to use Biblivre IV and through it you will be able to choose whether to restore the information from another Biblivre installation (by means of a backup or through a migration of Biblivre 3) or if you wish to start a new library. Please read each option below carefully and select the most appropriate one.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.150.subfield.i	Qualifier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.payment_date	Payment date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.status	Situation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.error.no_valid_terms	The specified search does not contain valid terms	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_print_user_cards	Print user cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.users_with_late_lendings	List only users with pending lendings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.delivered_quantity	Quantity received	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.holdings_full	Full Report on Asset Cataloging	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.2	Type of secondary entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.page_help	<p>In order to conduct a loan you will have to select the reader who will take the volume and select the unit or copy to be lent. Search by reader can be made by name, user number or any other field previously registered. In order to find the copy, use your Asset Cataloging Reference.</p><p>Returns can be made through the selected reader or directly by the Asset Cataloging Reference of the copy (unit) which is being returned or renewed..</p><p>the deadline for returning the unit is calculated according to User Type, as configured by the menu <strong>Administration</strong> and defined during the reader registration process.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.fine_value	Value of fine in case of late returns	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.distributed_search	Distributed search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging_authorities	Authorities	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import	Import Biblivre 3 Data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_quotation_list	List quotations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.disable	Disable library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.welcome	Welcome to Biblivre IV	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.paper_description	{paper_size} {count} labels ({height} mm x {width} mm)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.order	Order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.selected_records_plural	{0} Values Added	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.670.subfield.b	Information found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.670.subfield.a	Name taken from	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.2	Type of secondary entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.1	Form of entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.short_type	Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.availability.unavailable	Unavailable	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.group.circulation	Circulation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.title.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.delivery_time	Delivery time (Promised on)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.currency	This configuration represents the currency to be used in the case of fines and on the acquisition module.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.restore_complete_backup.title	Restore all the Backup information, replacing all the libraries in this Biblivre	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.database_main	Main	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.success.move	Records successfully moved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.acquisition_quotation	Quotations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.availability	Availability	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.delete_success	Reservation deleted successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.029.subfield.a	ISNM number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.created_between	Cataloged between	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_delete_record_title.forever	Delete quotation record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260	Publication, edition, etc.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_delete_record_question.forever	Do you really wish to delete this Order record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.fieldset.title.values	Values	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_delete_record.forever	It will be permanently deleted from the system and cannot be retrieved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.913	Local code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.simple_term_title	Fill in the search terms	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.title	Database reindexing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.lending.error.blocked_user	The selected reader is blocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.records_found_singular	{0} record found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.2._	no information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.error.delete	Error when deleting supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.type.do_not_import	Do not import	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_505	Content notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.error.delete.user_has_accesscard	This user has an access card in use. Return the card before deleting this user.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.created_by	Person in charge	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_130	Anonymous work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	language_name	English (United States)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_534	Facsimile notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.360.subfield.z	Geographical subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.360.subfield.y	Chronological subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_delete_record_title	Delete Order record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.360.subfield.x	General subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.upload_popup.uploading	Sending file...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.reservations	Reservations Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.progress_popup.title	Biblivre 4 maintenance	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.reservation_date	Reservation Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.term.up	Term Use for (UF)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_520	Summary notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.411.subfield.a	Name of event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_521	Target public notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.title.quantity	Quantity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.multi_schema	Multi-libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_110	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.tabs.form	Registry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_111	Author Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.indicator.1.1	Single or compound Surname	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.indicator.1.2	Compound surname (obsolete)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.indicator.1.3	Family name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configurations.page_help	The routine for Multi-libraries Configuration allows modification of global configurations of the library group and standard configurations to be used by the registered libraries. All the configurations marked with asterisk (*) will be used as standards in new libraries registered in this group, but they can be modified internally by administrators, through the option <em>"Administration"</em>, <em>"Configurations"</em>, in the upper menu.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.clear	Clear	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.indicator.1.0	Single or compound name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.selected_records_singular	{0} Value Added	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.term.tg	Broader Term (BT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.term.te	Narrower Term (NT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.preview	Pre-visualization	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.confirm_delete_record_title	Exclude vocabulary record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.490	Serial Indication	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.term.ta	Associated Term (AT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.search	Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.modified	Updated on	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.521.subfield.a	Target public notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.phone_home	Home Telephone No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.unclassified	<Unclassified>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_translations	Manage translations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.501.subfield.a	Notes starting with the term "with"	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260.subfield.b	Name of Publisher, Publishing company, etc..	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260.subfield.c	Date of publication, distribution, etc.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.user.search	Insert name or User number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260.subfield.e	Name of printing company	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.error.invalid_search_parameters	Parameters in this search are not correct	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.author_type.select_author_type	Select author type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.search.results_per_page	Results per page	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260.subfield.a	Place of publication, distribution, etc.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.biblivre_is_locked_please_wait	This Biblivre is under maintenance. Please try again in a few minutes.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_500	Notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_delete_record.trash	Records will be sent to the trash database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260.subfield.f	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_502	Thesis note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.260.subfield.g	Date of print	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_504	Bibliography notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_506	Restricted access notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_lending_list	List loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.520.subfield.a	Summary notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.record_reserved_to_the_following_readers	This record is reserved to the following readers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.new_password	New password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.subfield.b	Subordinated units	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.subfield.c	Venue of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.subject	Subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.save.success	Configurations modified successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	z3950.adresses.list.no_address_found	Z39.50 Server found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.password_not_matching	The fields  "new password " and "repeat new password" have to be identical	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	marc.bibliographic.datafield.110.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.search_limit	The search conducted found {0} records, but only the {1} ones will be shown	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.subfield.n	Number of the part - section of the work - order of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.error.generate	Error when generating report. Check form information.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.renew	Renew	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.error.save	Error saving Record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_100	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.user.open_item_button	Open record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.success.unblock	User successfully unblocked	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.vocabulary.simple_search	Vocabulary search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.subfield.a	Name of entity or of place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.unblock	Error when unblocking Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_order_delete	Delete order records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.ok	Ok	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_cancel_editing.1	Do you wish to cancel editing this requisition record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.button	Restore selected backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.indexing_groups.total	Total	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_670	Name withdrawn from	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.confirm_cancel_editing_title	Cancel edition of Z39.50 Server	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.field_count	Field Count	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.362.indicator.1.1	Non-formatted note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.error.invalid_file	Invalid File	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.362.indicator.1.0	Formatted style	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.no	No	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.search_button	Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.confirm_cancel_editing.1	Do you wish to cancel editing the Z39.50 Server?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.success	Backup restoration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_access_control_bind	Manage access control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_cancel_editing.1	Do you wish to delete editing this supplier record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_print_labels	Print labels	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.080.subfield.2	Number of edition of the CDU	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.indicator.1.0	simple or compound name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_cancel_editing.2	All the alterations will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.indicator.1.3	family name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.popup.title	Label format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.indicator.1.1	simple or compound surname	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.log_header	[Log for Biblivre 4 backup restoration]	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.indicator.1.2	compound surname (obsolete)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.button_authorities	Reindex authorities base	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.authorities.simple_search	Authorities Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.520.subfield.u	URI	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.user_current_lending_list	Copies on loan to this reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.subfield.b	Qualifier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.map	Map	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.subfield.a	Abbreviated Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.255.subfield.a	Scale	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging_label	Labels	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_680	Scope Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_700	Secondary Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_685	Background or Glossary Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.clean_install	New Library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_order_list	List orders	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.access_control	Access cards and access Control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.query_placeholder	Fill in the terms for the search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.any	Any	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.confirm_title	Restore Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.description	Description	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.lend.success	Card successfully bound	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.title.unblock	Unblock Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.inactive	Mark as inactive	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.2	Type of secondary entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.error.description	Failure creating a new library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.topographic	Topographic Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.title.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	text.main.logged_out	<p>The program <strong>Free Library (Biblivre) version 4.0</strong> is an application promoting the digital inclusion of the citizen in the information society. Know more about the project in <em>"About"</em>, in the option <em>"Help"</em> in the upper menu.</p>\n<p>It is a program involving cataloging and the dissemination of collections from public and private libraries, of varied sizes, in addition to promoting the circulation and sharing of information content, such as texts, music, images and films or any other kind of digital object.</p>\n<p>Today <strong>Biblivre</strong> is successful throughout Brazil as well as abroad and, in view of its high cultural importance, it is consolidating as the preferential application for the digital inclusion of citizens.</p>\n<p>If you wish to search the catalogue and have access to the digital works available, please use the option <em>"Search"</em> in the upper menu. No username or password is required.</p>\n<p>For other services, such as circulation, cataloging, acquisition and administration, you will need a <strong>username</strong> and <strong>password</strong>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload_popup.processing	Processing...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.indexing_groups.up_term	Term of Use for (UF)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.2.4	Source not specified	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.select_item_button	Select record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.block	Block	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.button_vocabulary	Reindex vocabulary base	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.error	Import data error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.400	Other name form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_accesscards_delete	Delete access cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.download.field.languages	Language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.block	Error when blocking Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.subfield.d	Dates associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_670	Origin of information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.subfield.c	Title and other terms associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.410	Other name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.tabs.fines	Fines	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.subfield.q	Form of complete name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.expected_date	Expected date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.success.delete	Card successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.unavailable	Unavailable	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.630.indicator.1	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.private	Private	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	digitalmedia.error.file_could_not_be_saved	The file sent could not be saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_id	User id	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.411	Other name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.2.0	Library of Congress Subject Headings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.subfield.a	Surname and/or name of author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.subfield.b	Numeration following name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_590	Local notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.field.upload_file	Select backup file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.daily_fine	Daily fine	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.indicator.1.0	Simple or compound name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.indicator.1.1	Simple or compound surname	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.indicator.1.2	Composed surname (obsolete)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.indicator.1.3	Family name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.advanced_search	Advanced Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.title	This configuration represents the name of the library, to be shown on the upper part of the Biblivre pages and in the reports.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.label_full	Complete Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.search.result_limit	Result limit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.error	Backup restoration error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.gender	Gender	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.empty_lending_list	This reader does not have units (copies) lent	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.acquisition_supplier	Suppliers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.card_not_found	Card not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.usertype.confirm_cancel_editing_title	Cancel editing of User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.confirm_cancel_editing_title	Cancel addition of Access Cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.no_servers	A Z39.50 search is not possible as there are no remote libraries registered. In order to solve this problem, please registers Z39.50 servers of the libraries of interest in the option <em>" Z39.50 Servers"</em> within <em>"Administration"</em> in the upper Menu. For this a name of <strong>user</strong> and<strong>password</strong> is needed.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.editor	Publisher	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.source_file_title	Import records from a file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.year	Year	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.groups.digitalmedia	Digital Media	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.reservation_limit	Simultaneous reservations limit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.description	Use this option should you wish to restore an existing Biblivre 4 backup. Should Biblivre find backups saved in your documents, you will be able to restore them directly from the list below. Otherwise, you will have to send a backup file (extension <strong>.b4bz</strong>) by means of the form.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.failure.unblock	Failure unblocking User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.expiration_date	Quotation expiration date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.submit_button	Change password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.field.upload_file	Select backup file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.work	Work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.reader	Reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.1	Generates secondary entry in sheet	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.failure.block	Failure blocking User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.450	Use For	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.subfield.b	Time period formatted from 9999 b.C onwards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.subfield.a	Code of time period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	digitalmedia.error.no_file_uploaded	No file sent	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045.subfield.c	Time period formatted before 9999 b.C	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.indicator.2.0	Another abbreviated Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.days_late	Days behind schedule	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.error.order_not_found	It was not possible to find the order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.error.toggle	Error changing library status.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.holding_lent_to_the_following_reader	This copy was lent to the reader below	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_555	Notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.650.subfield.a	Topical Subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.sort_by	Sort by	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.accesscards.unbind_card	Return Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permission.error.create_login	Error when creating User login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.indicator.1.0	Do not generate secondary Title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.field.collection	Collection	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.delete	Delete	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.migrate.error	Error when importing data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_status.pending_issues	Has pending issues	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.indicator.1.1	Generate secondary Title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title	Reports	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.wait	Subject to the size of the database, this operation may take longer. Biblivre will not be available during this process as it may last up to 15 minutes.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.deadline_date	Valid until	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_651	Subject geography	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852	Information on location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_650	Subject topic	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.database.work	Work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration	Administration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.856	Work tracking by electronic means	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.login_already_exists	This login already exists. Choose another name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.success.description	Backup successfully restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.requester	Requester	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	format.datetime	dd/MM/yyyy HH:mm	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configurations.error.disable_multi_schema_schema_count	It is not possible to disable the multi=libraries scheme when more than one library is enabled.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.new_holding	New unit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.publisher	Publisher	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.no_card_found	No card found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.650.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.650.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.650.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.access_denied	Access denied. Invalid user or password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.success	Reindexing concluded successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.534.subfield.a	Fac-simile note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.p	Name of the part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.success.block	User blocked successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_lending_lend	Conduct work loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.n	Number of the part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.confirm_delete_record_question.forever	Do you really wish to delete the User Login?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.411	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.error.select_reader_first	To lend a copy you need, in the first place, to select a reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.indexing_groups.all	Any field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.button.print_labels	Print labels	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.f	Date of edition of item that is being processed	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.year	Year	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.d	Date that appears close to the uniform entry title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.subfield.a	Uniform title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_630	Subject Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_indexing	Manage database indexing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.685.subfield.i	Explanatory text	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.confirm_delete_record.forever	It will be deleted forever from system and cannot be restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.save_as_new	Save as new	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.reserve_success	Reservation successfully made	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.page_help	<p> the Z39.50 server routine allows registration and search in Servers used  by the Distributed Search routine. To register the data of the Z39.50 collection are needed, as well as the URL address and access port.</p>\n<p>When accessing this routine, Biblivre will automatically list all the Servers previously registered. You may then filter the list, inserting the <em>Name</em> of a Server you may wish to find.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload.description	Select below the language file you wish to send for processing by Biblivre 4.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tabs.form	Form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.value_must_be_boolean	Value in this field must be true or false	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.indicator.1.2	name in the direct order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.title	Password change	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.invalid_password	The field "current password" does not match with your password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_delete_record_question	Do you really wish to delete this authority record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.indicator.1.0	inverted name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.110.indicator.1.1	name of jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.490.indicator.1.0	Unsplit title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.3	Material specifications	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.490.indicator.1.1	Split title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.590.subfield.a	Local notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_request_list	List requests	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.invalid_pg_dump_path	Invalid path. Biblivre will not be able to create backups because the <strong>pg_dump</strong> file was not found.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.holdings.title	Search Copy (Unit)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.accession_number	Asset Cataloging Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.confirm_title	Import Biblivre 3 data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.cataloging.accession_number_prefix	Asset cataloging is the field that solely identifies a copy. In Biblivre, the rule for asset reference numbers depends on the year of acquisition of the unit, on the quantity of units entered in the year and on the prefix of the asset reference number. This prefix is the term to be included before the year number, in the format <prefix>.<year>.<counter> (Ex: Bib.2014.7).	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_delete_record.forever	It will be deleted from system forever and cannot be recovered	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.indicator.1.1	name of jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.indicator.1.2	name in direct order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.indicator.1.0	Inverted name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.previous	Previous	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.restore_with_new_schema_name	Restore this library using a new address	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_usertype_list	List user types	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.button.select_page	Select users in this page	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_user_types	User Types	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_610	Subject collective entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_611	Subject event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select_report	Select a Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.680	Scope note (SC)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.business_days	This configuration represents the working days at the library and shall be used by the loan and reservation modules. The main use of this configuration is to avoid scheduling the return of the copy on a date in which the library is closed.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.wait	Wait	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.users	Users	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.685	Historical or glossary note (GLOSS)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.circulation	Circulation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.user_deleted	User deleted from system	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.cataloging_bibliographic	Bibliographic	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.cataloging	Bibliographic Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.supplier_number	Taxpayer No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.670	Note on the origin of term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.error.invalid_record_type	Blank or unknown record type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.existing_card	Card already exists	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.authorities.page_help	<p>The search by Authorities allows retrieving information on the authors in the content of this library, if and when are cataloged </p>\n<p>The search will look for one of the terms inserted in the following fields: <em>{0}</em>.</p>\n<p>Terms are searched in its full format, however it is possible to use the asterisk (*) to look for incomplete terms, so that the search <em>'brasil*'</em> may find records containing, for example <em>'brasil'</em>, <em>'brasilia'</em> and <em>brasileiro</em>. Double quotation marks can be used to find two terms in sequence, so that the search <em>"my love"</em> may find records containing the two terms together, but it will not find records such as  in the text <em>'my first love'</em>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.add_field	Add term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_750	Topic Term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.goodbye	Goodbye	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.error.no_user_type_found	No User Type found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.button.select_page	Select items in this page	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.lending_time_limit	Loan term limit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.tabs.lendings	Loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tabs.marc	MARC	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_600	Subject person	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.groups.login	Login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.subtitle	This configuration represents a subtitle for the library, to be shown on the upper part of the Biblivre pages, just below the <strong>Name of Library </strong>. This is an optional configuration.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.360.subfield.y	Chronological subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.360.subfield.x	General subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.360.subfield.z	Geographical subdivision adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.selected_records_singular	{0} Value Added	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.e	Name of event subunits	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.a	Name of event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.c	Venue of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.selected_records_singular	{0} user selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.n	Name of order of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.user	Search by User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.subfield.t	Title of the work close to entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.490.subfield.a	Title of series	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.490.subfield.v	Number of volume or sequence designation of the series	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.080.subfield.a	Classification Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830.indicator.2	Number of characters to be overridden in alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.value_is_required	Filling in this field is required	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.360.subfield.a	Topical term adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.area	Neighborhood	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.success.create	New library successfully created.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.success.save	Request successfully included	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.group.cataloging	Cataloging	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.select_restore.description	Use this option if you wish to restore an existing Biblivre 4 backup. When the Biblivre find backups saved among your documents, you will be able to restore the, directly from the list below. Otherwise, you will have to send a backup file (extension <strong>.b4bz</strong>) through the form.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_list_by_type	List of Users by Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reinstall.confirm.title	Go to the restoration and reconfiguration screen	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.button.import_all	Import all the pages	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.registered_between	Registered between	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.lendings_count	Total number of Books lent in the period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.reservation	Reservations Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.end_date	Final Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.indicator.1.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.p	Number of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.clean_install.button	Start as a new library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.411.subfield.a	Name of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.repeat_password	Repeat password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_delete_record_title.forever	Delete Order record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.help	Help	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.error.you_cannot_delete_yourself	You cannot delete yourself or mark you as inactive	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.button.list_all	List All	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.1.0	Does not generate entry for title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.prefix	Prefix	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.1.1	Generates entry for title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.custom_count	Bibliographic Record Count by Marc Field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.invalid_handler	It was not possible to find a handler for this action	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.containing_text	Containing the text	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.material_type	Material type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.button.migrate	Import data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.expected_return_date	Expected return date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041.indicator.1	Indication of translation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_vocabulary_delete	Delete vocabulary record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.work_full	Work database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tabs.holdings	Copies (Units)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.paper_description	{paper_size} {count} labels ({height} mm x {width} mm)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.search_bibliographic	Bibliographic	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.b	Date that appears close to the uniform entry title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.a	Uniform title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.success.delete	Request successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.page_help	<p>Supplier routine allows supplier registration and search. Searches will search for each one of the terms inserted in the fields <em>Fancy Name, Company Name or Taxpayer No. </em>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.f	Work date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.530.subfield.a	Notes on physical form availability	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_maintenance	Maintenance	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.requester	Requester	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.multi_schema.enabled	The multi-library system is already active for this Biblivre 4 installation. The system administrator can deactivate this option in the multi-library configuration menu.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.n	Number of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.no_lendings	This user has no lendings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.title.author	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.id	Record Id	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.a	Name of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_cancel_editing_title	Cancel editing of authority record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_699	Subject local	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.access_control.card_available	This card is available	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.400.subfield.a	Surname and/or Name of Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	label.login	Login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.title	Permissions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.button.import_this_page	Import records from this page	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.invalid_writable_path	Invalid path. This directory does not exist or Biblivre is not authorized to write.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.d	Date of acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.e	Number given to cquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.b	Address	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.c	Form of acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.a	Name of source	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.description.4	Problems with the search, registered records are not found.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.f	Owner	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.h	Purchase price	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.o	Type of unit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.description.2	Modification in the configuration of searchable fields;	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.subfield.n	Quantity of items purchased	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.uncancel	Card will be recovered and will be available for use	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.description.3	Import of old Biblivre records; and	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.830	Secondary entry - Series - Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.1.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.error.invalid_database	Invalid database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.created	Registered in	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.description.1	Database reindexing is a process thorugh which Biblivre analyzes each record registered, and creates indexes in certain field in order to make searches possible. This is a lengthy process that has to be executed only in the specific cases below:<br/>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.306.subfield.a	Duration time	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.active_lendings	Active lendings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.button.remove_login	Remove Login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.a	Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.button.select_reader	Select reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.b	Sub-location or collection	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.c	Location on rack	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.save	Impossible to save configurations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.e	Mail address	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.label.example	ex.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.button.reserve	Reserve	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.500.subfield.a	General notes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.quantity	Quantity of copies	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_z3950_servers	Z39.50 Servers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.title.quantity	Quantity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.same_password	The new password must be different from the current password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.usertype.confirm_cancel_editing.1	Do you wish to cancel editing this User Type?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.usertype.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.field.code	Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.success.save	User Type successfully included	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.suffix	Suffix	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.400.subfield.a	Surname and/or name of author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.360.subfield.a	Topical term adopted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.late_lendings	Late Loans Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.z	Public note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.856	Tracking of works through electronic means	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.2.2	analytical entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.indexing_groups.other_name	Other name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.currency	Currency	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.q	Condição física da parte	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.x	Internal note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.delivered	Order received	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.u	URI	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.group.acquisition	Acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.supplier_select	Select a Supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.multi_schema_translations	Translations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.j	Control number in rack	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.select_page	Select records from this page	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.on_the_field	In the field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.subfield.n	Country code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.e	Name of subunits of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.c	Venue for the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.material_type	Type of material	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.fieldset.contact	Contacts/Phone numbers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.n	Number of order of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.selected_records_plural	{0} units (copies/items) selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_400	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.common.button.upload	Send	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.362	Information on Publication and/or Volume Dates	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.360	Remissive SA (see also) and AT (related or associated term)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.supplier_select	Select a Supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.shelf_location	Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.indicator.2._	no information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.dump	It was not possible to generate translation file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.couldnt_unzip_backup	Backup selected could not be unzipped	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_delete_record_title	Delete requisition record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.confirm_delete_record_question	Do you really wish to delete this Order record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_reports	Create Reports	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.classification	Classification (CDD)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.url	URL	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.error.no_record_found	No valid Record was found in the file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.enable	Enable library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.record_count	Records in this base: <strong>{0}</strong>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.holdings.title	Search Bibliographic record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_delete_record_title	Delete authority record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_delete_record_question	Do you really wish to exclude this bibliographic record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	format.date_user_friendly	DD/MM/YYYY	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.select_restore.library_list_inside_backup	Libraries in this backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.holdings_creation_by_date	Reporto n Total Work Inclusions by Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.birthday	Date of Birth	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.complement	Complement	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.750	Topical term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_type	User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.fine_popup.description	This is a 'behind schedule' (late) return and is subject to a fine. Please check below the information presented and confirm if the fine will be added to the user records in order to be paid in the future (Fine), if it was paid together with the return (Pay) or if it will be exempted (Exempt).	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.340	Physical carrier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permission.success.permissions_saved	Permissions modified successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.343	Data of flat coordinate	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_013	Information from patent control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342	Data on geospatial reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.added_to_list	Added to list	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.marc_popup.description	Use the box below to modify the MARC of this record before importing it.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.1.2	name in direct order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.1.0	inverted name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.confirm	Do you wish to confirm base reindexing?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.indicator.1.1	name of jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.090.subfield.b	Code of author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.090.subfield.a	Classification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.search_vocabulary	Vocabulary	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.modified	Cancellation/Alteration Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740	Secondary entry - Additional Title - Analytical	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_410	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_411	Another name format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.090.subfield.d	Copy number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.090.subfield.c	Edition / volume	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.error	Backup restoring error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_020	ISBN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_024	ISRC	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.print_receipt	Print receipt	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_022	ISSN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.form.remove	Remove	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.240.indicator.2.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.362.indicator.1	Date format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_quotation_save	Save quotation record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3migration	Import Biblivre 3 data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.info	Remarks	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.orders_by_date	Report on Orders by Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.lend_success	Copy (unit) lent successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.invalid_origin_schema	Backup did not have selected library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.edit	Edit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_cancel_editing.1	Do you wish to cancel editing this quotation record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.confirm_cancel_editing.1	Do you wish to cancel inclusion of Access Cards?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.label_exclude_digital_media	Backup without digital files	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_permissions	Logins and Permissions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541.indicator.1	Privacy	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_list	List users	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.isrc_already_in_database	There is already a record with this ISRC in the database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.address_state	State	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.save_as_new	Save as new	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.610.indicator.1	Form of entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.isrc	ISRC	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.select.default	Select an option	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.help_about_biblivre	About Biblivre	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.save.success	Records imported successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.confirm_cancel_editing_title	Cancel edition of supplier registration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.upload_popup.uploading	Sending file...	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	field.error.required	Filling in this field is compulsory	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.created	Registration Date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.reserve_date	Reservation date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permission.success.create_login	Login and permissions successfully created	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.file_not_found	File not found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.issn	ISSN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.043.subfield.a	Code of geographical area	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.reservation_count	Records reserved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.help_about_library	About the Library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.restore.restore_partial_backup.description	To restore only some libraries, use the form below. In this case you may either choose the libraries to be restored and they will replace the existing ones, or they will be restored as new libraries. This is useful for duplicating libraries or for checking if backup is correct.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.administration.z3950.server.active	Local active server z39.50	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.indexing_groups.entity	Entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.success.save	User successfully included	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.310.subfield.a	Usual Periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.holdings_reserved	Reserved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.310.subfield.b	Date of usual periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.090	Call number / Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_request_delete	Delete requests record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.indexing_groups.vt_ta_term	Associated Term (AT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.newest_backup	Most recent Backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.schemas.description	Please see below all the libraries registered in this Biblivre 4. Should you wish to modify a name or subtitle, please go to the configurations screen of the Library.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.description_found_backups_1	See below backups found in the documents in your computer. To restore these backups, press the button on your name.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.150	Narrower Term (NT)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_lending_return	Conduct work returns	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.failure.delete	Failure deleting user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_cancel_editing_title	Cancel editing of requisition record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.add_cards	Ad Cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.1.2	Secondary subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.confirm_delete_record.forever	The Z39.50 Server will be deleted forever from the system and cannot be restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_status.inactive	Inactive	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.name	Company Name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.pg_dump_path	Attention: This is an advanced configuration, although important. Biblivre will endeavor to automatically find the path for the program <strong>pg_dump</strong> and except in cases when an error is show below, you will not need to modify this configuration. This configuration represents the path on the server where Biblivre is installed, for the executable <strong>pg_dump</strong> which is distributed with the PostgreSQL. Should this configuration be invalid, Biblivre will not be able to create safety copies.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_authorities_move	Move authority record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_move_record_description_singular	Do you really wish to mover this record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.title.cancel	Cancel Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reindex.warning	This process may take some minutes, subject to the hardware configuration of your server. During this, Biblivre will not be available for record searches, but will operate again when reindexing finishes.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.user.simple_term_title	Fill in the terms for the search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.paid_value	Total Value Paid	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.delete_failure	Reservation delete failure	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.082.subfield.a	Classification Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.lend	Lend	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.acquisition	Acquisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.913	Local code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_150	Narrower Term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_delete_record_question	Do you really wish to delete this quotation record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3restore.confirm_description	Do you really wish to restore this Backup?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.fieldset.database	Database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.clear_simple_search	Clear search results	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.source_search_subtitle	Select a remote library and fill in the search terms. The search will provide a limit of  {0} records. If you do not see the record that interests you, please refine your search.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.vocabulary_550	Broader Term	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.phone_work_extension	Extension of commercial telephone number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.confirm_delete_record_title.forever	Delete user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_cancel_editing.1	Do you wish to cancel editing this bibliographic record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.confirm_cancel_editing_title	Cancel editing unit record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.late_lendings_count	Total of late loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.no_records_found	No records found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.d	Date that appears close to the uniform entry title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.receipt_date	Receipt date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.user	Report by User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.p	Name of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.number_of_holdings	Number of Copies	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.main	Main	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.f	Date of edition of the item that is being processed	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.page_help	<p>Requisition routine allows registration and search of work requisitions. A requisition is a record on a work the Library wishes to purchase and can be used to conduct Quotations with previously registered Suppliers.</p>\n<p>Search will look for each one of the terms inserted in the fields <em>Requester, author or Title </em>.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.no_reserves	This user has no reservations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.l	Text language. Language of the text in full	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.no_language_code_specified	The translations file sent does not have the language identifier: <strong>*language_code</strong>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.082.subfield.2	Number of edition of the CDD	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.confirm_delete_record_question.forever	Do you really wish to delete this quotation record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.indicator.1	Secondary Title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.210.indicator.2	Title Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_data	Data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.distributed.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permission.success.password_saved	Password modified successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_490	Series	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.1.0	No specified level	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.750.indicator.1.1	Primary subject	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.unavailable	Backup unavailable	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.question.block	Do you really wish to block this Card?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.confirm_delete_record_title.forever	Delete Z39.50 Server	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.title.block	Block Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.digitalmedia_upload	Upload digital media	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.fine.success_pay_fine	Fine paid successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.circulation_lending	Loans and Returns	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.holdings_count	Copies	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.subfield.a	Surname and/or name of author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.step_1_title	Select origin of import data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.subfield.b	Numbering that follows the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.651.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.cataloging.accession_number_prefix	Prefix of asset reference number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.duplicated_destination_schema	It is not possible to restore two libraries for a single shortcut	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.651.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.reservation.record_list_reserved	List only records reserved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.651.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.indexing_groups.event	Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.javascript_locale_not_available	There is no JavaScript language identifier for the translations file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.321	Previous Periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.no_server_found	No z39.50 server found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.invalid_user	Invalid or non-existing user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_late_lendings	Late loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.description	Select below the items you wish to import from the Biblivre 3 database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.error	Error	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.total_value	Total value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.supplier	Supplier	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.selected_records_singular	{0} record selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.020.subfield.a	ISBN number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.020.subfield.c	Acquisition arrangement	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.confirm_description	Do you really wish to import Biblivre 3 data?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.button.select_reader	Select reader	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.score	Score	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.2	Order type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.groups.digital_media	Digital Media	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.address_number	Number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.subfield.q	Complete form of the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.error.no_quotation_found	No quotation found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.marc_field	Marc Field	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.subfield.d	Dates associated to name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100.subfield.c	Title and other words associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.852.indicator.1	Classification scheme	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.delivery_time	Delivery time (as promised)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.address	Address	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_100	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.biblivre_report_header	Biblivre reports	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.all_digits	All	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	field.error.digits_only	This field must be filled in with numbers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300	Physical description	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.change_password.repeat_password	Repeat new password	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.306	Duration time	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.card_not_found	No Card found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.button.select_user	Select User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.confirm_delete_record_title.forever	Delete Access Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.1.0	Horizontal coordinate system	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.651.subfield.a	Geographical name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.unblock	Card will be unblocked and will be available for use	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.block	Card will be blocked and will not be available for use	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.310	Usual Periodicity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.1.1	Vertical coordinate system	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.circulation_access_control_list	List access control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.success.delete	User Type successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.title	Selected database	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.cataloging_vocabulary_save	Save vocabulary record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.error.existing_cards	The following Cards already exist:	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.subfield.a	Work title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.holdings_by_date	Copies Registration Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.0	Geographical	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.next	Next	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.1	Map  projection	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.quotation_select	Select one Quotation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.2	System of grid coordinates	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.3	Flat place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.4	Place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_110	Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.5	Geodesic model	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.lendings_current	Total number of Books still on loan	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.authorities_111	Author Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.6	Altitude	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.invalid_psql_path	Invalid path. Biblivre cannot create and recover backups because the <strong>psql</strong> file was not found.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.7	To specify	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.success.delete	Supplier successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.342.indicator.2.8	Depth	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.question.uncancel	Do you really wish to recover this Card?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.subfield.f	Date of work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.import_popup.title	Importing Records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.t	Title of the work close to the entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.258.subfield.b	Denomination	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_supplier_list	List suppliers	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.258.subfield.a	Issuing jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.q	Complete form of name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.gender.1	Male	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.gender.2	Female	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.groups.admin	Administration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.unit_value	Unit Value	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.author_type	Author type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.records	Report on Inclusion of Works during Period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_accesscards_save	Include access cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.c	Title and other terms associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.d	Dates associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.a	Surname and/or name of author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.b	Numbering following name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.error.save	Error saving quotation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700.subfield.e	Relation to the document	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_delete_record.trash	It will be moved to the trash recycle bin	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.type	User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.title.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.1.1	Generates entry for title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.243.indicator.1.0	Does not generated entry for title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.680.subfield.a	Scope note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.130.indicator.1	Number of characters to be overridden in the alphabetation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field_count.description	<p>After selecting the Marc field and Ordering, please conduct bibliographic search that will be the basis for the report, or press <strong>Issue Report</strong> to use the complete bibliographic base.</p>\n<p><strong>Attention:</strong> Issuance of this report may take some minutes, depending on the size of the bibliographic base.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.end_number	End number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.modified_between	Modified between	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.form.hidden_subfields_singular	Show hidden subfield	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.z3950.error.save	Error saving Z39.50 Server	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.backup.schemas.description	Select below all the libraries that will make up the backup. If a backup has several libraries, you will be able to choose the ones to be restored when necessary.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_access_cards	Access Cards	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.quantity	Quantity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_order_save	Save order record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_restore	Restore database backup	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.id_rg	Identity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.download.button	Download the language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.edit	Edit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.label_digital_media_only	Backup of digital files	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.field.reservation_time_limit	Reservation time	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	format.datetime_user_friendly	DD/MM/YYYY hh:mm	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.acquisition_supplier_save	Save supplier record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.operator	Operator	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.t	Title of the work close to the entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.q	Complete format of the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_delete_record_question.forever	Do you really wish to delete this requisition record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_710	Secondary Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.record_will_be_ignored	This record will not be imported	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_711	Secondary Author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.d	Dates associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configurations.error.value_must_be_numeric	The value in this field must be numeric	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.summary	Catalogue Summary Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.550	BT (broader term)	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.a	Name and/or surname of author	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.field.status	Status	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_field.id	User number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.b	Numbering following name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.c	Title and other terms associated to the name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_remove_attachment_description	Do you wish to delete this digital file?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.simple_term_title	Fill in User Type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	warning.reindex_database	You need database reindexing	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.groups.cataloging	Cataloging	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.user.select_item_button	Select record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.advanced_search	Bibliographic Advanced Search	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre4restore.error.description	Regrettably an error occurred when restoring this Biblivre 4  backup. Check next screen through the error log and, if necessary, go to the Biblivre forum for assistance.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.z	Geographical subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.amount	Quantity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.x	General subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.600.subfield.y	Chronological subdivision	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.users_without_user_card	List only users that never had their library card printed	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.confirm_remove_attachment	Delete digital file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_delete_record_question	Do you really wish to delete this requisition record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.k	Subheadings	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.error.accession_number_unavailable	This asset reference number is already in use by other unit. Please fill in another value or leave it blank so that the system can make the calculation automatically.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_delete_record_title.forever	Delete requisition record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.author_type.100	Person	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.button.add	Add	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.change_status.title.uncancel	Recover Card	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.field.created	Order date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_730	Uniform Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.records_found_plural	{0} records found	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.100.indicator.1	Entry form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.holding.error.shouldnt_delete_because_holding_is_or_was_lent	This unit is or was already lent and must not be deleted. Should it be no longer available, the correct procedure is to change from 'available' to 'unavailable'. However, if you still wish to delete this unit, press button <b>"Force Deletion "</b>.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.page_help	<p>The <strong>"User Registry"</strong> allows storing information on readers and library employees in order to facilitate lendings, reservations and also to control access of these users to the library.</p>\n<p>Before registering a user it is recommended to check whether he/she is already registered, through a <strong>Simple search</strong>, which will search each of the terms inserted in the selected field or through an <strong>Advanced research </strong>, which provides a better control on users found, allowing, for example, searching users with pending fines.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.author_type.110	Collective Entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.order.selected_records_plural	{0} Values Added	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.author_type.111	Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.button.unblock	Unblock	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.a	Name of entity or of place	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.b	Subordinated units	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.edition	Edition number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.c	Venue of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.city	City	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.d	Date of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	aquisition.quotation.error.quotation_not_found	It was not possible to find the quotation	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.l	Text language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_740	Analytical Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.n	Number of part - section of the work	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.success.save	Language file processed successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.indicator.1.1	Name of jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.administration_translations	Translations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.isbn	ISBN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.indicator.1.0	Inverted name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710.subfield.t	Title of the work close to entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110.indicator.1.2	Name in the direct order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.type.vocabulary	Vocabulary	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	menu.circulation_reservation	Reservations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.b	Illustrations	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.a	Number of volumes and/or pages	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.c	Dimensions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.option.location	Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.2	Type of title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.246.indicator.1	Note control/secondary title entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.record.success.save	Record successfully included	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.success.update	User Type successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.custom.user_field.phone_work	Commercial Telephone No.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.e	Additional material	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.f	Type of storage unit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.g	Size of storage unit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.users.failure.disable	Failure marking user as inactive	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_090	Location	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.bibliographic.id	Record Id	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.library	Library	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.upload_popup.title	Opening file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.2.2	analytical entry	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.schemas.title	List of Libraries in this Server	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.estimated_fine	Estimated fine in case of return today	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.confirm_delete_record.forever	It will be permanently deleted from the system and cannot be retrieved.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.migrate.success	Data imported successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.041	Language code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.040	Cataloging source	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	search.common.button.filter	Filter	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.043	Code of geographical area	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configurations.error.disable_multi_schema_outside_global	It is not possible to disable the multi-libraries scheme  within a library.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.backup_never_downloaded	This backup was never downloaded	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.045	Code for the chronological period	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_cancel_editing.1	Do you wish to cancel editing this authority record?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.confirm_cancel_editing.2	All the modifications will be lost	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_082	CDD	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.authorities.indexing_groups.total	Total	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user.fine.pending	Pending	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_080	CDU	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.upload.field.user_created	Upload translations created by the user	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.corrupted_backup_file	Backup selected is not a valid file or is corrupt	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.labels.popup.title	Labels format	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.6	6 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.7	7 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.8	8 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.300.subfield.3	Additional Material Specification	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.9	9 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.general.business_days	Business days	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.2	2 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.3	3 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.4	4 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.5	5 characters to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.555.indicator.1	Constant exhibition control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.migration.title	Biblivre 3 data migration	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.0	No character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.success.description	Data successfully imported	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.245.indicator.2.1	1 character to be overridden	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.select.option.bibliography	Author Bibliography Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.supplier.field.vat_registration_number	State registration number	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.database.record_moved	Record moved to {0}	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.receipt.renews	Renewals	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tabs.brief	Catalographic Summary	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.vocabulary.datafield.685.subfield.i	Explanatory text	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.reinstall.confirm.question	Your attention, please. All the options will delete the data in your library in favor of the retrieved data. Do you wish to continue?	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.select.default	Select an option	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_095	Area is known by the CNPq	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.button.new	New record	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.029	ISNM	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.user_status.inactive	Inactive	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.nonmusical_sound	No musical sound	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.022	ISSN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.024	Other standardized numbers or codes	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.595.subfield.b	Notes for bibliography, indices and/or appendices	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.595.subfield.a	Bibliography code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.020	ISBN	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.343.subfield.a	Method for codification of flat coordinate	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.setup.biblivre3import.button	Import Biblivre 3 data	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.343.subfield.b	Flat distance unit	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.title.circulation.lending_receipt.printer.type	Type of printer for loan receipts	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.n	Number of order of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	login.error.user_has_login	This user already has a login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.indicator.1.2	name in direct order	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.close	Close	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.indicator.1.1	name of jurisdiction	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.e	Name of event subunits	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711.indicator.1.0	inverted name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_041	Language	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.d	Event date	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.c	Venue for the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.translations.error.invalid_file	Invalid file	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_043	Geographical Code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.import.save.failed	Error when importing Records	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.success.update	Request successfully saved	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.tab.record.custom.field_label.biblio_045	Chronological Code	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.g	Additional information	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.upload_popup.title	Sending File	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.form	Form	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	format.date	dd/MM/yyyy	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.111.subfield.a	Name of the event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.user_type.page_help	<p>The Users Type routine allows registration and search of Users types used by the Users Registration routine. Herein you will find definitions about pieces of information such as Limits of simultaneous Loans, terms for loan returns and daily fines for each type of user separately.</p>\n<p>When accessing this routine, Biblivre will automatically list all the types of Users previously registered. You will be able to filter that list, inserting the <em>Name</em> of a Type of User you wish to trace.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.accesscards.success.unblock	Card unblocked successfully	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.110	Author - Collective entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.013	Information about patent control	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.111	Author - Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.login	Login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configuration.title.general.subtitle	Subtitle of this Group of Libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.730	Secondary entry - Uniform title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.949	Asset cataloging reference	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	error.invalid_parameters	Biblivre could not understand parameters received	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.525.subfield.a	Supplementary Note	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.bibliographic.indexing_groups.title	Title	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.success.save	Quotation successfully included	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.items.administration_permissions	Manage permissions	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.late_lendings	Late Lendings Report	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.configuration.description.general.backup_path	This configuration represents the path on the server where Biblivre is installed, for the file in which Biblivre security copies are to be kept. Should this configuration be empty, security copies will be save on the directory <strong>Biblivre</strong> in the folder of the user of the system.<br> The recommendation is to associate this path to any kind of automatic backup in cloud such as the services <strong>Dropbox</strong>, <strong>SkyDrive</strong> or <strong>Google Drive</strong>. Should Biblivre be unable to keep the files in the specified path, they will be kept in a temporary directory and may not become available. Please remember that a backup is the only way to retrieve data inserted in Biblivre.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.request.field.author_type	Author type	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.lending.lending_count	Copies lent	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.permissions.confirm_delete_record_title.forever	Delete User Login	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.holding.datafield.541	Note on acquisition source	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.authorities.datafield.100	Author - Personal name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.title.user_creation_count	Total of Inclusions by User	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.700	Secondary entry - Personal name	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.unblock	Unblock	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.maintenance.backup.error.invalid_schema	Backup list has one or more invalid libraries	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	common.calculating	Calculating	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.material_type.all	All	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.field.requisition	Requisition	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.manage.error.create	Failure creating new library.	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.710	Secondary entry - Collective Entity	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.711	Secondary entry - Event	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.vocabulary.confirm_delete_record.forever	It will be deleted forever from the system and cannot be restored	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	multi_schema.configuration.description.general.subtitle	Subtitle shown when the main page in this library broup is accessed. This page will list all the registered libraries in this group (managed by the same Biblivre 4).	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	acquisition.quotation.success.delete	Quotation successfully deleted	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	marc.bibliographic.datafield.740.indicator.2._	no information provided	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	administration.reports.field.lendings	Loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	circulation.user_cards.selected_records_plural	{0} users selected	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
en-US	cataloging.lending.error.limit_exceeded	The selected reader surpassed the limit of authorized loans	2014-07-26 10:56:18.338867	1	2014-07-26 10:56:18.338867	1	f
es	multi_schema.restore.title	Opciones de Restauración de Backup	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.select_restore.description_found_backups	Abajo están los backups encontrados en la carpeta <strong>{0}</strong> del servidor Biblivre. Pulse sobre el backup para ver la lista de opciones de restauración disponibles.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.warning_overwrite	Atención: ya existe una biblioteca registrada con la dirección arriba. Si usted efectuara la restauración con esta opción seleccionada, el contenido de la biblioteca existente será sustituido por el contenido del Backup.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.backup.schemas.title	Copia de Seguridad (Backup) de Bibliotecas Múltiples	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	administration.maintenance.backup.error.invalid_destination_schema	El atajo de destino es inválido.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.select_restore.title	Restauración de Backup de Bibliotecas Múltiples	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.restore_with_original_schema_name	Restaurar esta biblioteca usando su dirección original.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.manage.error.cant_disable_last_library	No es posible deshabilitar todas las bibliotecas de este grupo. Al menos una debe quedar habilitada.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	administration.maintenance.backup.error.backup_file_not_found	Archivo de backup no encontrado	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.dont_restore	No restaurar esta biblioteca	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.restore_complete_backup.description	En caso de desear restaurar todo el contenido de este backup, use la tecla abajo. Atención: Esto sustituirá TODO el contenido de su Biblivre, incluso sustituyendo todas las bibliotecas existentes por las que se encuentran en el backup. Use esta opción solo si desea retornar completamente en el tiempo, hasta la fecha del backup.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.restore_partial_backup.title	Restaurar bibliotecas de acuerdo con los criterios arriba.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.manage.disable	Deshabilitar biblioteca	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.restore_complete_backup.title	Restaurar todas las informaciones del Backup, substituyendo todas las bibliotecas de este Biblivre.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.manage.error.toggle	Error al cambiar el estado de la biblioteca.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.configurations.error.disable_multi_schema_schema_count	No es posible deshabilitar el sistema de multi bibliotecas mientras exista más de una biblioteca habilitada.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.restore_with_new_schema_name	Restaurar esta biblioteca usando una nueva dirección.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.select_restore.description	Use esta opción en caso de desear restaurar un backup existente del Biblivre 4. En el caso de que el Biblivre encuentre backups guardados en sus documentos, usted podrá restaurarlos directamente de la lista siguiente. De lo contrario, usted deberá enviar un archivo de backup (extensión <strong>.b4bz</strong>) a través del formulario.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.select_restore.library_list_inside_backup	Bibliotecas en este backup	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	administration.maintenance.backup.error.invalid_origin_schema	El Backup no posee la biblioteca seleccionada.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.restore.restore_partial_backup.description	Para restaurar solo algunas bibliotecas, use el formulario siguiente. En este caso usted podrá elegir qué bibliotecas serán restauradas y si ellas sustituirán a las existentes o si serán restauradas como nuevas bibliotecas. Esto es útil para duplicar bibliotecas o verificar si el backup está correcto.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.manage.enable	Habilitar biblioteca	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	administration.maintenance.backup.error.duplicated_destination_schema	No es posible restaurar dos bibliotecas para un único atajo.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.backup.schemas.description	Seleccione abajo todas las bibliotecas que formarán parte del backup. Aunque un backup contenga distintas bibliotecas, usted podrá elegir cuál desea restaurar cuando así lo precise.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
es	multi_schema.configurations.error.disable_multi_schema_outside_global	No es posible deshabilitar el sistema de multi bibliotecas del interior de una biblioteca.	2014-07-26 10:56:23.669888	1	2014-07-26 10:56:23.669888	1	f
pt-BR	multi_schema.restore.restore_partial_backup.description	Para restaurar apenas algumas bibliotecas, use o formulário abaixo. Neste caso você poderá escolher quais bibliotecas serão restauradas e se elas substituirão as existentes ou se serão restauradas como novas bibliotecas. Isto é útil para duplicar bibliotecas ou verificar se o backup está correto.	2014-07-19 13:48:01.039737	1	2014-07-26 10:56:27.710005	1	f
en-US	cataloging.bibliographic.automatic_holding_help	<p>Use the form below to speed up the Copies creation process. This is an optional step and no holding will be created if the form below is left blank. In that case, you can create your holdings in the <em>Copies</em> tab.</p><p>If you want to create the Copies now, the only mandatory field is "Number of Copies". This field will decide the number of copies created for each volume, so, if the bibliographic record has 3 volumes and you set "Number of Copies" as 2, 6 copies will be created, 2 for each volume. If there's only one volume, fill in the "Volume Number" field, and if there's no volume, leave both fields blank.</p>	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.configuration.title.logged_in_text	Greeting message for logged users	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	circulation.user_reservation.page_help	<p>To reserve your selected book, please search for it below, just like in the Bibliographic Search module.</p>	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	warning.download_site	Go to download site	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.reports.field.id	Registration No.	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding.holding_count	Number of copies	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.configuration.title.logged_out_text	Greeting message for unlogged users	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding_title	Automatic Copies Creation	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.permissions.items.circulation_reservation_list	List reserves	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.reports.field.biblio_reservation	Reserves by bibliographical record	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	marc.bibliographic.datafield.730.indicator.2._	no information provided	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	menu.circulation_user_reservation	Reserves	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.configuration.description.logged_in_text	Message that will show at Biblivre's welcome screen, for users that have logged in. You may use HTML tags, but be careful not to break Biblivre's layout. Warning: this configuration is related to the Translations module. Changes made here will only affect the current language. To change other languages, use the Translations Module or open Biblivre in the desired language.	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	warning.new_version	There's an update for Biblivre 4 available<br/>Current Version: {0}. Latest version: {1}	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.reports.field.holdings_count	Number of copies	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	menu.multi_schema_backup	Backup and Restore	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding.holding_acquisition_date	Acquisition date	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding.holding_library	Depository Library	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	menu.self_circulation	Reserves	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.permissions.items.circulation_reservation_reserve	Reserve	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.configuration.description.logged_out_text	Message that will show at Biblivre's welcome screen, for users that haven't logged in. You may use HTML tags, but be careful not to break Biblivre's layout. Warning: this configuration is related to the Translations module. Changes made here will only affect the current language. To change other languages, use the Translations Module or open Biblivre in the desired language.	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.reports.field.holding_reservation	Reserves by Holding Id	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.migration.groups.reservations	Reserves	2014-07-26 10:56:18.338867	1	2014-07-26 12:01:11.320131	1	f
en-US	marc.bibliographic.datafield.730.subfield.a	Uniform title given to document	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding.holding_acquisition_type	Acquisition Type	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.permissions.items.circulation_user_reservation	Reserve a book yourself	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding.holding_volume_number	Volume number	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	cataloging.bibliographic.automatic_holding.holding_volume_count	Number of volumes	2014-07-26 12:01:11.320131	1	2014-07-26 12:01:11.320131	1	f
en-US	administration.setup.biblivre3import.description	A Biblivre 3 installation was detected in this computer. You may wish to import these data for Biblivre 4, by selecting the items you are interested in, and pressing the button below. After importation, <strong>you will have to reindex the three bases: the Bibliographic one, and the ones for Authorities and Vocabulary </strong>, through the <strong>"Maintenance"</strong> screen in <strong>"Administration"</strong> and <strong>select again the permissions of employees with access to Biblivre</strong>, through the <strong>"Logins and Permissions"</strong> screen in <strong>"Administration"</strong>.	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	acquisition.quotation.confirm_delete_record.trash	It will be sent to the "trash" recycle bin database	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	circulation.user.confirm_delete_record.inactive	He will be deleted from the search list and will only be found through an "advanced search", from which he can be excluded forever, or recovered	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	cataloging.database.trash_full	Recycle "trash" bin	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	cataloging.vocabulary.confirm_delete_record.trash	It will be moved to the recycle-bin "trash" database"	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	cataloging.holding.confirm_delete_record.trash	It will be moved to the recycle "trash" bin	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	marc.bibliographic.datafield.501	Notes starting with the term "with"	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	circulation.user_cards.page_help	<p>The module<strong>"Printing User Cards"</strong> allows generating the identification labels of the library readers.</p>\n<p>It is possible to generate the user cards for one or more readers in a single printing, using the search below.</p>\n<p>After finding the reader(s), use the button <strong>"Select user "</strong> to add them to the User Cards printing list. You can do several searches, without missing the previous selection. Once you are satisfied with the selection, press the button <strong>"print user cards "</strong>. You can select the position of the first user card in the label page.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	cataloging.database.trash	Recycle "trash" bin	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	administration.reports.page_help	<p>The Reports routine allows to create and print several reports made available by Biblivre. Reports available are Split among the Acquisition, Cataloging and Circulation routines.</p>\n<p>Some of the reports available have filters, such as Bibliographic Base, or Term, for example. For others, you just have to select the report and press "Generate Report" ".</p>	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	circulation.user.confirm_delete_record_question.inactive	Do you really wish to mark this user as "inactive "?	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	administration.accesscards.page_help	<p>Routine for Access Cards allows registration and search of Cards used by Access control routines. Biblivre offers two registration options:</p>\n<ul><li>Register New Card: Use just one access card;</li><li>To Register Card Sequence: use more than just one access card in sequence. Use the field "pre-visualization' to see how card will be numbered.</li></ul>\n<p>When accessing this routine, Biblivre will automatically list all the Access Cards previously registered. You may then filter that list, inserting the <em>Code</em> of the Access Card you wish to find.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	multi_schema.translations.page_help	<p>The module of <strong>"Translations"</strong> for Multilibraries Works similarly to the version corresponding to just one library. However, texts which were modified here will be applied to all the libraries in the group, provided they have not modified the original value of each translation.</p>\n<p>For example, if you modify the translation of the key <strong>"menu.search"</strong> from "Search" to "Trace" through the Translations module for multi-libraries, all the libraries in this group will see the new translation. However, if one of the administrators of one of these libraries modifies, through the <strong>"Translations"</strong> module of his library, the same key to "Search", this in-house translation will have priority just for this library.</p>\n<p>In order to add a new language, you will have to download the language file in Portuguese, do the translation of the texts and then upload the file. Remember that only the <strong>texts</strong> (after the = sign) must be modified.  Do not modify the keys, as otherwise the Biblivre 4 will not be able to trace the text </p>\n<p>Example: Let´s say that you wish to modify the text in the main menu from <i>Search</i> to <i>Trace</i>.  You will have to download the language file and modify this line:</p>\n<p><strong>*menu.search</strong> = Search</p>\n<p>To:</p>\n<p><strong>*menu.search</strong> = Trace</p>\n<p>and then upload the language file. Biblivre 4 will process the file and will modify the menu text.</p>	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	acquisition.supplier.confirm_delete_record.trash	It will be moved to the "trash" database	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
en-US	circulation.user.confirm_delete_record_title.inactive	Mark user as "inactive"	2014-07-26 10:56:18.338867	1	2014-07-26 13:41:48.22945	1	f
pt-BR	administration.reports.title.custom_count	Relatório de contagem pelo campo Marc	2014-05-21 21:47:27.923	1	2016-06-04 19:36:48.423	0	f
pt-BR	cataloging.bibliographic.search.holding_accession_number	Tombo patrimonial	2016-06-04 19:36:48.432	0	2016-06-04 19:36:48.432	0	f
pt-BR	cataloging.bibliographic.search.holding_id	Código de barras da etiqueta	2016-06-04 19:36:48.438	0	2016-06-04 19:36:48.438	0	f
pt-BR	search.holding.shelf_location	Localização	2016-06-04 19:36:48.44	0	2016-06-04 19:36:48.44	0	f
pt-BR	circulation.lending.no_holding_found	Nenhum exemplar encontrado	2016-06-04 19:36:48.542	0	2016-06-04 19:36:48.542	0	f
en-US	administration.reports.title.custom_count	Marc field counting report	2014-07-26 10:56:18.338867	1	2016-06-04 19:36:48.548	0	f
en-US	cataloging.bibliographic.search.holding_accession_number	Asset number	2016-06-04 19:36:48.551	0	2016-06-04 19:36:48.551	0	f
en-US	cataloging.bibliographic.search.holding_id	Label barcode number	2016-06-04 19:36:48.553	0	2016-06-04 19:36:48.553	0	f
en-US	search.holding.shelf_location	Location	2016-06-04 19:36:48.556	0	2016-06-04 19:36:48.556	0	f
en-US	circulation.lending.no_holding_found	No copy found	2016-06-04 19:36:48.558	0	2016-06-04 19:36:48.558	0	f
es	administration.reports.title.custom_count	Informe de recuento del campo Marc	2014-07-19 11:28:46.69376	1	2016-06-04 19:36:48.56	0	f
es	cataloging.bibliographic.search.holding_accession_number	Sello patrimonial	2016-06-04 19:36:48.564	0	2016-06-04 19:36:48.564	0	f
es	cataloging.bibliographic.search.holding_id	Código de barras de la etiqueta	2016-06-04 19:36:48.566	0	2016-06-04 19:36:48.566	0	f
es	search.holding.shelf_location	Localización	2016-06-04 19:36:48.568	0	2016-06-04 19:36:48.568	0	f
es	circulation.lending.no_holding_found	Ningún ejemplar encontrado	2016-06-04 19:36:48.569	0	2016-06-04 19:36:48.569	0	f
pt-BR	administration.setup.biblivre3restore.log_header	[Log de restauração de backup do Biblivre 3]\n\n	2016-06-04 19:36:48.573	0	2016-06-04 19:36:48.573	0	f
en-US	administration.setup.biblivre3restore.log_header	[Log for Biblivre 3 backup restoration]\n\n	2016-06-04 19:36:48.574	0	2016-06-04 19:36:48.574	0	f
es	administration.setup.biblivre3restore.log_header	[Log de restauración de backup del Biblivre 3]\n\n	2016-06-04 19:36:48.576	0	2016-06-04 19:36:48.576	0	f
pt-BR	administration.setup.biblivre4restore.skip	Ignorar	2016-06-04 19:36:54.261	0	2016-06-04 19:36:54.261	0	f
en-US	administration.setup.biblivre4restore.skip	Skip	2016-06-04 19:36:54.264	0	2016-06-04 19:36:54.264	0	f
es	administration.setup.biblivre4restore.skip	Pasar	2016-06-04 19:36:54.266	0	2016-06-04 19:36:54.266	0	f
pt-BR	administration.setup.biblivre4restore.error.digital_media_only_selected	O Backup selecionado contém apenas arquivos digitais. Tente novamente usando um backup completo ou parcial sem arquivos digitais	2016-06-04 19:36:54.267	0	2016-06-04 19:36:54.267	0	f
en-US	administration.setup.biblivre4restore.error.digital_media_only_selected	The selected Backup is a Digital Media Only file.  Try again using a Complete Backup file or one without Digital Media	2016-06-04 19:36:54.269	0	2016-06-04 19:36:54.269	0	f
es	administration.setup.biblivre4restore.error.digital_media_only_selected	La copia de seguridad seleccionada contiene sólo los archivos digitales. Trate de usar una copia de seguridad completa o parcial sin archivos digitales	2016-06-04 19:36:54.27	0	2016-06-04 19:36:54.27	0	f
pt-BR	administration.setup.biblivre4restore.error.digital_media_only_should_be_selected	O segundo arquivo de backup selecionado não contém apenas arquivos digitais	2016-06-04 19:36:54.271	0	2016-06-04 19:36:54.271	0	f
en-US	administration.setup.biblivre4restore.error.digital_media_only_should_be_selected	The second file selected is not a Digital Media Only file	2016-06-04 19:36:54.273	0	2016-06-04 19:36:54.273	0	f
es	administration.setup.biblivre4restore.error.digital_media_only_should_be_selected	 El segundo archivo que seleccionó no  contiene sólo archivos digitales	2016-06-04 19:36:54.274	0	2016-06-04 19:36:54.274	0	f
pt-BR	administration.setup.biblivre4restore.select_digital_media	Selecione um Backup de Mídias Digitais	2016-06-04 19:36:54.275	0	2016-06-04 19:36:54.275	0	f
en-US	administration.setup.biblivre4restore.select_digital_media	Select a Digital Media Backup file	2016-06-04 19:36:54.276	0	2016-06-04 19:36:54.276	0	f
es	administration.setup.biblivre4restore.select_digital_media	Seleccione una copia de seguridad de archivos digitales	2016-06-04 19:36:54.279	0	2016-06-04 19:36:54.279	0	f
pt-BR	administration.setup.biblivre4restore.select_digital_media.description	O arquivo de backup selecionado anteriormente não possui Mídias Digitais.  Caso você possua um backup somente de Mídias Digitais, selecione abaixo o arquivo desejado, ou faça o upload do mesmo. Caso não deseje importar Mídias Digitais, clique no botão <strong>Ignorar</strong>.	2016-06-04 19:36:54.28	0	2016-06-04 19:36:54.28	0	f
en-US	administration.setup.biblivre4restore.select_digital_media.description	The previously selected Backup file doesn't have any Digital Media. If you have a Digital Media Only backup, select the desired one below, or upload the Digital Media Only backup file. If you don't want to import Digital Media, click on <strong>Skip</strong>.	2016-06-04 19:36:54.281	0	2016-06-04 19:36:54.281	0	f
es	administration.setup.biblivre4restore.select_digital_media.description	El archivo de copia de seguridad seleccionado previamente no contiene archivos digitales. Si usted tiene una copia de seguridad de sólo archivos digitales, seleccione el archivo que desee a continuación, o cargar el mismo. Si no desea importar Digital Media, haga clic en <strong>Pasar</ strong>.	2016-06-04 19:36:54.283	0	2016-06-04 19:36:54.283	0	f
pt-BR	multi_schema.manage.drop_schema.confirm_title	Excluir biblioteca	2016-06-04 19:36:54.284	0	2016-06-04 19:36:54.284	0	f
en-US	multi_schema.manage.drop_schema.confirm_title	Delete library	2016-06-04 19:36:54.285	0	2016-06-04 19:36:54.285	0	f
es	multi_schema.manage.drop_schema.confirm_title	Excluir biblioteca	2016-06-04 19:36:54.287	0	2016-06-04 19:36:54.287	0	f
pt-BR	multi_schema.manage.drop_schema.confirm_description	Você realmente deseja excluir esta biblioteca?	2016-06-04 19:36:54.288	0	2016-06-04 19:36:54.288	0	f
en-US	multi_schema.manage.drop_schema.confirm_description	Do you really want to delete this library?	2016-06-04 19:36:54.288	0	2016-06-04 19:36:54.288	0	f
es	multi_schema.manage.drop_schema.confirm_description	¿Usted realmente desea excluir esta biblioteca?	2016-06-04 19:36:54.289	0	2016-06-04 19:36:54.289	0	f
pt-BR	multi_schema.manage.drop_schema.confirm	Ela será excluída permanentemente do sistema e não poderá ser recuperada	2016-06-04 19:36:54.29	0	2016-06-04 19:36:54.29	0	f
en-US	multi_schema.manage.drop_schema.confirm	It will be deleted from the system forever and cannot be restored	2016-06-04 19:36:54.293	0	2016-06-04 19:36:54.293	0	f
es	multi_schema.manage.drop_schema.confirm	La biblioteca será excluida permanentemente del sistema y no podrá ser recuperada	2016-06-04 19:36:54.294	0	2016-06-04 19:36:54.294	0	f
pt-BR	multi_schema.backup.display_and_select_libraries	Exibir e selecionar bibliotecas {min} a {max}	2016-06-04 19:36:54.298	0	2016-06-04 19:36:54.298	0	f
en-US	multi_schema.backup.display_and_select_libraries	Show and select libraries from {min} to {max}	2016-06-04 19:36:54.299	0	2016-06-04 19:36:54.299	0	f
es	multi_schema.backup.display_and_select_libraries	Ver y seleccionar las bibliotecas de {min} a {max}	2016-06-04 19:36:54.3	0	2016-06-04 19:36:54.3	0	f
pt-BR	administration.setup.biblivre4restore.select_file	Selecione um arquivo de backup do Biblivre 4	2014-06-14 19:32:35.338749	1	2016-06-04 19:36:54.302	0	f
en-US	administration.setup.biblivre4restore.select_file	Select a Biblivre 4 backup file	2014-07-26 10:56:18.338867	1	2016-06-04 19:36:54.303	0	f
es	administration.setup.biblivre4restore.select_file	Seleccione un archivo de copia de seguridad Biblivre 4	2014-07-19 11:28:46.69376	1	2016-06-04 19:36:54.305	0	f
pt-BR	multi_schema.restore.limit.title	Bibliotecas no arquivo selecionado	2016-06-04 19:36:54.306	0	2016-06-04 19:36:54.306	0	f
en-US	multi_schema.restore.limit.title	Libraries in the selected file	2016-06-04 19:36:54.308	0	2016-06-04 19:36:54.308	0	f
es	multi_schema.restore.limit.title	Bibliotecas en el archivo seleccionado	2016-06-04 19:36:54.31	0	2016-06-04 19:36:54.31	0	f
pt-BR	multi_schema.restore.limit.description	O arquivo selecionado possui um número muito grande de bibliotecas. Por limites do banco de dados, a restauração deverá ser feita em passos, de no máximo 20 bibliotecas por passo. Clique nos links abaixo para listar as bibliotecas desejadas, e selecione as bibliotecas que serão restauradas. Repita esse procedimento até que todas as bibliotecas desejadas tenham sido restauradas.	2016-06-04 19:36:54.311	0	2016-06-04 19:36:54.311	0	f
en-US	multi_schema.restore.limit.description	The selected file contains a high number of libraries. Due to database limitations, you should restore those libraries in steps, limited to 20 libraries in each step. Click in a link below to list the desired libraries, and select the ones you want to restore. Repeat these steps untill you've restored all the libraries you need.	2016-06-04 19:36:54.313	0	2016-06-04 19:36:54.313	0	f
es	multi_schema.restore.limit.description	 El archivo seleccionado tiene un gran número de bibliotecas. Debido a las limitaciones de la base de datos, la restauración debe hacerse en pasos de hasta 20 bibliotecas a paso. Haga clic en los enlaces abajo para enumerar la biblioteca que desee y seleccione las bibliotecas que se restaurarán. Repita este procedimiento hasta que se hayan restaurado todas las bibliotecas deseadas.	2016-06-04 19:36:54.314	0	2016-06-04 19:36:54.314	0	f
pt-BR	cataloging.bibliographic.indexing_groups.publisher	Editora	2016-06-04 19:36:54.323	0	2016-06-04 19:36:54.323	0	f
en-US	cataloging.bibliographic.indexing_groups.publisher	Publisher	2016-06-04 19:36:54.326	0	2016-06-04 19:36:54.326	0	f
es	cataloging.bibliographic.indexing_groups.publisher	Editora	2016-06-04 19:36:54.327	0	2016-06-04 19:36:54.327	0	f
pt-BR	cataloging.bibliographic.indexing_groups.series	Série	2016-06-04 19:36:54.329	0	2016-06-04 19:36:54.329	0	f
en-US	cataloging.bibliographic.indexing_groups.series	Series	2016-06-04 19:36:54.33	0	2016-06-04 19:36:54.33	0	f
es	cataloging.bibliographic.indexing_groups.series	Serie	2016-06-04 19:36:54.33	0	2016-06-04 19:36:54.33	0	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_501	Notas	2016-06-04 19:36:54.333	0	2016-06-04 19:36:54.333	0	f
en-US	cataloging.tab.record.custom.field_label.biblio_501	Notes	2016-06-04 19:36:54.334	0	2016-06-04 19:36:54.334	0	f
es	cataloging.tab.record.custom.field_label.biblio_501	Notas	2016-06-04 19:36:54.336	0	2016-06-04 19:36:54.336	0	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_530	Notas	2016-06-04 19:36:54.337	0	2016-06-04 19:36:54.337	0	f
en-US	cataloging.tab.record.custom.field_label.biblio_530	Notes	2016-06-04 19:36:54.338	0	2016-06-04 19:36:54.338	0	f
es	cataloging.tab.record.custom.field_label.biblio_530	Notas	2016-06-04 19:36:54.34	0	2016-06-04 19:36:54.34	0	f
pt-BR	cataloging.tab.record.custom.field_label.biblio_595	Notas	2016-06-04 19:36:54.342	0	2016-06-04 19:36:54.342	0	f
en-US	cataloging.tab.record.custom.field_label.biblio_595	Notes	2016-06-04 19:36:54.344	0	2016-06-04 19:36:54.344	0	f
es	cataloging.tab.record.custom.field_label.biblio_595	Notas	2016-06-04 19:36:54.345	0	2016-06-04 19:36:54.345	0	f
\.


--
-- TOC entry 2550 (class 0 OID 16446)
-- Dependencies: 170 2636
-- Data for Name: versions; Type: TABLE DATA; Schema: global; Owner: biblivre
--

COPY versions (installed_versions) FROM stdin;
4.0.0b
4.0.1b
4.0.2b
4.0.3b
4.0.4b
4.0.5b
4.0.6b
4.0.7b
4.0.8b
4.0.9b
4.0.10b
4.0.11b
4.0.12b
4.1.0
4.1.1
4.1.2
4.1.3
4.1.4
4.1.5
4.1.6
4.1.7
4.1.8
4.1.9
4.1.10
4.1.10a
4.1.11
\.


SET search_path = single, pg_catalog;

--
-- TOC entry 2552 (class 0 OID 16470)
-- Dependencies: 172 2636
-- Data for Name: access_cards; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY access_cards (id, code, status, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2672 (class 0 OID 0)
-- Dependencies: 171
-- Name: access_cards_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('access_cards_id_seq', 1, false);


--
-- TOC entry 2554 (class 0 OID 16481)
-- Dependencies: 174 2636
-- Data for Name: access_control; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY access_control (id, access_card_id, user_id, arrival_time, departure_time, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2673 (class 0 OID 0)
-- Dependencies: 173
-- Name: access_control_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('access_control_id_seq', 1, false);


--
-- TOC entry 2555 (class 0 OID 16488)
-- Dependencies: 175 2636
-- Data for Name: authorities_brief_formats; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_brief_formats (datafield, format, sort_order, created, created_by, modified, modified_by) FROM stdin;
100	${a}_{; }${c}_{ - }${d}	1	2014-03-20 12:20:01.029	\N	2014-03-20 12:20:01.029	\N
670	${a}	7	2014-03-20 12:23:36.822	\N	2014-03-20 12:23:36.822	\N
400	${a}	4	2014-03-20 12:22:53.502	\N	2014-03-20 12:22:53.502	\N
410	${a}	5	2014-03-20 12:23:04.503	\N	2014-03-20 12:23:04.503	\N
411	${a}	6	2014-03-20 12:23:14.566	\N	2014-03-20 12:23:14.566	\N
111	${a}_{; }${c}_{ - }${d}	3	2014-03-20 12:22:40.585	\N	2014-03-20 12:22:40.585	\N
110	${a}_{; }${b}_{; }${c}_{ - }${d}	2	2014-03-20 12:22:07.272	\N	2014-03-20 12:22:07.272	\N
\.


--
-- TOC entry 2556 (class 0 OID 16496)
-- Dependencies: 176 2636
-- Data for Name: authorities_form_datafields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_form_datafields (datafield, collapsed, repeatable, indicator_1, indicator_2, material_type, created, created_by, modified, modified_by) FROM stdin;
100	f	f	0,1,2,3		100	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
110	f	f	0,1,2		110	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
111	f	f	0,1,2		111	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
400	f	t			100	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
410	f	t			110	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
411	f	t			111	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
670	f	t			100,110,111	2014-02-08 15:21:25.813358	\N	2014-02-08 15:21:25.813358	\N
\.


--
-- TOC entry 2557 (class 0 OID 16506)
-- Dependencies: 177 2636
-- Data for Name: authorities_form_subfields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_form_subfields (datafield, subfield, collapsed, repeatable, created, created_by, modified, modified_by, autocomplete_type) FROM stdin;
100	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
100	b	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
100	c	f	t	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
100	d	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
100	q	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
400	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
670	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
670	b	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	c	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	d	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	e	f	t	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	g	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	k	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
111	n	f	t	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
411	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
110	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
110	b	f	t	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
110	c	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
110	d	f	t	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
110	l	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
110	n	f	t	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
410	a	f	f	2014-02-08 15:26:31.667337	\N	2014-02-08 15:26:31.667337	\N	disabled
\.


--
-- TOC entry 2558 (class 0 OID 16517)
-- Dependencies: 178 2636
-- Data for Name: authorities_idx_autocomplete; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_idx_autocomplete (id, datafield, subfield, word, phrase, record_id) FROM stdin;
\.


--
-- TOC entry 2674 (class 0 OID 0)
-- Dependencies: 179
-- Name: authorities_idx_autocomplete_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('authorities_idx_autocomplete_id_seq', 1, false);


--
-- TOC entry 2560 (class 0 OID 16525)
-- Dependencies: 180 2636
-- Data for Name: authorities_idx_fields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_idx_fields (record_id, indexing_group_id, word, datafield) FROM stdin;
\.


--
-- TOC entry 2561 (class 0 OID 16531)
-- Dependencies: 181 2636
-- Data for Name: authorities_idx_sort; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_idx_sort (record_id, indexing_group_id, phrase, ignore_chars_count) FROM stdin;
\.


--
-- TOC entry 2562 (class 0 OID 16537)
-- Dependencies: 182 2636
-- Data for Name: authorities_indexing_groups; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_indexing_groups (id, translation_key, datafields, sortable, default_sort, created, created_by, modified, modified_by) FROM stdin;
0	all	\N	f	f	2014-03-04 11:09:07.241	\N	2014-03-04 11:09:07.241	\N
1	author	100_a	t	t	2014-03-04 11:13:31.512	\N	2014-03-04 11:13:31.512	\N
2	entity	110_a	t	f	2014-03-04 11:13:46.059	\N	2014-03-04 11:13:46.059	\N
3	event	111_a	t	f	2014-03-04 11:14:39.973	\N	2014-03-04 11:14:39.973	\N
4	other_name	400_a, 410_a, 411_a	t	f	2014-03-04 11:14:55.617	\N	2014-03-04 11:14:55.617	\N
\.


--
-- TOC entry 2675 (class 0 OID 0)
-- Dependencies: 183
-- Name: authorities_indexing_groups_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('authorities_indexing_groups_id_seq', 5, false);


--
-- TOC entry 2564 (class 0 OID 16549)
-- Dependencies: 184 2636
-- Data for Name: authorities_records; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_records (id, iso2709, material, database, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2676 (class 0 OID 0)
-- Dependencies: 185
-- Name: authorities_records_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('authorities_records_id_seq', 1, false);


--
-- TOC entry 2566 (class 0 OID 16560)
-- Dependencies: 186 2636
-- Data for Name: authorities_search_results; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_search_results (search_id, indexing_group_id, record_id) FROM stdin;
\.


--
-- TOC entry 2567 (class 0 OID 16563)
-- Dependencies: 187 2636
-- Data for Name: authorities_searches; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY authorities_searches (id, parameters, created, created_by) FROM stdin;
\.


--
-- TOC entry 2677 (class 0 OID 0)
-- Dependencies: 188
-- Name: authorities_searches_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('authorities_searches_id_seq', 1, false);


--
-- TOC entry 2569 (class 0 OID 16572)
-- Dependencies: 189 2636
-- Data for Name: backups; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY backups (id, created, path, schemas, type, scope, downloaded, steps, current_step) FROM stdin;
\.


--
-- TOC entry 2678 (class 0 OID 0)
-- Dependencies: 190
-- Name: backups_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('backups_id_seq', 1, false);


--
-- TOC entry 2571 (class 0 OID 16582)
-- Dependencies: 191 2636
-- Data for Name: biblio_brief_formats; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_brief_formats (datafield, format, sort_order, created, created_by, modified, modified_by) FROM stdin;
260	${a}_{: }${b}_{, }${c}	20	2014-02-01 12:04:44.576993	\N	2014-02-01 12:04:44.576993	\N
650	${a}_{ - }${x}_{ - }${y}_{ - }${z}	41	2014-02-01 12:06:20.547937	\N	2014-02-01 12:06:20.547937	\N
651	${a}_{ - }${x}_{ - }${y}_{ - }${z}	42	2014-02-01 12:06:27.116236	\N	2014-02-01 12:06:27.116236	\N
699	${a}_{ - }${x}_{ - }${y}_{ - }${z}	43	2014-02-01 12:06:34.276548	\N	2014-02-01 12:06:34.276548	\N
306	${a}	25	2014-02-01 12:13:07.424794	\N	2014-02-01 12:13:07.424794	\N
520	${a}	27	2014-02-01 12:13:19.273647	\N	2014-02-01 12:13:19.273647	\N
020	${a}	22	2014-02-01 12:04:17.840354	\N	2014-02-01 12:04:17.840354	\N
022	${a}	23	2014-02-01 12:04:24.056557	\N	2014-02-01 12:04:24.056557	\N
024	${a}	24	2014-02-01 12:04:30.936737	\N	2014-02-01 12:04:30.936737	\N
256	${a}	44	2014-02-01 12:15:25.005212	\N	2014-02-01 12:15:25.005212	\N
043	${a}	45	2014-02-01 12:15:33.581457	\N	2014-02-01 12:15:33.581457	\N
045	${a}	46	2014-02-01 12:15:42.981651	\N	2014-02-01 12:15:42.981651	\N
255	${a}	47	2014-02-01 12:15:46.853963	\N	2014-02-01 12:15:46.853963	\N
041	${a}	48	2014-02-01 12:15:50.093832	\N	2014-02-01 12:15:50.093832	\N
090	${a}_{ }${b}_{ }${c}_{ }${d}	49	2014-02-01 12:05:17.018043	\N	2014-02-01 12:05:17.018043	\N
310	${a}	50	2014-02-01 12:16:08.046403	\N	2014-02-01 12:16:08.046403	\N
362	${a}	51	2014-02-01 12:16:11.822932	\N	2014-02-01 12:16:11.822932	\N
555	${a}	52	2014-02-01 12:16:16.422789	\N	2014-02-01 12:16:16.422789	\N
852	${a}	53	2014-02-01 12:16:20.998809	\N	2014-02-01 12:16:20.998809	\N
400	${a}	5	2014-02-01 12:03:15.21457	\N	2014-02-01 12:03:15.21457	\N
410	${a}	6	2014-02-01 12:03:19.934289	\N	2014-02-01 12:03:19.934289	\N
411	${a}	7	2014-02-01 12:03:27.070922	\N	2014-02-01 12:03:27.070922	\N
243	${a}_{ }${f}	12	2014-02-01 12:09:14.089412	\N	2014-02-01 12:09:14.089412	\N
240	${a}	13	2014-02-01 12:09:24.050018	\N	2014-02-01 12:09:24.050018	\N
730	${a}	14	2014-02-01 12:09:30.866228	\N	2014-02-01 12:09:30.866228	\N
740	${a}_{ }${n}_{ }${p}	15	2014-02-01 12:09:44.610667	\N	2014-02-01 12:09:44.610667	\N
250	${a}	17	2014-02-01 12:10:18.923422	\N	2014-02-01 12:10:18.923422	\N
257	${a}	18	2014-02-01 12:10:36.436278	\N	2014-02-01 12:10:36.436278	\N
258	${a}	19	2014-02-01 12:10:41.228113	\N	2014-02-01 12:10:41.228113	\N
300	${a}_{ }${b}_{ }${c}_{ }${e}	21	2014-02-01 12:12:58.160709	\N	2014-02-01 12:12:58.160709	\N
013	${a}_{; }${b}_{; }${c}_{; }${d}_{; }${e}_{; }${f}	56	2014-02-01 12:18:17.042647	\N	2014-02-01 12:18:17.042647	\N
095	${a}	57	2014-02-01 12:18:25.330589	\N	2014-02-01 12:18:25.330589	\N
500	${a}	28	2014-02-01 12:13:34.913539	\N	2014-02-01 12:13:34.913539	\N
504	${a}	29	2014-02-01 12:13:43.050064	\N	2014-02-01 12:13:43.050064	\N
505	${a}	30	2014-02-01 12:13:49.402136	\N	2014-02-01 12:13:49.402136	\N
521	${a}	31	2014-02-01 12:13:56.762462	\N	2014-02-01 12:13:56.762462	\N
534	${a}	32	2014-02-01 12:14:02.570381	\N	2014-02-01 12:14:02.570381	\N
590	${a}	33	2014-02-01 12:14:06.138512	\N	2014-02-01 12:14:06.138512	\N
502	${a}	34	2014-02-01 12:14:11.876239	\N	2014-02-01 12:14:11.876239	\N
506	${a}	35	2014-02-01 12:14:17.131068	\N	2014-02-01 12:14:17.131068	\N
876	${h}	36	2014-02-01 12:14:30.355534	\N	2014-02-01 12:14:30.355534	\N
080	${a}_{ }${2}	54	2014-02-01 12:16:38.015323	\N	2014-02-01 12:16:38.015323	\N
082	${a}_{ }${2}	55	2014-02-01 12:17:24.376916	\N	2014-02-01 12:17:24.376916	\N
501	${a}	28	2016-06-04 19:36:53.393	\N	2016-06-04 19:36:53.393	\N
530	${a}	31	2016-06-04 19:36:53.393	\N	2016-06-04 19:36:53.393	\N
595	${a}	33	2016-06-04 19:36:53.393	\N	2016-06-04 19:36:53.393	\N
245	${a}_{: }${b}_{ / }${c}	11	2013-05-11 14:09:53.242277	\N	2013-05-11 14:09:53.242277	\N
100	${a}_{ - }${d}_{ }(${q})	1	2013-05-11 14:09:22.681914	\N	2013-05-11 14:09:22.681914	\N
110	${a}_{. }${b. }_{ }(${n}_{ : }${d}_{ : }${c})	2	2013-05-11 14:09:28.849574	\N	2013-05-11 14:09:28.849574	\N
111	${a}_{. }(${n}_{ : }${d}_{ : }${c})	3	2013-05-11 14:09:33.10575	\N	2013-05-11 14:09:33.10575	\N
130	${a}_{. }${l}_{. }${f}	4	2014-02-01 11:43:41.882279	\N	2014-02-01 11:43:41.882279	\N
600	${a}_{. }${b}_{. }${c}_{. }${d}_{ - }${x}_{ - }${y}_{ - }${z}	37	2014-02-01 12:05:47.099015	\N	2014-02-01 12:05:47.099015	\N
610	${a}_{. }${b}_{ - }${x}_{ - }${y}_{ - }${z}	38	2014-02-01 12:05:55.971671	\N	2014-02-01 12:05:55.971671	\N
611	${a}_{. }${b. }_{ }(${n}_{ : }${d}_{ : }${c})_{ - }${x}_{ - }${y}_{ - }${z}	39	2014-02-01 12:06:02.963596	\N	2014-02-01 12:06:02.963596	\N
700	${a}_{. }${d}	8	2014-02-01 11:44:15.995588	\N	2014-02-01 11:44:15.995588	\N
710	${a}_{. }${b. }_{ }(${n}_{ : }${d}_{ : }${c})	9	2014-02-01 11:44:21.019794	\N	2014-02-01 11:44:21.019794	\N
711	${a}_{. }${b. }_{ }(${n}_{ : }${d}_{ : }${c})	10	2014-02-01 11:44:27.579924	\N	2014-02-01 11:44:27.579924	\N
630	${a}_{. }(${d})	40	2014-02-01 12:06:13.363821	\N	2014-02-01 12:06:13.363821	\N
490	(${a}_{ ; }${v})	26	2014-02-01 12:13:12.984999	\N	2014-02-01 12:13:12.984999	\N
830	${a}_{. }${p}_{ ; }${v}	16	2014-02-01 12:09:56.027131	\N	2014-02-01 12:09:56.027131	\N
\.


--
-- TOC entry 2572 (class 0 OID 16590)
-- Dependencies: 192 2636
-- Data for Name: biblio_form_datafields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_form_datafields (datafield, collapsed, repeatable, indicator_1, indicator_2, material_type, created, created_by, modified, modified_by) FROM stdin;
013	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
020	f	f			book	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
022	f	f			book,periodic,articles	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
029	f	t			score,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
040	f	f			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
045	f	f	_,0,1,2		map	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
080	f	f			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
082	f	f			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
255	f	t			map	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
090	f	f			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
095	f	f			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
100	f	f	1,0,2,3		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
110	f	f	0,1,2		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
111	f	f	0,1,2		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
245	f	f	1,0	0,1,2,3,4,5,6,7,8,9	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
250	f	f			book,thesis	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
256	f	f			computer_legible	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
257	f	f			movie	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
258	f	f			photo	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
260	f	t			book,manuscript,thesis,computer_legible,map,movie,score,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
300	f	f			book,manuscript,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
306	f	t			movie,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
340	f	t			map	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
342	f	t	0,1	0,1,2,3,4,5,6,7,8	map	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
343	f	t			map	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
490	f	t	0,1		book,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
500	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
501	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
502	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
504	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
505	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
520	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
521	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
530	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
534	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
590	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
595	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
600	f	t	0,1,2,3		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
610	f	t	0,1,2		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
611	f	t	0,1,2		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
650	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
651	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
700	f	t	1,0,2,3	_,2	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
710	f	t	0,1,2	_,2	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
711	f	t	0,1,2		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
856	f	t			book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
630	f	t	0,1,2,3,4,5,6,7,8,9		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
730	f	t	0,1,2,3,4,5,6,7,8,9	_,2	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
740	f	t	0,1,2,3,4,5,6,7,8,9	_,2	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
043	f	f			map,periodic	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
830	f	t		0,1,2,3,4,5,6,7,8,9	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
041	f	t	0,1		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
240	f	f	1,0	0,1,2,3,4,5,6,7,8,9	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
243	f	f	1,0	0,1,2,3,4,5,6,7,8,9	book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
130	f	f	0,1,2,3,4,5,6,7,8,9		book,manuscript,pamphlet,thesis,computer_legible,map,movie,score,object_3d,photo,periodic,articles,music,nonmusical_sound	2013-04-13 13:42:03.23405	\N	2013-04-13 13:42:03.23405	\N
210	f	t	0,1	_,0	periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
246	f	t	0,1,2,3	_,0,1,2,3,4,5,6,7,8	periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
310	f	f			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
321	f	f			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
362	f	t	0,1		periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
515	f	t			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
525	f	t			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
550	f	t			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
555	f	t	_,0,8		periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
580	f	t			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
947	f	t			periodic	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N
\.


--
-- TOC entry 2573 (class 0 OID 16600)
-- Dependencies: 193 2636
-- Data for Name: biblio_form_subfields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_form_subfields (datafield, subfield, collapsed, repeatable, created, created_by, modified, modified_by, autocomplete_type) FROM stdin;
013	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
013	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
013	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
013	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
013	e	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
013	f	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
020	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
022	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
029	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
040	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
040	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
041	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
041	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
041	h	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
043	a	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
045	a	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
045	b	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
045	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
080	2	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
080	a	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
082	2	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
082	a	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
090	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
090	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
090	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
095	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	fixed_table
100	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
100	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
100	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
100	q	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
110	b	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
110	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
110	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
110	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
110	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
111	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
111	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
111	e	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
111	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
111	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
111	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
130	p	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	b	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
243	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
243	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
243	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
243	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
245	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
245	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
245	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
245	h	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
245	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
245	p	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
250	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
250	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
255	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
256	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
257	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
258	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
258	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
260	a	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
260	b	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
260	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
243	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	p	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
240	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
260	e	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
260	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
260	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
300	a	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
300	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
300	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
300	e	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
306	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
340	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
340	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
340	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
340	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
340	e	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
342	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
342	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
342	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
342	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
343	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
343	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
490	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
490	v	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
500	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
501	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
502	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
504	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
505	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
520	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
520	u	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
521	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
530	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
534	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
590	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
595	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
595	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	q	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	t	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
600	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	b	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	t	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
610	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	e	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	t	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
611	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	p	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
630	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
650	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
650	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
650	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
651	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
651	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
651	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	b	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	c	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	e	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	q	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
700	t	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	b	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
710	t	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	c	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	e	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
711	t	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	d	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	g	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	k	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	l	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	p	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	x	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	y	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
730	z	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
740	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
740	n	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
740	p	f	t	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
830	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
830	v	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
856	d	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
856	f	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
856	u	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
856	y	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	disabled
210	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
210	b	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	b	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	f	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	g	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	h	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	i	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	n	f	t	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
246	p	f	t	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
310	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
310	b	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
321	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
321	b	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
362	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
362	z	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
515	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
525	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
550	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
555	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
555	b	f	t	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
555	c	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
555	d	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
555	u	f	t	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
555	3	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
580	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	a	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	b	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	c	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	d	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	e	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	f	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	g	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	i	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	j	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	k	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	l	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	m	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	n	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	o	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	p	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	q	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	r	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	s	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	t	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	u	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
947	z	f	f	2014-04-28 19:25:12.931	1	2014-04-28 19:25:12.931	\N	disabled
100	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	authorities
110	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	authorities
111	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	authorities
600	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	vocabulary
610	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	vocabulary
611	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	vocabulary
630	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	vocabulary
650	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	vocabulary
651	a	f	f	2013-04-13 13:43:11.351056	\N	2013-04-13 13:43:11.351056	\N	vocabulary
\.


--
-- TOC entry 2574 (class 0 OID 16611)
-- Dependencies: 194 2636
-- Data for Name: biblio_holdings; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_holdings (id, record_id, iso2709, database, accession_number, location_d, created, created_by, modified, modified_by, material, availability, label_printed) FROM stdin;
\.


--
-- TOC entry 2679 (class 0 OID 0)
-- Dependencies: 195
-- Name: biblio_holdings_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('biblio_holdings_id_seq', 1, false);


--
-- TOC entry 2576 (class 0 OID 16624)
-- Dependencies: 196 2636
-- Data for Name: biblio_idx_autocomplete; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_idx_autocomplete (id, datafield, subfield, word, phrase, record_id) FROM stdin;
2	095	a	1.00.00.00-3	1.00.00.00-3 Ciências Exatas e da Terra	\N
3	095	a	ciencias	1.00.00.00-3 Ciências Exatas e da Terra	\N
4	095	a	exatas	1.00.00.00-3 Ciências Exatas e da Terra	\N
5	095	a	da	1.00.00.00-3 Ciências Exatas e da Terra	\N
6	095	a	terra	1.00.00.00-3 Ciências Exatas e da Terra	\N
7	095	a	1.01.00.00-8	1.01.00.00-8 Matemática	\N
8	095	a	matematica	1.01.00.00-8 Matemática	\N
9	095	a	1.01.01.00-4	1.01.01.00-4 Álgebra	\N
10	095	a	algebra	1.01.01.00-4 Álgebra	\N
11	095	a	1.01.01.01-2	1.01.01.01-2 Conjuntos	\N
12	095	a	conjuntos	1.01.01.01-2 Conjuntos	\N
13	095	a	1.01.01.02-0	1.01.01.02-0 Lógica Matemática	\N
14	095	a	logica	1.01.01.02-0 Lógica Matemática	\N
15	095	a	matematica	1.01.01.02-0 Lógica Matemática	\N
16	095	a	1.01.01.03-9	1.01.01.03-9 Teoria dos Números	\N
17	095	a	teoria	1.01.01.03-9 Teoria dos Números	\N
18	095	a	dos	1.01.01.03-9 Teoria dos Números	\N
19	095	a	numeros	1.01.01.03-9 Teoria dos Números	\N
20	095	a	1.01.01.04-7	1.01.01.04-7 Grupos de Algebra Não-Comutaviva	\N
21	095	a	grupos	1.01.01.04-7 Grupos de Algebra Não-Comutaviva	\N
22	095	a	de	1.01.01.04-7 Grupos de Algebra Não-Comutaviva	\N
23	095	a	algebra	1.01.01.04-7 Grupos de Algebra Não-Comutaviva	\N
24	095	a	nao-comutaviva	1.01.01.04-7 Grupos de Algebra Não-Comutaviva	\N
25	095	a	1.01.01.05-5	1.01.01.05-5 Algebra Comutativa	\N
26	095	a	algebra	1.01.01.05-5 Algebra Comutativa	\N
27	095	a	comutativa	1.01.01.05-5 Algebra Comutativa	\N
28	095	a	1.01.01.06-3	1.01.01.06-3 Geometria Algebrica	\N
29	095	a	geometria	1.01.01.06-3 Geometria Algebrica	\N
30	095	a	algebrica	1.01.01.06-3 Geometria Algebrica	\N
31	095	a	1.01.02.00-0	1.01.02.00-0 Análise	\N
32	095	a	analise	1.01.02.00-0 Análise	\N
33	095	a	1.01.02.01-9	1.01.02.01-9 Análise Complexa	\N
34	095	a	analise	1.01.02.01-9 Análise Complexa	\N
35	095	a	complexa	1.01.02.01-9 Análise Complexa	\N
36	095	a	1.01.02.02-7	1.01.02.02-7 Análise Funcional	\N
37	095	a	analise	1.01.02.02-7 Análise Funcional	\N
38	095	a	funcional	1.01.02.02-7 Análise Funcional	\N
39	095	a	1.01.02.03-5	1.01.02.03-5 Análise Funcional Não-Linear	\N
40	095	a	analise	1.01.02.03-5 Análise Funcional Não-Linear	\N
41	095	a	funcional	1.01.02.03-5 Análise Funcional Não-Linear	\N
42	095	a	nao-linear	1.01.02.03-5 Análise Funcional Não-Linear	\N
43	095	a	1.01.02.04-3	1.01.02.04-3 Equações Diferênciais Ordinárias	\N
44	095	a	equacoes	1.01.02.04-3 Equações Diferênciais Ordinárias	\N
45	095	a	diferenciais	1.01.02.04-3 Equações Diferênciais Ordinárias	\N
46	095	a	ordinarias	1.01.02.04-3 Equações Diferênciais Ordinárias	\N
47	095	a	1.01.02.05-1	1.01.02.05-1 Equações Diferênciais Parciais	\N
48	095	a	equacoes	1.01.02.05-1 Equações Diferênciais Parciais	\N
49	095	a	diferenciais	1.01.02.05-1 Equações Diferênciais Parciais	\N
50	095	a	parciais	1.01.02.05-1 Equações Diferênciais Parciais	\N
51	095	a	1.01.02.06-0	1.01.02.06-0 Equações Diferênciais Funcionais	\N
52	095	a	equacoes	1.01.02.06-0 Equações Diferênciais Funcionais	\N
53	095	a	diferenciais	1.01.02.06-0 Equações Diferênciais Funcionais	\N
54	095	a	funcionais	1.01.02.06-0 Equações Diferênciais Funcionais	\N
55	095	a	1.01.03.00-7	1.01.03.00-7 Geometria e Topologia	\N
56	095	a	geometria	1.01.03.00-7 Geometria e Topologia	\N
57	095	a	topologia	1.01.03.00-7 Geometria e Topologia	\N
58	095	a	1.01.03.01-5	1.01.03.01-5 Geometria Diferêncial	\N
59	095	a	geometria	1.01.03.01-5 Geometria Diferêncial	\N
60	095	a	diferencial	1.01.03.01-5 Geometria Diferêncial	\N
61	095	a	1.01.03.02-3	1.01.03.02-3 Topologia Algébrica	\N
62	095	a	topologia	1.01.03.02-3 Topologia Algébrica	\N
63	095	a	algebrica	1.01.03.02-3 Topologia Algébrica	\N
64	095	a	1.01.03.03-1	1.01.03.03-1 Topologia das Variedades	\N
65	095	a	topologia	1.01.03.03-1 Topologia das Variedades	\N
66	095	a	das	1.01.03.03-1 Topologia das Variedades	\N
67	095	a	variedades	1.01.03.03-1 Topologia das Variedades	\N
68	095	a	1.01.03.04-0	1.01.03.04-0 Sistemas Dinâmicos	\N
69	095	a	sistemas	1.01.03.04-0 Sistemas Dinâmicos	\N
70	095	a	dinamicos	1.01.03.04-0 Sistemas Dinâmicos	\N
71	095	a	1.01.03.05-8	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
72	095	a	teoria	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
73	095	a	das	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
74	095	a	singularidades	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
75	095	a	teoria	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
76	095	a	das	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
77	095	a	catastrofes	1.01.03.05-8 Teoria das Singularidades e Teoria das Catástrofes	\N
78	095	a	1.01.03.06-6	1.01.03.06-6 Teoria das Folheações	\N
79	095	a	teoria	1.01.03.06-6 Teoria das Folheações	\N
80	095	a	das	1.01.03.06-6 Teoria das Folheações	\N
81	095	a	folheacoes	1.01.03.06-6 Teoria das Folheações	\N
82	095	a	1.01.04.00-3	1.01.04.00-3 Matemática Aplicada	\N
83	095	a	matematica	1.01.04.00-3 Matemática Aplicada	\N
84	095	a	aplicada	1.01.04.00-3 Matemática Aplicada	\N
85	095	a	1.01.04.01-1	1.01.04.01-1 Física Matemática	\N
86	095	a	fisica	1.01.04.01-1 Física Matemática	\N
87	095	a	matematica	1.01.04.01-1 Física Matemática	\N
88	095	a	1.01.04.02-0	1.01.04.02-0 Análise Numérica	\N
89	095	a	analise	1.01.04.02-0 Análise Numérica	\N
90	095	a	numerica	1.01.04.02-0 Análise Numérica	\N
91	095	a	1.01.04.03-8	1.01.04.03-8 Matemática Discreta e Combinatoria	\N
92	095	a	matematica	1.01.04.03-8 Matemática Discreta e Combinatoria	\N
93	095	a	discreta	1.01.04.03-8 Matemática Discreta e Combinatoria	\N
94	095	a	combinatoria	1.01.04.03-8 Matemática Discreta e Combinatoria	\N
95	095	a	1.02.00.00-2	1.02.00.00-2 Probabilidade e Estatística	\N
96	095	a	probabilidade	1.02.00.00-2 Probabilidade e Estatística	\N
97	095	a	estatistica	1.02.00.00-2 Probabilidade e Estatística	\N
98	095	a	1.02.01.00-9	1.02.01.00-9 Probabilidade	\N
99	095	a	probabilidade	1.02.01.00-9 Probabilidade	\N
100	095	a	1.02.01.01-7	1.02.01.01-7 Teoria Geral e Fundamentos da Probabilidade	\N
101	095	a	teoria	1.02.01.01-7 Teoria Geral e Fundamentos da Probabilidade	\N
102	095	a	geral	1.02.01.01-7 Teoria Geral e Fundamentos da Probabilidade	\N
103	095	a	fundamentos	1.02.01.01-7 Teoria Geral e Fundamentos da Probabilidade	\N
104	095	a	da	1.02.01.01-7 Teoria Geral e Fundamentos da Probabilidade	\N
105	095	a	probabilidade	1.02.01.01-7 Teoria Geral e Fundamentos da Probabilidade	\N
106	095	a	1.02.01.02-5	1.02.01.02-5 Teoria Geral e Processos Estocásticos	\N
107	095	a	teoria	1.02.01.02-5 Teoria Geral e Processos Estocásticos	\N
108	095	a	geral	1.02.01.02-5 Teoria Geral e Processos Estocásticos	\N
109	095	a	processos	1.02.01.02-5 Teoria Geral e Processos Estocásticos	\N
110	095	a	estocasticos	1.02.01.02-5 Teoria Geral e Processos Estocásticos	\N
111	095	a	1.02.01.03-3	1.02.01.03-3 Teoremas de Limite	\N
112	095	a	teoremas	1.02.01.03-3 Teoremas de Limite	\N
113	095	a	de	1.02.01.03-3 Teoremas de Limite	\N
114	095	a	limite	1.02.01.03-3 Teoremas de Limite	\N
115	095	a	1.02.01.04-1	1.02.01.04-1 Processos Markovianos	\N
116	095	a	processos	1.02.01.04-1 Processos Markovianos	\N
117	095	a	markovianos	1.02.01.04-1 Processos Markovianos	\N
118	095	a	1.02.01.05-0	1.02.01.05-0 Análise Estocástica	\N
119	095	a	analise	1.02.01.05-0 Análise Estocástica	\N
120	095	a	estocastica	1.02.01.05-0 Análise Estocástica	\N
121	095	a	1.02.01.06-8	1.02.01.06-8 Processos Estocásticos Especiais	\N
122	095	a	processos	1.02.01.06-8 Processos Estocásticos Especiais	\N
123	095	a	estocasticos	1.02.01.06-8 Processos Estocásticos Especiais	\N
124	095	a	especiais	1.02.01.06-8 Processos Estocásticos Especiais	\N
125	095	a	1.02.02.00-5	1.02.02.00-5 Estatística	\N
126	095	a	estatistica	1.02.02.00-5 Estatística	\N
127	095	a	1.02.02.01-3	1.02.02.01-3 Fundamentos da Estatística	\N
128	095	a	fundamentos	1.02.02.01-3 Fundamentos da Estatística	\N
129	095	a	da	1.02.02.01-3 Fundamentos da Estatística	\N
130	095	a	estatistica	1.02.02.01-3 Fundamentos da Estatística	\N
131	095	a	1.02.02.02-1	1.02.02.02-1 Inferência Paramétrica	\N
132	095	a	inferencia	1.02.02.02-1 Inferência Paramétrica	\N
133	095	a	parametrica	1.02.02.02-1 Inferência Paramétrica	\N
134	095	a	1.02.02.03-0	1.02.02.03-0 Inferência Nao-Paramétrica	\N
135	095	a	inferencia	1.02.02.03-0 Inferência Nao-Paramétrica	\N
136	095	a	nao-parametrica	1.02.02.03-0 Inferência Nao-Paramétrica	\N
137	095	a	1.02.02.04-8	1.02.02.04-8 Inferência em Processos Estocásticos	\N
138	095	a	inferencia	1.02.02.04-8 Inferência em Processos Estocásticos	\N
139	095	a	em	1.02.02.04-8 Inferência em Processos Estocásticos	\N
140	095	a	processos	1.02.02.04-8 Inferência em Processos Estocásticos	\N
141	095	a	estocasticos	1.02.02.04-8 Inferência em Processos Estocásticos	\N
142	095	a	1.02.02.05-6	1.02.02.05-6 Análise Multivariada	\N
143	095	a	analise	1.02.02.05-6 Análise Multivariada	\N
144	095	a	multivariada	1.02.02.05-6 Análise Multivariada	\N
145	095	a	1.02.02.06-4	1.02.02.06-4 Regressão e Correlação	\N
146	095	a	regressao	1.02.02.06-4 Regressão e Correlação	\N
147	095	a	correlacao	1.02.02.06-4 Regressão e Correlação	\N
148	095	a	1.02.02.07-2	1.02.02.07-2 Planejamento de Experimentos	\N
149	095	a	planejamento	1.02.02.07-2 Planejamento de Experimentos	\N
150	095	a	de	1.02.02.07-2 Planejamento de Experimentos	\N
151	095	a	experimentos	1.02.02.07-2 Planejamento de Experimentos	\N
152	095	a	1.02.02.08-0	1.02.02.08-0 Análise de Dados	\N
153	095	a	analise	1.02.02.08-0 Análise de Dados	\N
154	095	a	de	1.02.02.08-0 Análise de Dados	\N
155	095	a	dados	1.02.02.08-0 Análise de Dados	\N
156	095	a	1.02.03.00-1	1.02.03.00-1 Probabilidade e Estatística Aplicadas	\N
157	095	a	probabilidade	1.02.03.00-1 Probabilidade e Estatística Aplicadas	\N
158	095	a	estatistica	1.02.03.00-1 Probabilidade e Estatística Aplicadas	\N
159	095	a	aplicadas	1.02.03.00-1 Probabilidade e Estatística Aplicadas	\N
160	095	a	1.03.00.00-7	1.03.00.00-7 Ciência da Computação	\N
161	095	a	ciencia	1.03.00.00-7 Ciência da Computação	\N
162	095	a	da	1.03.00.00-7 Ciência da Computação	\N
163	095	a	computacao	1.03.00.00-7 Ciência da Computação	\N
164	095	a	1.03.01.00-3	1.03.01.00-3 Teoria da Computação	\N
165	095	a	teoria	1.03.01.00-3 Teoria da Computação	\N
166	095	a	da	1.03.01.00-3 Teoria da Computação	\N
167	095	a	computacao	1.03.01.00-3 Teoria da Computação	\N
168	095	a	1.03.01.01-1	1.03.01.01-1 Computabilidade e Modelos de Computação	\N
169	095	a	computabilidade	1.03.01.01-1 Computabilidade e Modelos de Computação	\N
170	095	a	modelos	1.03.01.01-1 Computabilidade e Modelos de Computação	\N
171	095	a	de	1.03.01.01-1 Computabilidade e Modelos de Computação	\N
172	095	a	computacao	1.03.01.01-1 Computabilidade e Modelos de Computação	\N
173	095	a	1.03.01.02-0	1.03.01.02-0 Linguagem Formais e Automatos	\N
174	095	a	linguagem	1.03.01.02-0 Linguagem Formais e Automatos	\N
175	095	a	formais	1.03.01.02-0 Linguagem Formais e Automatos	\N
176	095	a	automatos	1.03.01.02-0 Linguagem Formais e Automatos	\N
177	095	a	1.03.01.03-8	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
178	095	a	analise	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
179	095	a	de	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
180	095	a	algoritmos	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
181	095	a	complexidade	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
182	095	a	de	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
183	095	a	computacao	1.03.01.03-8 Análise de Algoritmos e Complexidade de Computação	\N
184	095	a	1.03.01.04-6	1.03.01.04-6 Lógicas e Semântica de Programas	\N
185	095	a	logicas	1.03.01.04-6 Lógicas e Semântica de Programas	\N
186	095	a	semantica	1.03.01.04-6 Lógicas e Semântica de Programas	\N
187	095	a	de	1.03.01.04-6 Lógicas e Semântica de Programas	\N
188	095	a	programas	1.03.01.04-6 Lógicas e Semântica de Programas	\N
189	095	a	1.03.02.00-0	1.03.02.00-0 Matemática da Computação	\N
190	095	a	matematica	1.03.02.00-0 Matemática da Computação	\N
191	095	a	da	1.03.02.00-0 Matemática da Computação	\N
192	095	a	computacao	1.03.02.00-0 Matemática da Computação	\N
193	095	a	1.03.02.01-8	1.03.02.01-8 Matemática Simbólica	\N
194	095	a	matematica	1.03.02.01-8 Matemática Simbólica	\N
195	095	a	simbolica	1.03.02.01-8 Matemática Simbólica	\N
196	095	a	1.03.02.02-6	1.03.02.02-6 Modelos Analíticos e de Simulação	\N
197	095	a	modelos	1.03.02.02-6 Modelos Analíticos e de Simulação	\N
198	095	a	analiticos	1.03.02.02-6 Modelos Analíticos e de Simulação	\N
199	095	a	de	1.03.02.02-6 Modelos Analíticos e de Simulação	\N
200	095	a	simulacao	1.03.02.02-6 Modelos Analíticos e de Simulação	\N
201	095	a	1.03.03.00-6	1.03.03.00-6 Metodologia e Técnicas da Computação	\N
202	095	a	metodologia	1.03.03.00-6 Metodologia e Técnicas da Computação	\N
203	095	a	tecnicas	1.03.03.00-6 Metodologia e Técnicas da Computação	\N
204	095	a	da	1.03.03.00-6 Metodologia e Técnicas da Computação	\N
205	095	a	computacao	1.03.03.00-6 Metodologia e Técnicas da Computação	\N
206	095	a	1.03.03.01-4	1.03.03.01-4 Linguagens de Programação	\N
207	095	a	linguagens	1.03.03.01-4 Linguagens de Programação	\N
208	095	a	de	1.03.03.01-4 Linguagens de Programação	\N
209	095	a	programacao	1.03.03.01-4 Linguagens de Programação	\N
210	095	a	1.03.03.02-2	1.03.03.02-2 Engenharia de Software	\N
211	095	a	engenharia	1.03.03.02-2 Engenharia de Software	\N
212	095	a	de	1.03.03.02-2 Engenharia de Software	\N
213	095	a	software	1.03.03.02-2 Engenharia de Software	\N
214	095	a	1.03.03.03-0	1.03.03.03-0 Banco de Dados	\N
215	095	a	banco	1.03.03.03-0 Banco de Dados	\N
216	095	a	de	1.03.03.03-0 Banco de Dados	\N
217	095	a	dados	1.03.03.03-0 Banco de Dados	\N
218	095	a	1.03.03.04-9	1.03.03.04-9 Sistemas de Informação	\N
219	095	a	sistemas	1.03.03.04-9 Sistemas de Informação	\N
220	095	a	de	1.03.03.04-9 Sistemas de Informação	\N
221	095	a	informacao	1.03.03.04-9 Sistemas de Informação	\N
222	095	a	1.03.03.05-7	1.03.03.05-7 Processamento Gráfico (Graphics)	\N
223	095	a	processamento	1.03.03.05-7 Processamento Gráfico (Graphics)	\N
224	095	a	grafico	1.03.03.05-7 Processamento Gráfico (Graphics)	\N
225	095	a	(graphics)	1.03.03.05-7 Processamento Gráfico (Graphics)	\N
226	095	a	1.03.04.00-2	1.03.04.00-2 Sistemas de Computação	\N
227	095	a	sistemas	1.03.04.00-2 Sistemas de Computação	\N
228	095	a	de	1.03.04.00-2 Sistemas de Computação	\N
229	095	a	computacao	1.03.04.00-2 Sistemas de Computação	\N
230	095	a	1.03.04.01-0	1.03.04.01-0 Hardware	\N
231	095	a	hardware	1.03.04.01-0 Hardware	\N
232	095	a	1.03.04.02-9	1.03.04.02-9 Arquitetura de Sistemas de Computação	\N
233	095	a	arquitetura	1.03.04.02-9 Arquitetura de Sistemas de Computação	\N
234	095	a	de	1.03.04.02-9 Arquitetura de Sistemas de Computação	\N
235	095	a	sistemas	1.03.04.02-9 Arquitetura de Sistemas de Computação	\N
236	095	a	de	1.03.04.02-9 Arquitetura de Sistemas de Computação	\N
237	095	a	computacao	1.03.04.02-9 Arquitetura de Sistemas de Computação	\N
238	095	a	1.03.04.03-7	1.03.04.03-7 Software Básico	\N
239	095	a	software	1.03.04.03-7 Software Básico	\N
240	095	a	basico	1.03.04.03-7 Software Básico	\N
241	095	a	1.03.04.04-5	1.03.04.04-5 Teleinformática	\N
242	095	a	teleinformatica	1.03.04.04-5 Teleinformática	\N
243	095	a	1.04.00.00-1	1.04.00.00-1 Astronomia	\N
244	095	a	astronomia	1.04.00.00-1 Astronomia	\N
245	095	a	1.04.01.00-8	1.04.01.00-8 Astronomia de Posição e Mecânica Celeste	\N
246	095	a	astronomia	1.04.01.00-8 Astronomia de Posição e Mecânica Celeste	\N
247	095	a	de	1.04.01.00-8 Astronomia de Posição e Mecânica Celeste	\N
248	095	a	posicao	1.04.01.00-8 Astronomia de Posição e Mecânica Celeste	\N
249	095	a	mecanica	1.04.01.00-8 Astronomia de Posição e Mecânica Celeste	\N
250	095	a	celeste	1.04.01.00-8 Astronomia de Posição e Mecânica Celeste	\N
251	095	a	1.04.01.01-6	1.04.01.01-6 Astronomia Fundamental	\N
252	095	a	astronomia	1.04.01.01-6 Astronomia Fundamental	\N
253	095	a	fundamental	1.04.01.01-6 Astronomia Fundamental	\N
254	095	a	1.04.01.02-4	1.04.01.02-4 Astronomia Dinâmica	\N
255	095	a	astronomia	1.04.01.02-4 Astronomia Dinâmica	\N
256	095	a	dinamica	1.04.01.02-4 Astronomia Dinâmica	\N
257	095	a	1.04.02.00-4	1.04.02.00-4 Astrofísica Estelar	\N
258	095	a	astrofisica	1.04.02.00-4 Astrofísica Estelar	\N
259	095	a	estelar	1.04.02.00-4 Astrofísica Estelar	\N
260	095	a	1.04.03.00-0	1.04.03.00-0 Astrofísica do Meio Interestelar	\N
261	095	a	astrofisica	1.04.03.00-0 Astrofísica do Meio Interestelar	\N
262	095	a	do	1.04.03.00-0 Astrofísica do Meio Interestelar	\N
263	095	a	meio	1.04.03.00-0 Astrofísica do Meio Interestelar	\N
264	095	a	interestelar	1.04.03.00-0 Astrofísica do Meio Interestelar	\N
265	095	a	1.04.03.01-9	1.04.03.01-9 Meio Interestelar	\N
266	095	a	meio	1.04.03.01-9 Meio Interestelar	\N
267	095	a	interestelar	1.04.03.01-9 Meio Interestelar	\N
268	095	a	1.04.03.02-7	1.04.03.02-7 Nebulosa	\N
269	095	a	nebulosa	1.04.03.02-7 Nebulosa	\N
270	095	a	1.04.04.00-7	1.04.04.00-7 Astrofísica Extragaláctica	\N
271	095	a	astrofisica	1.04.04.00-7 Astrofísica Extragaláctica	\N
272	095	a	extragalactica	1.04.04.00-7 Astrofísica Extragaláctica	\N
273	095	a	1.04.04.01-5	1.04.04.01-5 Galáxias	\N
274	095	a	galaxias	1.04.04.01-5 Galáxias	\N
275	095	a	1.04.04.02-3	1.04.04.02-3 Aglomerados de Galáxias	\N
276	095	a	aglomerados	1.04.04.02-3 Aglomerados de Galáxias	\N
277	095	a	de	1.04.04.02-3 Aglomerados de Galáxias	\N
278	095	a	galaxias	1.04.04.02-3 Aglomerados de Galáxias	\N
279	095	a	1.04.04.03-1	1.04.04.03-1 Quasares	\N
280	095	a	quasares	1.04.04.03-1 Quasares	\N
281	095	a	1.04.04.04-0	1.04.04.04-0 Cosmologia	\N
282	095	a	cosmologia	1.04.04.04-0 Cosmologia	\N
283	095	a	1.04.05.00-3	1.04.05.00-3 Astrofísica do Sistema Solar	\N
284	095	a	astrofisica	1.04.05.00-3 Astrofísica do Sistema Solar	\N
285	095	a	do	1.04.05.00-3 Astrofísica do Sistema Solar	\N
286	095	a	sistema	1.04.05.00-3 Astrofísica do Sistema Solar	\N
287	095	a	solar	1.04.05.00-3 Astrofísica do Sistema Solar	\N
288	095	a	1.04.05.01-1	1.04.05.01-1 Física Solar	\N
289	095	a	fisica	1.04.05.01-1 Física Solar	\N
290	095	a	solar	1.04.05.01-1 Física Solar	\N
291	095	a	1.04.05.02-0	1.04.05.02-0 Movimento da Terra	\N
292	095	a	movimento	1.04.05.02-0 Movimento da Terra	\N
293	095	a	da	1.04.05.02-0 Movimento da Terra	\N
294	095	a	terra	1.04.05.02-0 Movimento da Terra	\N
295	095	a	1.04.05.03-8	1.04.05.03-8 Sistema Planetário	\N
296	095	a	sistema	1.04.05.03-8 Sistema Planetário	\N
297	095	a	planetario	1.04.05.03-8 Sistema Planetário	\N
298	095	a	1.04.06.00-0	1.04.06.00-0 Instrumentação Astronômica	\N
299	095	a	instrumentacao	1.04.06.00-0 Instrumentação Astronômica	\N
300	095	a	astronomica	1.04.06.00-0 Instrumentação Astronômica	\N
301	095	a	1.04.06.01-8	1.04.06.01-8 Astronômia Ótica	\N
302	095	a	astronomia	1.04.06.01-8 Astronômia Ótica	\N
303	095	a	otica	1.04.06.01-8 Astronômia Ótica	\N
304	095	a	1.04.06.02-6	1.04.06.02-6 Radioastronomia	\N
305	095	a	radioastronomia	1.04.06.02-6 Radioastronomia	\N
306	095	a	1.04.06.03-4	1.04.06.03-4 Astronomia Espacial	\N
307	095	a	astronomia	1.04.06.03-4 Astronomia Espacial	\N
308	095	a	espacial	1.04.06.03-4 Astronomia Espacial	\N
309	095	a	1.04.06.04-2	1.04.06.04-2 Processamento de Dados Astronômicos	\N
310	095	a	processamento	1.04.06.04-2 Processamento de Dados Astronômicos	\N
311	095	a	de	1.04.06.04-2 Processamento de Dados Astronômicos	\N
312	095	a	dados	1.04.06.04-2 Processamento de Dados Astronômicos	\N
313	095	a	astronomicos	1.04.06.04-2 Processamento de Dados Astronômicos	\N
314	095	a	1.05.00.00-6	1.05.00.00-6 Física	\N
315	095	a	fisica	1.05.00.00-6 Física	\N
316	095	a	1.05.01.00-2	1.05.01.00-2 Física Geral	\N
317	095	a	fisica	1.05.01.00-2 Física Geral	\N
318	095	a	geral	1.05.01.00-2 Física Geral	\N
319	095	a	1.05.01.01-0	1.05.01.01-0 Métodos Matemáticos da Física	\N
320	095	a	metodos	1.05.01.01-0 Métodos Matemáticos da Física	\N
321	095	a	matematicos	1.05.01.01-0 Métodos Matemáticos da Física	\N
322	095	a	da	1.05.01.01-0 Métodos Matemáticos da Física	\N
323	095	a	fisica	1.05.01.01-0 Métodos Matemáticos da Física	\N
324	095	a	1.05.01.02-9	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
325	095	a	fisica	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
326	095	a	classica	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
327	095	a	fisica	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
328	095	a	quantica;	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
329	095	a	mecanica	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
330	095	a	campos	1.05.01.02-9 Física Clássica e Física Quântica; Mecânica e Campos	\N
331	095	a	1.05.01.03-7	1.05.01.03-7 Relatividade e Gravitação	\N
332	095	a	relatividade	1.05.01.03-7 Relatividade e Gravitação	\N
333	095	a	gravitacao	1.05.01.03-7 Relatividade e Gravitação	\N
334	095	a	1.05.01.04-5	1.05.01.04-5 Física Estatística e Termodinâmica	\N
335	095	a	fisica	1.05.01.04-5 Física Estatística e Termodinâmica	\N
336	095	a	estatistica	1.05.01.04-5 Física Estatística e Termodinâmica	\N
337	095	a	termodinamica	1.05.01.04-5 Física Estatística e Termodinâmica	\N
338	095	a	1.05.01.05-3	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
339	095	a	metrologia,	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
340	095	a	tecnicas	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
341	095	a	gerais	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
342	095	a	de	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
343	095	a	laboratorio,	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
344	095	a	sistema	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
345	095	a	de	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
346	095	a	instrumentacao	1.05.01.05-3 Metrologia, Técnicas Gerais de Laboratório, Sistema de Instrumentação	\N
347	095	a	1.05.01.06-1	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
348	095	a	instrumentacao	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
349	095	a	especifica	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
350	095	a	de	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
351	095	a	uso	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
352	095	a	geral	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
353	095	a	em	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
354	095	a	fisica	1.05.01.06-1 Instrumentação Específica de Uso Geral em Física	\N
355	095	a	1.05.02.00-9	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
356	095	a	areas	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
357	095	a	classicas	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
358	095	a	de	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
359	095	a	fenomenologia	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
360	095	a	suas	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
361	095	a	aplicacoes	1.05.02.00-9 Áreas Clássicas de Fenomenologia e suas Aplicações	\N
362	095	a	1.05.02.01-7	1.05.02.01-7 Eletricidade e Magnetismo; Campos e Partículas Carregadas	\N
363	095	a	eletricidade	1.05.02.01-7 Eletricidade e Magnetismo; Campos e Partículas Carregadas	\N
364	095	a	magnetismo;	1.05.02.01-7 Eletricidade e Magnetismo; Campos e Partículas Carregadas	\N
365	095	a	campos	1.05.02.01-7 Eletricidade e Magnetismo; Campos e Partículas Carregadas	\N
366	095	a	particulas	1.05.02.01-7 Eletricidade e Magnetismo; Campos e Partículas Carregadas	\N
367	095	a	carregadas	1.05.02.01-7 Eletricidade e Magnetismo; Campos e Partículas Carregadas	\N
368	095	a	1.05.02.02-5	1.05.02.02-5 Ótica	\N
369	095	a	otica	1.05.02.02-5 Ótica	\N
370	095	a	1.05.02.03-3	1.05.02.03-3 Acústica	\N
371	095	a	acustica	1.05.02.03-3 Acústica	\N
372	095	a	1.05.02.04-1	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
373	095	a	transferencia	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
374	095	a	de	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
375	095	a	calor;	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
376	095	a	processos	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
377	095	a	termicos	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
378	095	a	termodinamicos	1.05.02.04-1 Transferência de Calor; Processos Térmicos e Termodinâmicos	\N
379	095	a	1.05.02.05-0	1.05.02.05-0 Mecânica, Elasticidade e Reologia	\N
380	095	a	mecanica,	1.05.02.05-0 Mecânica, Elasticidade e Reologia	\N
381	095	a	elasticidade	1.05.02.05-0 Mecânica, Elasticidade e Reologia	\N
382	095	a	reologia	1.05.02.05-0 Mecânica, Elasticidade e Reologia	\N
383	095	a	1.05.02.06-8	1.05.02.06-8 Dinâmica dos Fluidos	\N
384	095	a	dinamica	1.05.02.06-8 Dinâmica dos Fluidos	\N
385	095	a	dos	1.05.02.06-8 Dinâmica dos Fluidos	\N
386	095	a	fluidos	1.05.02.06-8 Dinâmica dos Fluidos	\N
387	095	a	1.05.03.00-5	1.05.03.00-5 Física das Partículas Elementares e Campos	\N
388	095	a	fisica	1.05.03.00-5 Física das Partículas Elementares e Campos	\N
389	095	a	das	1.05.03.00-5 Física das Partículas Elementares e Campos	\N
390	095	a	particulas	1.05.03.00-5 Física das Partículas Elementares e Campos	\N
391	095	a	elementares	1.05.03.00-5 Física das Partículas Elementares e Campos	\N
392	095	a	campos	1.05.03.00-5 Física das Partículas Elementares e Campos	\N
393	095	a	1.05.03.01-3	1.05.03.01-3 Teoria Geral de Partículas e Campos	\N
394	095	a	teoria	1.05.03.01-3 Teoria Geral de Partículas e Campos	\N
395	095	a	geral	1.05.03.01-3 Teoria Geral de Partículas e Campos	\N
396	095	a	de	1.05.03.01-3 Teoria Geral de Partículas e Campos	\N
397	095	a	particulas	1.05.03.01-3 Teoria Geral de Partículas e Campos	\N
398	095	a	campos	1.05.03.01-3 Teoria Geral de Partículas e Campos	\N
399	095	a	1.05.03.02-1	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
400	095	a	teorias	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
401	095	a	especificas	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
402	095	a	modelos	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
403	095	a	de	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
404	095	a	interacao;	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
405	095	a	sistematica	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
406	095	a	de	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
407	095	a	particulas;	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
408	095	a	raios	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
409	095	a	cosmicos	1.05.03.02-1 Teorias Específicas e Modelos de Interação; Sistematica de Partículas; Raios Cósmicos	\N
410	095	a	1.05.03.03-0	1.05.03.03-0 Reações Específicas e Fenomiologia de Partículas	\N
411	095	a	reacoes	1.05.03.03-0 Reações Específicas e Fenomiologia de Partículas	\N
412	095	a	especificas	1.05.03.03-0 Reações Específicas e Fenomiologia de Partículas	\N
413	095	a	fenomiologia	1.05.03.03-0 Reações Específicas e Fenomiologia de Partículas	\N
414	095	a	de	1.05.03.03-0 Reações Específicas e Fenomiologia de Partículas	\N
415	095	a	particulas	1.05.03.03-0 Reações Específicas e Fenomiologia de Partículas	\N
416	095	a	1.05.03.04-8	1.05.03.04-8 Propriedades de Partículas Específicas e Ressonâncias	\N
417	095	a	propriedades	1.05.03.04-8 Propriedades de Partículas Específicas e Ressonâncias	\N
418	095	a	de	1.05.03.04-8 Propriedades de Partículas Específicas e Ressonâncias	\N
419	095	a	particulas	1.05.03.04-8 Propriedades de Partículas Específicas e Ressonâncias	\N
420	095	a	especificas	1.05.03.04-8 Propriedades de Partículas Específicas e Ressonâncias	\N
421	095	a	ressonancias	1.05.03.04-8 Propriedades de Partículas Específicas e Ressonâncias	\N
422	095	a	1.05.04.00-1	1.05.04.00-1 Física Nuclear	\N
423	095	a	fisica	1.05.04.00-1 Física Nuclear	\N
424	095	a	nuclear	1.05.04.00-1 Física Nuclear	\N
425	095	a	1.05.04.01-0	1.05.04.01-0 Estrutura Nuclear	\N
426	095	a	estrutura	1.05.04.01-0 Estrutura Nuclear	\N
427	095	a	nuclear	1.05.04.01-0 Estrutura Nuclear	\N
428	095	a	1.05.04.02-8	1.05.04.02-8 Desintegração Nuclear e Radioatividade	\N
429	095	a	desintegracao	1.05.04.02-8 Desintegração Nuclear e Radioatividade	\N
430	095	a	nuclear	1.05.04.02-8 Desintegração Nuclear e Radioatividade	\N
431	095	a	radioatividade	1.05.04.02-8 Desintegração Nuclear e Radioatividade	\N
432	095	a	1.05.04.03-6	1.05.04.03-6 Reações Nucleares e Espalhamento Geral	\N
433	095	a	reacoes	1.05.04.03-6 Reações Nucleares e Espalhamento Geral	\N
434	095	a	nucleares	1.05.04.03-6 Reações Nucleares e Espalhamento Geral	\N
435	095	a	espalhamento	1.05.04.03-6 Reações Nucleares e Espalhamento Geral	\N
436	095	a	geral	1.05.04.03-6 Reações Nucleares e Espalhamento Geral	\N
437	095	a	1.05.04.04-4	1.05.04.04-4 Reações Nucleares e Espalhamento (Reações Específicas)	\N
438	095	a	reacoes	1.05.04.04-4 Reações Nucleares e Espalhamento (Reações Específicas)	\N
439	095	a	nucleares	1.05.04.04-4 Reações Nucleares e Espalhamento (Reações Específicas)	\N
440	095	a	espalhamento	1.05.04.04-4 Reações Nucleares e Espalhamento (Reações Específicas)	\N
441	095	a	(reacoes	1.05.04.04-4 Reações Nucleares e Espalhamento (Reações Específicas)	\N
442	095	a	especificas)	1.05.04.04-4 Reações Nucleares e Espalhamento (Reações Específicas)	\N
443	095	a	1.05.04.05-2	1.05.04.05-2 Propriedades de Núcleos Específicos	\N
444	095	a	propriedades	1.05.04.05-2 Propriedades de Núcleos Específicos	\N
445	095	a	de	1.05.04.05-2 Propriedades de Núcleos Específicos	\N
446	095	a	nucleos	1.05.04.05-2 Propriedades de Núcleos Específicos	\N
447	095	a	especificos	1.05.04.05-2 Propriedades de Núcleos Específicos	\N
448	095	a	1.05.04.06-0	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
449	095	a	metodos	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
450	095	a	experimentais	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
451	095	a	instrumentacao	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
452	095	a	para	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
453	095	a	particulas	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
454	095	a	elementares	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
455	095	a	fisica	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
456	095	a	nuclear	1.05.04.06-0 Métodos Experimentais e Instrumentação para Partículas Elementares e Física Nuclear	\N
457	095	a	1.05.05.00-8	1.05.05.00-8 Física Atômica e Molécular	\N
458	095	a	fisica	1.05.05.00-8 Física Atômica e Molécular	\N
459	095	a	atomica	1.05.05.00-8 Física Atômica e Molécular	\N
460	095	a	molecular	1.05.05.00-8 Física Atômica e Molécular	\N
461	095	a	1.05.05.01-6	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
462	095	a	estrutura	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
463	095	a	eletronica	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
464	095	a	de	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
465	095	a	atomos	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
466	095	a	moleculas;	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
467	095	a	teoria	1.05.05.01-6 Estrutura Eletrônica de Átomos e Moléculas; Teoria	\N
468	095	a	1.05.05.02-4	1.05.05.02-4 Espectros Atômicos e Integração de Fótons	\N
469	095	a	espectros	1.05.05.02-4 Espectros Atômicos e Integração de Fótons	\N
470	095	a	atomicos	1.05.05.02-4 Espectros Atômicos e Integração de Fótons	\N
471	095	a	integracao	1.05.05.02-4 Espectros Atômicos e Integração de Fótons	\N
472	095	a	de	1.05.05.02-4 Espectros Atômicos e Integração de Fótons	\N
473	095	a	fotons	1.05.05.02-4 Espectros Atômicos e Integração de Fótons	\N
474	095	a	1.05.05.03-2	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
475	095	a	espectros	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
476	095	a	moleculares	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
477	095	a	interacoes	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
478	095	a	de	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
479	095	a	fotons	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
480	095	a	com	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
481	095	a	moleculas	1.05.05.03-2 Espectros Moléculares e Interações de Fótons com Moléculas	\N
482	095	a	1.05.05.04-0	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
483	095	a	processos	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
484	095	a	de	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
485	095	a	colisao	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
486	095	a	interacoes	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
487	095	a	de	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
488	095	a	atomos	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
489	095	a	moleculas	1.05.05.04-0 Processos de Colisão e Interações de Átomos e Moléculas	\N
490	095	a	1.05.05.05-9	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
491	095	a	inf.sobre	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
492	095	a	atomos	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
493	095	a	moleculas	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
494	095	a	obtidos	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
495	095	a	experimentalmente;instrumentacao	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
496	095	a	tecnicas	1.05.05.05-9 Inf.Sobre Átomos e Moléculas Obtidos Experimentalmente;Instrumentação e Técnicas	\N
497	095	a	1.05.05.06-7	1.05.05.06-7 Estudos de Átomos e Moléculas Especiais	\N
498	095	a	estudos	1.05.05.06-7 Estudos de Átomos e Moléculas Especiais	\N
499	095	a	de	1.05.05.06-7 Estudos de Átomos e Moléculas Especiais	\N
500	095	a	atomos	1.05.05.06-7 Estudos de Átomos e Moléculas Especiais	\N
501	095	a	moleculas	1.05.05.06-7 Estudos de Átomos e Moléculas Especiais	\N
502	095	a	especiais	1.05.05.06-7 Estudos de Átomos e Moléculas Especiais	\N
503	095	a	1.05.06.00-4	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
504	095	a	fisica	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
505	095	a	dos	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
506	095	a	fluidos,	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
507	095	a	fisica	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
508	095	a	de	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
509	095	a	plasmas	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
510	095	a	descargas	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
511	095	a	eletricas	1.05.06.00-4 Física dos Fluidos, Física de Plasmas e Descargas Elétricas	\N
512	095	a	1.05.06.01-2	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
513	095	a	cinetica	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
514	095	a	teoria	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
515	095	a	de	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
516	095	a	transporte	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
517	095	a	de	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
518	095	a	fluidos;	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
519	095	a	propriedades	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
520	095	a	fisicas	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
521	095	a	de	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
522	095	a	gases	1.05.06.01-2 Cinética e Teoria de Transporte de Fluidos; Propriedades Físicas de Gases	\N
523	095	a	1.05.06.02-0	1.05.06.02-0 Física de Plasmas e Descargas Elétricas	\N
524	095	a	fisica	1.05.06.02-0 Física de Plasmas e Descargas Elétricas	\N
525	095	a	de	1.05.06.02-0 Física de Plasmas e Descargas Elétricas	\N
526	095	a	plasmas	1.05.06.02-0 Física de Plasmas e Descargas Elétricas	\N
527	095	a	descargas	1.05.06.02-0 Física de Plasmas e Descargas Elétricas	\N
528	095	a	eletricas	1.05.06.02-0 Física de Plasmas e Descargas Elétricas	\N
529	095	a	1.05.07.00-0	1.05.07.00-0 Física da Matéria Condensada	\N
530	095	a	fisica	1.05.07.00-0 Física da Matéria Condensada	\N
531	095	a	da	1.05.07.00-0 Física da Matéria Condensada	\N
532	095	a	materia	1.05.07.00-0 Física da Matéria Condensada	\N
533	095	a	condensada	1.05.07.00-0 Física da Matéria Condensada	\N
534	095	a	1.05.07.01-9	1.05.07.01-9 Estrutura de Líquidos e Sólidos; Cristalografia	\N
535	095	a	estrutura	1.05.07.01-9 Estrutura de Líquidos e Sólidos; Cristalografia	\N
536	095	a	de	1.05.07.01-9 Estrutura de Líquidos e Sólidos; Cristalografia	\N
537	095	a	liquidos	1.05.07.01-9 Estrutura de Líquidos e Sólidos; Cristalografia	\N
538	095	a	solidos;	1.05.07.01-9 Estrutura de Líquidos e Sólidos; Cristalografia	\N
539	095	a	cristalografia	1.05.07.01-9 Estrutura de Líquidos e Sólidos; Cristalografia	\N
540	095	a	1.05.07.02-7	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
541	095	a	propriedades	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
542	095	a	mecanicas	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
543	095	a	acusticas	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
544	095	a	da	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
545	095	a	materia	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
546	095	a	condensada	1.05.07.02-7 Propriedades Mecânicas e Acústicas da Matéria Condensada	\N
547	095	a	1.05.07.03-5	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
548	095	a	dinamica	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
549	095	a	da	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
550	095	a	rede	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
551	095	a	estatistica	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
552	095	a	de	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
553	095	a	cristais	1.05.07.03-5 Dinâmica da Rede e Estatística de Cristais	\N
554	095	a	1.05.07.04-3	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
555	095	a	equacao	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
556	095	a	de	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
557	095	a	estado,	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
558	095	a	equilibrio	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
559	095	a	de	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
560	095	a	fases	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
561	095	a	transicoes	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
562	095	a	de	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
563	095	a	fase	1.05.07.04-3 Equação de Estado, Equilíbrio de Fases e Transições de Fase	\N
564	095	a	1.05.07.05-1	1.05.07.05-1 Propriedades Térmicas da Matéria Condensada	\N
565	095	a	propriedades	1.05.07.05-1 Propriedades Térmicas da Matéria Condensada	\N
566	095	a	termicas	1.05.07.05-1 Propriedades Térmicas da Matéria Condensada	\N
567	095	a	da	1.05.07.05-1 Propriedades Térmicas da Matéria Condensada	\N
568	095	a	materia	1.05.07.05-1 Propriedades Térmicas da Matéria Condensada	\N
569	095	a	condensada	1.05.07.05-1 Propriedades Térmicas da Matéria Condensada	\N
570	095	a	1.05.07.06-0	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
571	095	a	propriedades	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
572	095	a	de	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
573	095	a	transportes	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
574	095	a	de	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
575	095	a	materia	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
576	095	a	condensada	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
577	095	a	(nao	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
578	095	a	eletronicas)	1.05.07.06-0 Propriedades de Transportes de Matéria Condensada (Não Eletrônicas)	\N
579	095	a	1.05.07.07-8	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
580	095	a	campos	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
581	095	a	quanticos	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
582	095	a	solidos,	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
583	095	a	helio,	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
584	095	a	liquido,	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
585	095	a	solido	1.05.07.07-8 Campos Quânticos e Sólidos, Hélio, Líquido, Sólido	\N
586	095	a	1.05.07.08-6	1.05.07.08-6 Superfícies e Interfaces; Películas e Filamentos	\N
587	095	a	superficies	1.05.07.08-6 Superfícies e Interfaces; Películas e Filamentos	\N
588	095	a	interfaces;	1.05.07.08-6 Superfícies e Interfaces; Películas e Filamentos	\N
589	095	a	peliculas	1.05.07.08-6 Superfícies e Interfaces; Películas e Filamentos	\N
590	095	a	filamentos	1.05.07.08-6 Superfícies e Interfaces; Películas e Filamentos	\N
591	095	a	1.05.07.09-4	1.05.07.09-4 Estados Eletrônicos	\N
592	095	a	estados	1.05.07.09-4 Estados Eletrônicos	\N
593	095	a	eletronicos	1.05.07.09-4 Estados Eletrônicos	\N
594	095	a	1.05.07.10-8	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
595	095	a	transp.eletronicos	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
596	095	a	prop.	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
597	095	a	eletricas	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
598	095	a	de	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
599	095	a	superficies;	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
600	095	a	interfaces	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
601	095	a	peliculas	1.05.07.10-8 Transp.Eletrônicos e Prop. Elétricas de Superfícies; Interfaces e Películas	\N
602	095	a	1.05.07.11-6	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
603	095	a	estruturas	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
604	095	a	eletronicas	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
605	095	a	propriedades	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
606	095	a	eletricas	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
607	095	a	de	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
608	095	a	superficies	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
609	095	a	interfaces	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
610	095	a	peliculas	1.05.07.11-6 Estruturas Eletrônicas e Propriedades Elétricas de Superfícies Interfaces e Películas	\N
611	095	a	1.05.07.12-4	1.05.07.12-4 Supercondutividade	\N
612	095	a	supercondutividade	1.05.07.12-4 Supercondutividade	\N
613	095	a	1.05.07.13-2	1.05.07.13-2 Materiais Magnéticos e Propriedades Magnéticas	\N
614	095	a	materiais	1.05.07.13-2 Materiais Magnéticos e Propriedades Magnéticas	\N
615	095	a	magneticos	1.05.07.13-2 Materiais Magnéticos e Propriedades Magnéticas	\N
616	095	a	propriedades	1.05.07.13-2 Materiais Magnéticos e Propriedades Magnéticas	\N
617	095	a	magneticas	1.05.07.13-2 Materiais Magnéticos e Propriedades Magnéticas	\N
618	095	a	1.05.07.14-0	1.05.07.14-0 Ressonância Mag.e Relax.Na Mat.Condens;Efeitos Mosbauer;Corr.Ang.Pertubada	\N
619	095	a	ressonancia	1.05.07.14-0 Ressonância Mag.e Relax.Na Mat.Condens;Efeitos Mosbauer;Corr.Ang.Pertubada	\N
620	095	a	mag.e	1.05.07.14-0 Ressonância Mag.e Relax.Na Mat.Condens;Efeitos Mosbauer;Corr.Ang.Pertubada	\N
621	095	a	relax.na	1.05.07.14-0 Ressonância Mag.e Relax.Na Mat.Condens;Efeitos Mosbauer;Corr.Ang.Pertubada	\N
622	095	a	mat.condens;efeitos	1.05.07.14-0 Ressonância Mag.e Relax.Na Mat.Condens;Efeitos Mosbauer;Corr.Ang.Pertubada	\N
623	095	a	mosbauer;corr.ang.pertubada	1.05.07.14-0 Ressonância Mag.e Relax.Na Mat.Condens;Efeitos Mosbauer;Corr.Ang.Pertubada	\N
624	095	a	1.05.07.15-9	1.05.07.15-9 Materiais Dielétricos e Propriedades Dielétricas	\N
625	095	a	materiais	1.05.07.15-9 Materiais Dielétricos e Propriedades Dielétricas	\N
626	095	a	dieletricos	1.05.07.15-9 Materiais Dielétricos e Propriedades Dielétricas	\N
627	095	a	propriedades	1.05.07.15-9 Materiais Dielétricos e Propriedades Dielétricas	\N
628	095	a	dieletricas	1.05.07.15-9 Materiais Dielétricos e Propriedades Dielétricas	\N
629	095	a	1.05.07.16-7	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
630	095	a	prop.oticas	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
631	095	a	espectrosc.da	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
632	095	a	mat.condens;outras	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
633	095	a	inter.da	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
634	095	a	mat.com	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
635	095	a	rad.e	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
636	095	a	part.	1.05.07.16-7 Prop.Óticas e Espectrosc.da Mat.Condens;Outras Inter.da Mat.Com Rad.e Part.	\N
637	095	a	1.05.07.17-5	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
638	095	a	emissao	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
639	095	a	eletronica	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
640	095	a	ionica	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
641	095	a	por	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
642	095	a	liquidos	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
643	095	a	solidos;	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
644	095	a	fenomenos	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
645	095	a	de	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
646	095	a	impacto	1.05.07.17-5 Emissão Eletrônica e Iônica por Líquidos e Sólidos; Fenômenos de Impacto	\N
647	095	a	1.06.00.00-0	1.06.00.00-0 Química	\N
648	095	a	quimica	1.06.00.00-0 Química	\N
649	095	a	1.06.01.00-7	1.06.01.00-7 Química Orgânica	\N
650	095	a	quimica	1.06.01.00-7 Química Orgânica	\N
651	095	a	organica	1.06.01.00-7 Química Orgânica	\N
652	095	a	1.06.01.01-5	1.06.01.01-5 Estrutura, Conformação e Estereoquímica	\N
653	095	a	estrutura,	1.06.01.01-5 Estrutura, Conformação e Estereoquímica	\N
654	095	a	conformacao	1.06.01.01-5 Estrutura, Conformação e Estereoquímica	\N
655	095	a	estereoquimica	1.06.01.01-5 Estrutura, Conformação e Estereoquímica	\N
656	095	a	1.06.01.02-3	1.06.01.02-3 Sintese Orgânica	\N
657	095	a	sintese	1.06.01.02-3 Sintese Orgânica	\N
658	095	a	organica	1.06.01.02-3 Sintese Orgânica	\N
659	095	a	1.06.01.03-1	1.06.01.03-1 Fisico-Química Orgânica	\N
660	095	a	fisico-quimica	1.06.01.03-1 Fisico-Química Orgânica	\N
661	095	a	organica	1.06.01.03-1 Fisico-Química Orgânica	\N
662	095	a	1.06.01.04-0	1.06.01.04-0 Fotoquímica Orgânica	\N
663	095	a	fotoquimica	1.06.01.04-0 Fotoquímica Orgânica	\N
664	095	a	organica	1.06.01.04-0 Fotoquímica Orgânica	\N
665	095	a	1.06.01.05-8	1.06.01.05-8 Química dos Produtos Naturais	\N
666	095	a	quimica	1.06.01.05-8 Química dos Produtos Naturais	\N
667	095	a	dos	1.06.01.05-8 Química dos Produtos Naturais	\N
668	095	a	produtos	1.06.01.05-8 Química dos Produtos Naturais	\N
669	095	a	naturais	1.06.01.05-8 Química dos Produtos Naturais	\N
670	095	a	1.06.01.06-6	1.06.01.06-6 Evolução, Sistemática e Ecologia Química	\N
671	095	a	evolucao,	1.06.01.06-6 Evolução, Sistemática e Ecologia Química	\N
672	095	a	sistematica	1.06.01.06-6 Evolução, Sistemática e Ecologia Química	\N
673	095	a	ecologia	1.06.01.06-6 Evolução, Sistemática e Ecologia Química	\N
674	095	a	quimica	1.06.01.06-6 Evolução, Sistemática e Ecologia Química	\N
675	095	a	1.06.01.07-4	1.06.01.07-4 Polimeros e Colóides	\N
676	095	a	polimeros	1.06.01.07-4 Polimeros e Colóides	\N
677	095	a	coloides	1.06.01.07-4 Polimeros e Colóides	\N
678	095	a	1.06.02.00-3	1.06.02.00-3 Química Inorgânica	\N
679	095	a	quimica	1.06.02.00-3 Química Inorgânica	\N
680	095	a	inorganica	1.06.02.00-3 Química Inorgânica	\N
681	095	a	1.06.02.01-1	1.06.02.01-1 Campos de Coordenação	\N
682	095	a	campos	1.06.02.01-1 Campos de Coordenação	\N
683	095	a	de	1.06.02.01-1 Campos de Coordenação	\N
684	095	a	coordenacao	1.06.02.01-1 Campos de Coordenação	\N
685	095	a	1.06.02.02-0	1.06.02.02-0 Não-Metais e Seus Compostos	\N
686	095	a	nao-metais	1.06.02.02-0 Não-Metais e Seus Compostos	\N
687	095	a	seus	1.06.02.02-0 Não-Metais e Seus Compostos	\N
688	095	a	compostos	1.06.02.02-0 Não-Metais e Seus Compostos	\N
689	095	a	1.06.02.03-8	1.06.02.03-8 Compostos Organo-Metálicos	\N
690	095	a	compostos	1.06.02.03-8 Compostos Organo-Metálicos	\N
691	095	a	organo-metalicos	1.06.02.03-8 Compostos Organo-Metálicos	\N
692	095	a	1.06.02.04-6	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
693	095	a	determinacao	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
694	095	a	de	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
695	095	a	estrutura	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
696	095	a	de	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
697	095	a	compostos	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
698	095	a	inorganicos	1.06.02.04-6 Determinação de Estrutura de Compostos Inorgânicos	\N
699	095	a	1.06.02.05-4	1.06.02.05-4 Foto-Química Inorgânica	\N
700	095	a	foto-quimica	1.06.02.05-4 Foto-Química Inorgânica	\N
701	095	a	inorganica	1.06.02.05-4 Foto-Química Inorgânica	\N
702	095	a	1.06.02.06-2	1.06.02.06-2 Fisico Química Inorgânica	\N
703	095	a	fisico	1.06.02.06-2 Fisico Química Inorgânica	\N
704	095	a	quimica	1.06.02.06-2 Fisico Química Inorgânica	\N
705	095	a	inorganica	1.06.02.06-2 Fisico Química Inorgânica	\N
706	095	a	1.06.02.07-0	1.06.02.07-0 Química Bio-Inorgânica	\N
707	095	a	quimica	1.06.02.07-0 Química Bio-Inorgânica	\N
708	095	a	bio-inorganica	1.06.02.07-0 Química Bio-Inorgânica	\N
709	095	a	1.06.03.00-0	1.06.03.00-0 Fisico-Química	\N
710	095	a	fisico-quimica	1.06.03.00-0 Fisico-Química	\N
711	095	a	1.06.03.01-8	1.06.03.01-8 Cinética Química e Catálise	\N
712	095	a	cinetica	1.06.03.01-8 Cinética Química e Catálise	\N
713	095	a	quimica	1.06.03.01-8 Cinética Química e Catálise	\N
714	095	a	catalise	1.06.03.01-8 Cinética Química e Catálise	\N
715	095	a	1.06.03.02-6	1.06.03.02-6 Eletroquímica	\N
716	095	a	eletroquimica	1.06.03.02-6 Eletroquímica	\N
717	095	a	1.06.03.03-4	1.06.03.03-4 Espectroscopia	\N
718	095	a	espectroscopia	1.06.03.03-4 Espectroscopia	\N
719	095	a	1.06.03.04-2	1.06.03.04-2 Química de Interfaces	\N
720	095	a	quimica	1.06.03.04-2 Química de Interfaces	\N
721	095	a	de	1.06.03.04-2 Química de Interfaces	\N
722	095	a	interfaces	1.06.03.04-2 Química de Interfaces	\N
723	095	a	1.06.03.05-0	1.06.03.05-0 Química do Estado Condensado	\N
724	095	a	quimica	1.06.03.05-0 Química do Estado Condensado	\N
725	095	a	do	1.06.03.05-0 Química do Estado Condensado	\N
726	095	a	estado	1.06.03.05-0 Química do Estado Condensado	\N
727	095	a	condensado	1.06.03.05-0 Química do Estado Condensado	\N
728	095	a	1.06.03.06-9	1.06.03.06-9 Química Nuclear e Radioquímica	\N
729	095	a	quimica	1.06.03.06-9 Química Nuclear e Radioquímica	\N
730	095	a	nuclear	1.06.03.06-9 Química Nuclear e Radioquímica	\N
731	095	a	radioquimica	1.06.03.06-9 Química Nuclear e Radioquímica	\N
732	095	a	1.06.03.07-7	1.06.03.07-7 Química Teórica	\N
733	095	a	quimica	1.06.03.07-7 Química Teórica	\N
734	095	a	teorica	1.06.03.07-7 Química Teórica	\N
735	095	a	1.06.03.08-5	1.06.03.08-5 Termodinâmica Química	\N
736	095	a	termodinamica	1.06.03.08-5 Termodinâmica Química	\N
737	095	a	quimica	1.06.03.08-5 Termodinâmica Química	\N
738	095	a	1.06.04.00-6	1.06.04.00-6 Química Analítica	\N
739	095	a	quimica	1.06.04.00-6 Química Analítica	\N
740	095	a	analitica	1.06.04.00-6 Química Analítica	\N
741	095	a	1.06.04.01-4	1.06.04.01-4 Separação	\N
742	095	a	separacao	1.06.04.01-4 Separação	\N
743	095	a	1.06.04.02-2	1.06.04.02-2 Métodos Óticos de Análise	\N
744	095	a	metodos	1.06.04.02-2 Métodos Óticos de Análise	\N
745	095	a	oticos	1.06.04.02-2 Métodos Óticos de Análise	\N
746	095	a	de	1.06.04.02-2 Métodos Óticos de Análise	\N
747	095	a	analise	1.06.04.02-2 Métodos Óticos de Análise	\N
748	095	a	1.06.04.03-0	1.06.04.03-0 Eletroanalítica	\N
749	095	a	eletroanalitica	1.06.04.03-0 Eletroanalítica	\N
750	095	a	1.06.04.04-9	1.06.04.04-9 Gravimetria	\N
751	095	a	gravimetria	1.06.04.04-9 Gravimetria	\N
752	095	a	1.06.04.05-7	1.06.04.05-7 Titimetria	\N
753	095	a	titimetria	1.06.04.05-7 Titimetria	\N
754	095	a	1.06.04.06-5	1.06.04.06-5 Instrumentação Analítica	\N
755	095	a	instrumentacao	1.06.04.06-5 Instrumentação Analítica	\N
756	095	a	analitica	1.06.04.06-5 Instrumentação Analítica	\N
757	095	a	1.06.04.07-3	1.06.04.07-3 Análise de Traços e Química Ambiental	\N
758	095	a	analise	1.06.04.07-3 Análise de Traços e Química Ambiental	\N
759	095	a	de	1.06.04.07-3 Análise de Traços e Química Ambiental	\N
760	095	a	tracos	1.06.04.07-3 Análise de Traços e Química Ambiental	\N
761	095	a	quimica	1.06.04.07-3 Análise de Traços e Química Ambiental	\N
762	095	a	ambiental	1.06.04.07-3 Análise de Traços e Química Ambiental	\N
763	095	a	1.07.00.00-5	1.07.00.00-5 GeoCiências	\N
764	095	a	geociencias	1.07.00.00-5 GeoCiências	\N
765	095	a	1.07.01.00-1	1.07.01.00-1 Geologia	\N
766	095	a	geologia	1.07.01.00-1 Geologia	\N
767	095	a	1.07.01.01-0	1.07.01.01-0 Mineralogia	\N
768	095	a	mineralogia	1.07.01.01-0 Mineralogia	\N
769	095	a	1.07.01.02-8	1.07.01.02-8 Petrologia	\N
770	095	a	petrologia	1.07.01.02-8 Petrologia	\N
771	095	a	1.07.01.03-6	1.07.01.03-6 Geoquímica	\N
772	095	a	geoquimica	1.07.01.03-6 Geoquímica	\N
773	095	a	1.07.01.04-4	1.07.01.04-4 Geologia Regional	\N
774	095	a	geologia	1.07.01.04-4 Geologia Regional	\N
775	095	a	regional	1.07.01.04-4 Geologia Regional	\N
776	095	a	1.07.01.05-2	1.07.01.05-2 Geotectônica	\N
777	095	a	geotectonica	1.07.01.05-2 Geotectônica	\N
778	095	a	1.07.01.06-0	1.07.01.06-0 Geocronologia	\N
779	095	a	geocronologia	1.07.01.06-0 Geocronologia	\N
780	095	a	1.07.01.07-9	1.07.01.07-9 Cartografia Geológica	\N
781	095	a	cartografia	1.07.01.07-9 Cartografia Geológica	\N
782	095	a	geologica	1.07.01.07-9 Cartografia Geológica	\N
783	095	a	1.07.01.08-7	1.07.01.08-7 Metalogenia	\N
784	095	a	metalogenia	1.07.01.08-7 Metalogenia	\N
785	095	a	1.07.01.09-5	1.07.01.09-5 Hidrogeologia	\N
786	095	a	hidrogeologia	1.07.01.09-5 Hidrogeologia	\N
787	095	a	1.07.01.10-9	1.07.01.10-9 Prospecção Mineral	\N
788	095	a	prospeccao	1.07.01.10-9 Prospecção Mineral	\N
789	095	a	mineral	1.07.01.10-9 Prospecção Mineral	\N
790	095	a	1.07.01.11-7	1.07.01.11-7 Sedimentologia	\N
791	095	a	sedimentologia	1.07.01.11-7 Sedimentologia	\N
792	095	a	1.07.01.12-5	1.07.01.12-5 Paleontologia Estratigráfica	\N
793	095	a	paleontologia	1.07.01.12-5 Paleontologia Estratigráfica	\N
794	095	a	estratigrafica	1.07.01.12-5 Paleontologia Estratigráfica	\N
795	095	a	1.07.01.13-3	1.07.01.13-3 Estratigrafia	\N
796	095	a	estratigrafia	1.07.01.13-3 Estratigrafia	\N
797	095	a	1.07.01.14-1	1.07.01.14-1 Geologia Ambiental	\N
798	095	a	geologia	1.07.01.14-1 Geologia Ambiental	\N
799	095	a	ambiental	1.07.01.14-1 Geologia Ambiental	\N
800	095	a	1.07.02.00-8	1.07.02.00-8 Geofísica	\N
801	095	a	geofisica	1.07.02.00-8 Geofísica	\N
802	095	a	1.07.02.01-6	1.07.02.01-6 Geomagnetismo	\N
803	095	a	geomagnetismo	1.07.02.01-6 Geomagnetismo	\N
804	095	a	1.07.02.02-4	1.07.02.02-4 Sismologia	\N
805	095	a	sismologia	1.07.02.02-4 Sismologia	\N
806	095	a	1.07.02.03-2	1.07.02.03-2 Geotermia e Fluxo Térmico	\N
807	095	a	geotermia	1.07.02.03-2 Geotermia e Fluxo Térmico	\N
808	095	a	fluxo	1.07.02.03-2 Geotermia e Fluxo Térmico	\N
809	095	a	termico	1.07.02.03-2 Geotermia e Fluxo Térmico	\N
810	095	a	1.07.02.04-0	1.07.02.04-0 Propriedades Físicas das Rochas	\N
811	095	a	propriedades	1.07.02.04-0 Propriedades Físicas das Rochas	\N
812	095	a	fisicas	1.07.02.04-0 Propriedades Físicas das Rochas	\N
813	095	a	das	1.07.02.04-0 Propriedades Físicas das Rochas	\N
814	095	a	rochas	1.07.02.04-0 Propriedades Físicas das Rochas	\N
815	095	a	1.07.02.05-9	1.07.02.05-9 Geofísica Nuclear	\N
816	095	a	geofisica	1.07.02.05-9 Geofísica Nuclear	\N
817	095	a	nuclear	1.07.02.05-9 Geofísica Nuclear	\N
818	095	a	1.07.02.06-7	1.07.02.06-7 Sensoriamento Remoto	\N
819	095	a	sensoriamento	1.07.02.06-7 Sensoriamento Remoto	\N
820	095	a	remoto	1.07.02.06-7 Sensoriamento Remoto	\N
821	095	a	1.07.02.07-5	1.07.02.07-5 Aeronomia	\N
822	095	a	aeronomia	1.07.02.07-5 Aeronomia	\N
823	095	a	1.07.02.08-3	1.07.02.08-3 Desenvolvimento de Instrumentação Geofísica	\N
824	095	a	desenvolvimento	1.07.02.08-3 Desenvolvimento de Instrumentação Geofísica	\N
825	095	a	de	1.07.02.08-3 Desenvolvimento de Instrumentação Geofísica	\N
826	095	a	instrumentacao	1.07.02.08-3 Desenvolvimento de Instrumentação Geofísica	\N
827	095	a	geofisica	1.07.02.08-3 Desenvolvimento de Instrumentação Geofísica	\N
828	095	a	1.07.02.09-1	1.07.02.09-1 Geofísica Aplicada	\N
829	095	a	geofisica	1.07.02.09-1 Geofísica Aplicada	\N
830	095	a	aplicada	1.07.02.09-1 Geofísica Aplicada	\N
831	095	a	1.07.02.10-5	1.07.02.10-5 Gravimetria	\N
832	095	a	gravimetria	1.07.02.10-5 Gravimetria	\N
833	095	a	1.07.03.00-4	1.07.03.00-4 Meteorologia	\N
834	095	a	meteorologia	1.07.03.00-4 Meteorologia	\N
835	095	a	1.07.03.01-2	1.07.03.01-2 Meteorologia Dinâmica	\N
836	095	a	meteorologia	1.07.03.01-2 Meteorologia Dinâmica	\N
837	095	a	dinamica	1.07.03.01-2 Meteorologia Dinâmica	\N
838	095	a	1.07.03.02-0	1.07.03.02-0 Meteorologia Sinótica	\N
839	095	a	meteorologia	1.07.03.02-0 Meteorologia Sinótica	\N
840	095	a	sinotica	1.07.03.02-0 Meteorologia Sinótica	\N
841	095	a	1.07.03.03-9	1.07.03.03-9 Meteorologia Física	\N
842	095	a	meteorologia	1.07.03.03-9 Meteorologia Física	\N
843	095	a	fisica	1.07.03.03-9 Meteorologia Física	\N
844	095	a	1.07.03.04-7	1.07.03.04-7 Química da Atmosfera	\N
845	095	a	quimica	1.07.03.04-7 Química da Atmosfera	\N
846	095	a	da	1.07.03.04-7 Química da Atmosfera	\N
847	095	a	atmosfera	1.07.03.04-7 Química da Atmosfera	\N
848	095	a	1.07.03.05-5	1.07.03.05-5 Instrumentação Meteorológica	\N
849	095	a	instrumentacao	1.07.03.05-5 Instrumentação Meteorológica	\N
850	095	a	meteorologica	1.07.03.05-5 Instrumentação Meteorológica	\N
851	095	a	1.07.03.06-3	1.07.03.06-3 Climatologia	\N
852	095	a	climatologia	1.07.03.06-3 Climatologia	\N
853	095	a	1.07.03.07-1	1.07.03.07-1 Micrometeorologia	\N
854	095	a	micrometeorologia	1.07.03.07-1 Micrometeorologia	\N
855	095	a	1.07.03.08-0	1.07.03.08-0 Sensoriamento Remoto da Atmosfera	\N
856	095	a	sensoriamento	1.07.03.08-0 Sensoriamento Remoto da Atmosfera	\N
857	095	a	remoto	1.07.03.08-0 Sensoriamento Remoto da Atmosfera	\N
858	095	a	da	1.07.03.08-0 Sensoriamento Remoto da Atmosfera	\N
859	095	a	atmosfera	1.07.03.08-0 Sensoriamento Remoto da Atmosfera	\N
860	095	a	1.07.03.09-8	1.07.03.09-8 Meteorologia Aplicada	\N
861	095	a	meteorologia	1.07.03.09-8 Meteorologia Aplicada	\N
862	095	a	aplicada	1.07.03.09-8 Meteorologia Aplicada	\N
863	095	a	1.07.04.00-0	1.07.04.00-0 Geodesia	\N
864	095	a	geodesia	1.07.04.00-0 Geodesia	\N
865	095	a	1.07.04.01-9	1.07.04.01-9 Geodesia Física	\N
866	095	a	geodesia	1.07.04.01-9 Geodesia Física	\N
867	095	a	fisica	1.07.04.01-9 Geodesia Física	\N
868	095	a	1.07.04.02-7	1.07.04.02-7 Geodesia Geométrica	\N
869	095	a	geodesia	1.07.04.02-7 Geodesia Geométrica	\N
870	095	a	geometrica	1.07.04.02-7 Geodesia Geométrica	\N
871	095	a	1.07.04.03-5	1.07.04.03-5 Geodesia Celeste	\N
872	095	a	geodesia	1.07.04.03-5 Geodesia Celeste	\N
873	095	a	celeste	1.07.04.03-5 Geodesia Celeste	\N
874	095	a	1.07.04.04-3	1.07.04.04-3 Fotogrametria	\N
875	095	a	fotogrametria	1.07.04.04-3 Fotogrametria	\N
876	095	a	1.07.04.05-1	1.07.04.05-1 Cartografia Básica	\N
877	095	a	cartografia	1.07.04.05-1 Cartografia Básica	\N
878	095	a	basica	1.07.04.05-1 Cartografia Básica	\N
879	095	a	1.07.05.00-7	1.07.05.00-7 Geografia Física	\N
880	095	a	geografia	1.07.05.00-7 Geografia Física	\N
881	095	a	fisica	1.07.05.00-7 Geografia Física	\N
882	095	a	1.07.05.01-5	1.07.05.01-5 Geomorfologia	\N
883	095	a	geomorfologia	1.07.05.01-5 Geomorfologia	\N
884	095	a	1.07.05.02-3	1.07.05.02-3 Climatologia Geográfica	\N
885	095	a	climatologia	1.07.05.02-3 Climatologia Geográfica	\N
886	095	a	geografica	1.07.05.02-3 Climatologia Geográfica	\N
887	095	a	1.07.05.03-1	1.07.05.03-1 Pedologia	\N
888	095	a	pedologia	1.07.05.03-1 Pedologia	\N
889	095	a	1.07.05.04-0	1.07.05.04-0 Hidrogeografia	\N
890	095	a	hidrogeografia	1.07.05.04-0 Hidrogeografia	\N
891	095	a	1.07.05.05-8	1.07.05.05-8 Geoecologia	\N
892	095	a	geoecologia	1.07.05.05-8 Geoecologia	\N
893	095	a	1.07.05.06-6	1.07.05.06-6 Fotogeografia (Físico-Ecológica)	\N
894	095	a	fotogeografia	1.07.05.06-6 Fotogeografia (Físico-Ecológica)	\N
895	095	a	(fisico-ecologica)	1.07.05.06-6 Fotogeografia (Físico-Ecológica)	\N
896	095	a	1.07.05.07-4	1.07.05.07-4 Geocartografia	\N
897	095	a	geocartografia	1.07.05.07-4 Geocartografia	\N
898	095	a	1.08.00.00-0	1.08.00.00-0 Oceanografia	\N
899	095	a	oceanografia	1.08.00.00-0 Oceanografia	\N
900	095	a	1.08.01.00-6	1.08.01.00-6 Oceanografia Biológica	\N
901	095	a	oceanografia	1.08.01.00-6 Oceanografia Biológica	\N
902	095	a	biologica	1.08.01.00-6 Oceanografia Biológica	\N
903	095	a	1.08.01.01-4	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
904	095	a	interacao	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
905	095	a	entre	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
906	095	a	os	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
907	095	a	organismos	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
908	095	a	marinhos	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
909	095	a	os	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
910	095	a	parametros	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
911	095	a	ambientais	1.08.01.01-4 Interação entre os Organismos Marinhos e os Parâmetros Ambientais	\N
912	095	a	1.08.02.00-2	1.08.02.00-2 Oceanografia Física	\N
913	095	a	oceanografia	1.08.02.00-2 Oceanografia Física	\N
914	095	a	fisica	1.08.02.00-2 Oceanografia Física	\N
915	095	a	1.08.02.01-0	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
916	095	a	variaveis	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
917	095	a	fisicas	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
918	095	a	da	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
919	095	a	agua	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
920	095	a	do	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
921	095	a	mar	1.08.02.01-0 Variáveis Físicas da Água do Mar	\N
922	095	a	1.08.02.02-9	1.08.02.02-9 Movimento da Água do Mar	\N
923	095	a	movimento	1.08.02.02-9 Movimento da Água do Mar	\N
924	095	a	da	1.08.02.02-9 Movimento da Água do Mar	\N
925	095	a	agua	1.08.02.02-9 Movimento da Água do Mar	\N
926	095	a	do	1.08.02.02-9 Movimento da Água do Mar	\N
927	095	a	mar	1.08.02.02-9 Movimento da Água do Mar	\N
928	095	a	1.08.02.03-7	1.08.02.03-7 Origem das Massas de Água	\N
929	095	a	origem	1.08.02.03-7 Origem das Massas de Água	\N
930	095	a	das	1.08.02.03-7 Origem das Massas de Água	\N
931	095	a	massas	1.08.02.03-7 Origem das Massas de Água	\N
932	095	a	de	1.08.02.03-7 Origem das Massas de Água	\N
933	095	a	agua	1.08.02.03-7 Origem das Massas de Água	\N
934	095	a	1.08.02.04-5	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
935	095	a	interacao	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
936	095	a	do	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
937	095	a	oceano	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
938	095	a	com	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
939	095	a	leito	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
940	095	a	do	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
941	095	a	mar	1.08.02.04-5 Interação do Oceano com o Leito do Mar	\N
942	095	a	1.08.02.05-3	1.08.02.05-3 Interação do Oceano com a Atmosfera	\N
943	095	a	interacao	1.08.02.05-3 Interação do Oceano com a Atmosfera	\N
944	095	a	do	1.08.02.05-3 Interação do Oceano com a Atmosfera	\N
945	095	a	oceano	1.08.02.05-3 Interação do Oceano com a Atmosfera	\N
946	095	a	com	1.08.02.05-3 Interação do Oceano com a Atmosfera	\N
947	095	a	atmosfera	1.08.02.05-3 Interação do Oceano com a Atmosfera	\N
948	095	a	1.08.03.00-9	1.08.03.00-9 Oceanografia Química	\N
949	095	a	oceanografia	1.08.03.00-9 Oceanografia Química	\N
950	095	a	quimica	1.08.03.00-9 Oceanografia Química	\N
951	095	a	1.08.03.01-7	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
952	095	a	propriedades	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
953	095	a	quimicas	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
954	095	a	da	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
955	095	a	agua	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
956	095	a	do	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
957	095	a	mar	1.08.03.01-7 Propriedades Químicas da Água do Mar	\N
958	095	a	1.08.03.02-5	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
959	095	a	interacoes	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
960	095	a	quimico-biologicas/geologicas	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
961	095	a	das	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
962	095	a	substancias	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
963	095	a	quimicas	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
964	095	a	da	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
965	095	a	agua	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
966	095	a	do	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
967	095	a	mar	1.08.03.02-5 Interações Químico-Biológicas/Geológicas das Substâncias Químicas da Água do Mar	\N
968	095	a	1.08.04.00-5	1.08.04.00-5 Oceanografia Geológica	\N
969	095	a	oceanografia	1.08.04.00-5 Oceanografia Geológica	\N
970	095	a	geologica	1.08.04.00-5 Oceanografia Geológica	\N
971	095	a	1.08.04.01-3	1.08.04.01-3 Geomorfologia Submarina	\N
972	095	a	geomorfologia	1.08.04.01-3 Geomorfologia Submarina	\N
973	095	a	submarina	1.08.04.01-3 Geomorfologia Submarina	\N
974	095	a	1.08.04.02-1	1.08.04.02-1 Sedimentologia Marinha	\N
975	095	a	sedimentologia	1.08.04.02-1 Sedimentologia Marinha	\N
976	095	a	marinha	1.08.04.02-1 Sedimentologia Marinha	\N
977	095	a	1.08.04.03-0	1.08.04.03-0 Geofísica Marinha	\N
978	095	a	geofisica	1.08.04.03-0 Geofísica Marinha	\N
979	095	a	marinha	1.08.04.03-0 Geofísica Marinha	\N
980	095	a	2.00.00.00-6	2.00.00.00-6 Ciências Biológicas	\N
981	095	a	ciencias	2.00.00.00-6 Ciências Biológicas	\N
982	095	a	biologicas	2.00.00.00-6 Ciências Biológicas	\N
983	095	a	2.01.00.00-0	2.01.00.00-0 Biologia Geral	\N
984	095	a	biologia	2.01.00.00-0 Biologia Geral	\N
985	095	a	geral	2.01.00.00-0 Biologia Geral	\N
986	095	a	2.02.00.00-5	2.02.00.00-5 Genética	\N
987	095	a	genetica	2.02.00.00-5 Genética	\N
988	095	a	2.02.01.00-1	2.02.01.00-1 Genética Quantitativa	\N
989	095	a	genetica	2.02.01.00-1 Genética Quantitativa	\N
990	095	a	quantitativa	2.02.01.00-1 Genética Quantitativa	\N
991	095	a	2.02.02.00-8	2.02.02.00-8 Genética Molecular e de Microorganismos	\N
992	095	a	genetica	2.02.02.00-8 Genética Molecular e de Microorganismos	\N
993	095	a	molecular	2.02.02.00-8 Genética Molecular e de Microorganismos	\N
994	095	a	de	2.02.02.00-8 Genética Molecular e de Microorganismos	\N
995	095	a	microorganismos	2.02.02.00-8 Genética Molecular e de Microorganismos	\N
996	095	a	2.02.03.00-4	2.02.03.00-4 Genética Vegetal	\N
997	095	a	genetica	2.02.03.00-4 Genética Vegetal	\N
998	095	a	vegetal	2.02.03.00-4 Genética Vegetal	\N
999	095	a	2.02.04.00-0	2.02.04.00-0 Genética Animal	\N
1000	095	a	genetica	2.02.04.00-0 Genética Animal	\N
1001	095	a	animal	2.02.04.00-0 Genética Animal	\N
1002	095	a	2.02.05.00-7	2.02.05.00-7 Genética Humana e Médica	\N
1003	095	a	genetica	2.02.05.00-7 Genética Humana e Médica	\N
1004	095	a	humana	2.02.05.00-7 Genética Humana e Médica	\N
1005	095	a	medica	2.02.05.00-7 Genética Humana e Médica	\N
1006	095	a	2.02.06.00-3	2.02.06.00-3 Mutagênese	\N
1007	095	a	mutagenese	2.02.06.00-3 Mutagênese	\N
1008	095	a	2.03.00.00-0	2.03.00.00-0 Botânica	\N
1009	095	a	botanica	2.03.00.00-0 Botânica	\N
1010	095	a	2.03.01.00-6	2.03.01.00-6 Paleobotânica	\N
1011	095	a	paleobotanica	2.03.01.00-6 Paleobotânica	\N
1012	095	a	2.03.02.00-2	2.03.02.00-2 Morfologia Vegetal	\N
1013	095	a	morfologia	2.03.02.00-2 Morfologia Vegetal	\N
1014	095	a	vegetal	2.03.02.00-2 Morfologia Vegetal	\N
1015	095	a	2.03.02.01-0	2.03.02.01-0 Morfologia Externa	\N
1016	095	a	morfologia	2.03.02.01-0 Morfologia Externa	\N
1017	095	a	externa	2.03.02.01-0 Morfologia Externa	\N
1018	095	a	2.03.02.02-9	2.03.02.02-9 Citologia Vegetal	\N
1019	095	a	citologia	2.03.02.02-9 Citologia Vegetal	\N
1020	095	a	vegetal	2.03.02.02-9 Citologia Vegetal	\N
1021	095	a	2.03.02.03-7	2.03.02.03-7 Anatomia Vegetal	\N
1022	095	a	anatomia	2.03.02.03-7 Anatomia Vegetal	\N
1023	095	a	vegetal	2.03.02.03-7 Anatomia Vegetal	\N
1024	095	a	2.03.02.04-5	2.03.02.04-5 Palinologia	\N
1025	095	a	palinologia	2.03.02.04-5 Palinologia	\N
1026	095	a	2.03.03.00-9	2.03.03.00-9 Fisiologia Vegetal	\N
1027	095	a	fisiologia	2.03.03.00-9 Fisiologia Vegetal	\N
1028	095	a	vegetal	2.03.03.00-9 Fisiologia Vegetal	\N
1029	095	a	2.03.03.01-7	2.03.03.01-7 Nutrição e Crescimento Vegetal	\N
1030	095	a	nutricao	2.03.03.01-7 Nutrição e Crescimento Vegetal	\N
1031	095	a	crescimento	2.03.03.01-7 Nutrição e Crescimento Vegetal	\N
1032	095	a	vegetal	2.03.03.01-7 Nutrição e Crescimento Vegetal	\N
1033	095	a	2.03.03.02-5	2.03.03.02-5 Reprodução Vegetal	\N
1034	095	a	reproducao	2.03.03.02-5 Reprodução Vegetal	\N
1035	095	a	vegetal	2.03.03.02-5 Reprodução Vegetal	\N
1036	095	a	2.03.03.03-3	2.03.03.03-3 Ecofisiologia Vegetal	\N
1037	095	a	ecofisiologia	2.03.03.03-3 Ecofisiologia Vegetal	\N
1038	095	a	vegetal	2.03.03.03-3 Ecofisiologia Vegetal	\N
1039	095	a	2.03.04.00-5	2.03.04.00-5 Taxonomia Vegetal	\N
1040	095	a	taxonomia	2.03.04.00-5 Taxonomia Vegetal	\N
1041	095	a	vegetal	2.03.04.00-5 Taxonomia Vegetal	\N
1042	095	a	2.03.04.01-3	2.03.04.01-3 Taxonomia de Criptógamos	\N
1043	095	a	taxonomia	2.03.04.01-3 Taxonomia de Criptógamos	\N
1044	095	a	de	2.03.04.01-3 Taxonomia de Criptógamos	\N
1045	095	a	criptogamos	2.03.04.01-3 Taxonomia de Criptógamos	\N
1046	095	a	2.03.04.02-1	2.03.04.02-1 Taxonomia de Fanerógamos	\N
1047	095	a	taxonomia	2.03.04.02-1 Taxonomia de Fanerógamos	\N
1048	095	a	de	2.03.04.02-1 Taxonomia de Fanerógamos	\N
1049	095	a	fanerogamos	2.03.04.02-1 Taxonomia de Fanerógamos	\N
1050	095	a	2.03.05.00-1	2.03.05.00-1 Fitogeografia	\N
1051	095	a	fitogeografia	2.03.05.00-1 Fitogeografia	\N
1052	095	a	2.03.06.00-8	2.03.06.00-8 Botânica Aplicada	\N
1053	095	a	botanica	2.03.06.00-8 Botânica Aplicada	\N
1054	095	a	aplicada	2.03.06.00-8 Botânica Aplicada	\N
1055	095	a	2.04.00.00-4	2.04.00.00-4 Zoologia	\N
1056	095	a	zoologia	2.04.00.00-4 Zoologia	\N
1057	095	a	2.04.01.00-0	2.04.01.00-0 Paleozoologia	\N
1058	095	a	paleozoologia	2.04.01.00-0 Paleozoologia	\N
1059	095	a	2.04.02.00-7	2.04.02.00-7 Morfologia dos Grupos Recentes	\N
1060	095	a	morfologia	2.04.02.00-7 Morfologia dos Grupos Recentes	\N
1061	095	a	dos	2.04.02.00-7 Morfologia dos Grupos Recentes	\N
1062	095	a	grupos	2.04.02.00-7 Morfologia dos Grupos Recentes	\N
1063	095	a	recentes	2.04.02.00-7 Morfologia dos Grupos Recentes	\N
1064	095	a	2.04.03.00-3	2.04.03.00-3 Fisiologia dos Grupos Recentes	\N
1065	095	a	fisiologia	2.04.03.00-3 Fisiologia dos Grupos Recentes	\N
1066	095	a	dos	2.04.03.00-3 Fisiologia dos Grupos Recentes	\N
1067	095	a	grupos	2.04.03.00-3 Fisiologia dos Grupos Recentes	\N
1068	095	a	recentes	2.04.03.00-3 Fisiologia dos Grupos Recentes	\N
1069	095	a	2.04.04.00-0	2.04.04.00-0 Comportamento Animal	\N
1070	095	a	comportamento	2.04.04.00-0 Comportamento Animal	\N
1071	095	a	animal	2.04.04.00-0 Comportamento Animal	\N
1072	095	a	2.04.05.00-6	2.04.05.00-6 Taxonomia dos Grupos Recentes	\N
1073	095	a	taxonomia	2.04.05.00-6 Taxonomia dos Grupos Recentes	\N
1074	095	a	dos	2.04.05.00-6 Taxonomia dos Grupos Recentes	\N
1075	095	a	grupos	2.04.05.00-6 Taxonomia dos Grupos Recentes	\N
1076	095	a	recentes	2.04.05.00-6 Taxonomia dos Grupos Recentes	\N
1077	095	a	2.04.06.00-2	2.04.06.00-2 Zoologia Aplicada	\N
1078	095	a	zoologia	2.04.06.00-2 Zoologia Aplicada	\N
1079	095	a	aplicada	2.04.06.00-2 Zoologia Aplicada	\N
1080	095	a	2.04.06.01-0	2.04.06.01-0 Conservação das Espécies Animais	\N
1081	095	a	conservacao	2.04.06.01-0 Conservação das Espécies Animais	\N
1082	095	a	das	2.04.06.01-0 Conservação das Espécies Animais	\N
1083	095	a	especies	2.04.06.01-0 Conservação das Espécies Animais	\N
1084	095	a	animais	2.04.06.01-0 Conservação das Espécies Animais	\N
1085	095	a	2.04.06.02-9	2.04.06.02-9 Utilização dos Animais	\N
1086	095	a	utilizacao	2.04.06.02-9 Utilização dos Animais	\N
1087	095	a	dos	2.04.06.02-9 Utilização dos Animais	\N
1088	095	a	animais	2.04.06.02-9 Utilização dos Animais	\N
1089	095	a	2.04.06.03-7	2.04.06.03-7 Controle Populacional de Animais	\N
1090	095	a	controle	2.04.06.03-7 Controle Populacional de Animais	\N
1091	095	a	populacional	2.04.06.03-7 Controle Populacional de Animais	\N
1092	095	a	de	2.04.06.03-7 Controle Populacional de Animais	\N
1093	095	a	animais	2.04.06.03-7 Controle Populacional de Animais	\N
1094	095	a	2.05.00.00-9	2.05.00.00-9 Ecologia	\N
1095	095	a	ecologia	2.05.00.00-9 Ecologia	\N
1096	095	a	2.05.01.00-5	2.05.01.00-5 Ecologia Teórica	\N
1097	095	a	ecologia	2.05.01.00-5 Ecologia Teórica	\N
1098	095	a	teorica	2.05.01.00-5 Ecologia Teórica	\N
1099	095	a	2.05.02.00-1	2.05.02.00-1 Ecologia de Ecossistemas	\N
1100	095	a	ecologia	2.05.02.00-1 Ecologia de Ecossistemas	\N
1101	095	a	de	2.05.02.00-1 Ecologia de Ecossistemas	\N
1102	095	a	ecossistemas	2.05.02.00-1 Ecologia de Ecossistemas	\N
1103	095	a	2.05.03.00-8	2.05.03.00-8 Ecologia Aplicada	\N
1104	095	a	ecologia	2.05.03.00-8 Ecologia Aplicada	\N
1105	095	a	aplicada	2.05.03.00-8 Ecologia Aplicada	\N
1106	095	a	2.06.00.00-3	2.06.00.00-3 Morfologia	\N
1107	095	a	morfologia	2.06.00.00-3 Morfologia	\N
1108	095	a	2.06.01.00-0	2.06.01.00-0 Citologia e Biologia Celular	\N
1109	095	a	citologia	2.06.01.00-0 Citologia e Biologia Celular	\N
1110	095	a	biologia	2.06.01.00-0 Citologia e Biologia Celular	\N
1111	095	a	celular	2.06.01.00-0 Citologia e Biologia Celular	\N
1112	095	a	2.06.02.00-6	2.06.02.00-6 Embriologia	\N
1113	095	a	embriologia	2.06.02.00-6 Embriologia	\N
1114	095	a	2.06.03.00-2	2.06.03.00-2 Histologia	\N
1115	095	a	histologia	2.06.03.00-2 Histologia	\N
1116	095	a	2.06.04.00-9	2.06.04.00-9 Anatomia	\N
1117	095	a	anatomia	2.06.04.00-9 Anatomia	\N
1118	095	a	2.06.04.01-7	2.06.04.01-7 Anatomia Humana	\N
1119	095	a	anatomia	2.06.04.01-7 Anatomia Humana	\N
1120	095	a	humana	2.06.04.01-7 Anatomia Humana	\N
1121	095	a	2.07.00.00-8	2.07.00.00-8 Fisiologia	\N
1122	095	a	fisiologia	2.07.00.00-8 Fisiologia	\N
1123	095	a	2.07.01.00-4	2.07.01.00-4 Fisiologia Geral	\N
1124	095	a	fisiologia	2.07.01.00-4 Fisiologia Geral	\N
1125	095	a	geral	2.07.01.00-4 Fisiologia Geral	\N
1126	095	a	2.07.02.00-0	2.07.02.00-0 Fisiologia de Órgaos e Sistemas	\N
1127	095	a	fisiologia	2.07.02.00-0 Fisiologia de Órgaos e Sistemas	\N
1128	095	a	de	2.07.02.00-0 Fisiologia de Órgaos e Sistemas	\N
1129	095	a	orgaos	2.07.02.00-0 Fisiologia de Órgaos e Sistemas	\N
1130	095	a	sistemas	2.07.02.00-0 Fisiologia de Órgaos e Sistemas	\N
1131	095	a	2.07.02.01-9	2.07.02.01-9 Neurofisiologia	\N
1132	095	a	neurofisiologia	2.07.02.01-9 Neurofisiologia	\N
1133	095	a	2.07.02.02-7	2.07.02.02-7 Fisiologia Cardiovascular	\N
1134	095	a	fisiologia	2.07.02.02-7 Fisiologia Cardiovascular	\N
1135	095	a	cardiovascular	2.07.02.02-7 Fisiologia Cardiovascular	\N
1136	095	a	2.07.02.03-5	2.07.02.03-5 Fisiologia da Respiração	\N
1137	095	a	fisiologia	2.07.02.03-5 Fisiologia da Respiração	\N
1138	095	a	da	2.07.02.03-5 Fisiologia da Respiração	\N
1139	095	a	respiracao	2.07.02.03-5 Fisiologia da Respiração	\N
1140	095	a	2.07.02.04-3	2.07.02.04-3 Fisiologia Renal	\N
1141	095	a	fisiologia	2.07.02.04-3 Fisiologia Renal	\N
1142	095	a	renal	2.07.02.04-3 Fisiologia Renal	\N
1143	095	a	2.07.02.05-1	2.07.02.05-1 Fisiologia Endocrina	\N
1144	095	a	fisiologia	2.07.02.05-1 Fisiologia Endocrina	\N
1145	095	a	endocrina	2.07.02.05-1 Fisiologia Endocrina	\N
1146	095	a	2.07.02.06-0	2.07.02.06-0 Fisiologia da Digestão	\N
1147	095	a	fisiologia	2.07.02.06-0 Fisiologia da Digestão	\N
1148	095	a	da	2.07.02.06-0 Fisiologia da Digestão	\N
1149	095	a	digestao	2.07.02.06-0 Fisiologia da Digestão	\N
1150	095	a	2.07.02.07-8	2.07.02.07-8 Cinesiologia	\N
1151	095	a	cinesiologia	2.07.02.07-8 Cinesiologia	\N
1152	095	a	2.07.03.00-7	2.07.03.00-7 Fisiologia do Esforço	\N
1153	095	a	fisiologia	2.07.03.00-7 Fisiologia do Esforço	\N
1154	095	a	do	2.07.03.00-7 Fisiologia do Esforço	\N
1155	095	a	esforco	2.07.03.00-7 Fisiologia do Esforço	\N
1156	095	a	2.07.04.00-3	2.07.04.00-3 Fisiologia Comparada	\N
1157	095	a	fisiologia	2.07.04.00-3 Fisiologia Comparada	\N
1158	095	a	comparada	2.07.04.00-3 Fisiologia Comparada	\N
1159	095	a	2.08.00.00-2	2.08.00.00-2 Bioquímica	\N
1160	095	a	bioquimica	2.08.00.00-2 Bioquímica	\N
1161	095	a	2.08.01.00-9	2.08.01.00-9 Química de Macromoléculas	\N
1162	095	a	quimica	2.08.01.00-9 Química de Macromoléculas	\N
1163	095	a	de	2.08.01.00-9 Química de Macromoléculas	\N
1164	095	a	macromoleculas	2.08.01.00-9 Química de Macromoléculas	\N
1165	095	a	2.08.01.01-7	2.08.01.01-7 Proteínas	\N
1166	095	a	proteinas	2.08.01.01-7 Proteínas	\N
1167	095	a	2.08.01.02-5	2.08.01.02-5 Lipídeos	\N
1168	095	a	lipideos	2.08.01.02-5 Lipídeos	\N
1169	095	a	2.08.01.03-3	2.08.01.03-3 Glicídeos	\N
1170	095	a	glicideos	2.08.01.03-3 Glicídeos	\N
1171	095	a	2.08.02.00-5	2.08.02.00-5 Bioquímica dos Microorganismos	\N
1172	095	a	bioquimica	2.08.02.00-5 Bioquímica dos Microorganismos	\N
1173	095	a	dos	2.08.02.00-5 Bioquímica dos Microorganismos	\N
1174	095	a	microorganismos	2.08.02.00-5 Bioquímica dos Microorganismos	\N
1175	095	a	2.08.03.00-1	2.08.03.00-1 Metabolismo e Bioenergética	\N
1176	095	a	metabolismo	2.08.03.00-1 Metabolismo e Bioenergética	\N
1177	095	a	bioenergetica	2.08.03.00-1 Metabolismo e Bioenergética	\N
1178	095	a	2.08.04.00-8	2.08.04.00-8 Biologia Molecular	\N
1179	095	a	biologia	2.08.04.00-8 Biologia Molecular	\N
1180	095	a	molecular	2.08.04.00-8 Biologia Molecular	\N
1181	095	a	2.08.05.00-4	2.08.05.00-4 Enzimologia	\N
1182	095	a	enzimologia	2.08.05.00-4 Enzimologia	\N
1183	095	a	2.09.00.00-7	2.09.00.00-7 Biofísica	\N
1184	095	a	biofisica	2.09.00.00-7 Biofísica	\N
1185	095	a	2.09.01.00-3	2.09.01.00-3 Biofísica Molecular	\N
1186	095	a	biofisica	2.09.01.00-3 Biofísica Molecular	\N
1187	095	a	molecular	2.09.01.00-3 Biofísica Molecular	\N
1188	095	a	2.09.02.00-0	2.09.02.00-0 Biofísica Celular	\N
1189	095	a	biofisica	2.09.02.00-0 Biofísica Celular	\N
1190	095	a	celular	2.09.02.00-0 Biofísica Celular	\N
1191	095	a	2.09.03.00-6	2.09.03.00-6 Biofísica de Processos e Sistemas	\N
1192	095	a	biofisica	2.09.03.00-6 Biofísica de Processos e Sistemas	\N
1193	095	a	de	2.09.03.00-6 Biofísica de Processos e Sistemas	\N
1194	095	a	processos	2.09.03.00-6 Biofísica de Processos e Sistemas	\N
1195	095	a	sistemas	2.09.03.00-6 Biofísica de Processos e Sistemas	\N
1196	095	a	2.09.04.00-2	2.09.04.00-2 Radiologia e Fotobiologia	\N
1197	095	a	radiologia	2.09.04.00-2 Radiologia e Fotobiologia	\N
1198	095	a	fotobiologia	2.09.04.00-2 Radiologia e Fotobiologia	\N
1199	095	a	2.10.00.00-0	2.10.00.00-0 Farmacologia	\N
1200	095	a	farmacologia	2.10.00.00-0 Farmacologia	\N
1201	095	a	2.10.01.00-6	2.10.01.00-6 Farmacologia Geral	\N
1202	095	a	farmacologia	2.10.01.00-6 Farmacologia Geral	\N
1203	095	a	geral	2.10.01.00-6 Farmacologia Geral	\N
1204	095	a	2.10.01.01-4	2.10.01.01-4 Farmacocinética	\N
1205	095	a	farmacocinetica	2.10.01.01-4 Farmacocinética	\N
1206	095	a	2.10.01.02-2	2.10.01.02-2 Biodisponibilidade	\N
1207	095	a	biodisponibilidade	2.10.01.02-2 Biodisponibilidade	\N
1208	095	a	2.10.02.00-2	2.10.02.00-2 Farmacologia Autonômica	\N
1209	095	a	farmacologia	2.10.02.00-2 Farmacologia Autonômica	\N
1210	095	a	autonomica	2.10.02.00-2 Farmacologia Autonômica	\N
1211	095	a	2.10.03.00-9	2.10.03.00-9 Neuropsicofarmacologia	\N
1212	095	a	neuropsicofarmacologia	2.10.03.00-9 Neuropsicofarmacologia	\N
1213	095	a	2.10.04.00-5	2.10.04.00-5 Farmacologia Cardiorenal	\N
1214	095	a	farmacologia	2.10.04.00-5 Farmacologia Cardiorenal	\N
1215	095	a	cardiorenal	2.10.04.00-5 Farmacologia Cardiorenal	\N
1216	095	a	2.10.05.00-1	2.10.05.00-1 Farmacologia Bioquímica e Molecular	\N
1217	095	a	farmacologia	2.10.05.00-1 Farmacologia Bioquímica e Molecular	\N
1218	095	a	bioquimica	2.10.05.00-1 Farmacologia Bioquímica e Molecular	\N
1219	095	a	molecular	2.10.05.00-1 Farmacologia Bioquímica e Molecular	\N
1220	095	a	2.10.06.00-8	2.10.06.00-8 Etnofarmacologia	\N
1221	095	a	etnofarmacologia	2.10.06.00-8 Etnofarmacologia	\N
1222	095	a	2.10.07.00-4	2.10.07.00-4 Toxicologia	\N
1223	095	a	toxicologia	2.10.07.00-4 Toxicologia	\N
1224	095	a	2.10.08.00-0	2.10.08.00-0 Farmacologia Clínica	\N
1225	095	a	farmacologia	2.10.08.00-0 Farmacologia Clínica	\N
1226	095	a	clinica	2.10.08.00-0 Farmacologia Clínica	\N
1227	095	a	2.11.00.00-4	2.11.00.00-4 Imunologia	\N
1228	095	a	imunologia	2.11.00.00-4 Imunologia	\N
1229	095	a	2.11.01.00-0	2.11.01.00-0 Imunoquímica	\N
1230	095	a	imunoquimica	2.11.01.00-0 Imunoquímica	\N
1231	095	a	2.11.02.00-7	2.11.02.00-7 Imunologia Celular	\N
1232	095	a	imunologia	2.11.02.00-7 Imunologia Celular	\N
1233	095	a	celular	2.11.02.00-7 Imunologia Celular	\N
1234	095	a	2.11.03.00-3	2.11.03.00-3 Imunogenética	\N
1235	095	a	imunogenetica	2.11.03.00-3 Imunogenética	\N
1236	095	a	2.11.04.00-0	2.11.04.00-0 Imunologia Aplicada	\N
1237	095	a	imunologia	2.11.04.00-0 Imunologia Aplicada	\N
1238	095	a	aplicada	2.11.04.00-0 Imunologia Aplicada	\N
1239	095	a	2.12.00.00-9	2.12.00.00-9 Microbiologia	\N
1240	095	a	microbiologia	2.12.00.00-9 Microbiologia	\N
1241	095	a	2.12.01.00-5	2.12.01.00-5 Biologia e Fisiologia dos Microorganismos	\N
1242	095	a	biologia	2.12.01.00-5 Biologia e Fisiologia dos Microorganismos	\N
1243	095	a	fisiologia	2.12.01.00-5 Biologia e Fisiologia dos Microorganismos	\N
1244	095	a	dos	2.12.01.00-5 Biologia e Fisiologia dos Microorganismos	\N
1245	095	a	microorganismos	2.12.01.00-5 Biologia e Fisiologia dos Microorganismos	\N
1246	095	a	2.12.01.01-3	2.12.01.01-3 Virologia	\N
1247	095	a	virologia	2.12.01.01-3 Virologia	\N
1248	095	a	2.12.01.02-1	2.12.01.02-1 Bacterologia	\N
1249	095	a	bacterologia	2.12.01.02-1 Bacterologia	\N
1250	095	a	2.12.01.03-0	2.12.01.03-0 Micologia	\N
1251	095	a	micologia	2.12.01.03-0 Micologia	\N
1252	095	a	2.12.02.00-1	2.12.02.00-1 Microbiologia Aplicada	\N
1253	095	a	microbiologia	2.12.02.00-1 Microbiologia Aplicada	\N
1254	095	a	aplicada	2.12.02.00-1 Microbiologia Aplicada	\N
1255	095	a	2.12.02.01-0	2.12.02.01-0 Microbiologia Médica	\N
1256	095	a	microbiologia	2.12.02.01-0 Microbiologia Médica	\N
1257	095	a	medica	2.12.02.01-0 Microbiologia Médica	\N
1258	095	a	2.12.02.02-8	2.12.02.02-8 Microbiologia Industrial e de Fermentação	\N
1259	095	a	microbiologia	2.12.02.02-8 Microbiologia Industrial e de Fermentação	\N
1260	095	a	industrial	2.12.02.02-8 Microbiologia Industrial e de Fermentação	\N
1261	095	a	de	2.12.02.02-8 Microbiologia Industrial e de Fermentação	\N
1262	095	a	fermentacao	2.12.02.02-8 Microbiologia Industrial e de Fermentação	\N
1263	095	a	2.13.00.00-3	2.13.00.00-3 Parasitologia	\N
1264	095	a	parasitologia	2.13.00.00-3 Parasitologia	\N
1265	095	a	2.13.01.00-0	2.13.01.00-0 Protozoologia de Parasitos	\N
1266	095	a	protozoologia	2.13.01.00-0 Protozoologia de Parasitos	\N
1267	095	a	de	2.13.01.00-0 Protozoologia de Parasitos	\N
1268	095	a	parasitos	2.13.01.00-0 Protozoologia de Parasitos	\N
1269	095	a	2.13.01.01-8	2.13.01.01-8 Protozoologia Parasitária Humana	\N
1270	095	a	protozoologia	2.13.01.01-8 Protozoologia Parasitária Humana	\N
1271	095	a	parasitaria	2.13.01.01-8 Protozoologia Parasitária Humana	\N
1272	095	a	humana	2.13.01.01-8 Protozoologia Parasitária Humana	\N
1273	095	a	2.13.01.02-6	2.13.01.02-6 Protozoologia Parasitária Animal	\N
1274	095	a	protozoologia	2.13.01.02-6 Protozoologia Parasitária Animal	\N
1275	095	a	parasitaria	2.13.01.02-6 Protozoologia Parasitária Animal	\N
1276	095	a	animal	2.13.01.02-6 Protozoologia Parasitária Animal	\N
1277	095	a	2.13.02.00-6	2.13.02.00-6 Helmintologia de Parasitos	\N
1278	095	a	helmintologia	2.13.02.00-6 Helmintologia de Parasitos	\N
1279	095	a	de	2.13.02.00-6 Helmintologia de Parasitos	\N
1280	095	a	parasitos	2.13.02.00-6 Helmintologia de Parasitos	\N
1281	095	a	2.13.02.01-4	2.13.02.01-4 Helmintologia Humana	\N
1282	095	a	helmintologia	2.13.02.01-4 Helmintologia Humana	\N
1283	095	a	humana	2.13.02.01-4 Helmintologia Humana	\N
1284	095	a	2.13.02.02-2	2.13.02.02-2 Helmintologia Animal	\N
1285	095	a	helmintologia	2.13.02.02-2 Helmintologia Animal	\N
1286	095	a	animal	2.13.02.02-2 Helmintologia Animal	\N
1287	095	a	2.13.03.00-2	2.13.03.00-2 Entomologia e Malacologia de Parasitos e Vetores	\N
1288	095	a	entomologia	2.13.03.00-2 Entomologia e Malacologia de Parasitos e Vetores	\N
1289	095	a	malacologia	2.13.03.00-2 Entomologia e Malacologia de Parasitos e Vetores	\N
1290	095	a	de	2.13.03.00-2 Entomologia e Malacologia de Parasitos e Vetores	\N
1291	095	a	parasitos	2.13.03.00-2 Entomologia e Malacologia de Parasitos e Vetores	\N
1292	095	a	vetores	2.13.03.00-2 Entomologia e Malacologia de Parasitos e Vetores	\N
1293	095	a	3.00.00.00-9	3.00.00.00-9 Engenharias	\N
1294	095	a	engenharias	3.00.00.00-9 Engenharias	\N
1295	095	a	3.01.00.00-3	3.01.00.00-3 Engenharia Civil	\N
1296	095	a	engenharia	3.01.00.00-3 Engenharia Civil	\N
1297	095	a	civil	3.01.00.00-3 Engenharia Civil	\N
1298	095	a	3.01.01.00-0	3.01.01.00-0 Construção Civil	\N
1299	095	a	construcao	3.01.01.00-0 Construção Civil	\N
1300	095	a	civil	3.01.01.00-0 Construção Civil	\N
1301	095	a	3.01.01.01-8	3.01.01.01-8 Materiais e Componentes de Construção	\N
1302	095	a	materiais	3.01.01.01-8 Materiais e Componentes de Construção	\N
1303	095	a	componentes	3.01.01.01-8 Materiais e Componentes de Construção	\N
1304	095	a	de	3.01.01.01-8 Materiais e Componentes de Construção	\N
1305	095	a	construcao	3.01.01.01-8 Materiais e Componentes de Construção	\N
1306	095	a	3.01.01.02-6	3.01.01.02-6 Processos Construtivos	\N
1307	095	a	processos	3.01.01.02-6 Processos Construtivos	\N
1308	095	a	construtivos	3.01.01.02-6 Processos Construtivos	\N
1309	095	a	3.01.01.03-4	3.01.01.03-4 Instalações Prediais	\N
1310	095	a	instalacoes	3.01.01.03-4 Instalações Prediais	\N
1311	095	a	prediais	3.01.01.03-4 Instalações Prediais	\N
1312	095	a	3.01.02.00-6	3.01.02.00-6 Estruturas	\N
1313	095	a	estruturas	3.01.02.00-6 Estruturas	\N
1314	095	a	3.01.02.01-4	3.01.02.01-4 Estruturas de Concreto	\N
1315	095	a	estruturas	3.01.02.01-4 Estruturas de Concreto	\N
1316	095	a	de	3.01.02.01-4 Estruturas de Concreto	\N
1317	095	a	concreto	3.01.02.01-4 Estruturas de Concreto	\N
1318	095	a	3.01.02.02-2	3.01.02.02-2 Estruturas de Madeiras	\N
1319	095	a	estruturas	3.01.02.02-2 Estruturas de Madeiras	\N
1320	095	a	de	3.01.02.02-2 Estruturas de Madeiras	\N
1321	095	a	madeiras	3.01.02.02-2 Estruturas de Madeiras	\N
1322	095	a	3.01.02.03-0	3.01.02.03-0 Estruturas Metálicas	\N
1323	095	a	estruturas	3.01.02.03-0 Estruturas Metálicas	\N
1324	095	a	metalicas	3.01.02.03-0 Estruturas Metálicas	\N
1325	095	a	3.01.02.04-9	3.01.02.04-9 Mecânica das Estruturas	\N
1326	095	a	mecanica	3.01.02.04-9 Mecânica das Estruturas	\N
1327	095	a	das	3.01.02.04-9 Mecânica das Estruturas	\N
1328	095	a	estruturas	3.01.02.04-9 Mecânica das Estruturas	\N
1329	095	a	3.01.03.00-2	3.01.03.00-2 Geotécnica	\N
1330	095	a	geotecnica	3.01.03.00-2 Geotécnica	\N
1331	095	a	3.01.03.01-0	3.01.03.01-0 Fundações e Escavações	\N
1332	095	a	fundacoes	3.01.03.01-0 Fundações e Escavações	\N
1333	095	a	escavacoes	3.01.03.01-0 Fundações e Escavações	\N
1334	095	a	3.01.03.02-9	3.01.03.02-9 Mecânicas das Rochas	\N
1335	095	a	mecanicas	3.01.03.02-9 Mecânicas das Rochas	\N
1336	095	a	das	3.01.03.02-9 Mecânicas das Rochas	\N
1337	095	a	rochas	3.01.03.02-9 Mecânicas das Rochas	\N
1338	095	a	3.01.03.03-7	3.01.03.03-7 Mecânicas dos Solos	\N
1339	095	a	mecanicas	3.01.03.03-7 Mecânicas dos Solos	\N
1340	095	a	dos	3.01.03.03-7 Mecânicas dos Solos	\N
1341	095	a	solos	3.01.03.03-7 Mecânicas dos Solos	\N
1342	095	a	3.01.03.04-5	3.01.03.04-5 Obras de Terra e Enrocamento	\N
1343	095	a	obras	3.01.03.04-5 Obras de Terra e Enrocamento	\N
1344	095	a	de	3.01.03.04-5 Obras de Terra e Enrocamento	\N
1345	095	a	terra	3.01.03.04-5 Obras de Terra e Enrocamento	\N
1346	095	a	enrocamento	3.01.03.04-5 Obras de Terra e Enrocamento	\N
1347	095	a	3.01.03.05-3	3.01.03.05-3 Pavimentos	\N
1348	095	a	pavimentos	3.01.03.05-3 Pavimentos	\N
1349	095	a	3.01.04.00-9	3.01.04.00-9 Engenharia Hidráulica	\N
1350	095	a	engenharia	3.01.04.00-9 Engenharia Hidráulica	\N
1351	095	a	hidraulica	3.01.04.00-9 Engenharia Hidráulica	\N
1352	095	a	3.01.04.01-7	3.01.04.01-7 Hidráulica	\N
1353	095	a	hidraulica	3.01.04.01-7 Hidráulica	\N
1354	095	a	3.01.04.02-5	3.01.04.02-5 Hidrologia	\N
1355	095	a	hidrologia	3.01.04.02-5 Hidrologia	\N
1356	095	a	3.01.05.00-5	3.01.05.00-5 Infra-Estrutura de Transportes	\N
1357	095	a	infra-estrutura	3.01.05.00-5 Infra-Estrutura de Transportes	\N
1358	095	a	de	3.01.05.00-5 Infra-Estrutura de Transportes	\N
1359	095	a	transportes	3.01.05.00-5 Infra-Estrutura de Transportes	\N
1360	095	a	3.01.05.01-3	3.01.05.01-3 Aeroportos; Projeto e Construção	\N
1361	095	a	aeroportos;	3.01.05.01-3 Aeroportos; Projeto e Construção	\N
1362	095	a	projeto	3.01.05.01-3 Aeroportos; Projeto e Construção	\N
1363	095	a	construcao	3.01.05.01-3 Aeroportos; Projeto e Construção	\N
1364	095	a	3.01.05.02-1	3.01.05.02-1 Ferrovias; Projetos e Construção	\N
1365	095	a	ferrovias;	3.01.05.02-1 Ferrovias; Projetos e Construção	\N
1366	095	a	projetos	3.01.05.02-1 Ferrovias; Projetos e Construção	\N
1367	095	a	construcao	3.01.05.02-1 Ferrovias; Projetos e Construção	\N
1368	095	a	3.01.05.03-0	3.01.05.03-0 Portos e Vias Nevegáveis; Projeto e Construção	\N
1369	095	a	portos	3.01.05.03-0 Portos e Vias Nevegáveis; Projeto e Construção	\N
1370	095	a	vias	3.01.05.03-0 Portos e Vias Nevegáveis; Projeto e Construção	\N
1371	095	a	nevegaveis;	3.01.05.03-0 Portos e Vias Nevegáveis; Projeto e Construção	\N
1372	095	a	projeto	3.01.05.03-0 Portos e Vias Nevegáveis; Projeto e Construção	\N
1373	095	a	construcao	3.01.05.03-0 Portos e Vias Nevegáveis; Projeto e Construção	\N
1374	095	a	3.01.05.04-8	3.01.05.04-8 Rodovias; Projeto e Construção	\N
1375	095	a	rodovias;	3.01.05.04-8 Rodovias; Projeto e Construção	\N
1376	095	a	projeto	3.01.05.04-8 Rodovias; Projeto e Construção	\N
1377	095	a	construcao	3.01.05.04-8 Rodovias; Projeto e Construção	\N
1378	095	a	3.02.00.00-8	3.02.00.00-8 Engenharia de Minas	\N
1379	095	a	engenharia	3.02.00.00-8 Engenharia de Minas	\N
1380	095	a	de	3.02.00.00-8 Engenharia de Minas	\N
1381	095	a	minas	3.02.00.00-8 Engenharia de Minas	\N
1382	095	a	3.02.01.00-4	3.02.01.00-4 Pesquisa Mineral	\N
1383	095	a	pesquisa	3.02.01.00-4 Pesquisa Mineral	\N
1384	095	a	mineral	3.02.01.00-4 Pesquisa Mineral	\N
1385	095	a	3.02.01.01-2	3.02.01.01-2 Caracterização do Minério	\N
1386	095	a	caracterizacao	3.02.01.01-2 Caracterização do Minério	\N
1387	095	a	do	3.02.01.01-2 Caracterização do Minério	\N
1388	095	a	minerio	3.02.01.01-2 Caracterização do Minério	\N
1389	095	a	3.02.01.02-0	3.02.01.02-0 Dimensionamento de Jazidas	\N
1390	095	a	dimensionamento	3.02.01.02-0 Dimensionamento de Jazidas	\N
1391	095	a	de	3.02.01.02-0 Dimensionamento de Jazidas	\N
1392	095	a	jazidas	3.02.01.02-0 Dimensionamento de Jazidas	\N
1393	095	a	3.02.02.00-0	3.02.02.00-0 Lavra	\N
1394	095	a	lavra	3.02.02.00-0 Lavra	\N
1395	095	a	3.02.02.01-9	3.02.02.01-9 Lavra a Céu Aberto	\N
1396	095	a	lavra	3.02.02.01-9 Lavra a Céu Aberto	\N
1397	095	a	ceu	3.02.02.01-9 Lavra a Céu Aberto	\N
1398	095	a	aberto	3.02.02.01-9 Lavra a Céu Aberto	\N
1399	095	a	3.02.02.02-7	3.02.02.02-7 Lavra de Mina Subterrânea	\N
1400	095	a	lavra	3.02.02.02-7 Lavra de Mina Subterrânea	\N
1401	095	a	de	3.02.02.02-7 Lavra de Mina Subterrânea	\N
1402	095	a	mina	3.02.02.02-7 Lavra de Mina Subterrânea	\N
1403	095	a	subterranea	3.02.02.02-7 Lavra de Mina Subterrânea	\N
1404	095	a	3.02.02.03-5	3.02.02.03-5 Equipamentos de Lavra	\N
1405	095	a	equipamentos	3.02.02.03-5 Equipamentos de Lavra	\N
1406	095	a	de	3.02.02.03-5 Equipamentos de Lavra	\N
1407	095	a	lavra	3.02.02.03-5 Equipamentos de Lavra	\N
1408	095	a	3.02.03.00-7	3.02.03.00-7 Tratamento de Minérios	\N
1409	095	a	tratamento	3.02.03.00-7 Tratamento de Minérios	\N
1410	095	a	de	3.02.03.00-7 Tratamento de Minérios	\N
1411	095	a	minerios	3.02.03.00-7 Tratamento de Minérios	\N
1412	095	a	3.02.03.01-5	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1413	095	a	metodos	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1414	095	a	de	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1415	095	a	concentracao	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1416	095	a	enriquecimento	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1417	095	a	de	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1418	095	a	minerios	3.02.03.01-5 Métodos de Concentração e Enriquecimento de Minérios	\N
1419	095	a	3.02.03.02-3	3.02.03.02-3 Equipamentos de Beneficiamento de Minérios	\N
1420	095	a	equipamentos	3.02.03.02-3 Equipamentos de Beneficiamento de Minérios	\N
1421	095	a	de	3.02.03.02-3 Equipamentos de Beneficiamento de Minérios	\N
1422	095	a	beneficiamento	3.02.03.02-3 Equipamentos de Beneficiamento de Minérios	\N
1423	095	a	de	3.02.03.02-3 Equipamentos de Beneficiamento de Minérios	\N
1424	095	a	minerios	3.02.03.02-3 Equipamentos de Beneficiamento de Minérios	\N
1425	095	a	3.03.00.00-2	3.03.00.00-2 Engenharia de Materiais e Metalúrgica	\N
1426	095	a	engenharia	3.03.00.00-2 Engenharia de Materiais e Metalúrgica	\N
1427	095	a	de	3.03.00.00-2 Engenharia de Materiais e Metalúrgica	\N
1428	095	a	materiais	3.03.00.00-2 Engenharia de Materiais e Metalúrgica	\N
1429	095	a	metalurgica	3.03.00.00-2 Engenharia de Materiais e Metalúrgica	\N
1430	095	a	3.03.01.00-9	3.03.01.00-9 Instalações e Equipamentos Metalúrgicos	\N
1431	095	a	instalacoes	3.03.01.00-9 Instalações e Equipamentos Metalúrgicos	\N
1432	095	a	equipamentos	3.03.01.00-9 Instalações e Equipamentos Metalúrgicos	\N
1433	095	a	metalurgicos	3.03.01.00-9 Instalações e Equipamentos Metalúrgicos	\N
1434	095	a	3.03.01.01-7	3.03.01.01-7 Instalações Metalúrgicas	\N
1435	095	a	instalacoes	3.03.01.01-7 Instalações Metalúrgicas	\N
1436	095	a	metalurgicas	3.03.01.01-7 Instalações Metalúrgicas	\N
1437	095	a	3.03.01.02-5	3.03.01.02-5 Equipamentos Metalúrgicos	\N
1438	095	a	equipamentos	3.03.01.02-5 Equipamentos Metalúrgicos	\N
1439	095	a	metalurgicos	3.03.01.02-5 Equipamentos Metalúrgicos	\N
1440	095	a	3.03.02.00-5	3.03.02.00-5 Metalurgia Extrativa	\N
1441	095	a	metalurgia	3.03.02.00-5 Metalurgia Extrativa	\N
1442	095	a	extrativa	3.03.02.00-5 Metalurgia Extrativa	\N
1443	095	a	3.03.02.01-3	3.03.02.01-3 Aglomeração	\N
1444	095	a	aglomeracao	3.03.02.01-3 Aglomeração	\N
1445	095	a	3.03.02.02-1	3.03.02.02-1 Eletrometalurgia	\N
1446	095	a	eletrometalurgia	3.03.02.02-1 Eletrometalurgia	\N
1447	095	a	3.03.02.03-0	3.03.02.03-0 Hidrometalurgia	\N
1448	095	a	hidrometalurgia	3.03.02.03-0 Hidrometalurgia	\N
1449	095	a	3.03.02.04-8	3.03.02.04-8 Pirometalurgia	\N
1450	095	a	pirometalurgia	3.03.02.04-8 Pirometalurgia	\N
1451	095	a	3.03.02.05-6	3.03.02.05-6 Tratamento de Minérios	\N
1452	095	a	tratamento	3.03.02.05-6 Tratamento de Minérios	\N
1453	095	a	de	3.03.02.05-6 Tratamento de Minérios	\N
1454	095	a	minerios	3.03.02.05-6 Tratamento de Minérios	\N
1455	095	a	3.03.03.00-1	3.03.03.00-1 Metalurgia de Transformação	\N
1456	095	a	metalurgia	3.03.03.00-1 Metalurgia de Transformação	\N
1457	095	a	de	3.03.03.00-1 Metalurgia de Transformação	\N
1458	095	a	transformacao	3.03.03.00-1 Metalurgia de Transformação	\N
1459	095	a	3.03.03.01-0	3.03.03.01-0 Conformação Mecânica	\N
1460	095	a	conformacao	3.03.03.01-0 Conformação Mecânica	\N
1461	095	a	mecanica	3.03.03.01-0 Conformação Mecânica	\N
1462	095	a	3.03.03.02-8	3.03.03.02-8 Fundição	\N
1463	095	a	fundicao	3.03.03.02-8 Fundição	\N
1464	095	a	3.03.03.03-6	3.03.03.03-6 Metalurgia de Po	\N
1465	095	a	metalurgia	3.03.03.03-6 Metalurgia de Po	\N
1466	095	a	de	3.03.03.03-6 Metalurgia de Po	\N
1467	095	a	po	3.03.03.03-6 Metalurgia de Po	\N
1468	095	a	3.03.03.04-4	3.03.03.04-4 Recobrimentos	\N
1469	095	a	recobrimentos	3.03.03.04-4 Recobrimentos	\N
1470	095	a	3.03.03.05-2	3.03.03.05-2 Soldagem	\N
1471	095	a	soldagem	3.03.03.05-2 Soldagem	\N
1472	095	a	3.03.03.06-0	3.03.03.06-0 Tratamento Térmicos, Mecânicos e Químicos	\N
1473	095	a	tratamento	3.03.03.06-0 Tratamento Térmicos, Mecânicos e Químicos	\N
1474	095	a	termicos,	3.03.03.06-0 Tratamento Térmicos, Mecânicos e Químicos	\N
1475	095	a	mecanicos	3.03.03.06-0 Tratamento Térmicos, Mecânicos e Químicos	\N
1476	095	a	quimicos	3.03.03.06-0 Tratamento Térmicos, Mecânicos e Químicos	\N
1477	095	a	3.03.03.07-9	3.03.03.07-9 Usinagem	\N
1478	095	a	usinagem	3.03.03.07-9 Usinagem	\N
1479	095	a	3.03.04.00-8	3.03.04.00-8 Metalurgia Fisica	\N
1480	095	a	metalurgia	3.03.04.00-8 Metalurgia Fisica	\N
1481	095	a	fisica	3.03.04.00-8 Metalurgia Fisica	\N
1482	095	a	3.03.04.01-6	3.03.04.01-6 Estrutura dos Metais e Ligas	\N
1483	095	a	estrutura	3.03.04.01-6 Estrutura dos Metais e Ligas	\N
1484	095	a	dos	3.03.04.01-6 Estrutura dos Metais e Ligas	\N
1485	095	a	metais	3.03.04.01-6 Estrutura dos Metais e Ligas	\N
1486	095	a	ligas	3.03.04.01-6 Estrutura dos Metais e Ligas	\N
1487	095	a	3.03.04.02-4	3.03.04.02-4 Propriedades Físicas dos Metais e Ligas	\N
1488	095	a	propriedades	3.03.04.02-4 Propriedades Físicas dos Metais e Ligas	\N
1489	095	a	fisicas	3.03.04.02-4 Propriedades Físicas dos Metais e Ligas	\N
1490	095	a	dos	3.03.04.02-4 Propriedades Físicas dos Metais e Ligas	\N
1491	095	a	metais	3.03.04.02-4 Propriedades Físicas dos Metais e Ligas	\N
1492	095	a	ligas	3.03.04.02-4 Propriedades Físicas dos Metais e Ligas	\N
1493	095	a	3.03.04.03-2	3.03.04.03-2 Propriedades Mecânicas dos Metais e Ligas	\N
1494	095	a	propriedades	3.03.04.03-2 Propriedades Mecânicas dos Metais e Ligas	\N
1495	095	a	mecanicas	3.03.04.03-2 Propriedades Mecânicas dos Metais e Ligas	\N
1496	095	a	dos	3.03.04.03-2 Propriedades Mecânicas dos Metais e Ligas	\N
1497	095	a	metais	3.03.04.03-2 Propriedades Mecânicas dos Metais e Ligas	\N
1498	095	a	ligas	3.03.04.03-2 Propriedades Mecânicas dos Metais e Ligas	\N
1499	095	a	3.03.04.04-0	3.03.04.04-0 Transformação de Fases	\N
1500	095	a	transformacao	3.03.04.04-0 Transformação de Fases	\N
1501	095	a	de	3.03.04.04-0 Transformação de Fases	\N
1502	095	a	fases	3.03.04.04-0 Transformação de Fases	\N
1503	095	a	3.03.04.05-9	3.03.04.05-9 Corrosão	\N
1504	095	a	corrosao	3.03.04.05-9 Corrosão	\N
1505	095	a	3.03.05.00-4	3.03.05.00-4 Materiais não Metálicos	\N
1506	095	a	materiais	3.03.05.00-4 Materiais não Metálicos	\N
1507	095	a	nao	3.03.05.00-4 Materiais não Metálicos	\N
1508	095	a	metalicos	3.03.05.00-4 Materiais não Metálicos	\N
1509	095	a	3.03.05.01-2	3.03.05.01-2 Extração e Transformação de Materiais	\N
1510	095	a	extracao	3.03.05.01-2 Extração e Transformação de Materiais	\N
1511	095	a	transformacao	3.03.05.01-2 Extração e Transformação de Materiais	\N
1512	095	a	de	3.03.05.01-2 Extração e Transformação de Materiais	\N
1513	095	a	materiais	3.03.05.01-2 Extração e Transformação de Materiais	\N
1514	095	a	3.03.05.02-0	3.03.05.02-0 Cerâmicos	\N
1515	095	a	ceramicos	3.03.05.02-0 Cerâmicos	\N
1516	095	a	3.03.05.03-9	3.03.05.03-9 Materiais Conjugados não Metálicos	\N
1517	095	a	materiais	3.03.05.03-9 Materiais Conjugados não Metálicos	\N
1518	095	a	conjugados	3.03.05.03-9 Materiais Conjugados não Metálicos	\N
1519	095	a	nao	3.03.05.03-9 Materiais Conjugados não Metálicos	\N
1520	095	a	metalicos	3.03.05.03-9 Materiais Conjugados não Metálicos	\N
1521	095	a	3.03.05.04-7	3.03.05.04-7 Polímeros, Aplicações	\N
1522	095	a	polimeros,	3.03.05.04-7 Polímeros, Aplicações	\N
1523	095	a	aplicacoes	3.03.05.04-7 Polímeros, Aplicações	\N
1524	095	a	3.04.00.00-7	3.04.00.00-7 Engenharia Elétrica	\N
1525	095	a	engenharia	3.04.00.00-7 Engenharia Elétrica	\N
1526	095	a	eletrica	3.04.00.00-7 Engenharia Elétrica	\N
1527	095	a	3.04.01.00-3	3.04.01.00-3 Materiais Elétricos	\N
1528	095	a	materiais	3.04.01.00-3 Materiais Elétricos	\N
1529	095	a	eletricos	3.04.01.00-3 Materiais Elétricos	\N
1530	095	a	3.04.01.01-1	3.04.01.01-1 Materiais Condutores	\N
1531	095	a	materiais	3.04.01.01-1 Materiais Condutores	\N
1532	095	a	condutores	3.04.01.01-1 Materiais Condutores	\N
1533	095	a	3.04.01.02-0	3.04.01.02-0 Materiais e Componentes Semicondutores	\N
1534	095	a	materiais	3.04.01.02-0 Materiais e Componentes Semicondutores	\N
1535	095	a	componentes	3.04.01.02-0 Materiais e Componentes Semicondutores	\N
1536	095	a	semicondutores	3.04.01.02-0 Materiais e Componentes Semicondutores	\N
1537	095	a	3.04.01.03-8	3.04.01.03-8 Materiais e Dispositivos Supercondutores	\N
1538	095	a	materiais	3.04.01.03-8 Materiais e Dispositivos Supercondutores	\N
1539	095	a	dispositivos	3.04.01.03-8 Materiais e Dispositivos Supercondutores	\N
1540	095	a	supercondutores	3.04.01.03-8 Materiais e Dispositivos Supercondutores	\N
1541	095	a	3.04.01.04-6	3.04.01.04-6 Materiais Dielétricos, Piesoelétricos e Ferroelétricos	\N
1542	095	a	materiais	3.04.01.04-6 Materiais Dielétricos, Piesoelétricos e Ferroelétricos	\N
1543	095	a	dieletricos,	3.04.01.04-6 Materiais Dielétricos, Piesoelétricos e Ferroelétricos	\N
1544	095	a	piesoeletricos	3.04.01.04-6 Materiais Dielétricos, Piesoelétricos e Ferroelétricos	\N
1545	095	a	ferroeletricos	3.04.01.04-6 Materiais Dielétricos, Piesoelétricos e Ferroelétricos	\N
1546	095	a	3.04.01.05-4	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1547	095	a	materiais	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1548	095	a	componentes	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1549	095	a	eletrooticos	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1550	095	a	magnetooticos,	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1551	095	a	materiais	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1552	095	a	fotoeletricos	3.04.01.05-4 Materiais e Componentes Eletroóticos e Magnetoóticos, Materiais Fotoelétricos	\N
1553	095	a	3.04.01.06-2	3.04.01.06-2 Materiais e Dispositivos Magnéticos	\N
1554	095	a	materiais	3.04.01.06-2 Materiais e Dispositivos Magnéticos	\N
1555	095	a	dispositivos	3.04.01.06-2 Materiais e Dispositivos Magnéticos	\N
1556	095	a	magneticos	3.04.01.06-2 Materiais e Dispositivos Magnéticos	\N
1557	095	a	3.04.02.00-0	3.04.02.00-0 Medidas Elétricas, Magnéticas e Eletrônicas; Instrumentação	\N
1558	095	a	medidas	3.04.02.00-0 Medidas Elétricas, Magnéticas e Eletrônicas; Instrumentação	\N
1559	095	a	eletricas,	3.04.02.00-0 Medidas Elétricas, Magnéticas e Eletrônicas; Instrumentação	\N
1560	095	a	magneticas	3.04.02.00-0 Medidas Elétricas, Magnéticas e Eletrônicas; Instrumentação	\N
1561	095	a	eletronicas;	3.04.02.00-0 Medidas Elétricas, Magnéticas e Eletrônicas; Instrumentação	\N
1562	095	a	instrumentacao	3.04.02.00-0 Medidas Elétricas, Magnéticas e Eletrônicas; Instrumentação	\N
1563	095	a	3.04.02.01-8	3.04.02.01-8 Medidas Elétricas	\N
1564	095	a	medidas	3.04.02.01-8 Medidas Elétricas	\N
1565	095	a	eletricas	3.04.02.01-8 Medidas Elétricas	\N
1566	095	a	3.04.02.02-6	3.04.02.02-6 Medidas Magnéticas	\N
1567	095	a	medidas	3.04.02.02-6 Medidas Magnéticas	\N
1568	095	a	magneticas	3.04.02.02-6 Medidas Magnéticas	\N
1569	095	a	3.04.02.03-4	3.04.02.03-4 Instrumentação Eletromecânica	\N
1570	095	a	instrumentacao	3.04.02.03-4 Instrumentação Eletromecânica	\N
1571	095	a	eletromecanica	3.04.02.03-4 Instrumentação Eletromecânica	\N
1572	095	a	3.04.02.04-2	3.04.02.04-2 Instrumentação Eletrônica	\N
1573	095	a	instrumentacao	3.04.02.04-2 Instrumentação Eletrônica	\N
1574	095	a	eletronica	3.04.02.04-2 Instrumentação Eletrônica	\N
1575	095	a	3.04.02.05-0	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1576	095	a	sistemas	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1577	095	a	eletronicos	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1578	095	a	de	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1579	095	a	medida	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1580	095	a	de	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1581	095	a	controle	3.04.02.05-0 Sistemas Eletrônicos de Medida e de Controle	\N
1582	095	a	3.04.03.00-6	3.04.03.00-6 Circuitos Elétricos, Magnéticos e Eletrônicos	\N
1583	095	a	circuitos	3.04.03.00-6 Circuitos Elétricos, Magnéticos e Eletrônicos	\N
1584	095	a	eletricos,	3.04.03.00-6 Circuitos Elétricos, Magnéticos e Eletrônicos	\N
1585	095	a	magneticos	3.04.03.00-6 Circuitos Elétricos, Magnéticos e Eletrônicos	\N
1586	095	a	eletronicos	3.04.03.00-6 Circuitos Elétricos, Magnéticos e Eletrônicos	\N
1587	095	a	3.04.03.01-4	3.04.03.01-4 Teoria Geral dos Circuitos Elétricos	\N
1588	095	a	teoria	3.04.03.01-4 Teoria Geral dos Circuitos Elétricos	\N
1589	095	a	geral	3.04.03.01-4 Teoria Geral dos Circuitos Elétricos	\N
1590	095	a	dos	3.04.03.01-4 Teoria Geral dos Circuitos Elétricos	\N
1591	095	a	circuitos	3.04.03.01-4 Teoria Geral dos Circuitos Elétricos	\N
1592	095	a	eletricos	3.04.03.01-4 Teoria Geral dos Circuitos Elétricos	\N
1593	095	a	3.04.03.02-2	3.04.03.02-2 Circuitos Lineares e Não-Lineares	\N
1594	095	a	circuitos	3.04.03.02-2 Circuitos Lineares e Não-Lineares	\N
1595	095	a	lineares	3.04.03.02-2 Circuitos Lineares e Não-Lineares	\N
1596	095	a	nao-lineares	3.04.03.02-2 Circuitos Lineares e Não-Lineares	\N
1597	095	a	3.04.03.03-0	3.04.03.03-0 Circuitos Eletrônicos	\N
1598	095	a	circuitos	3.04.03.03-0 Circuitos Eletrônicos	\N
1599	095	a	eletronicos	3.04.03.03-0 Circuitos Eletrônicos	\N
1600	095	a	3.04.03.04-9	3.04.03.04-9 Circuitos Magnéticos, Magnetismos, Eletromagnetismo	\N
1601	095	a	circuitos	3.04.03.04-9 Circuitos Magnéticos, Magnetismos, Eletromagnetismo	\N
1602	095	a	magneticos,	3.04.03.04-9 Circuitos Magnéticos, Magnetismos, Eletromagnetismo	\N
1603	095	a	magnetismos,	3.04.03.04-9 Circuitos Magnéticos, Magnetismos, Eletromagnetismo	\N
1604	095	a	eletromagnetismo	3.04.03.04-9 Circuitos Magnéticos, Magnetismos, Eletromagnetismo	\N
1605	095	a	3.04.04.00-2	3.04.04.00-2 Sistemas Elétricos de Potência	\N
1606	095	a	sistemas	3.04.04.00-2 Sistemas Elétricos de Potência	\N
1607	095	a	eletricos	3.04.04.00-2 Sistemas Elétricos de Potência	\N
1608	095	a	de	3.04.04.00-2 Sistemas Elétricos de Potência	\N
1609	095	a	potencia	3.04.04.00-2 Sistemas Elétricos de Potência	\N
1610	095	a	3.04.04.01-0	3.04.04.01-0 Geração da Energia Elétrica	\N
1611	095	a	geracao	3.04.04.01-0 Geração da Energia Elétrica	\N
1612	095	a	da	3.04.04.01-0 Geração da Energia Elétrica	\N
1613	095	a	energia	3.04.04.01-0 Geração da Energia Elétrica	\N
1614	095	a	eletrica	3.04.04.01-0 Geração da Energia Elétrica	\N
1615	095	a	3.04.04.02-9	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1616	095	a	transmissao	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1617	095	a	da	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1618	095	a	energia	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1619	095	a	eletrica,	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1620	095	a	distribuicao	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1621	095	a	da	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1622	095	a	energia	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1623	095	a	eletrica	3.04.04.02-9 Transmissão da Energia Elétrica, Distribuição da Energia Elétrica	\N
1624	095	a	3.04.04.03-7	3.04.04.03-7 Conversão e Retificação da Energia Elétrica	\N
1625	095	a	conversao	3.04.04.03-7 Conversão e Retificação da Energia Elétrica	\N
1626	095	a	retificacao	3.04.04.03-7 Conversão e Retificação da Energia Elétrica	\N
1627	095	a	da	3.04.04.03-7 Conversão e Retificação da Energia Elétrica	\N
1628	095	a	energia	3.04.04.03-7 Conversão e Retificação da Energia Elétrica	\N
1629	095	a	eletrica	3.04.04.03-7 Conversão e Retificação da Energia Elétrica	\N
1630	095	a	3.04.04.04-5	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1631	095	a	medicao,	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1632	095	a	controle,	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1633	095	a	correcao	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1634	095	a	protecao	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1635	095	a	de	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1636	095	a	sistemas	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1637	095	a	eletricos	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1638	095	a	de	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1639	095	a	potencia	3.04.04.04-5 Medição, Controle, Correção e Proteção de Sistemas Elétricos de Potência	\N
1640	095	a	3.04.04.05-3	3.04.04.05-3 Máquinas Elétricas e Dispositivos de Potência	\N
1641	095	a	maquinas	3.04.04.05-3 Máquinas Elétricas e Dispositivos de Potência	\N
1642	095	a	eletricas	3.04.04.05-3 Máquinas Elétricas e Dispositivos de Potência	\N
1643	095	a	dispositivos	3.04.04.05-3 Máquinas Elétricas e Dispositivos de Potência	\N
1644	095	a	de	3.04.04.05-3 Máquinas Elétricas e Dispositivos de Potência	\N
1645	095	a	potencia	3.04.04.05-3 Máquinas Elétricas e Dispositivos de Potência	\N
1646	095	a	3.04.04.06-1	3.04.04.06-1 Instalações Elétricas Prediais e Industriais	\N
1647	095	a	instalacoes	3.04.04.06-1 Instalações Elétricas Prediais e Industriais	\N
1648	095	a	eletricas	3.04.04.06-1 Instalações Elétricas Prediais e Industriais	\N
1649	095	a	prediais	3.04.04.06-1 Instalações Elétricas Prediais e Industriais	\N
1650	095	a	industriais	3.04.04.06-1 Instalações Elétricas Prediais e Industriais	\N
1651	095	a	3.04.05.00-9	3.04.05.00-9 Eletrônica Industrial, Sistemas e Controles Eletrônicos	\N
1652	095	a	eletronica	3.04.05.00-9 Eletrônica Industrial, Sistemas e Controles Eletrônicos	\N
1653	095	a	industrial,	3.04.05.00-9 Eletrônica Industrial, Sistemas e Controles Eletrônicos	\N
1654	095	a	sistemas	3.04.05.00-9 Eletrônica Industrial, Sistemas e Controles Eletrônicos	\N
1655	095	a	controles	3.04.05.00-9 Eletrônica Industrial, Sistemas e Controles Eletrônicos	\N
1656	095	a	eletronicos	3.04.05.00-9 Eletrônica Industrial, Sistemas e Controles Eletrônicos	\N
1657	095	a	3.04.05.01-7	3.04.05.01-7 Eletrônica Industrial	\N
1658	095	a	eletronica	3.04.05.01-7 Eletrônica Industrial	\N
1659	095	a	industrial	3.04.05.01-7 Eletrônica Industrial	\N
1660	095	a	3.04.05.02-5	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1661	095	a	automacao	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1662	095	a	eletronica	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1663	095	a	de	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1664	095	a	processos	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1665	095	a	eletricos	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1666	095	a	industriais	3.04.05.02-5 Automação Eletrônica de Processos Elétricos e Industriais	\N
1667	095	a	3.04.05.03-3	3.04.05.03-3 Controle de Processos Eletrônicos, Retroalimentação	\N
1668	095	a	controle	3.04.05.03-3 Controle de Processos Eletrônicos, Retroalimentação	\N
1669	095	a	de	3.04.05.03-3 Controle de Processos Eletrônicos, Retroalimentação	\N
1670	095	a	processos	3.04.05.03-3 Controle de Processos Eletrônicos, Retroalimentação	\N
1671	095	a	eletronicos,	3.04.05.03-3 Controle de Processos Eletrônicos, Retroalimentação	\N
1672	095	a	retroalimentacao	3.04.05.03-3 Controle de Processos Eletrônicos, Retroalimentação	\N
1673	095	a	3.04.06.00-5	3.04.06.00-5 Telecomunicações	\N
1674	095	a	telecomunicacoes	3.04.06.00-5 Telecomunicações	\N
1675	095	a	3.04.06.01-3	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1676	095	a	teoria	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1677	095	a	eletromagnetica,	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1678	095	a	microondas,	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1679	095	a	propagacao	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1680	095	a	de	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1681	095	a	ondas,	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1682	095	a	antenas	3.04.06.01-3 Teoria Eletromagnética, Microondas, Propagação de Ondas, Antenas	\N
1683	095	a	3.04.06.02-1	3.04.06.02-1 Radionavegação e Radioastronomia	\N
1684	095	a	radionavegacao	3.04.06.02-1 Radionavegação e Radioastronomia	\N
1685	095	a	radioastronomia	3.04.06.02-1 Radionavegação e Radioastronomia	\N
1686	095	a	3.04.06.03-0	3.04.06.03-0 Sistemas de Telecomunicações	\N
1687	095	a	sistemas	3.04.06.03-0 Sistemas de Telecomunicações	\N
1688	095	a	de	3.04.06.03-0 Sistemas de Telecomunicações	\N
1689	095	a	telecomunicacoes	3.04.06.03-0 Sistemas de Telecomunicações	\N
1690	095	a	3.05.00.00-1	3.05.00.00-1 Engenharia Mecânica	\N
1691	095	a	engenharia	3.05.00.00-1 Engenharia Mecânica	\N
1692	095	a	mecanica	3.05.00.00-1 Engenharia Mecânica	\N
1693	095	a	3.05.01.00-8	3.05.01.00-8 Fenômenos de Transporte	\N
1694	095	a	fenomenos	3.05.01.00-8 Fenômenos de Transporte	\N
1695	095	a	de	3.05.01.00-8 Fenômenos de Transporte	\N
1696	095	a	transporte	3.05.01.00-8 Fenômenos de Transporte	\N
1697	095	a	3.05.01.01-6	3.05.01.01-6 Transferência de Calor	\N
1698	095	a	transferencia	3.05.01.01-6 Transferência de Calor	\N
1699	095	a	de	3.05.01.01-6 Transferência de Calor	\N
1700	095	a	calor	3.05.01.01-6 Transferência de Calor	\N
1701	095	a	3.05.01.02-4	3.05.01.02-4 Mecânica dos Fluidos	\N
1702	095	a	mecanica	3.05.01.02-4 Mecânica dos Fluidos	\N
1703	095	a	dos	3.05.01.02-4 Mecânica dos Fluidos	\N
1704	095	a	fluidos	3.05.01.02-4 Mecânica dos Fluidos	\N
1705	095	a	3.05.01.03-2	3.05.01.03-2 Dinâmica dos Gases	\N
1706	095	a	dinamica	3.05.01.03-2 Dinâmica dos Gases	\N
1707	095	a	dos	3.05.01.03-2 Dinâmica dos Gases	\N
1708	095	a	gases	3.05.01.03-2 Dinâmica dos Gases	\N
1709	095	a	3.05.01.04-0	3.05.01.04-0 Principios Variacionais e Métodos Numéricos	\N
1710	095	a	principios	3.05.01.04-0 Principios Variacionais e Métodos Numéricos	\N
1711	095	a	variacionais	3.05.01.04-0 Principios Variacionais e Métodos Numéricos	\N
1712	095	a	metodos	3.05.01.04-0 Principios Variacionais e Métodos Numéricos	\N
1713	095	a	numericos	3.05.01.04-0 Principios Variacionais e Métodos Numéricos	\N
1714	095	a	3.05.02.00-4	3.05.02.00-4 Engenharia Térmica	\N
1715	095	a	engenharia	3.05.02.00-4 Engenharia Térmica	\N
1716	095	a	termica	3.05.02.00-4 Engenharia Térmica	\N
1717	095	a	3.05.02.01-2	3.05.02.01-2 Termodinâmica	\N
1718	095	a	termodinamica	3.05.02.01-2 Termodinâmica	\N
1719	095	a	3.05.02.02-0	3.05.02.02-0 Controle Ambiental	\N
1720	095	a	controle	3.05.02.02-0 Controle Ambiental	\N
1721	095	a	ambiental	3.05.02.02-0 Controle Ambiental	\N
1722	095	a	3.05.02.03-9	3.05.02.03-9 Aproveitamento da Energia	\N
1723	095	a	aproveitamento	3.05.02.03-9 Aproveitamento da Energia	\N
1724	095	a	da	3.05.02.03-9 Aproveitamento da Energia	\N
1725	095	a	energia	3.05.02.03-9 Aproveitamento da Energia	\N
1726	095	a	3.05.03.00-0	3.05.03.00-0 Mecânica dos Sólidos	\N
1727	095	a	mecanica	3.05.03.00-0 Mecânica dos Sólidos	\N
1728	095	a	dos	3.05.03.00-0 Mecânica dos Sólidos	\N
1729	095	a	solidos	3.05.03.00-0 Mecânica dos Sólidos	\N
1730	095	a	3.05.03.01-9	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1731	095	a	mecanica	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1732	095	a	dos	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1733	095	a	corpos	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1734	095	a	solidos,	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1735	095	a	elasticos	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1736	095	a	plasticos	3.05.03.01-9 Mecânica dos Corpos Sólidos, Elásticos e Plásticos	\N
1737	095	a	3.05.03.02-7	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1738	095	a	dinamica	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1739	095	a	dos	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1740	095	a	corpos	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1741	095	a	rigidos,	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1742	095	a	elasticos	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1743	095	a	plasticos	3.05.03.02-7 Dinâmica dos Corpos Rígidos, Elásticos e Plásticos	\N
1744	095	a	3.05.03.03-5	3.05.03.03-5 Análise de Tensões	\N
1745	095	a	analise	3.05.03.03-5 Análise de Tensões	\N
1746	095	a	de	3.05.03.03-5 Análise de Tensões	\N
1747	095	a	tensoes	3.05.03.03-5 Análise de Tensões	\N
1748	095	a	3.05.03.04-3	3.05.03.04-3 Termoelasticidade	\N
1749	095	a	termoelasticidade	3.05.03.04-3 Termoelasticidade	\N
1750	095	a	3.05.04.00-7	3.05.04.00-7 Projetos de Máquinas	\N
1751	095	a	projetos	3.05.04.00-7 Projetos de Máquinas	\N
1752	095	a	de	3.05.04.00-7 Projetos de Máquinas	\N
1753	095	a	maquinas	3.05.04.00-7 Projetos de Máquinas	\N
1754	095	a	3.05.04.01-5	3.05.04.01-5 Teoria dos Mecanismos	\N
1755	095	a	teoria	3.05.04.01-5 Teoria dos Mecanismos	\N
1756	095	a	dos	3.05.04.01-5 Teoria dos Mecanismos	\N
1757	095	a	mecanismos	3.05.04.01-5 Teoria dos Mecanismos	\N
1758	095	a	3.05.04.02-3	3.05.04.02-3 Estática e Dinâmica Aplicada	\N
1759	095	a	estatica	3.05.04.02-3 Estática e Dinâmica Aplicada	\N
1760	095	a	dinamica	3.05.04.02-3 Estática e Dinâmica Aplicada	\N
1761	095	a	aplicada	3.05.04.02-3 Estática e Dinâmica Aplicada	\N
1762	095	a	3.05.04.03-1	3.05.04.03-1 Elementos de Máquinas	\N
1763	095	a	elementos	3.05.04.03-1 Elementos de Máquinas	\N
1764	095	a	de	3.05.04.03-1 Elementos de Máquinas	\N
1765	095	a	maquinas	3.05.04.03-1 Elementos de Máquinas	\N
1766	095	a	3.05.04.04-0	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1767	095	a	fundamentos	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1768	095	a	gerais	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1769	095	a	de	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1770	095	a	projetos	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1771	095	a	das	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1772	095	a	maquinas	3.05.04.04-0 Fundamentos Gerais de Projetos das Máquinas	\N
1773	095	a	3.05.04.05-8	3.05.04.05-8 Máquinas, Motores e Equipamentos	\N
1774	095	a	maquinas,	3.05.04.05-8 Máquinas, Motores e Equipamentos	\N
1775	095	a	motores	3.05.04.05-8 Máquinas, Motores e Equipamentos	\N
1776	095	a	equipamentos	3.05.04.05-8 Máquinas, Motores e Equipamentos	\N
1777	095	a	3.05.04.06-6	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1778	095	a	metodos	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1779	095	a	de	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1780	095	a	sintese	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1781	095	a	otimizacao	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1782	095	a	aplicados	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1783	095	a	ao	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1784	095	a	projeto	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1785	095	a	mecanico	3.05.04.06-6 Métodos de Síntese e Otimização Aplicados ao Projeto Mecânico	\N
1786	095	a	3.05.04.07-4	3.05.04.07-4 Controle de Sistemas Mecânicos	\N
1787	095	a	controle	3.05.04.07-4 Controle de Sistemas Mecânicos	\N
1788	095	a	de	3.05.04.07-4 Controle de Sistemas Mecânicos	\N
1789	095	a	sistemas	3.05.04.07-4 Controle de Sistemas Mecânicos	\N
1790	095	a	mecanicos	3.05.04.07-4 Controle de Sistemas Mecânicos	\N
1791	095	a	3.05.04.08-2	3.05.04.08-2 Aproveitamento de Energia	\N
1792	095	a	aproveitamento	3.05.04.08-2 Aproveitamento de Energia	\N
1793	095	a	de	3.05.04.08-2 Aproveitamento de Energia	\N
1794	095	a	energia	3.05.04.08-2 Aproveitamento de Energia	\N
1795	095	a	3.05.05.00-3	3.05.05.00-3 Processos de Fabricação	\N
1796	095	a	processos	3.05.05.00-3 Processos de Fabricação	\N
1797	095	a	de	3.05.05.00-3 Processos de Fabricação	\N
1798	095	a	fabricacao	3.05.05.00-3 Processos de Fabricação	\N
1799	095	a	3.05.05.01-1	3.05.05.01-1 Matrizes e Ferramentas	\N
1800	095	a	matrizes	3.05.05.01-1 Matrizes e Ferramentas	\N
1801	095	a	ferramentas	3.05.05.01-1 Matrizes e Ferramentas	\N
1802	095	a	3.05.05.02-0	3.05.05.02-0 Máquinas de Usinagem e Conformação	\N
1803	095	a	maquinas	3.05.05.02-0 Máquinas de Usinagem e Conformação	\N
1804	095	a	de	3.05.05.02-0 Máquinas de Usinagem e Conformação	\N
1805	095	a	usinagem	3.05.05.02-0 Máquinas de Usinagem e Conformação	\N
1806	095	a	conformacao	3.05.05.02-0 Máquinas de Usinagem e Conformação	\N
1807	095	a	3.05.05.03-8	3.05.05.03-8 Controle Numérico	\N
1808	095	a	controle	3.05.05.03-8 Controle Numérico	\N
1809	095	a	numerico	3.05.05.03-8 Controle Numérico	\N
1810	095	a	3.05.05.04-6	3.05.05.04-6 Robotização	\N
1811	095	a	robotizacao	3.05.05.04-6 Robotização	\N
1812	095	a	3.05.05.05-4	3.05.05.05-4 Processos de Fabricação, Seleção Econômica	\N
1813	095	a	processos	3.05.05.05-4 Processos de Fabricação, Seleção Econômica	\N
1814	095	a	de	3.05.05.05-4 Processos de Fabricação, Seleção Econômica	\N
1815	095	a	fabricacao,	3.05.05.05-4 Processos de Fabricação, Seleção Econômica	\N
1816	095	a	selecao	3.05.05.05-4 Processos de Fabricação, Seleção Econômica	\N
1817	095	a	economica	3.05.05.05-4 Processos de Fabricação, Seleção Econômica	\N
1818	095	a	3.06.00.00-6	3.06.00.00-6 Engenharia Química	\N
1819	095	a	engenharia	3.06.00.00-6 Engenharia Química	\N
1820	095	a	quimica	3.06.00.00-6 Engenharia Química	\N
1821	095	a	3.06.01.00-2	3.06.01.00-2 Processos Industriais de Engenharia Química	\N
1822	095	a	processos	3.06.01.00-2 Processos Industriais de Engenharia Química	\N
1823	095	a	industriais	3.06.01.00-2 Processos Industriais de Engenharia Química	\N
1824	095	a	de	3.06.01.00-2 Processos Industriais de Engenharia Química	\N
1825	095	a	engenharia	3.06.01.00-2 Processos Industriais de Engenharia Química	\N
1826	095	a	quimica	3.06.01.00-2 Processos Industriais de Engenharia Química	\N
1827	095	a	3.06.01.01-0	3.06.01.01-0 Processos Bioquimicos	\N
1828	095	a	processos	3.06.01.01-0 Processos Bioquimicos	\N
1829	095	a	bioquimicos	3.06.01.01-0 Processos Bioquimicos	\N
1830	095	a	3.06.01.02-9	3.06.01.02-9 Processos Orgânicos	\N
1831	095	a	processos	3.06.01.02-9 Processos Orgânicos	\N
1832	095	a	organicos	3.06.01.02-9 Processos Orgânicos	\N
1833	095	a	3.06.01.03-7	3.06.01.03-7 Processos Inorgânicos	\N
1834	095	a	processos	3.06.01.03-7 Processos Inorgânicos	\N
1835	095	a	inorganicos	3.06.01.03-7 Processos Inorgânicos	\N
1836	095	a	3.06.02.00-9	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1837	095	a	operacoes	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1838	095	a	industriais	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1839	095	a	equipamentos	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1840	095	a	para	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1841	095	a	engenharia	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1842	095	a	quimica	3.06.02.00-9 Operações Industriais e Equipamentos para Engenharia Química	\N
1843	095	a	3.06.02.01-7	3.06.02.01-7 Reatores Químicos	\N
1844	095	a	reatores	3.06.02.01-7 Reatores Químicos	\N
1845	095	a	quimicos	3.06.02.01-7 Reatores Químicos	\N
1846	095	a	3.06.02.02-5	3.06.02.02-5 Operações Características de Processos Bioquímicos	\N
1847	095	a	operacoes	3.06.02.02-5 Operações Características de Processos Bioquímicos	\N
1848	095	a	caracteristicas	3.06.02.02-5 Operações Características de Processos Bioquímicos	\N
1849	095	a	de	3.06.02.02-5 Operações Características de Processos Bioquímicos	\N
1850	095	a	processos	3.06.02.02-5 Operações Características de Processos Bioquímicos	\N
1851	095	a	bioquimicos	3.06.02.02-5 Operações Características de Processos Bioquímicos	\N
1852	095	a	3.06.02.03-3	3.06.02.03-3 Operações de Separação e Mistura	\N
1853	095	a	operacoes	3.06.02.03-3 Operações de Separação e Mistura	\N
1854	095	a	de	3.06.02.03-3 Operações de Separação e Mistura	\N
1855	095	a	separacao	3.06.02.03-3 Operações de Separação e Mistura	\N
1856	095	a	mistura	3.06.02.03-3 Operações de Separação e Mistura	\N
1857	095	a	3.06.03.00-5	3.06.03.00-5 Tecnologia Química	\N
1858	095	a	tecnologia	3.06.03.00-5 Tecnologia Química	\N
1859	095	a	quimica	3.06.03.00-5 Tecnologia Química	\N
1860	095	a	3.06.03.01-3	3.06.03.01-3 Balancos Globais de Matéria e Energia	\N
1861	095	a	balancos	3.06.03.01-3 Balancos Globais de Matéria e Energia	\N
1862	095	a	globais	3.06.03.01-3 Balancos Globais de Matéria e Energia	\N
1863	095	a	de	3.06.03.01-3 Balancos Globais de Matéria e Energia	\N
1864	095	a	materia	3.06.03.01-3 Balancos Globais de Matéria e Energia	\N
1865	095	a	energia	3.06.03.01-3 Balancos Globais de Matéria e Energia	\N
1866	095	a	3.06.03.02-1	3.06.03.02-1 Água	\N
1867	095	a	agua	3.06.03.02-1 Água	\N
1868	095	a	3.06.03.03-0	3.06.03.03-0 Álcool	\N
1869	095	a	alcool	3.06.03.03-0 Álcool	\N
1870	095	a	3.06.03.04-8	3.06.03.04-8 Alimentos	\N
1871	095	a	alimentos	3.06.03.04-8 Alimentos	\N
1872	095	a	3.06.03.05-6	3.06.03.05-6 Borrachas	\N
1873	095	a	borrachas	3.06.03.05-6 Borrachas	\N
1874	095	a	3.06.03.06-4	3.06.03.06-4 Carvão	\N
1875	095	a	carvao	3.06.03.06-4 Carvão	\N
1876	095	a	3.06.03.07-2	3.06.03.07-2 Cerâmica	\N
1877	095	a	ceramica	3.06.03.07-2 Cerâmica	\N
1878	095	a	3.06.03.08-0	3.06.03.08-0 Cimento	\N
1879	095	a	cimento	3.06.03.08-0 Cimento	\N
1880	095	a	3.06.03.09-9	3.06.03.09-9 Couro	\N
1881	095	a	couro	3.06.03.09-9 Couro	\N
1882	095	a	3.06.03.10-2	3.06.03.10-2 Detergentes	\N
1883	095	a	detergentes	3.06.03.10-2 Detergentes	\N
1884	095	a	3.06.03.11-0	3.06.03.11-0 Fertilizantes	\N
1885	095	a	fertilizantes	3.06.03.11-0 Fertilizantes	\N
1886	095	a	3.06.03.12-9	3.06.03.12-9 Medicamentos	\N
1887	095	a	medicamentos	3.06.03.12-9 Medicamentos	\N
1888	095	a	3.06.03.13-7	3.06.03.13-7 Metais não-Ferrosos	\N
1889	095	a	metais	3.06.03.13-7 Metais não-Ferrosos	\N
1890	095	a	nao-ferrosos	3.06.03.13-7 Metais não-Ferrosos	\N
1891	095	a	3.06.03.14-5	3.06.03.14-5 Óleos	\N
1892	095	a	oleos	3.06.03.14-5 Óleos	\N
1893	095	a	3.06.03.15-3	3.06.03.15-3 Papel e Celulose	\N
1894	095	a	papel	3.06.03.15-3 Papel e Celulose	\N
1895	095	a	celulose	3.06.03.15-3 Papel e Celulose	\N
1896	095	a	3.06.03.16-1	3.06.03.16-1 Petróleo e Petroquímica	\N
1897	095	a	petroleo	3.06.03.16-1 Petróleo e Petroquímica	\N
1898	095	a	petroquimica	3.06.03.16-1 Petróleo e Petroquímica	\N
1899	095	a	3.06.03.17-0	3.06.03.17-0 Polímeros	\N
1900	095	a	polimeros	3.06.03.17-0 Polímeros	\N
1901	095	a	3.06.03.18-8	3.06.03.18-8 Produtos Naturais	\N
1902	095	a	produtos	3.06.03.18-8 Produtos Naturais	\N
1903	095	a	naturais	3.06.03.18-8 Produtos Naturais	\N
1904	095	a	3.06.03.19-6	3.06.03.19-6 Têxteis	\N
1905	095	a	texteis	3.06.03.19-6 Têxteis	\N
1906	095	a	3.06.03.20-0	3.06.03.20-0 Tratamentos e Aproveitamento de Rejeitos	\N
1907	095	a	tratamentos	3.06.03.20-0 Tratamentos e Aproveitamento de Rejeitos	\N
1908	095	a	aproveitamento	3.06.03.20-0 Tratamentos e Aproveitamento de Rejeitos	\N
1909	095	a	de	3.06.03.20-0 Tratamentos e Aproveitamento de Rejeitos	\N
1910	095	a	rejeitos	3.06.03.20-0 Tratamentos e Aproveitamento de Rejeitos	\N
1911	095	a	3.06.03.21-8	3.06.03.21-8 Xisto	\N
1912	095	a	xisto	3.06.03.21-8 Xisto	\N
1913	095	a	3.07.00.00-0	3.07.00.00-0 Engenharia Sanitária	\N
1914	095	a	engenharia	3.07.00.00-0 Engenharia Sanitária	\N
1915	095	a	sanitaria	3.07.00.00-0 Engenharia Sanitária	\N
1916	095	a	3.07.01.00-7	3.07.01.00-7 Recursos Hídricos	\N
1917	095	a	recursos	3.07.01.00-7 Recursos Hídricos	\N
1918	095	a	hidricos	3.07.01.00-7 Recursos Hídricos	\N
1919	095	a	3.07.01.01-5	3.07.01.01-5 Planejamento Integrado dos Recursos Hídricos	\N
1920	095	a	planejamento	3.07.01.01-5 Planejamento Integrado dos Recursos Hídricos	\N
1921	095	a	integrado	3.07.01.01-5 Planejamento Integrado dos Recursos Hídricos	\N
1922	095	a	dos	3.07.01.01-5 Planejamento Integrado dos Recursos Hídricos	\N
1923	095	a	recursos	3.07.01.01-5 Planejamento Integrado dos Recursos Hídricos	\N
1924	095	a	hidricos	3.07.01.01-5 Planejamento Integrado dos Recursos Hídricos	\N
1925	095	a	3.07.01.02-3	3.07.01.02-3 Tecnologia e Problemas Sanitários de Irrigação	\N
1926	095	a	tecnologia	3.07.01.02-3 Tecnologia e Problemas Sanitários de Irrigação	\N
1927	095	a	problemas	3.07.01.02-3 Tecnologia e Problemas Sanitários de Irrigação	\N
1928	095	a	sanitarios	3.07.01.02-3 Tecnologia e Problemas Sanitários de Irrigação	\N
1929	095	a	de	3.07.01.02-3 Tecnologia e Problemas Sanitários de Irrigação	\N
1930	095	a	irrigacao	3.07.01.02-3 Tecnologia e Problemas Sanitários de Irrigação	\N
1931	095	a	3.07.01.03-1	3.07.01.03-1 Águas Subterrâneas e Poços Profundos	\N
1932	095	a	aguas	3.07.01.03-1 Águas Subterrâneas e Poços Profundos	\N
1933	095	a	subterraneas	3.07.01.03-1 Águas Subterrâneas e Poços Profundos	\N
1934	095	a	pocos	3.07.01.03-1 Águas Subterrâneas e Poços Profundos	\N
1935	095	a	profundos	3.07.01.03-1 Águas Subterrâneas e Poços Profundos	\N
1936	095	a	3.07.01.04-0	3.07.01.04-0 Controle de Enchentes e de Barragens	\N
1937	095	a	controle	3.07.01.04-0 Controle de Enchentes e de Barragens	\N
1938	095	a	de	3.07.01.04-0 Controle de Enchentes e de Barragens	\N
1939	095	a	enchentes	3.07.01.04-0 Controle de Enchentes e de Barragens	\N
1940	095	a	de	3.07.01.04-0 Controle de Enchentes e de Barragens	\N
1941	095	a	barragens	3.07.01.04-0 Controle de Enchentes e de Barragens	\N
1942	095	a	3.07.01.05-8	3.07.01.05-8 Sedimentologia	\N
1943	095	a	sedimentologia	3.07.01.05-8 Sedimentologia	\N
1944	095	a	3.07.02.00-3	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1945	095	a	tratamento	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1946	095	a	de	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1947	095	a	aguas	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1948	095	a	de	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1949	095	a	abastecimento	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1950	095	a	residuarias	3.07.02.00-3 Tratamento de Águas de Abastecimento e Residuárias	\N
1951	095	a	3.07.02.01-1	3.07.02.01-1 Química Sanitária	\N
1952	095	a	quimica	3.07.02.01-1 Química Sanitária	\N
1953	095	a	sanitaria	3.07.02.01-1 Química Sanitária	\N
1954	095	a	3.07.02.02-0	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1955	095	a	processos	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1956	095	a	simplificados	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1957	095	a	de	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1958	095	a	tratamento	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1959	095	a	de	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1960	095	a	aguas	3.07.02.02-0 Processos Simplificados de Tratamento de Águas	\N
1961	095	a	3.07.02.03-8	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1962	095	a	tecnicas	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1963	095	a	convencionais	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1964	095	a	de	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1965	095	a	tratamento	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1966	095	a	de	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1967	095	a	aguas	3.07.02.03-8 Técnicas Convencionais de Tratamento de Águas	\N
1968	095	a	3.07.02.04-6	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1969	095	a	tecnicas	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1970	095	a	avancadas	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1971	095	a	de	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1972	095	a	tratamento	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1973	095	a	de	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1974	095	a	aguas	3.07.02.04-6 Técnicas Avancadas de Tratamento de Águas	\N
1975	095	a	3.07.02.05-4	3.07.02.05-4 Estudos e Caracterização de Efluentes Industriais	\N
1976	095	a	estudos	3.07.02.05-4 Estudos e Caracterização de Efluentes Industriais	\N
1977	095	a	caracterizacao	3.07.02.05-4 Estudos e Caracterização de Efluentes Industriais	\N
1978	095	a	de	3.07.02.05-4 Estudos e Caracterização de Efluentes Industriais	\N
1979	095	a	efluentes	3.07.02.05-4 Estudos e Caracterização de Efluentes Industriais	\N
1980	095	a	industriais	3.07.02.05-4 Estudos e Caracterização de Efluentes Industriais	\N
1981	095	a	3.07.02.06-2	3.07.02.06-2 Lay Out de Processos Industriais	\N
1982	095	a	lay	3.07.02.06-2 Lay Out de Processos Industriais	\N
1983	095	a	out	3.07.02.06-2 Lay Out de Processos Industriais	\N
1984	095	a	de	3.07.02.06-2 Lay Out de Processos Industriais	\N
1985	095	a	processos	3.07.02.06-2 Lay Out de Processos Industriais	\N
1986	095	a	industriais	3.07.02.06-2 Lay Out de Processos Industriais	\N
1987	095	a	3.07.02.07-0	3.07.02.07-0 Resíduos Radioativos	\N
1988	095	a	residuos	3.07.02.07-0 Resíduos Radioativos	\N
1989	095	a	radioativos	3.07.02.07-0 Resíduos Radioativos	\N
1990	095	a	3.07.03.00-0	3.07.03.00-0 Saneamento Básico	\N
1991	095	a	saneamento	3.07.03.00-0 Saneamento Básico	\N
1992	095	a	basico	3.07.03.00-0 Saneamento Básico	\N
1993	095	a	3.07.03.01-8	3.07.03.01-8 Técnicas de Abastecimento da Água	\N
1994	095	a	tecnicas	3.07.03.01-8 Técnicas de Abastecimento da Água	\N
1995	095	a	de	3.07.03.01-8 Técnicas de Abastecimento da Água	\N
1996	095	a	abastecimento	3.07.03.01-8 Técnicas de Abastecimento da Água	\N
1997	095	a	da	3.07.03.01-8 Técnicas de Abastecimento da Água	\N
1998	095	a	agua	3.07.03.01-8 Técnicas de Abastecimento da Água	\N
1999	095	a	3.07.03.02-6	3.07.03.02-6 Drenagem de Águas Residuárias	\N
2000	095	a	drenagem	3.07.03.02-6 Drenagem de Águas Residuárias	\N
2001	095	a	de	3.07.03.02-6 Drenagem de Águas Residuárias	\N
2002	095	a	aguas	3.07.03.02-6 Drenagem de Águas Residuárias	\N
2003	095	a	residuarias	3.07.03.02-6 Drenagem de Águas Residuárias	\N
2004	095	a	3.07.03.03-4	3.07.03.03-4 Drenagem Urbana de Águas Pluviais	\N
2005	095	a	drenagem	3.07.03.03-4 Drenagem Urbana de Águas Pluviais	\N
2006	095	a	urbana	3.07.03.03-4 Drenagem Urbana de Águas Pluviais	\N
2007	095	a	de	3.07.03.03-4 Drenagem Urbana de Águas Pluviais	\N
2008	095	a	aguas	3.07.03.03-4 Drenagem Urbana de Águas Pluviais	\N
2009	095	a	pluviais	3.07.03.03-4 Drenagem Urbana de Águas Pluviais	\N
2010	095	a	3.07.03.04-2	3.07.03.04-2 Resíduos Sólidos, Domésticos e Industriais	\N
2011	095	a	residuos	3.07.03.04-2 Resíduos Sólidos, Domésticos e Industriais	\N
2012	095	a	solidos,	3.07.03.04-2 Resíduos Sólidos, Domésticos e Industriais	\N
2013	095	a	domesticos	3.07.03.04-2 Resíduos Sólidos, Domésticos e Industriais	\N
2014	095	a	industriais	3.07.03.04-2 Resíduos Sólidos, Domésticos e Industriais	\N
2015	095	a	3.07.03.05-0	3.07.03.05-0 Limpeza Pública	\N
2016	095	a	limpeza	3.07.03.05-0 Limpeza Pública	\N
2017	095	a	publica	3.07.03.05-0 Limpeza Pública	\N
2018	095	a	3.07.03.06-9	3.07.03.06-9 Instalações Hidráulico-Sanitárias	\N
2019	095	a	instalacoes	3.07.03.06-9 Instalações Hidráulico-Sanitárias	\N
2020	095	a	hidraulico-sanitarias	3.07.03.06-9 Instalações Hidráulico-Sanitárias	\N
2021	095	a	3.07.04.00-6	3.07.04.00-6 Saneamento Ambiental	\N
2022	095	a	saneamento	3.07.04.00-6 Saneamento Ambiental	\N
2023	095	a	ambiental	3.07.04.00-6 Saneamento Ambiental	\N
2024	095	a	3.07.04.01-4	3.07.04.01-4 Ecologia Aplicada à Engenharia Sanitária	\N
2025	095	a	ecologia	3.07.04.01-4 Ecologia Aplicada à Engenharia Sanitária	\N
2026	095	a	aplicada	3.07.04.01-4 Ecologia Aplicada à Engenharia Sanitária	\N
2027	095	a	engenharia	3.07.04.01-4 Ecologia Aplicada à Engenharia Sanitária	\N
2028	095	a	sanitaria	3.07.04.01-4 Ecologia Aplicada à Engenharia Sanitária	\N
2029	095	a	3.07.04.02-2	3.07.04.02-2 Microbiologia Aplicada e Engenharia Sanitária	\N
2030	095	a	microbiologia	3.07.04.02-2 Microbiologia Aplicada e Engenharia Sanitária	\N
2031	095	a	aplicada	3.07.04.02-2 Microbiologia Aplicada e Engenharia Sanitária	\N
2032	095	a	engenharia	3.07.04.02-2 Microbiologia Aplicada e Engenharia Sanitária	\N
2033	095	a	sanitaria	3.07.04.02-2 Microbiologia Aplicada e Engenharia Sanitária	\N
2034	095	a	3.07.04.03-0	3.07.04.03-0 Parasitologia Aplicada à Engenharia Sanitária	\N
2035	095	a	parasitologia	3.07.04.03-0 Parasitologia Aplicada à Engenharia Sanitária	\N
2036	095	a	aplicada	3.07.04.03-0 Parasitologia Aplicada à Engenharia Sanitária	\N
2037	095	a	engenharia	3.07.04.03-0 Parasitologia Aplicada à Engenharia Sanitária	\N
2038	095	a	sanitaria	3.07.04.03-0 Parasitologia Aplicada à Engenharia Sanitária	\N
2039	095	a	3.07.04.04-9	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2040	095	a	qualidade	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2041	095	a	do	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2042	095	a	ar,	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2043	095	a	das	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2044	095	a	aguas	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2045	095	a	do	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2046	095	a	solo	3.07.04.04-9 Qualidade do Ar, das Águas e do Solo	\N
2047	095	a	3.07.04.05-7	3.07.04.05-7 Controle da Poluição	\N
2048	095	a	controle	3.07.04.05-7 Controle da Poluição	\N
2049	095	a	da	3.07.04.05-7 Controle da Poluição	\N
2050	095	a	poluicao	3.07.04.05-7 Controle da Poluição	\N
2051	095	a	3.07.04.06-5	3.07.04.06-5 Legislação Ambiental	\N
2052	095	a	legislacao	3.07.04.06-5 Legislação Ambiental	\N
2053	095	a	ambiental	3.07.04.06-5 Legislação Ambiental	\N
2054	095	a	3.08.00.00-5	3.08.00.00-5 Engenharia de Produção	\N
2055	095	a	engenharia	3.08.00.00-5 Engenharia de Produção	\N
2056	095	a	de	3.08.00.00-5 Engenharia de Produção	\N
2057	095	a	producao	3.08.00.00-5 Engenharia de Produção	\N
2058	095	a	3.08.01.00-1	3.08.01.00-1 Gerência de Produção	\N
2059	095	a	gerencia	3.08.01.00-1 Gerência de Produção	\N
2060	095	a	de	3.08.01.00-1 Gerência de Produção	\N
2061	095	a	producao	3.08.01.00-1 Gerência de Produção	\N
2062	095	a	3.08.01.01-0	3.08.01.01-0 Planejamento de Instalações Industriais	\N
2063	095	a	planejamento	3.08.01.01-0 Planejamento de Instalações Industriais	\N
2064	095	a	de	3.08.01.01-0 Planejamento de Instalações Industriais	\N
2065	095	a	instalacoes	3.08.01.01-0 Planejamento de Instalações Industriais	\N
2066	095	a	industriais	3.08.01.01-0 Planejamento de Instalações Industriais	\N
2067	095	a	3.08.01.02-8	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2068	095	a	planejamento,	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2069	095	a	projeto	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2070	095	a	controle	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2071	095	a	de	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2072	095	a	sistemas	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2073	095	a	de	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2074	095	a	producao	3.08.01.02-8 Planejamento, Projeto e Controle de Sistemas de Produção	\N
2075	095	a	3.08.01.03-6	3.08.01.03-6 Higiene e Segurança do Trabalho	\N
2076	095	a	higiene	3.08.01.03-6 Higiene e Segurança do Trabalho	\N
2077	095	a	seguranca	3.08.01.03-6 Higiene e Segurança do Trabalho	\N
2078	095	a	do	3.08.01.03-6 Higiene e Segurança do Trabalho	\N
2079	095	a	trabalho	3.08.01.03-6 Higiene e Segurança do Trabalho	\N
2080	095	a	3.08.01.04-4	3.08.01.04-4 Suprimentos	\N
2081	095	a	suprimentos	3.08.01.04-4 Suprimentos	\N
2082	095	a	3.08.01.05-2	3.08.01.05-2 Garantia de Controle de Qualidade	\N
2083	095	a	garantia	3.08.01.05-2 Garantia de Controle de Qualidade	\N
2084	095	a	de	3.08.01.05-2 Garantia de Controle de Qualidade	\N
2085	095	a	controle	3.08.01.05-2 Garantia de Controle de Qualidade	\N
2086	095	a	de	3.08.01.05-2 Garantia de Controle de Qualidade	\N
2087	095	a	qualidade	3.08.01.05-2 Garantia de Controle de Qualidade	\N
2088	095	a	3.08.02.00-8	3.08.02.00-8 Pesquisa Operacional	\N
2089	095	a	pesquisa	3.08.02.00-8 Pesquisa Operacional	\N
2090	095	a	operacional	3.08.02.00-8 Pesquisa Operacional	\N
2091	095	a	3.08.02.01-6	3.08.02.01-6 Processos Estocásticos e Teorias da Filas	\N
2092	095	a	processos	3.08.02.01-6 Processos Estocásticos e Teorias da Filas	\N
2093	095	a	estocasticos	3.08.02.01-6 Processos Estocásticos e Teorias da Filas	\N
2094	095	a	teorias	3.08.02.01-6 Processos Estocásticos e Teorias da Filas	\N
2095	095	a	da	3.08.02.01-6 Processos Estocásticos e Teorias da Filas	\N
2096	095	a	filas	3.08.02.01-6 Processos Estocásticos e Teorias da Filas	\N
2097	095	a	3.08.02.02-4	3.08.02.02-4 Programação Linear, Não-Linear, Mista e Dinâmica	\N
2098	095	a	programacao	3.08.02.02-4 Programação Linear, Não-Linear, Mista e Dinâmica	\N
2099	095	a	linear,	3.08.02.02-4 Programação Linear, Não-Linear, Mista e Dinâmica	\N
2100	095	a	nao-linear,	3.08.02.02-4 Programação Linear, Não-Linear, Mista e Dinâmica	\N
2101	095	a	mista	3.08.02.02-4 Programação Linear, Não-Linear, Mista e Dinâmica	\N
2102	095	a	dinamica	3.08.02.02-4 Programação Linear, Não-Linear, Mista e Dinâmica	\N
2103	095	a	3.08.02.03-2	3.08.02.03-2 Séries Temporais	\N
2104	095	a	series	3.08.02.03-2 Séries Temporais	\N
2105	095	a	temporais	3.08.02.03-2 Séries Temporais	\N
2106	095	a	3.08.02.04-0	3.08.02.04-0 Teoria dos Grafos	\N
2107	095	a	teoria	3.08.02.04-0 Teoria dos Grafos	\N
2108	095	a	dos	3.08.02.04-0 Teoria dos Grafos	\N
2109	095	a	grafos	3.08.02.04-0 Teoria dos Grafos	\N
2110	095	a	3.08.02.05-9	3.08.02.05-9 Teoria dos Jogos	\N
2111	095	a	teoria	3.08.02.05-9 Teoria dos Jogos	\N
2112	095	a	dos	3.08.02.05-9 Teoria dos Jogos	\N
2113	095	a	jogos	3.08.02.05-9 Teoria dos Jogos	\N
2114	095	a	3.08.03.00-4	3.08.03.00-4 Engenharia do Produto	\N
2115	095	a	engenharia	3.08.03.00-4 Engenharia do Produto	\N
2116	095	a	do	3.08.03.00-4 Engenharia do Produto	\N
2117	095	a	produto	3.08.03.00-4 Engenharia do Produto	\N
2118	095	a	3.08.03.01-2	3.08.03.01-2 Ergonomia	\N
2119	095	a	ergonomia	3.08.03.01-2 Ergonomia	\N
2120	095	a	3.08.03.02-0	3.08.03.02-0 Metodologia de Projeto do Produto	\N
2121	095	a	metodologia	3.08.03.02-0 Metodologia de Projeto do Produto	\N
2122	095	a	de	3.08.03.02-0 Metodologia de Projeto do Produto	\N
2123	095	a	projeto	3.08.03.02-0 Metodologia de Projeto do Produto	\N
2124	095	a	do	3.08.03.02-0 Metodologia de Projeto do Produto	\N
2125	095	a	produto	3.08.03.02-0 Metodologia de Projeto do Produto	\N
2126	095	a	3.08.03.03-9	3.08.03.03-9 Processos de Trabalho	\N
2127	095	a	processos	3.08.03.03-9 Processos de Trabalho	\N
2128	095	a	de	3.08.03.03-9 Processos de Trabalho	\N
2129	095	a	trabalho	3.08.03.03-9 Processos de Trabalho	\N
2130	095	a	3.08.03.04-7	3.08.03.04-7 Gerência do Projeto e do Produto	\N
2131	095	a	gerencia	3.08.03.04-7 Gerência do Projeto e do Produto	\N
2132	095	a	do	3.08.03.04-7 Gerência do Projeto e do Produto	\N
2133	095	a	projeto	3.08.03.04-7 Gerência do Projeto e do Produto	\N
2134	095	a	do	3.08.03.04-7 Gerência do Projeto e do Produto	\N
2135	095	a	produto	3.08.03.04-7 Gerência do Projeto e do Produto	\N
2136	095	a	3.08.03.05-5	3.08.03.05-5 Desenvolvimento de Produto	\N
2137	095	a	desenvolvimento	3.08.03.05-5 Desenvolvimento de Produto	\N
2138	095	a	de	3.08.03.05-5 Desenvolvimento de Produto	\N
2139	095	a	produto	3.08.03.05-5 Desenvolvimento de Produto	\N
2140	095	a	3.08.04.00-0	3.08.04.00-0 Engenharia Econômica	\N
2141	095	a	engenharia	3.08.04.00-0 Engenharia Econômica	\N
2142	095	a	economica	3.08.04.00-0 Engenharia Econômica	\N
2143	095	a	3.08.04.01-9	3.08.04.01-9 Estudo de Mercado	\N
2144	095	a	estudo	3.08.04.01-9 Estudo de Mercado	\N
2145	095	a	de	3.08.04.01-9 Estudo de Mercado	\N
2146	095	a	mercado	3.08.04.01-9 Estudo de Mercado	\N
2147	095	a	3.08.04.02-7	3.08.04.02-7 Localização Industrial	\N
2148	095	a	localizacao	3.08.04.02-7 Localização Industrial	\N
2149	095	a	industrial	3.08.04.02-7 Localização Industrial	\N
2150	095	a	3.08.04.03-5	3.08.04.03-5 Análise de Custos	\N
2151	095	a	analise	3.08.04.03-5 Análise de Custos	\N
2152	095	a	de	3.08.04.03-5 Análise de Custos	\N
2153	095	a	custos	3.08.04.03-5 Análise de Custos	\N
2154	095	a	3.08.04.04-3	3.08.04.04-3 Economia de Tecnologia	\N
2155	095	a	economia	3.08.04.04-3 Economia de Tecnologia	\N
2156	095	a	de	3.08.04.04-3 Economia de Tecnologia	\N
2157	095	a	tecnologia	3.08.04.04-3 Economia de Tecnologia	\N
2158	095	a	3.08.04.05-1	3.08.04.05-1 Vida Econômica dos Equipamentos	\N
2159	095	a	vida	3.08.04.05-1 Vida Econômica dos Equipamentos	\N
2160	095	a	economica	3.08.04.05-1 Vida Econômica dos Equipamentos	\N
2161	095	a	dos	3.08.04.05-1 Vida Econômica dos Equipamentos	\N
2162	095	a	equipamentos	3.08.04.05-1 Vida Econômica dos Equipamentos	\N
2163	095	a	3.08.04.06-0	3.08.04.06-0 Avaliação de Projetos	\N
2164	095	a	avaliacao	3.08.04.06-0 Avaliação de Projetos	\N
2165	095	a	de	3.08.04.06-0 Avaliação de Projetos	\N
2166	095	a	projetos	3.08.04.06-0 Avaliação de Projetos	\N
2167	095	a	3.09.00.00-0	3.09.00.00-0 Engenharia Nuclear	\N
2168	095	a	engenharia	3.09.00.00-0 Engenharia Nuclear	\N
2169	095	a	nuclear	3.09.00.00-0 Engenharia Nuclear	\N
2170	095	a	3.09.01.00-6	3.09.01.00-6 Aplicações de Radioisotopos	\N
2171	095	a	aplicacoes	3.09.01.00-6 Aplicações de Radioisotopos	\N
2172	095	a	de	3.09.01.00-6 Aplicações de Radioisotopos	\N
2173	095	a	radioisotopos	3.09.01.00-6 Aplicações de Radioisotopos	\N
2174	095	a	3.09.01.01-4	3.09.01.01-4 Produção de Radioisotopos	\N
2175	095	a	producao	3.09.01.01-4 Produção de Radioisotopos	\N
2176	095	a	de	3.09.01.01-4 Produção de Radioisotopos	\N
2177	095	a	radioisotopos	3.09.01.01-4 Produção de Radioisotopos	\N
2178	095	a	3.09.01.02-2	3.09.01.02-2 Aplicações Industriais de Radioisotopos	\N
2179	095	a	aplicacoes	3.09.01.02-2 Aplicações Industriais de Radioisotopos	\N
2180	095	a	industriais	3.09.01.02-2 Aplicações Industriais de Radioisotopos	\N
2181	095	a	de	3.09.01.02-2 Aplicações Industriais de Radioisotopos	\N
2182	095	a	radioisotopos	3.09.01.02-2 Aplicações Industriais de Radioisotopos	\N
2183	095	a	3.09.01.03-0	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2184	095	a	instrumentacao	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2185	095	a	para	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2186	095	a	medida	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2187	095	a	controle	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2188	095	a	de	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2189	095	a	radiacao	3.09.01.03-0 Instrumentação para Medida e Controle de Radiação	\N
2190	095	a	3.09.02.00-2	3.09.02.00-2 Fusão Controlada	\N
2191	095	a	fusao	3.09.02.00-2 Fusão Controlada	\N
2192	095	a	controlada	3.09.02.00-2 Fusão Controlada	\N
2193	095	a	3.09.02.01-0	3.09.02.01-0 Processos Industriais da Fusão Controlada	\N
2194	095	a	processos	3.09.02.01-0 Processos Industriais da Fusão Controlada	\N
2195	095	a	industriais	3.09.02.01-0 Processos Industriais da Fusão Controlada	\N
2196	095	a	da	3.09.02.01-0 Processos Industriais da Fusão Controlada	\N
2197	095	a	fusao	3.09.02.01-0 Processos Industriais da Fusão Controlada	\N
2198	095	a	controlada	3.09.02.01-0 Processos Industriais da Fusão Controlada	\N
2199	095	a	3.09.02.02-9	3.09.02.02-9 Problemas Tecnológicos da Fusão Controlada	\N
2200	095	a	problemas	3.09.02.02-9 Problemas Tecnológicos da Fusão Controlada	\N
2201	095	a	tecnologicos	3.09.02.02-9 Problemas Tecnológicos da Fusão Controlada	\N
2202	095	a	da	3.09.02.02-9 Problemas Tecnológicos da Fusão Controlada	\N
2203	095	a	fusao	3.09.02.02-9 Problemas Tecnológicos da Fusão Controlada	\N
2204	095	a	controlada	3.09.02.02-9 Problemas Tecnológicos da Fusão Controlada	\N
2205	095	a	3.09.03.00-9	3.09.03.00-9 Combustível Nuclear	\N
2206	095	a	combustivel	3.09.03.00-9 Combustível Nuclear	\N
2207	095	a	nuclear	3.09.03.00-9 Combustível Nuclear	\N
2208	095	a	3.09.03.01-7	3.09.03.01-7 Extração de Combustível Nuclear	\N
2209	095	a	extracao	3.09.03.01-7 Extração de Combustível Nuclear	\N
2210	095	a	de	3.09.03.01-7 Extração de Combustível Nuclear	\N
2211	095	a	combustivel	3.09.03.01-7 Extração de Combustível Nuclear	\N
2212	095	a	nuclear	3.09.03.01-7 Extração de Combustível Nuclear	\N
2213	095	a	3.09.03.02-5	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2214	095	a	conversao,	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2215	095	a	enriquecimento	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2216	095	a	fabricacao	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2217	095	a	de	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2218	095	a	combustivel	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2219	095	a	nuclear	3.09.03.02-5 Conversão, Enriquecimento e Fabricação de Combustível Nuclear	\N
2220	095	a	3.09.03.03-3	3.09.03.03-3 Reprocessamento de Combustível Nuclear	\N
2221	095	a	reprocessamento	3.09.03.03-3 Reprocessamento de Combustível Nuclear	\N
2222	095	a	de	3.09.03.03-3 Reprocessamento de Combustível Nuclear	\N
2223	095	a	combustivel	3.09.03.03-3 Reprocessamento de Combustível Nuclear	\N
2224	095	a	nuclear	3.09.03.03-3 Reprocessamento de Combustível Nuclear	\N
2225	095	a	3.09.03.04-1	3.09.03.04-1 Rejeitos de Combustível Nuclear	\N
2226	095	a	rejeitos	3.09.03.04-1 Rejeitos de Combustível Nuclear	\N
2227	095	a	de	3.09.03.04-1 Rejeitos de Combustível Nuclear	\N
2228	095	a	combustivel	3.09.03.04-1 Rejeitos de Combustível Nuclear	\N
2229	095	a	nuclear	3.09.03.04-1 Rejeitos de Combustível Nuclear	\N
2230	095	a	3.09.04.00-5	3.09.04.00-5 Tecnologia dos Reatores	\N
2231	095	a	tecnologia	3.09.04.00-5 Tecnologia dos Reatores	\N
2232	095	a	dos	3.09.04.00-5 Tecnologia dos Reatores	\N
2233	095	a	reatores	3.09.04.00-5 Tecnologia dos Reatores	\N
2234	095	a	3.09.04.01-3	3.09.04.01-3 Núcleo do Reator	\N
2235	095	a	nucleo	3.09.04.01-3 Núcleo do Reator	\N
2236	095	a	do	3.09.04.01-3 Núcleo do Reator	\N
2237	095	a	reator	3.09.04.01-3 Núcleo do Reator	\N
2238	095	a	3.09.04.02-1	3.09.04.02-1 Materiais Nucleares e Blindagem de Reatores	\N
2239	095	a	materiais	3.09.04.02-1 Materiais Nucleares e Blindagem de Reatores	\N
2240	095	a	nucleares	3.09.04.02-1 Materiais Nucleares e Blindagem de Reatores	\N
2241	095	a	blindagem	3.09.04.02-1 Materiais Nucleares e Blindagem de Reatores	\N
2242	095	a	de	3.09.04.02-1 Materiais Nucleares e Blindagem de Reatores	\N
2243	095	a	reatores	3.09.04.02-1 Materiais Nucleares e Blindagem de Reatores	\N
2244	095	a	3.09.04.03-0	3.09.04.03-0 Transferência de Calor em Reatores	\N
2245	095	a	transferencia	3.09.04.03-0 Transferência de Calor em Reatores	\N
2246	095	a	de	3.09.04.03-0 Transferência de Calor em Reatores	\N
2247	095	a	calor	3.09.04.03-0 Transferência de Calor em Reatores	\N
2248	095	a	em	3.09.04.03-0 Transferência de Calor em Reatores	\N
2249	095	a	reatores	3.09.04.03-0 Transferência de Calor em Reatores	\N
2250	095	a	3.09.04.04-8	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2251	095	a	geracao	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2252	095	a	integracao	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2253	095	a	com	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2254	095	a	sistemas	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2255	095	a	eletricos	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2256	095	a	em	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2257	095	a	reatores	3.09.04.04-8 Geração e Integração Com Sistemas Elétricos em Reatores	\N
2258	095	a	3.09.04.05-6	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2259	095	a	instrumentacao	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2260	095	a	para	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2261	095	a	operacao	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2262	095	a	controle	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2263	095	a	de	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2264	095	a	reatores	3.09.04.05-6 Instrumentação Para Operação e Controle de Reatores	\N
2265	095	a	3.09.04.06-4	3.09.04.06-4 Seguranca, Localização e Licênciamento de Reatores	\N
2266	095	a	seguranca,	3.09.04.06-4 Seguranca, Localização e Licênciamento de Reatores	\N
2267	095	a	localizacao	3.09.04.06-4 Seguranca, Localização e Licênciamento de Reatores	\N
2268	095	a	licenciamento	3.09.04.06-4 Seguranca, Localização e Licênciamento de Reatores	\N
2269	095	a	de	3.09.04.06-4 Seguranca, Localização e Licênciamento de Reatores	\N
2270	095	a	reatores	3.09.04.06-4 Seguranca, Localização e Licênciamento de Reatores	\N
2271	095	a	3.09.04.07-2	3.09.04.07-2 Aspectos Econômicos de Reatores	\N
2272	095	a	aspectos	3.09.04.07-2 Aspectos Econômicos de Reatores	\N
2273	095	a	economicos	3.09.04.07-2 Aspectos Econômicos de Reatores	\N
2274	095	a	de	3.09.04.07-2 Aspectos Econômicos de Reatores	\N
2275	095	a	reatores	3.09.04.07-2 Aspectos Econômicos de Reatores	\N
2276	095	a	3.10.00.00-2	3.10.00.00-2 Engenharia de Transportes	\N
2277	095	a	engenharia	3.10.00.00-2 Engenharia de Transportes	\N
2278	095	a	de	3.10.00.00-2 Engenharia de Transportes	\N
2279	095	a	transportes	3.10.00.00-2 Engenharia de Transportes	\N
2280	095	a	3.10.01.00-9	3.10.01.00-9 Planejamento de Transportes	\N
2281	095	a	planejamento	3.10.01.00-9 Planejamento de Transportes	\N
2282	095	a	de	3.10.01.00-9 Planejamento de Transportes	\N
2283	095	a	transportes	3.10.01.00-9 Planejamento de Transportes	\N
2284	095	a	3.10.01.01-7	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2285	095	a	planejamento	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2286	095	a	organizacao	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2287	095	a	do	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2288	095	a	sistema	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2289	095	a	de	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2290	095	a	transporte	3.10.01.01-7 Planejamento e Organização do Sistema de Transporte	\N
2291	095	a	3.10.01.02-5	3.10.01.02-5 Economia dos Transportes	\N
2292	095	a	economia	3.10.01.02-5 Economia dos Transportes	\N
2293	095	a	dos	3.10.01.02-5 Economia dos Transportes	\N
2294	095	a	transportes	3.10.01.02-5 Economia dos Transportes	\N
2295	095	a	3.10.02.00-5	3.10.02.00-5 Veículos e Equipamentos de Controle	\N
2296	095	a	veiculos	3.10.02.00-5 Veículos e Equipamentos de Controle	\N
2297	095	a	equipamentos	3.10.02.00-5 Veículos e Equipamentos de Controle	\N
2298	095	a	de	3.10.02.00-5 Veículos e Equipamentos de Controle	\N
2299	095	a	controle	3.10.02.00-5 Veículos e Equipamentos de Controle	\N
2300	095	a	3.10.02.01-3	3.10.02.01-3 Vias de Transporte	\N
2301	095	a	vias	3.10.02.01-3 Vias de Transporte	\N
2302	095	a	de	3.10.02.01-3 Vias de Transporte	\N
2303	095	a	transporte	3.10.02.01-3 Vias de Transporte	\N
2304	095	a	3.10.02.02-1	3.10.02.02-1 Veículos de Transportes	\N
2305	095	a	veiculos	3.10.02.02-1 Veículos de Transportes	\N
2306	095	a	de	3.10.02.02-1 Veículos de Transportes	\N
2307	095	a	transportes	3.10.02.02-1 Veículos de Transportes	\N
2308	095	a	3.10.02.03-0	3.10.02.03-0 Estação de Transporte	\N
2309	095	a	estacao	3.10.02.03-0 Estação de Transporte	\N
2310	095	a	de	3.10.02.03-0 Estação de Transporte	\N
2311	095	a	transporte	3.10.02.03-0 Estação de Transporte	\N
2312	095	a	3.10.02.04-8	3.10.02.04-8 Equipamentos Auxiliares e Controles	\N
2313	095	a	equipamentos	3.10.02.04-8 Equipamentos Auxiliares e Controles	\N
2314	095	a	auxiliares	3.10.02.04-8 Equipamentos Auxiliares e Controles	\N
2315	095	a	controles	3.10.02.04-8 Equipamentos Auxiliares e Controles	\N
2316	095	a	3.10.03.00-1	3.10.03.00-1 Operações de Transportes	\N
2317	095	a	operacoes	3.10.03.00-1 Operações de Transportes	\N
2318	095	a	de	3.10.03.00-1 Operações de Transportes	\N
2319	095	a	transportes	3.10.03.00-1 Operações de Transportes	\N
2320	095	a	3.10.03.01-0	3.10.03.01-0 Engenharia de Tráfego	\N
2321	095	a	engenharia	3.10.03.01-0 Engenharia de Tráfego	\N
2322	095	a	de	3.10.03.01-0 Engenharia de Tráfego	\N
2323	095	a	trafego	3.10.03.01-0 Engenharia de Tráfego	\N
2324	095	a	3.10.03.02-8	3.10.03.02-8 Capacidade de Vias de Transporte	\N
2325	095	a	capacidade	3.10.03.02-8 Capacidade de Vias de Transporte	\N
2326	095	a	de	3.10.03.02-8 Capacidade de Vias de Transporte	\N
2327	095	a	vias	3.10.03.02-8 Capacidade de Vias de Transporte	\N
2328	095	a	de	3.10.03.02-8 Capacidade de Vias de Transporte	\N
2329	095	a	transporte	3.10.03.02-8 Capacidade de Vias de Transporte	\N
2330	095	a	3.10.03.03-6	3.10.03.03-6 Operação de Sistemas de Transporte	\N
2331	095	a	operacao	3.10.03.03-6 Operação de Sistemas de Transporte	\N
2332	095	a	de	3.10.03.03-6 Operação de Sistemas de Transporte	\N
2333	095	a	sistemas	3.10.03.03-6 Operação de Sistemas de Transporte	\N
2334	095	a	de	3.10.03.03-6 Operação de Sistemas de Transporte	\N
2335	095	a	transporte	3.10.03.03-6 Operação de Sistemas de Transporte	\N
2336	095	a	3.11.00.00-7	3.11.00.00-7 Engenharia Naval e Oceânica	\N
2337	095	a	engenharia	3.11.00.00-7 Engenharia Naval e Oceânica	\N
2338	095	a	naval	3.11.00.00-7 Engenharia Naval e Oceânica	\N
2339	095	a	oceanica	3.11.00.00-7 Engenharia Naval e Oceânica	\N
2340	095	a	3.11.01.00-3	3.11.01.00-3 Hidrodinâmica de Navios e Sistemas Oceânicos	\N
2341	095	a	hidrodinamica	3.11.01.00-3 Hidrodinâmica de Navios e Sistemas Oceânicos	\N
2342	095	a	de	3.11.01.00-3 Hidrodinâmica de Navios e Sistemas Oceânicos	\N
2343	095	a	navios	3.11.01.00-3 Hidrodinâmica de Navios e Sistemas Oceânicos	\N
2344	095	a	sistemas	3.11.01.00-3 Hidrodinâmica de Navios e Sistemas Oceânicos	\N
2345	095	a	oceanicos	3.11.01.00-3 Hidrodinâmica de Navios e Sistemas Oceânicos	\N
2346	095	a	3.11.01.01-1	3.11.01.01-1 Resistência Hidrodinâmica	\N
2347	095	a	resistencia	3.11.01.01-1 Resistência Hidrodinâmica	\N
2348	095	a	hidrodinamica	3.11.01.01-1 Resistência Hidrodinâmica	\N
2349	095	a	3.11.01.02-0	3.11.01.02-0 Propulsão de Navios	\N
2350	095	a	propulsao	3.11.01.02-0 Propulsão de Navios	\N
2351	095	a	de	3.11.01.02-0 Propulsão de Navios	\N
2352	095	a	navios	3.11.01.02-0 Propulsão de Navios	\N
2353	095	a	3.11.02.00-0	3.11.02.00-0 Estruturas Navais e Oceânicas	\N
2354	095	a	estruturas	3.11.02.00-0 Estruturas Navais e Oceânicas	\N
2355	095	a	navais	3.11.02.00-0 Estruturas Navais e Oceânicas	\N
2356	095	a	oceanicas	3.11.02.00-0 Estruturas Navais e Oceânicas	\N
2357	095	a	3.11.02.01-8	3.11.02.01-8 Análise Teórica e Experimental de Estrutura	\N
2358	095	a	analise	3.11.02.01-8 Análise Teórica e Experimental de Estrutura	\N
2359	095	a	teorica	3.11.02.01-8 Análise Teórica e Experimental de Estrutura	\N
2360	095	a	experimental	3.11.02.01-8 Análise Teórica e Experimental de Estrutura	\N
2361	095	a	de	3.11.02.01-8 Análise Teórica e Experimental de Estrutura	\N
2362	095	a	estrutura	3.11.02.01-8 Análise Teórica e Experimental de Estrutura	\N
2363	095	a	3.11.02.02-6	3.11.02.02-6 Dinâmica Estrutural Naval e Oceânica	\N
2364	095	a	dinamica	3.11.02.02-6 Dinâmica Estrutural Naval e Oceânica	\N
2365	095	a	estrutural	3.11.02.02-6 Dinâmica Estrutural Naval e Oceânica	\N
2366	095	a	naval	3.11.02.02-6 Dinâmica Estrutural Naval e Oceânica	\N
2367	095	a	oceanica	3.11.02.02-6 Dinâmica Estrutural Naval e Oceânica	\N
2368	095	a	3.11.02.03-4	3.11.02.03-4 Síntese Estrutural Naval e Oceânica	\N
2369	095	a	sintese	3.11.02.03-4 Síntese Estrutural Naval e Oceânica	\N
2370	095	a	estrutural	3.11.02.03-4 Síntese Estrutural Naval e Oceânica	\N
2371	095	a	naval	3.11.02.03-4 Síntese Estrutural Naval e Oceânica	\N
2372	095	a	oceanica	3.11.02.03-4 Síntese Estrutural Naval e Oceânica	\N
2373	095	a	3.11.03.00-6	3.11.03.00-6 Máquinas Marítimas	\N
2374	095	a	maquinas	3.11.03.00-6 Máquinas Marítimas	\N
2375	095	a	maritimas	3.11.03.00-6 Máquinas Marítimas	\N
2376	095	a	3.11.03.01-4	3.11.03.01-4 Análise de Sistemas Propulsores	\N
2377	095	a	analise	3.11.03.01-4 Análise de Sistemas Propulsores	\N
2378	095	a	de	3.11.03.01-4 Análise de Sistemas Propulsores	\N
2379	095	a	sistemas	3.11.03.01-4 Análise de Sistemas Propulsores	\N
2380	095	a	propulsores	3.11.03.01-4 Análise de Sistemas Propulsores	\N
2381	095	a	3.11.03.02-2	3.11.03.02-2 Controle e Automação de Sistemas Propulsores	\N
2382	095	a	controle	3.11.03.02-2 Controle e Automação de Sistemas Propulsores	\N
2383	095	a	automacao	3.11.03.02-2 Controle e Automação de Sistemas Propulsores	\N
2384	095	a	de	3.11.03.02-2 Controle e Automação de Sistemas Propulsores	\N
2385	095	a	sistemas	3.11.03.02-2 Controle e Automação de Sistemas Propulsores	\N
2386	095	a	propulsores	3.11.03.02-2 Controle e Automação de Sistemas Propulsores	\N
2387	095	a	3.11.03.03-0	3.11.03.03-0 Equipamentos Auxiliares do Sistema Propulsivo	\N
2388	095	a	equipamentos	3.11.03.03-0 Equipamentos Auxiliares do Sistema Propulsivo	\N
2389	095	a	auxiliares	3.11.03.03-0 Equipamentos Auxiliares do Sistema Propulsivo	\N
2390	095	a	do	3.11.03.03-0 Equipamentos Auxiliares do Sistema Propulsivo	\N
2391	095	a	sistema	3.11.03.03-0 Equipamentos Auxiliares do Sistema Propulsivo	\N
2392	095	a	propulsivo	3.11.03.03-0 Equipamentos Auxiliares do Sistema Propulsivo	\N
2393	095	a	3.11.03.04-9	3.11.03.04-9 Motor de Propulsão	\N
2394	095	a	motor	3.11.03.04-9 Motor de Propulsão	\N
2395	095	a	de	3.11.03.04-9 Motor de Propulsão	\N
2396	095	a	propulsao	3.11.03.04-9 Motor de Propulsão	\N
2397	095	a	3.11.04.00-2	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2398	095	a	projeto	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2399	095	a	de	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2400	095	a	navios	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2401	095	a	de	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2402	095	a	sistemas	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2403	095	a	oceanicos	3.11.04.00-2 Projeto de Navios e de Sistemas Oceânicos	\N
2404	095	a	3.11.04.01-0	3.11.04.01-0 Projetos de Navios	\N
2405	095	a	projetos	3.11.04.01-0 Projetos de Navios	\N
2406	095	a	de	3.11.04.01-0 Projetos de Navios	\N
2407	095	a	navios	3.11.04.01-0 Projetos de Navios	\N
2408	095	a	3.11.04.02-9	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2409	095	a	projetos	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2410	095	a	de	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2411	095	a	sistemas	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2412	095	a	oceanicos	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2413	095	a	fixos	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2414	095	a	semi-fixos	3.11.04.02-9 Projetos de Sistemas Oceânicos Fixos e Semi-Fixos	\N
2415	095	a	3.11.04.03-7	3.11.04.03-7 Projetos de Embarcações Não-Convencionais	\N
2416	095	a	projetos	3.11.04.03-7 Projetos de Embarcações Não-Convencionais	\N
2417	095	a	de	3.11.04.03-7 Projetos de Embarcações Não-Convencionais	\N
2418	095	a	embarcacoes	3.11.04.03-7 Projetos de Embarcações Não-Convencionais	\N
2419	095	a	nao-convencionais	3.11.04.03-7 Projetos de Embarcações Não-Convencionais	\N
2420	095	a	3.11.05.00-9	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2421	095	a	tecnologia	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2422	095	a	de	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2423	095	a	construcao	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2424	095	a	naval	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2425	095	a	de	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2426	095	a	sistemas	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2427	095	a	oceanicas	3.11.05.00-9 Tecnologia de Construção Naval e de Sistemas Oceânicas	\N
2428	095	a	3.11.05.01-7	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2429	095	a	metodos	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2430	095	a	de	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2431	095	a	fabricacao	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2432	095	a	de	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2433	095	a	navios	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2434	095	a	sistemas	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2435	095	a	oceanicos	3.11.05.01-7 Métodos de Fabricação de Navios e Sistemas Oceânicos	\N
2436	095	a	3.11.05.02-5	3.11.05.02-5 Soldagem de Estruturas Navais e Oceânicos	\N
2437	095	a	soldagem	3.11.05.02-5 Soldagem de Estruturas Navais e Oceânicos	\N
2438	095	a	de	3.11.05.02-5 Soldagem de Estruturas Navais e Oceânicos	\N
2439	095	a	estruturas	3.11.05.02-5 Soldagem de Estruturas Navais e Oceânicos	\N
2440	095	a	navais	3.11.05.02-5 Soldagem de Estruturas Navais e Oceânicos	\N
2441	095	a	oceanicos	3.11.05.02-5 Soldagem de Estruturas Navais e Oceânicos	\N
2442	095	a	3.11.05.03-3	3.11.05.03-3 Custos de Construção Naval	\N
2443	095	a	custos	3.11.05.03-3 Custos de Construção Naval	\N
2444	095	a	de	3.11.05.03-3 Custos de Construção Naval	\N
2445	095	a	construcao	3.11.05.03-3 Custos de Construção Naval	\N
2446	095	a	naval	3.11.05.03-3 Custos de Construção Naval	\N
2447	095	a	3.11.05.04-1	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2448	095	a	normatizacao	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2449	095	a	certificacao	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2450	095	a	de	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2451	095	a	qualidade	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2452	095	a	de	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2453	095	a	navios	3.11.05.04-1 Normatização e Certificação de Qualidade de Navios	\N
2454	095	a	3.12.00.00-1	3.12.00.00-1 Engenharia Aeroespacial	\N
2455	095	a	engenharia	3.12.00.00-1 Engenharia Aeroespacial	\N
2456	095	a	aeroespacial	3.12.00.00-1 Engenharia Aeroespacial	\N
2457	095	a	3.12.01.00-8	3.12.01.00-8 Aerodinâmica	\N
2458	095	a	aerodinamica	3.12.01.00-8 Aerodinâmica	\N
2459	095	a	3.12.01.01-6	3.12.01.01-6 Aerodinâmica de Aeronaves Espaciais	\N
2460	095	a	aerodinamica	3.12.01.01-6 Aerodinâmica de Aeronaves Espaciais	\N
2461	095	a	de	3.12.01.01-6 Aerodinâmica de Aeronaves Espaciais	\N
2462	095	a	aeronaves	3.12.01.01-6 Aerodinâmica de Aeronaves Espaciais	\N
2463	095	a	espaciais	3.12.01.01-6 Aerodinâmica de Aeronaves Espaciais	\N
2464	095	a	3.12.01.02-4	3.12.01.02-4 Aerodinâmica dos Processos Geofísicos e Interplanetarios	\N
2465	095	a	aerodinamica	3.12.01.02-4 Aerodinâmica dos Processos Geofísicos e Interplanetarios	\N
2466	095	a	dos	3.12.01.02-4 Aerodinâmica dos Processos Geofísicos e Interplanetarios	\N
2467	095	a	processos	3.12.01.02-4 Aerodinâmica dos Processos Geofísicos e Interplanetarios	\N
2468	095	a	geofisicos	3.12.01.02-4 Aerodinâmica dos Processos Geofísicos e Interplanetarios	\N
2469	095	a	interplanetarios	3.12.01.02-4 Aerodinâmica dos Processos Geofísicos e Interplanetarios	\N
2470	095	a	3.12.02.00-4	3.12.02.00-4 Dinâmica de Vôo	\N
2471	095	a	dinamica	3.12.02.00-4 Dinâmica de Vôo	\N
2472	095	a	de	3.12.02.00-4 Dinâmica de Vôo	\N
2473	095	a	voo	3.12.02.00-4 Dinâmica de Vôo	\N
2474	095	a	3.12.02.01-2	3.12.02.01-2 Trajetorias e Orbitas	\N
2475	095	a	trajetorias	3.12.02.01-2 Trajetorias e Orbitas	\N
2476	095	a	orbitas	3.12.02.01-2 Trajetorias e Orbitas	\N
2477	095	a	3.12.02.02-0	3.12.02.02-0 Estabilidade e Controle	\N
2478	095	a	estabilidade	3.12.02.02-0 Estabilidade e Controle	\N
2479	095	a	controle	3.12.02.02-0 Estabilidade e Controle	\N
2480	095	a	3.12.03.00-0	3.12.03.00-0 Estruturas Aeroespaciais	\N
2481	095	a	estruturas	3.12.03.00-0 Estruturas Aeroespaciais	\N
2482	095	a	aeroespaciais	3.12.03.00-0 Estruturas Aeroespaciais	\N
2483	095	a	3.12.03.01-9	3.12.03.01-9 Aeroelasticidade	\N
2484	095	a	aeroelasticidade	3.12.03.01-9 Aeroelasticidade	\N
2485	095	a	3.12.03.02-7	3.12.03.02-7 Fadiga	\N
2486	095	a	fadiga	3.12.03.02-7 Fadiga	\N
2487	095	a	3.12.03.03-5	3.12.03.03-5 Projeto de Estruturas Aeroespaciais	\N
2488	095	a	projeto	3.12.03.03-5 Projeto de Estruturas Aeroespaciais	\N
2489	095	a	de	3.12.03.03-5 Projeto de Estruturas Aeroespaciais	\N
2490	095	a	estruturas	3.12.03.03-5 Projeto de Estruturas Aeroespaciais	\N
2491	095	a	aeroespaciais	3.12.03.03-5 Projeto de Estruturas Aeroespaciais	\N
2492	095	a	3.12.04.00-7	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2493	095	a	materiais	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2494	095	a	processos	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2495	095	a	para	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2496	095	a	engenharia	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2497	095	a	aeronautica	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2498	095	a	aeroespacial	3.12.04.00-7 Materiais e Processos para Engenharia Aeronáutica e Aeroespacial	\N
2499	095	a	3.12.05.00-3	3.12.05.00-3 Propulsão Aeroespacial	\N
2500	095	a	propulsao	3.12.05.00-3 Propulsão Aeroespacial	\N
2501	095	a	aeroespacial	3.12.05.00-3 Propulsão Aeroespacial	\N
2502	095	a	3.12.05.01-1	3.12.05.01-1 Combustão e Escoamento com Reações Químicas	\N
2503	095	a	combustao	3.12.05.01-1 Combustão e Escoamento com Reações Químicas	\N
2504	095	a	escoamento	3.12.05.01-1 Combustão e Escoamento com Reações Químicas	\N
2505	095	a	com	3.12.05.01-1 Combustão e Escoamento com Reações Químicas	\N
2506	095	a	reacoes	3.12.05.01-1 Combustão e Escoamento com Reações Químicas	\N
2507	095	a	quimicas	3.12.05.01-1 Combustão e Escoamento com Reações Químicas	\N
2508	095	a	3.12.05.02-0	3.12.05.02-0 Propulsão de Foguetes	\N
2509	095	a	propulsao	3.12.05.02-0 Propulsão de Foguetes	\N
2510	095	a	de	3.12.05.02-0 Propulsão de Foguetes	\N
2511	095	a	foguetes	3.12.05.02-0 Propulsão de Foguetes	\N
2512	095	a	3.12.05.03-8	3.12.05.03-8 Máquinas de Fluxo	\N
2513	095	a	maquinas	3.12.05.03-8 Máquinas de Fluxo	\N
2514	095	a	de	3.12.05.03-8 Máquinas de Fluxo	\N
2515	095	a	fluxo	3.12.05.03-8 Máquinas de Fluxo	\N
2516	095	a	3.12.05.04-6	3.12.05.04-6 Motores Alternativos	\N
2517	095	a	motores	3.12.05.04-6 Motores Alternativos	\N
2518	095	a	alternativos	3.12.05.04-6 Motores Alternativos	\N
2519	095	a	3.12.06.00-0	3.12.06.00-0 Sistemas Aeroespaciais	\N
2520	095	a	sistemas	3.12.06.00-0 Sistemas Aeroespaciais	\N
2521	095	a	aeroespaciais	3.12.06.00-0 Sistemas Aeroespaciais	\N
2522	095	a	3.12.06.01-8	3.12.06.01-8 Aviões	\N
2523	095	a	avioes	3.12.06.01-8 Aviões	\N
2524	095	a	3.12.06.02-6	3.12.06.02-6 Foguetes	\N
2525	095	a	foguetes	3.12.06.02-6 Foguetes	\N
2526	095	a	3.12.06.03-4	3.12.06.03-4 Helicópteros	\N
2527	095	a	helicopteros	3.12.06.03-4 Helicópteros	\N
2528	095	a	3.12.06.04-2	3.12.06.04-2 Hovercraft	\N
2529	095	a	hovercraft	3.12.06.04-2 Hovercraft	\N
2530	095	a	3.12.06.05-0	3.12.06.05-0 Satélites e Outros Dispositivos Aeroespaciais	\N
2531	095	a	satelites	3.12.06.05-0 Satélites e Outros Dispositivos Aeroespaciais	\N
2532	095	a	outros	3.12.06.05-0 Satélites e Outros Dispositivos Aeroespaciais	\N
2533	095	a	dispositivos	3.12.06.05-0 Satélites e Outros Dispositivos Aeroespaciais	\N
2534	095	a	aeroespaciais	3.12.06.05-0 Satélites e Outros Dispositivos Aeroespaciais	\N
2535	095	a	3.12.06.06-9	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2536	095	a	normatizacao	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2537	095	a	certificacao	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2538	095	a	de	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2539	095	a	qualidade	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2540	095	a	de	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2541	095	a	aeronaves	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2542	095	a	componentes	3.12.06.06-9 Normatização e Certificação de Qualidade de Aeronaves e Componentes	\N
2543	095	a	3.12.06.07-7	3.12.06.07-7 Manutenção de Sistemas Aeroespaciais	\N
2544	095	a	manutencao	3.12.06.07-7 Manutenção de Sistemas Aeroespaciais	\N
2545	095	a	de	3.12.06.07-7 Manutenção de Sistemas Aeroespaciais	\N
2546	095	a	sistemas	3.12.06.07-7 Manutenção de Sistemas Aeroespaciais	\N
2547	095	a	aeroespaciais	3.12.06.07-7 Manutenção de Sistemas Aeroespaciais	\N
2548	095	a	3.13.00.00-6	3.13.00.00-6 Engenharia Biomédica	\N
2549	095	a	engenharia	3.13.00.00-6 Engenharia Biomédica	\N
2550	095	a	biomedica	3.13.00.00-6 Engenharia Biomédica	\N
2551	095	a	3.13.01.00-2	3.13.01.00-2 Bioengenharia	\N
2552	095	a	bioengenharia	3.13.01.00-2 Bioengenharia	\N
2553	095	a	3.13.01.01-0	3.13.01.01-0 Processamento de Sinais Biológicos	\N
2554	095	a	processamento	3.13.01.01-0 Processamento de Sinais Biológicos	\N
2555	095	a	de	3.13.01.01-0 Processamento de Sinais Biológicos	\N
2556	095	a	sinais	3.13.01.01-0 Processamento de Sinais Biológicos	\N
2557	095	a	biologicos	3.13.01.01-0 Processamento de Sinais Biológicos	\N
2558	095	a	3.13.01.02-9	3.13.01.02-9 Modelagem de Fenomenos Biológicos	\N
2559	095	a	modelagem	3.13.01.02-9 Modelagem de Fenomenos Biológicos	\N
2560	095	a	de	3.13.01.02-9 Modelagem de Fenomenos Biológicos	\N
2561	095	a	fenomenos	3.13.01.02-9 Modelagem de Fenomenos Biológicos	\N
2562	095	a	biologicos	3.13.01.02-9 Modelagem de Fenomenos Biológicos	\N
2563	095	a	3.13.01.03-7	3.13.01.03-7 Modelagem de Sistemas Biológicos	\N
2564	095	a	modelagem	3.13.01.03-7 Modelagem de Sistemas Biológicos	\N
2565	095	a	de	3.13.01.03-7 Modelagem de Sistemas Biológicos	\N
2566	095	a	sistemas	3.13.01.03-7 Modelagem de Sistemas Biológicos	\N
2567	095	a	biologicos	3.13.01.03-7 Modelagem de Sistemas Biológicos	\N
2568	095	a	3.13.02.00-9	3.13.02.00-9 Engenharia Médica	\N
2569	095	a	engenharia	3.13.02.00-9 Engenharia Médica	\N
2570	095	a	medica	3.13.02.00-9 Engenharia Médica	\N
2571	095	a	3.13.02.01-7	3.13.02.01-7 Biomateriais e Materiais Biocompatíveis	\N
2572	095	a	biomateriais	3.13.02.01-7 Biomateriais e Materiais Biocompatíveis	\N
2573	095	a	materiais	3.13.02.01-7 Biomateriais e Materiais Biocompatíveis	\N
2574	095	a	biocompativeis	3.13.02.01-7 Biomateriais e Materiais Biocompatíveis	\N
2575	095	a	3.13.02.02-5	3.13.02.02-5 Transdutores para Aplicações Biomédicas	\N
2576	095	a	transdutores	3.13.02.02-5 Transdutores para Aplicações Biomédicas	\N
2577	095	a	para	3.13.02.02-5 Transdutores para Aplicações Biomédicas	\N
2578	095	a	aplicacoes	3.13.02.02-5 Transdutores para Aplicações Biomédicas	\N
2579	095	a	biomedicas	3.13.02.02-5 Transdutores para Aplicações Biomédicas	\N
2580	095	a	3.13.02.03-3	3.13.02.03-3 Instrumentação Odontológica e Médico-Hospitalar	\N
2581	095	a	instrumentacao	3.13.02.03-3 Instrumentação Odontológica e Médico-Hospitalar	\N
2582	095	a	odontologica	3.13.02.03-3 Instrumentação Odontológica e Médico-Hospitalar	\N
2583	095	a	medico-hospitalar	3.13.02.03-3 Instrumentação Odontológica e Médico-Hospitalar	\N
2584	095	a	3.13.02.04-1	3.13.02.04-1 Tecnologia de Próteses	\N
2585	095	a	tecnologia	3.13.02.04-1 Tecnologia de Próteses	\N
2586	095	a	de	3.13.02.04-1 Tecnologia de Próteses	\N
2587	095	a	proteses	3.13.02.04-1 Tecnologia de Próteses	\N
2588	095	a	4.00.00.00-1	4.00.00.00-1 Ciências da Saúde	\N
2589	095	a	ciencias	4.00.00.00-1 Ciências da Saúde	\N
2590	095	a	da	4.00.00.00-1 Ciências da Saúde	\N
2591	095	a	saude	4.00.00.00-1 Ciências da Saúde	\N
2592	095	a	4.01.00.00-6	4.01.00.00-6 Medicina	\N
2593	095	a	medicina	4.01.00.00-6 Medicina	\N
2594	095	a	4.01.01.00-2	4.01.01.00-2 Clínica Médica	\N
2595	095	a	clinica	4.01.01.00-2 Clínica Médica	\N
2596	095	a	medica	4.01.01.00-2 Clínica Médica	\N
2597	095	a	4.01.01.01-0	4.01.01.01-0 Angiologia	\N
2598	095	a	angiologia	4.01.01.01-0 Angiologia	\N
2599	095	a	4.01.01.02-9	4.01.01.02-9 Dermatologia	\N
2600	095	a	dermatologia	4.01.01.02-9 Dermatologia	\N
2601	095	a	4.01.01.03-7	4.01.01.03-7 Alergologia e Imunologia Clínica	\N
2602	095	a	alergologia	4.01.01.03-7 Alergologia e Imunologia Clínica	\N
2603	095	a	imunologia	4.01.01.03-7 Alergologia e Imunologia Clínica	\N
2604	095	a	clinica	4.01.01.03-7 Alergologia e Imunologia Clínica	\N
2605	095	a	4.01.01.04-5	4.01.01.04-5 Cancerologia	\N
2606	095	a	cancerologia	4.01.01.04-5 Cancerologia	\N
2607	095	a	4.01.01.05-3	4.01.01.05-3 Hematologia	\N
2608	095	a	hematologia	4.01.01.05-3 Hematologia	\N
2609	095	a	4.01.01.06-1	4.01.01.06-1 Endocrinologia	\N
2610	095	a	endocrinologia	4.01.01.06-1 Endocrinologia	\N
2611	095	a	4.01.01.07-0	4.01.01.07-0 Neurologia	\N
2612	095	a	neurologia	4.01.01.07-0 Neurologia	\N
2613	095	a	4.01.01.08-8	4.01.01.08-8 Pediatria	\N
2614	095	a	pediatria	4.01.01.08-8 Pediatria	\N
2615	095	a	4.01.01.09-6	4.01.01.09-6 Doenças Infecciosas e Parasitárias	\N
2616	095	a	doencas	4.01.01.09-6 Doenças Infecciosas e Parasitárias	\N
2617	095	a	infecciosas	4.01.01.09-6 Doenças Infecciosas e Parasitárias	\N
2618	095	a	parasitarias	4.01.01.09-6 Doenças Infecciosas e Parasitárias	\N
2619	095	a	4.01.01.10-0	4.01.01.10-0 Cardiologia	\N
2620	095	a	cardiologia	4.01.01.10-0 Cardiologia	\N
2621	095	a	4.01.01.11-8	4.01.01.11-8 Gastroenterologia	\N
2622	095	a	gastroenterologia	4.01.01.11-8 Gastroenterologia	\N
2623	095	a	4.01.01.12-6	4.01.01.12-6 Pneumologia	\N
2624	095	a	pneumologia	4.01.01.12-6 Pneumologia	\N
2625	095	a	4.01.01.13-4	4.01.01.13-4 Nefrologia	\N
2626	095	a	nefrologia	4.01.01.13-4 Nefrologia	\N
2627	095	a	4.01.01.14-2	4.01.01.14-2 Reumatologia	\N
2628	095	a	reumatologia	4.01.01.14-2 Reumatologia	\N
2629	095	a	4.01.01.15-0	4.01.01.15-0 Ginecologia e Obstetrícia	\N
2630	095	a	ginecologia	4.01.01.15-0 Ginecologia e Obstetrícia	\N
2631	095	a	obstetricia	4.01.01.15-0 Ginecologia e Obstetrícia	\N
2632	095	a	4.01.01.16-9	4.01.01.16-9 Fisiatria	\N
2633	095	a	fisiatria	4.01.01.16-9 Fisiatria	\N
2634	095	a	4.01.01.17-7	4.01.01.17-7 Oftalmologia	\N
2635	095	a	oftalmologia	4.01.01.17-7 Oftalmologia	\N
2636	095	a	4.01.01.18-6	4.01.01.18-6 Ortopedia	\N
2637	095	a	ortopedia	4.01.01.18-6 Ortopedia	\N
2638	095	a	4.01.02.00-9	4.01.02.00-9 Cirurgia	\N
2639	095	a	cirurgia	4.01.02.00-9 Cirurgia	\N
2640	095	a	4.01.02.01-7	4.01.02.01-7 Cirurgia Plástica e Restauradora	\N
2641	095	a	cirurgia	4.01.02.01-7 Cirurgia Plástica e Restauradora	\N
2642	095	a	plastica	4.01.02.01-7 Cirurgia Plástica e Restauradora	\N
2643	095	a	restauradora	4.01.02.01-7 Cirurgia Plástica e Restauradora	\N
2644	095	a	4.01.02.02-5	4.01.02.02-5 Cirurgia Otorrinolaringológica	\N
2645	095	a	cirurgia	4.01.02.02-5 Cirurgia Otorrinolaringológica	\N
2646	095	a	otorrinolaringologica	4.01.02.02-5 Cirurgia Otorrinolaringológica	\N
2647	095	a	4.01.02.03-3	4.01.02.03-3 Cirurgia Oftalmológica	\N
2648	095	a	cirurgia	4.01.02.03-3 Cirurgia Oftalmológica	\N
2649	095	a	oftalmologica	4.01.02.03-3 Cirurgia Oftalmológica	\N
2650	095	a	4.01.02.04-1	4.01.02.04-1 Cirurgia Cardiovascular	\N
2651	095	a	cirurgia	4.01.02.04-1 Cirurgia Cardiovascular	\N
2652	095	a	cardiovascular	4.01.02.04-1 Cirurgia Cardiovascular	\N
2653	095	a	4.01.02.05-0	4.01.02.05-0 Cirurgia Toráxica	\N
2654	095	a	cirurgia	4.01.02.05-0 Cirurgia Toráxica	\N
2655	095	a	toraxica	4.01.02.05-0 Cirurgia Toráxica	\N
2656	095	a	4.01.02.06-8	4.01.02.06-8 Cirurgia Gastroenterologia	\N
2657	095	a	cirurgia	4.01.02.06-8 Cirurgia Gastroenterologia	\N
2658	095	a	gastroenterologia	4.01.02.06-8 Cirurgia Gastroenterologia	\N
2659	095	a	4.01.02.07-6	4.01.02.07-6 Cirurgia Pediátrica	\N
2660	095	a	cirurgia	4.01.02.07-6 Cirurgia Pediátrica	\N
2661	095	a	pediatrica	4.01.02.07-6 Cirurgia Pediátrica	\N
2662	095	a	4.01.02.08-4	4.01.02.08-4 Neurocirurgia	\N
2663	095	a	neurocirurgia	4.01.02.08-4 Neurocirurgia	\N
2664	095	a	4.01.02.09-2	4.01.02.09-2 Cirurgia Urológica	\N
2665	095	a	cirurgia	4.01.02.09-2 Cirurgia Urológica	\N
2666	095	a	urologica	4.01.02.09-2 Cirurgia Urológica	\N
2667	095	a	4.01.02.10-6	4.01.02.10-6 Cirurgia Proctológica	\N
2668	095	a	cirurgia	4.01.02.10-6 Cirurgia Proctológica	\N
2669	095	a	proctologica	4.01.02.10-6 Cirurgia Proctológica	\N
2670	095	a	4.01.02.11-4	4.01.02.11-4 Cirurgia Ortopédica	\N
2671	095	a	cirurgia	4.01.02.11-4 Cirurgia Ortopédica	\N
2672	095	a	ortopedica	4.01.02.11-4 Cirurgia Ortopédica	\N
2673	095	a	4.01.02.12-2	4.01.02.12-2 Cirurgia Traumatológica	\N
2674	095	a	cirurgia	4.01.02.12-2 Cirurgia Traumatológica	\N
2675	095	a	traumatologica	4.01.02.12-2 Cirurgia Traumatológica	\N
2676	095	a	4.01.02.13-0	4.01.02.13-0 Anestesiologia	\N
2677	095	a	anestesiologia	4.01.02.13-0 Anestesiologia	\N
2678	095	a	4.01.02.14-9	4.01.02.14-9 Cirurgia Experimental	\N
2679	095	a	cirurgia	4.01.02.14-9 Cirurgia Experimental	\N
2680	095	a	experimental	4.01.02.14-9 Cirurgia Experimental	\N
2681	095	a	4.01.03.00-5	4.01.03.00-5 Saúde Materno-Infantil	\N
2682	095	a	saude	4.01.03.00-5 Saúde Materno-Infantil	\N
2683	095	a	materno-infantil	4.01.03.00-5 Saúde Materno-Infantil	\N
2684	095	a	4.01.04.00-1	4.01.04.00-1 Psiquiatria	\N
2685	095	a	psiquiatria	4.01.04.00-1 Psiquiatria	\N
2686	095	a	4.01.05.00-8	4.01.05.00-8 Anatomia Patológica e Patologia Clínica	\N
2687	095	a	anatomia	4.01.05.00-8 Anatomia Patológica e Patologia Clínica	\N
2688	095	a	patologica	4.01.05.00-8 Anatomia Patológica e Patologia Clínica	\N
2689	095	a	patologia	4.01.05.00-8 Anatomia Patológica e Patologia Clínica	\N
2690	095	a	clinica	4.01.05.00-8 Anatomia Patológica e Patologia Clínica	\N
2691	095	a	4.01.06.00-4	4.01.06.00-4 Radiologia Médica	\N
2692	095	a	radiologia	4.01.06.00-4 Radiologia Médica	\N
2693	095	a	medica	4.01.06.00-4 Radiologia Médica	\N
2694	095	a	4.01.07.00-0	4.01.07.00-0 Medicina Legal e Deontologia	\N
2695	095	a	medicina	4.01.07.00-0 Medicina Legal e Deontologia	\N
2696	095	a	legal	4.01.07.00-0 Medicina Legal e Deontologia	\N
2697	095	a	deontologia	4.01.07.00-0 Medicina Legal e Deontologia	\N
2698	095	a	4.02.00.00-0	4.02.00.00-0 Odontologia	\N
2699	095	a	odontologia	4.02.00.00-0 Odontologia	\N
2700	095	a	4.02.01.00-7	4.02.01.00-7 Clínica Odontológica	\N
2701	095	a	clinica	4.02.01.00-7 Clínica Odontológica	\N
2702	095	a	odontologica	4.02.01.00-7 Clínica Odontológica	\N
2703	095	a	4.02.02.00-3	4.02.02.00-3 Cirurgia Buco-Maxilo-Facial	\N
2704	095	a	cirurgia	4.02.02.00-3 Cirurgia Buco-Maxilo-Facial	\N
2705	095	a	buco-maxilo-facial	4.02.02.00-3 Cirurgia Buco-Maxilo-Facial	\N
2706	095	a	4.02.03.00-0	4.02.03.00-0 Ortodontia	\N
2707	095	a	ortodontia	4.02.03.00-0 Ortodontia	\N
2708	095	a	4.02.04.00-6	4.02.04.00-6 Odontopediatria	\N
2709	095	a	odontopediatria	4.02.04.00-6 Odontopediatria	\N
2710	095	a	4.02.05.00-2	4.02.05.00-2 Periodontia	\N
2711	095	a	periodontia	4.02.05.00-2 Periodontia	\N
2712	095	a	4.02.06.00-9	4.02.06.00-9 Endodontia	\N
2713	095	a	endodontia	4.02.06.00-9 Endodontia	\N
2714	095	a	4.02.07.00-5	4.02.07.00-5 Radiologia Odontológica	\N
2715	095	a	radiologia	4.02.07.00-5 Radiologia Odontológica	\N
2716	095	a	odontologica	4.02.07.00-5 Radiologia Odontológica	\N
2717	095	a	4.02.08.00-1	4.02.08.00-1 Odontologia Social e Preventiva	\N
2718	095	a	odontologia	4.02.08.00-1 Odontologia Social e Preventiva	\N
2719	095	a	social	4.02.08.00-1 Odontologia Social e Preventiva	\N
2720	095	a	preventiva	4.02.08.00-1 Odontologia Social e Preventiva	\N
2721	095	a	4.02.09.00-8	4.02.09.00-8 Materiais Odontológicos	\N
2722	095	a	materiais	4.02.09.00-8 Materiais Odontológicos	\N
2723	095	a	odontologicos	4.02.09.00-8 Materiais Odontológicos	\N
2724	095	a	4.03.00.00-5	4.03.00.00-5 Farmácia	\N
2725	095	a	farmacia	4.03.00.00-5 Farmácia	\N
2726	095	a	4.03.01.00-1	4.03.01.00-1 Farmacotecnia	\N
2727	095	a	farmacotecnia	4.03.01.00-1 Farmacotecnia	\N
2728	095	a	4.03.02.00-8	4.03.02.00-8 Farmacognosia	\N
2729	095	a	farmacognosia	4.03.02.00-8 Farmacognosia	\N
2730	095	a	4.03.03.00-4	4.03.03.00-4 Análise Toxicológica	\N
2731	095	a	analise	4.03.03.00-4 Análise Toxicológica	\N
2732	095	a	toxicologica	4.03.03.00-4 Análise Toxicológica	\N
2733	095	a	4.03.04.00-0	4.03.04.00-0 Análise e Controle e Medicamentos	\N
2734	095	a	analise	4.03.04.00-0 Análise e Controle e Medicamentos	\N
2735	095	a	controle	4.03.04.00-0 Análise e Controle e Medicamentos	\N
2736	095	a	medicamentos	4.03.04.00-0 Análise e Controle e Medicamentos	\N
2737	095	a	4.03.05.00-7	4.03.05.00-7 Bromatologia	\N
2738	095	a	bromatologia	4.03.05.00-7 Bromatologia	\N
2739	095	a	4.04.00.00-0	4.04.00.00-0 Enfermagem	\N
2740	095	a	enfermagem	4.04.00.00-0 Enfermagem	\N
2741	095	a	4.04.01.00-6	4.04.01.00-6 Enfermagem Médico-Cirúrgica	\N
2742	095	a	enfermagem	4.04.01.00-6 Enfermagem Médico-Cirúrgica	\N
2743	095	a	medico-cirurgica	4.04.01.00-6 Enfermagem Médico-Cirúrgica	\N
2744	095	a	4.04.02.00-2	4.04.02.00-2 Enfermagem Obstétrica	\N
2745	095	a	enfermagem	4.04.02.00-2 Enfermagem Obstétrica	\N
2746	095	a	obstetrica	4.04.02.00-2 Enfermagem Obstétrica	\N
2747	095	a	4.04.03.00-9	4.04.03.00-9 Enfermagem Pediátrica	\N
2748	095	a	enfermagem	4.04.03.00-9 Enfermagem Pediátrica	\N
2749	095	a	pediatrica	4.04.03.00-9 Enfermagem Pediátrica	\N
2750	095	a	4.04.04.00-5	4.04.04.00-5 Enfermagem Psiquiátrica	\N
2751	095	a	enfermagem	4.04.04.00-5 Enfermagem Psiquiátrica	\N
2752	095	a	psiquiatrica	4.04.04.00-5 Enfermagem Psiquiátrica	\N
2753	095	a	4.04.05.00-1	4.04.05.00-1 Enfermagem de Doenças Contagiosas	\N
2754	095	a	enfermagem	4.04.05.00-1 Enfermagem de Doenças Contagiosas	\N
2755	095	a	de	4.04.05.00-1 Enfermagem de Doenças Contagiosas	\N
2756	095	a	doencas	4.04.05.00-1 Enfermagem de Doenças Contagiosas	\N
2757	095	a	contagiosas	4.04.05.00-1 Enfermagem de Doenças Contagiosas	\N
2758	095	a	4.04.06.00-8	4.04.06.00-8 Enfermagem de Saúde Pública	\N
2759	095	a	enfermagem	4.04.06.00-8 Enfermagem de Saúde Pública	\N
2760	095	a	de	4.04.06.00-8 Enfermagem de Saúde Pública	\N
2761	095	a	saude	4.04.06.00-8 Enfermagem de Saúde Pública	\N
2762	095	a	publica	4.04.06.00-8 Enfermagem de Saúde Pública	\N
2763	095	a	4.05.00.00-4	4.05.00.00-4 Nutrição	\N
2764	095	a	nutricao	4.05.00.00-4 Nutrição	\N
2765	095	a	4.05.01.00-0	4.05.01.00-0 Bioquímica da Nutrição	\N
2766	095	a	bioquimica	4.05.01.00-0 Bioquímica da Nutrição	\N
2767	095	a	da	4.05.01.00-0 Bioquímica da Nutrição	\N
2768	095	a	nutricao	4.05.01.00-0 Bioquímica da Nutrição	\N
2769	095	a	4.05.02.00-7	4.05.02.00-7 Dietética	\N
2770	095	a	dietetica	4.05.02.00-7 Dietética	\N
2771	095	a	4.05.03.00-3	4.05.03.00-3 Análise Nutricional de População	\N
2772	095	a	analise	4.05.03.00-3 Análise Nutricional de População	\N
2773	095	a	nutricional	4.05.03.00-3 Análise Nutricional de População	\N
2774	095	a	de	4.05.03.00-3 Análise Nutricional de População	\N
2775	095	a	populacao	4.05.03.00-3 Análise Nutricional de População	\N
2776	095	a	4.05.04.00-0	4.05.04.00-0 Desnutrição e Desenvolvimento Fisiológico	\N
2777	095	a	desnutricao	4.05.04.00-0 Desnutrição e Desenvolvimento Fisiológico	\N
2778	095	a	desenvolvimento	4.05.04.00-0 Desnutrição e Desenvolvimento Fisiológico	\N
2779	095	a	fisiologico	4.05.04.00-0 Desnutrição e Desenvolvimento Fisiológico	\N
2780	095	a	4.06.00.00-9	4.06.00.00-9 Saúde Coletiva	\N
2781	095	a	saude	4.06.00.00-9 Saúde Coletiva	\N
2782	095	a	coletiva	4.06.00.00-9 Saúde Coletiva	\N
2783	095	a	4.06.01.00-5	4.06.01.00-5 Epidemiologia	\N
2784	095	a	epidemiologia	4.06.01.00-5 Epidemiologia	\N
2785	095	a	4.06.02.00-1	4.06.02.00-1 Saúde Publica	\N
2786	095	a	saude	4.06.02.00-1 Saúde Publica	\N
2787	095	a	publica	4.06.02.00-1 Saúde Publica	\N
2788	095	a	4.06.03.00-8	4.06.03.00-8 Medicina Preventiva	\N
2789	095	a	medicina	4.06.03.00-8 Medicina Preventiva	\N
2790	095	a	preventiva	4.06.03.00-8 Medicina Preventiva	\N
2791	095	a	4.07.00.00-3	4.07.00.00-3 Fonoaudiologia	\N
2792	095	a	fonoaudiologia	4.07.00.00-3 Fonoaudiologia	\N
2793	095	a	4.08.00.00-8	4.08.00.00-8 Fisioterapia e Terapia Ocupacional	\N
2794	095	a	fisioterapia	4.08.00.00-8 Fisioterapia e Terapia Ocupacional	\N
2795	095	a	terapia	4.08.00.00-8 Fisioterapia e Terapia Ocupacional	\N
2796	095	a	ocupacional	4.08.00.00-8 Fisioterapia e Terapia Ocupacional	\N
2797	095	a	4.09.00.00-2	4.09.00.00-2 Educação Física	\N
2798	095	a	educacao	4.09.00.00-2 Educação Física	\N
2799	095	a	fisica	4.09.00.00-2 Educação Física	\N
2800	095	a	5.00.00.00-4	5.00.00.00-4 Ciências Agrárias	\N
2801	095	a	ciencias	5.00.00.00-4 Ciências Agrárias	\N
2802	095	a	agrarias	5.00.00.00-4 Ciências Agrárias	\N
2803	095	a	5.01.00.00-9	5.01.00.00-9 Agronomia	\N
2804	095	a	agronomia	5.01.00.00-9 Agronomia	\N
2805	095	a	5.01.01.00-5	5.01.01.00-5 Ciência do Solo	\N
2806	095	a	ciencia	5.01.01.00-5 Ciência do Solo	\N
2807	095	a	do	5.01.01.00-5 Ciência do Solo	\N
2808	095	a	solo	5.01.01.00-5 Ciência do Solo	\N
2809	095	a	5.01.01.01-3	5.01.01.01-3 Genese, Morfologia e Classificação dos Solos	\N
2810	095	a	genese,	5.01.01.01-3 Genese, Morfologia e Classificação dos Solos	\N
2811	095	a	morfologia	5.01.01.01-3 Genese, Morfologia e Classificação dos Solos	\N
2812	095	a	classificacao	5.01.01.01-3 Genese, Morfologia e Classificação dos Solos	\N
2813	095	a	dos	5.01.01.01-3 Genese, Morfologia e Classificação dos Solos	\N
2814	095	a	solos	5.01.01.01-3 Genese, Morfologia e Classificação dos Solos	\N
2815	095	a	5.01.01.02-1	5.01.01.02-1 Física do Solo	\N
2816	095	a	fisica	5.01.01.02-1 Física do Solo	\N
2817	095	a	do	5.01.01.02-1 Física do Solo	\N
2818	095	a	solo	5.01.01.02-1 Física do Solo	\N
2819	095	a	5.01.01.03-0	5.01.01.03-0 Química do Solo	\N
2820	095	a	quimica	5.01.01.03-0 Química do Solo	\N
2821	095	a	do	5.01.01.03-0 Química do Solo	\N
2822	095	a	solo	5.01.01.03-0 Química do Solo	\N
2823	095	a	5.01.01.04-8	5.01.01.04-8 Microbiologia e Bioquímica do Solo	\N
2824	095	a	microbiologia	5.01.01.04-8 Microbiologia e Bioquímica do Solo	\N
2825	095	a	bioquimica	5.01.01.04-8 Microbiologia e Bioquímica do Solo	\N
2826	095	a	do	5.01.01.04-8 Microbiologia e Bioquímica do Solo	\N
2827	095	a	solo	5.01.01.04-8 Microbiologia e Bioquímica do Solo	\N
2828	095	a	5.01.01.05-6	5.01.01.05-6 Fertilidade do Solo e Adubação	\N
2829	095	a	fertilidade	5.01.01.05-6 Fertilidade do Solo e Adubação	\N
2830	095	a	do	5.01.01.05-6 Fertilidade do Solo e Adubação	\N
2831	095	a	solo	5.01.01.05-6 Fertilidade do Solo e Adubação	\N
2832	095	a	adubacao	5.01.01.05-6 Fertilidade do Solo e Adubação	\N
2833	095	a	5.01.01.06-4	5.01.01.06-4 Manejo e Conservação do Solo	\N
2834	095	a	manejo	5.01.01.06-4 Manejo e Conservação do Solo	\N
2835	095	a	conservacao	5.01.01.06-4 Manejo e Conservação do Solo	\N
2836	095	a	do	5.01.01.06-4 Manejo e Conservação do Solo	\N
2837	095	a	solo	5.01.01.06-4 Manejo e Conservação do Solo	\N
2838	095	a	5.01.02.00-1	5.01.02.00-1 Fitossanidade	\N
2839	095	a	fitossanidade	5.01.02.00-1 Fitossanidade	\N
2840	095	a	5.01.02.01-0	5.01.02.01-0 Fitopatologia	\N
2841	095	a	fitopatologia	5.01.02.01-0 Fitopatologia	\N
2842	095	a	5.01.02.02-8	5.01.02.02-8 Entomologia Agrícola	\N
2843	095	a	entomologia	5.01.02.02-8 Entomologia Agrícola	\N
2844	095	a	agricola	5.01.02.02-8 Entomologia Agrícola	\N
2845	095	a	5.01.02.03-6	5.01.02.03-6 Parasitologia Agrícola	\N
2846	095	a	parasitologia	5.01.02.03-6 Parasitologia Agrícola	\N
2847	095	a	agricola	5.01.02.03-6 Parasitologia Agrícola	\N
2848	095	a	5.01.02.04-4	5.01.02.04-4 Microbiologia Agrícola	\N
2849	095	a	microbiologia	5.01.02.04-4 Microbiologia Agrícola	\N
2850	095	a	agricola	5.01.02.04-4 Microbiologia Agrícola	\N
2851	095	a	5.01.02.05-2	5.01.02.05-2 Defesa Fitossanitária	\N
2852	095	a	defesa	5.01.02.05-2 Defesa Fitossanitária	\N
2853	095	a	fitossanitaria	5.01.02.05-2 Defesa Fitossanitária	\N
2854	095	a	5.01.03.00-8	5.01.03.00-8 Fitotecnia	\N
2855	095	a	fitotecnia	5.01.03.00-8 Fitotecnia	\N
2856	095	a	5.01.03.01-6	5.01.03.01-6 Manejo e Tratos Culturais	\N
2857	095	a	manejo	5.01.03.01-6 Manejo e Tratos Culturais	\N
2858	095	a	tratos	5.01.03.01-6 Manejo e Tratos Culturais	\N
2859	095	a	culturais	5.01.03.01-6 Manejo e Tratos Culturais	\N
2860	095	a	5.01.03.02-4	5.01.03.02-4 Mecanização Agrícola	\N
2861	095	a	mecanizacao	5.01.03.02-4 Mecanização Agrícola	\N
2862	095	a	agricola	5.01.03.02-4 Mecanização Agrícola	\N
2863	095	a	5.01.03.03-2	5.01.03.03-2 Produção e Beneficiamento de Sementes	\N
2864	095	a	producao	5.01.03.03-2 Produção e Beneficiamento de Sementes	\N
2865	095	a	beneficiamento	5.01.03.03-2 Produção e Beneficiamento de Sementes	\N
2866	095	a	de	5.01.03.03-2 Produção e Beneficiamento de Sementes	\N
2867	095	a	sementes	5.01.03.03-2 Produção e Beneficiamento de Sementes	\N
2868	095	a	5.01.03.04-0	5.01.03.04-0 Produção de Mudas	\N
2869	095	a	producao	5.01.03.04-0 Produção de Mudas	\N
2870	095	a	de	5.01.03.04-0 Produção de Mudas	\N
2871	095	a	mudas	5.01.03.04-0 Produção de Mudas	\N
2872	095	a	5.01.03.05-9	5.01.03.05-9 Melhoramento Vegetal	\N
2873	095	a	melhoramento	5.01.03.05-9 Melhoramento Vegetal	\N
2874	095	a	vegetal	5.01.03.05-9 Melhoramento Vegetal	\N
2875	095	a	5.01.03.06-7	5.01.03.06-7 Fisiologia de Plantas Cultivadas	\N
2876	095	a	fisiologia	5.01.03.06-7 Fisiologia de Plantas Cultivadas	\N
2877	095	a	de	5.01.03.06-7 Fisiologia de Plantas Cultivadas	\N
2878	095	a	plantas	5.01.03.06-7 Fisiologia de Plantas Cultivadas	\N
2879	095	a	cultivadas	5.01.03.06-7 Fisiologia de Plantas Cultivadas	\N
2880	095	a	5.01.03.07-5	5.01.03.07-5 Matologia	\N
2881	095	a	matologia	5.01.03.07-5 Matologia	\N
2882	095	a	5.01.04.00-4	5.01.04.00-4 Floricultura, Parques e Jardins	\N
2883	095	a	floricultura,	5.01.04.00-4 Floricultura, Parques e Jardins	\N
2884	095	a	parques	5.01.04.00-4 Floricultura, Parques e Jardins	\N
2885	095	a	jardins	5.01.04.00-4 Floricultura, Parques e Jardins	\N
2886	095	a	5.01.04.01-2	5.01.04.01-2 Floricultura	\N
2887	095	a	floricultura	5.01.04.01-2 Floricultura	\N
2888	095	a	5.01.04.02-0	5.01.04.02-0 Parques e Jardins	\N
2889	095	a	parques	5.01.04.02-0 Parques e Jardins	\N
2890	095	a	jardins	5.01.04.02-0 Parques e Jardins	\N
2891	095	a	5.01.04.03-9	5.01.04.03-9 Arborização de Vias Públicas	\N
2892	095	a	arborizacao	5.01.04.03-9 Arborização de Vias Públicas	\N
2893	095	a	de	5.01.04.03-9 Arborização de Vias Públicas	\N
2894	095	a	vias	5.01.04.03-9 Arborização de Vias Públicas	\N
2895	095	a	publicas	5.01.04.03-9 Arborização de Vias Públicas	\N
2896	095	a	5.01.05.00-0	5.01.05.00-0 Agrometeorologia	\N
2897	095	a	agrometeorologia	5.01.05.00-0 Agrometeorologia	\N
2898	095	a	5.01.06.00-7	5.01.06.00-7 Extensão Rural	\N
2899	095	a	extensao	5.01.06.00-7 Extensão Rural	\N
2900	095	a	rural	5.01.06.00-7 Extensão Rural	\N
2901	095	a	5.02.00.00-3	5.02.00.00-3 Recursos Florestais e Engenharia Florestal	\N
2902	095	a	recursos	5.02.00.00-3 Recursos Florestais e Engenharia Florestal	\N
2903	095	a	florestais	5.02.00.00-3 Recursos Florestais e Engenharia Florestal	\N
2904	095	a	engenharia	5.02.00.00-3 Recursos Florestais e Engenharia Florestal	\N
2905	095	a	florestal	5.02.00.00-3 Recursos Florestais e Engenharia Florestal	\N
2906	095	a	5.02.01.00-0	5.02.01.00-0 Silvicultura	\N
2907	095	a	silvicultura	5.02.01.00-0 Silvicultura	\N
2908	095	a	5.02.01.01-8	5.02.01.01-8 Dendrologia	\N
2909	095	a	dendrologia	5.02.01.01-8 Dendrologia	\N
2910	095	a	5.02.01.02-6	5.02.01.02-6 Florestamento e Reflorestamento	\N
2911	095	a	florestamento	5.02.01.02-6 Florestamento e Reflorestamento	\N
2912	095	a	reflorestamento	5.02.01.02-6 Florestamento e Reflorestamento	\N
2913	095	a	5.02.01.03-4	5.02.01.03-4 Genética e Melhoramento Florestal	\N
2914	095	a	genetica	5.02.01.03-4 Genética e Melhoramento Florestal	\N
2915	095	a	melhoramento	5.02.01.03-4 Genética e Melhoramento Florestal	\N
2916	095	a	florestal	5.02.01.03-4 Genética e Melhoramento Florestal	\N
2917	095	a	5.02.01.04-2	5.02.01.04-2 Sementes Florestais	\N
2918	095	a	sementes	5.02.01.04-2 Sementes Florestais	\N
2919	095	a	florestais	5.02.01.04-2 Sementes Florestais	\N
2920	095	a	5.02.01.05-0	5.02.01.05-0 Nutrição Florestal	\N
2921	095	a	nutricao	5.02.01.05-0 Nutrição Florestal	\N
2922	095	a	florestal	5.02.01.05-0 Nutrição Florestal	\N
2923	095	a	5.02.01.06-9	5.02.01.06-9 Fisiologia Florestal	\N
2924	095	a	fisiologia	5.02.01.06-9 Fisiologia Florestal	\N
2925	095	a	florestal	5.02.01.06-9 Fisiologia Florestal	\N
2926	095	a	5.02.01.07-7	5.02.01.07-7 Solos Florestais	\N
2927	095	a	solos	5.02.01.07-7 Solos Florestais	\N
2928	095	a	florestais	5.02.01.07-7 Solos Florestais	\N
2929	095	a	5.02.01.08-5	5.02.01.08-5 Proteção Florestal	\N
2930	095	a	protecao	5.02.01.08-5 Proteção Florestal	\N
2931	095	a	florestal	5.02.01.08-5 Proteção Florestal	\N
2932	095	a	5.02.02.00-6	5.02.02.00-6 Manejo Florestal	\N
2933	095	a	manejo	5.02.02.00-6 Manejo Florestal	\N
2934	095	a	florestal	5.02.02.00-6 Manejo Florestal	\N
2935	095	a	5.02.02.01-4	5.02.02.01-4 Economia Florestal	\N
2936	095	a	economia	5.02.02.01-4 Economia Florestal	\N
2937	095	a	florestal	5.02.02.01-4 Economia Florestal	\N
2938	095	a	5.02.02.02-2	5.02.02.02-2 Politica e Legislação Florestal	\N
2939	095	a	politica	5.02.02.02-2 Politica e Legislação Florestal	\N
2940	095	a	legislacao	5.02.02.02-2 Politica e Legislação Florestal	\N
2941	095	a	florestal	5.02.02.02-2 Politica e Legislação Florestal	\N
2942	095	a	5.02.02.03-0	5.02.02.03-0 Administração Florestal	\N
2943	095	a	administracao	5.02.02.03-0 Administração Florestal	\N
2944	095	a	florestal	5.02.02.03-0 Administração Florestal	\N
2945	095	a	5.02.02.04-9	5.02.02.04-9 Dendrometria e Inventário Florestal	\N
2946	095	a	dendrometria	5.02.02.04-9 Dendrometria e Inventário Florestal	\N
2947	095	a	inventario	5.02.02.04-9 Dendrometria e Inventário Florestal	\N
2948	095	a	florestal	5.02.02.04-9 Dendrometria e Inventário Florestal	\N
2949	095	a	5.02.02.05-7	5.02.02.05-7 Fotointerpretação Florestal	\N
2950	095	a	fotointerpretacao	5.02.02.05-7 Fotointerpretação Florestal	\N
2951	095	a	florestal	5.02.02.05-7 Fotointerpretação Florestal	\N
2952	095	a	5.02.02.06-5	5.02.02.06-5 Ordenamento Florestal	\N
2953	095	a	ordenamento	5.02.02.06-5 Ordenamento Florestal	\N
2954	095	a	florestal	5.02.02.06-5 Ordenamento Florestal	\N
2955	095	a	5.02.03.00-2	5.02.03.00-2 Técnicas e Operações Florestais	\N
2956	095	a	tecnicas	5.02.03.00-2 Técnicas e Operações Florestais	\N
2957	095	a	operacoes	5.02.03.00-2 Técnicas e Operações Florestais	\N
2958	095	a	florestais	5.02.03.00-2 Técnicas e Operações Florestais	\N
2959	095	a	5.02.03.01-0	5.02.03.01-0 Exploração Florestal	\N
2960	095	a	exploracao	5.02.03.01-0 Exploração Florestal	\N
2961	095	a	florestal	5.02.03.01-0 Exploração Florestal	\N
2962	095	a	5.02.03.02-9	5.02.03.02-9 Mecanização Florestal	\N
2963	095	a	mecanizacao	5.02.03.02-9 Mecanização Florestal	\N
2964	095	a	florestal	5.02.03.02-9 Mecanização Florestal	\N
2965	095	a	5.02.04.00-9	5.02.04.00-9 Tecnologia e Utilização de Produtos Florestais	\N
2966	095	a	tecnologia	5.02.04.00-9 Tecnologia e Utilização de Produtos Florestais	\N
2967	095	a	utilizacao	5.02.04.00-9 Tecnologia e Utilização de Produtos Florestais	\N
2968	095	a	de	5.02.04.00-9 Tecnologia e Utilização de Produtos Florestais	\N
2969	095	a	produtos	5.02.04.00-9 Tecnologia e Utilização de Produtos Florestais	\N
2970	095	a	florestais	5.02.04.00-9 Tecnologia e Utilização de Produtos Florestais	\N
2971	095	a	5.02.04.01-7	5.02.04.01-7 Anatomia e Identificação de Produtos Florestais	\N
2972	095	a	anatomia	5.02.04.01-7 Anatomia e Identificação de Produtos Florestais	\N
2973	095	a	identificacao	5.02.04.01-7 Anatomia e Identificação de Produtos Florestais	\N
2974	095	a	de	5.02.04.01-7 Anatomia e Identificação de Produtos Florestais	\N
2975	095	a	produtos	5.02.04.01-7 Anatomia e Identificação de Produtos Florestais	\N
2976	095	a	florestais	5.02.04.01-7 Anatomia e Identificação de Produtos Florestais	\N
2977	095	a	5.02.04.02-5	5.02.04.02-5 Propriedades Físico-Mecânicas da Madeira	\N
2978	095	a	propriedades	5.02.04.02-5 Propriedades Físico-Mecânicas da Madeira	\N
2979	095	a	fisico-mecanicas	5.02.04.02-5 Propriedades Físico-Mecânicas da Madeira	\N
2980	095	a	da	5.02.04.02-5 Propriedades Físico-Mecânicas da Madeira	\N
2981	095	a	madeira	5.02.04.02-5 Propriedades Físico-Mecânicas da Madeira	\N
2982	095	a	5.02.04.03-3	5.02.04.03-3 Relações Água-Madeira e Secagem	\N
2983	095	a	relacoes	5.02.04.03-3 Relações Água-Madeira e Secagem	\N
2984	095	a	agua-madeira	5.02.04.03-3 Relações Água-Madeira e Secagem	\N
2985	095	a	secagem	5.02.04.03-3 Relações Água-Madeira e Secagem	\N
2986	095	a	5.02.04.04-1	5.02.04.04-1 Tratamento da Madeira	\N
2987	095	a	tratamento	5.02.04.04-1 Tratamento da Madeira	\N
2988	095	a	da	5.02.04.04-1 Tratamento da Madeira	\N
2989	095	a	madeira	5.02.04.04-1 Tratamento da Madeira	\N
2990	095	a	5.02.04.05-0	5.02.04.05-0 Processamento Mecânico da Madeira	\N
2991	095	a	processamento	5.02.04.05-0 Processamento Mecânico da Madeira	\N
2992	095	a	mecanico	5.02.04.05-0 Processamento Mecânico da Madeira	\N
2993	095	a	da	5.02.04.05-0 Processamento Mecânico da Madeira	\N
2994	095	a	madeira	5.02.04.05-0 Processamento Mecânico da Madeira	\N
2995	095	a	5.02.04.06-8	5.02.04.06-8 Química da Madeira	\N
2996	095	a	quimica	5.02.04.06-8 Química da Madeira	\N
2997	095	a	da	5.02.04.06-8 Química da Madeira	\N
2998	095	a	madeira	5.02.04.06-8 Química da Madeira	\N
2999	095	a	5.02.04.07-6	5.02.04.07-6 Resinas de Madeiras	\N
3000	095	a	resinas	5.02.04.07-6 Resinas de Madeiras	\N
3001	095	a	de	5.02.04.07-6 Resinas de Madeiras	\N
3002	095	a	madeiras	5.02.04.07-6 Resinas de Madeiras	\N
3003	095	a	5.02.04.08-4	5.02.04.08-4 Tecnologia de Celulose e Papel	\N
3004	095	a	tecnologia	5.02.04.08-4 Tecnologia de Celulose e Papel	\N
3005	095	a	de	5.02.04.08-4 Tecnologia de Celulose e Papel	\N
3006	095	a	celulose	5.02.04.08-4 Tecnologia de Celulose e Papel	\N
3007	095	a	papel	5.02.04.08-4 Tecnologia de Celulose e Papel	\N
3008	095	a	5.02.04.09-2	5.02.04.09-2 Tecnologia de Chapas	\N
3009	095	a	tecnologia	5.02.04.09-2 Tecnologia de Chapas	\N
3010	095	a	de	5.02.04.09-2 Tecnologia de Chapas	\N
3011	095	a	chapas	5.02.04.09-2 Tecnologia de Chapas	\N
3012	095	a	5.02.05.00-5	5.02.05.00-5 Conservação da Natureza	\N
3013	095	a	conservacao	5.02.05.00-5 Conservação da Natureza	\N
3014	095	a	da	5.02.05.00-5 Conservação da Natureza	\N
3015	095	a	natureza	5.02.05.00-5 Conservação da Natureza	\N
3016	095	a	5.02.05.01-3	5.02.05.01-3 Hidrologia Florestal	\N
3017	095	a	hidrologia	5.02.05.01-3 Hidrologia Florestal	\N
3018	095	a	florestal	5.02.05.01-3 Hidrologia Florestal	\N
3019	095	a	5.02.05.02-1	5.02.05.02-1 Conservação de Áreas Silvestres	\N
3020	095	a	conservacao	5.02.05.02-1 Conservação de Áreas Silvestres	\N
3021	095	a	de	5.02.05.02-1 Conservação de Áreas Silvestres	\N
3022	095	a	areas	5.02.05.02-1 Conservação de Áreas Silvestres	\N
3023	095	a	silvestres	5.02.05.02-1 Conservação de Áreas Silvestres	\N
3024	095	a	5.02.05.03-0	5.02.05.03-0 Conservação de Bacias Hidrográficas	\N
3025	095	a	conservacao	5.02.05.03-0 Conservação de Bacias Hidrográficas	\N
3026	095	a	de	5.02.05.03-0 Conservação de Bacias Hidrográficas	\N
3027	095	a	bacias	5.02.05.03-0 Conservação de Bacias Hidrográficas	\N
3028	095	a	hidrograficas	5.02.05.03-0 Conservação de Bacias Hidrográficas	\N
3029	095	a	5.02.05.04-8	5.02.05.04-8 Recuperação de Áreas Degradadas	\N
3030	095	a	recuperacao	5.02.05.04-8 Recuperação de Áreas Degradadas	\N
3031	095	a	de	5.02.05.04-8 Recuperação de Áreas Degradadas	\N
3032	095	a	areas	5.02.05.04-8 Recuperação de Áreas Degradadas	\N
3033	095	a	degradadas	5.02.05.04-8 Recuperação de Áreas Degradadas	\N
3034	095	a	5.02.06.00-1	5.02.06.00-1 Energia de Biomassa Florestal	\N
3035	095	a	energia	5.02.06.00-1 Energia de Biomassa Florestal	\N
3036	095	a	de	5.02.06.00-1 Energia de Biomassa Florestal	\N
3037	095	a	biomassa	5.02.06.00-1 Energia de Biomassa Florestal	\N
3038	095	a	florestal	5.02.06.00-1 Energia de Biomassa Florestal	\N
3039	095	a	5.03.00.00-8	5.03.00.00-8 Engenharia Agrícola	\N
3040	095	a	engenharia	5.03.00.00-8 Engenharia Agrícola	\N
3041	095	a	agricola	5.03.00.00-8 Engenharia Agrícola	\N
3042	095	a	5.03.01.00-4	5.03.01.00-4 Máquinas e Implementos Agrícolas	\N
3043	095	a	maquinas	5.03.01.00-4 Máquinas e Implementos Agrícolas	\N
3044	095	a	implementos	5.03.01.00-4 Máquinas e Implementos Agrícolas	\N
3045	095	a	agricolas	5.03.01.00-4 Máquinas e Implementos Agrícolas	\N
3046	095	a	5.03.02.00-0	5.03.02.00-0 Engenharia de Água e Solo	\N
3047	095	a	engenharia	5.03.02.00-0 Engenharia de Água e Solo	\N
3048	095	a	de	5.03.02.00-0 Engenharia de Água e Solo	\N
3049	095	a	agua	5.03.02.00-0 Engenharia de Água e Solo	\N
3050	095	a	solo	5.03.02.00-0 Engenharia de Água e Solo	\N
3051	095	a	5.03.02.01-9	5.03.02.01-9 Irrigação e Drenagem	\N
3052	095	a	irrigacao	5.03.02.01-9 Irrigação e Drenagem	\N
3053	095	a	drenagem	5.03.02.01-9 Irrigação e Drenagem	\N
3054	095	a	5.03.02.02-7	5.03.02.02-7 Conservação de Solo e Água	\N
3055	095	a	conservacao	5.03.02.02-7 Conservação de Solo e Água	\N
3056	095	a	de	5.03.02.02-7 Conservação de Solo e Água	\N
3057	095	a	solo	5.03.02.02-7 Conservação de Solo e Água	\N
3058	095	a	agua	5.03.02.02-7 Conservação de Solo e Água	\N
3059	095	a	5.03.03.00-7	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3060	095	a	engenharia	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3061	095	a	de	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3062	095	a	processamento	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3063	095	a	de	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3064	095	a	produtos	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3065	095	a	agricolas	5.03.03.00-7 Engenharia de Processamento de Produtos Agrícolas	\N
3066	095	a	5.03.03.01-5	5.03.03.01-5 Pré-Processamento de Produtos Agrícolas	\N
3067	095	a	pre-processamento	5.03.03.01-5 Pré-Processamento de Produtos Agrícolas	\N
3068	095	a	de	5.03.03.01-5 Pré-Processamento de Produtos Agrícolas	\N
3069	095	a	produtos	5.03.03.01-5 Pré-Processamento de Produtos Agrícolas	\N
3070	095	a	agricolas	5.03.03.01-5 Pré-Processamento de Produtos Agrícolas	\N
3071	095	a	5.03.03.02-3	5.03.03.02-3 Armazenamento de Produtos Agrícolas	\N
3072	095	a	armazenamento	5.03.03.02-3 Armazenamento de Produtos Agrícolas	\N
3073	095	a	de	5.03.03.02-3 Armazenamento de Produtos Agrícolas	\N
3074	095	a	produtos	5.03.03.02-3 Armazenamento de Produtos Agrícolas	\N
3075	095	a	agricolas	5.03.03.02-3 Armazenamento de Produtos Agrícolas	\N
3076	095	a	5.03.03.03-1	5.03.03.03-1 Transferência de Produtos Agrícolas	\N
3077	095	a	transferencia	5.03.03.03-1 Transferência de Produtos Agrícolas	\N
3078	095	a	de	5.03.03.03-1 Transferência de Produtos Agrícolas	\N
3079	095	a	produtos	5.03.03.03-1 Transferência de Produtos Agrícolas	\N
3080	095	a	agricolas	5.03.03.03-1 Transferência de Produtos Agrícolas	\N
3081	095	a	5.03.04.00-3	5.03.04.00-3 Construções Rurais e Ambiência	\N
3082	095	a	construcoes	5.03.04.00-3 Construções Rurais e Ambiência	\N
3083	095	a	rurais	5.03.04.00-3 Construções Rurais e Ambiência	\N
3084	095	a	ambiencia	5.03.04.00-3 Construções Rurais e Ambiência	\N
3085	095	a	5.03.04.01-1	5.03.04.01-1 Assentamento Rural	\N
3086	095	a	assentamento	5.03.04.01-1 Assentamento Rural	\N
3087	095	a	rural	5.03.04.01-1 Assentamento Rural	\N
3088	095	a	5.03.04.02-0	5.03.04.02-0 Engenharia de Construções Rurais	\N
3089	095	a	engenharia	5.03.04.02-0 Engenharia de Construções Rurais	\N
3090	095	a	de	5.03.04.02-0 Engenharia de Construções Rurais	\N
3091	095	a	construcoes	5.03.04.02-0 Engenharia de Construções Rurais	\N
3092	095	a	rurais	5.03.04.02-0 Engenharia de Construções Rurais	\N
3093	095	a	5.03.04.03-8	5.03.04.03-8 Saneamento Rural	\N
3094	095	a	saneamento	5.03.04.03-8 Saneamento Rural	\N
3095	095	a	rural	5.03.04.03-8 Saneamento Rural	\N
3096	095	a	5.03.05.00-0	5.03.05.00-0 Energização Rural	\N
3097	095	a	energizacao	5.03.05.00-0 Energização Rural	\N
3098	095	a	rural	5.03.05.00-0 Energização Rural	\N
3099	095	a	5.04.00.00-2	5.04.00.00-2 Zootecnia	\N
3100	095	a	zootecnia	5.04.00.00-2 Zootecnia	\N
3101	095	a	5.04.01.00-9	5.04.01.00-9 Ecologia dos Animais Domésticos e Etologia	\N
3102	095	a	ecologia	5.04.01.00-9 Ecologia dos Animais Domésticos e Etologia	\N
3103	095	a	dos	5.04.01.00-9 Ecologia dos Animais Domésticos e Etologia	\N
3104	095	a	animais	5.04.01.00-9 Ecologia dos Animais Domésticos e Etologia	\N
3105	095	a	domesticos	5.04.01.00-9 Ecologia dos Animais Domésticos e Etologia	\N
3106	095	a	etologia	5.04.01.00-9 Ecologia dos Animais Domésticos e Etologia	\N
3107	095	a	5.04.02.00-5	5.04.02.00-5 Genética e Melhoramento dos Animais Domésticos	\N
3108	095	a	genetica	5.04.02.00-5 Genética e Melhoramento dos Animais Domésticos	\N
3109	095	a	melhoramento	5.04.02.00-5 Genética e Melhoramento dos Animais Domésticos	\N
3110	095	a	dos	5.04.02.00-5 Genética e Melhoramento dos Animais Domésticos	\N
3111	095	a	animais	5.04.02.00-5 Genética e Melhoramento dos Animais Domésticos	\N
3112	095	a	domesticos	5.04.02.00-5 Genética e Melhoramento dos Animais Domésticos	\N
3113	095	a	5.04.03.00-1	5.04.03.00-1 Nutrição e Alimentação Animal	\N
3114	095	a	nutricao	5.04.03.00-1 Nutrição e Alimentação Animal	\N
3115	095	a	alimentacao	5.04.03.00-1 Nutrição e Alimentação Animal	\N
3116	095	a	animal	5.04.03.00-1 Nutrição e Alimentação Animal	\N
3117	095	a	5.04.03.01-0	5.04.03.01-0 Exigências Nutricionais dos Animais	\N
3118	095	a	exigencias	5.04.03.01-0 Exigências Nutricionais dos Animais	\N
3119	095	a	nutricionais	5.04.03.01-0 Exigências Nutricionais dos Animais	\N
3120	095	a	dos	5.04.03.01-0 Exigências Nutricionais dos Animais	\N
3121	095	a	animais	5.04.03.01-0 Exigências Nutricionais dos Animais	\N
3122	095	a	5.04.03.02-8	5.04.03.02-8 Avaliação de Alimentos para Animais	\N
3123	095	a	avaliacao	5.04.03.02-8 Avaliação de Alimentos para Animais	\N
3124	095	a	de	5.04.03.02-8 Avaliação de Alimentos para Animais	\N
3125	095	a	alimentos	5.04.03.02-8 Avaliação de Alimentos para Animais	\N
3126	095	a	para	5.04.03.02-8 Avaliação de Alimentos para Animais	\N
3127	095	a	animais	5.04.03.02-8 Avaliação de Alimentos para Animais	\N
3128	095	a	5.04.03.03-6	5.04.03.03-6 Conservação de Alimentos para Animais	\N
3129	095	a	conservacao	5.04.03.03-6 Conservação de Alimentos para Animais	\N
3130	095	a	de	5.04.03.03-6 Conservação de Alimentos para Animais	\N
3131	095	a	alimentos	5.04.03.03-6 Conservação de Alimentos para Animais	\N
3132	095	a	para	5.04.03.03-6 Conservação de Alimentos para Animais	\N
3133	095	a	animais	5.04.03.03-6 Conservação de Alimentos para Animais	\N
3134	095	a	5.04.04.00-8	5.04.04.00-8 Pastagem e Forragicultura	\N
3135	095	a	pastagem	5.04.04.00-8 Pastagem e Forragicultura	\N
3136	095	a	forragicultura	5.04.04.00-8 Pastagem e Forragicultura	\N
3137	095	a	5.04.04.01-6	5.04.04.01-6 Avaliação, Produção e Conservação de Forragens	\N
3138	095	a	avaliacao,	5.04.04.01-6 Avaliação, Produção e Conservação de Forragens	\N
3139	095	a	producao	5.04.04.01-6 Avaliação, Produção e Conservação de Forragens	\N
3140	095	a	conservacao	5.04.04.01-6 Avaliação, Produção e Conservação de Forragens	\N
3141	095	a	de	5.04.04.01-6 Avaliação, Produção e Conservação de Forragens	\N
3142	095	a	forragens	5.04.04.01-6 Avaliação, Produção e Conservação de Forragens	\N
3143	095	a	5.04.04.02-4	5.04.04.02-4 Manejo e Conservação de Pastagens	\N
3144	095	a	manejo	5.04.04.02-4 Manejo e Conservação de Pastagens	\N
3145	095	a	conservacao	5.04.04.02-4 Manejo e Conservação de Pastagens	\N
3146	095	a	de	5.04.04.02-4 Manejo e Conservação de Pastagens	\N
3147	095	a	pastagens	5.04.04.02-4 Manejo e Conservação de Pastagens	\N
3148	095	a	5.04.04.03-2	5.04.04.03-2 Fisiologia de Plantas Forrageiras	\N
3149	095	a	fisiologia	5.04.04.03-2 Fisiologia de Plantas Forrageiras	\N
3150	095	a	de	5.04.04.03-2 Fisiologia de Plantas Forrageiras	\N
3151	095	a	plantas	5.04.04.03-2 Fisiologia de Plantas Forrageiras	\N
3152	095	a	forrageiras	5.04.04.03-2 Fisiologia de Plantas Forrageiras	\N
3153	095	a	5.04.04.04-0	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3154	095	a	melhoramento	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3155	095	a	de	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3156	095	a	plantas	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3157	095	a	forrageiras	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3158	095	a	producao	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3159	095	a	de	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3160	095	a	sementes	5.04.04.04-0 Melhoramento de Plantas Forrageiras e Produção de Sementes	\N
3161	095	a	5.04.04.05-9	5.04.04.05-9 Toxicologia e Plantas Tóxicas	\N
3162	095	a	toxicologia	5.04.04.05-9 Toxicologia e Plantas Tóxicas	\N
3163	095	a	plantas	5.04.04.05-9 Toxicologia e Plantas Tóxicas	\N
3164	095	a	toxicas	5.04.04.05-9 Toxicologia e Plantas Tóxicas	\N
3165	095	a	5.04.05.00-4	5.04.05.00-4 Produção Animal	\N
3166	095	a	producao	5.04.05.00-4 Produção Animal	\N
3167	095	a	animal	5.04.05.00-4 Produção Animal	\N
3168	095	a	5.04.05.01-2	5.04.05.01-2 Criação de Animais	\N
3169	095	a	criacao	5.04.05.01-2 Criação de Animais	\N
3170	095	a	de	5.04.05.01-2 Criação de Animais	\N
3171	095	a	animais	5.04.05.01-2 Criação de Animais	\N
3172	095	a	5.04.05.02-0	5.04.05.02-0 Manejo de Animais	\N
3173	095	a	manejo	5.04.05.02-0 Manejo de Animais	\N
3174	095	a	de	5.04.05.02-0 Manejo de Animais	\N
3175	095	a	animais	5.04.05.02-0 Manejo de Animais	\N
3176	095	a	5.04.05.03-9	5.04.05.03-9 Instalações para Produção Animal	\N
3177	095	a	instalacoes	5.04.05.03-9 Instalações para Produção Animal	\N
3178	095	a	para	5.04.05.03-9 Instalações para Produção Animal	\N
3179	095	a	producao	5.04.05.03-9 Instalações para Produção Animal	\N
3180	095	a	animal	5.04.05.03-9 Instalações para Produção Animal	\N
3181	095	a	5.05.00.00-7	5.05.00.00-7 Medicina Veterinária	\N
3182	095	a	medicina	5.05.00.00-7 Medicina Veterinária	\N
3183	095	a	veterinaria	5.05.00.00-7 Medicina Veterinária	\N
3184	095	a	5.05.01.00-3	5.05.01.00-3 Clínica e Cirurgia Animal	\N
3185	095	a	clinica	5.05.01.00-3 Clínica e Cirurgia Animal	\N
3186	095	a	cirurgia	5.05.01.00-3 Clínica e Cirurgia Animal	\N
3187	095	a	animal	5.05.01.00-3 Clínica e Cirurgia Animal	\N
3188	095	a	5.05.01.01-1	5.05.01.01-1 Anestesiologia Animal	\N
3189	095	a	anestesiologia	5.05.01.01-1 Anestesiologia Animal	\N
3190	095	a	animal	5.05.01.01-1 Anestesiologia Animal	\N
3191	095	a	5.05.01.02-0	5.05.01.02-0 Técnica Cirúrgica Animal	\N
3192	095	a	tecnica	5.05.01.02-0 Técnica Cirúrgica Animal	\N
3193	095	a	cirurgica	5.05.01.02-0 Técnica Cirúrgica Animal	\N
3194	095	a	animal	5.05.01.02-0 Técnica Cirúrgica Animal	\N
3195	095	a	5.05.01.03-8	5.05.01.03-8 Radiologia de Animais	\N
3196	095	a	radiologia	5.05.01.03-8 Radiologia de Animais	\N
3197	095	a	de	5.05.01.03-8 Radiologia de Animais	\N
3198	095	a	animais	5.05.01.03-8 Radiologia de Animais	\N
3199	095	a	5.05.01.04-6	5.05.01.04-6 Farmacologia e Terapêutica Animal	\N
3200	095	a	farmacologia	5.05.01.04-6 Farmacologia e Terapêutica Animal	\N
3201	095	a	terapeutica	5.05.01.04-6 Farmacologia e Terapêutica Animal	\N
3202	095	a	animal	5.05.01.04-6 Farmacologia e Terapêutica Animal	\N
3203	095	a	5.05.01.05-4	5.05.01.05-4 Obstetrícia Animal	\N
3204	095	a	obstetricia	5.05.01.05-4 Obstetrícia Animal	\N
3205	095	a	animal	5.05.01.05-4 Obstetrícia Animal	\N
3206	095	a	5.05.01.06-2	5.05.01.06-2 Clínica Veterinária	\N
3207	095	a	clinica	5.05.01.06-2 Clínica Veterinária	\N
3208	095	a	veterinaria	5.05.01.06-2 Clínica Veterinária	\N
3209	095	a	5.05.01.07-0	5.05.01.07-0 Clínica Cirúrgica Animal	\N
3210	095	a	clinica	5.05.01.07-0 Clínica Cirúrgica Animal	\N
3211	095	a	cirurgica	5.05.01.07-0 Clínica Cirúrgica Animal	\N
3212	095	a	animal	5.05.01.07-0 Clínica Cirúrgica Animal	\N
3213	095	a	5.05.01.08-9	5.05.01.08-9 Toxicologia Animal	\N
3214	095	a	toxicologia	5.05.01.08-9 Toxicologia Animal	\N
3215	095	a	animal	5.05.01.08-9 Toxicologia Animal	\N
3216	095	a	5.05.02.00-0	5.05.02.00-0 Medicina Veterinária Preventiva	\N
3217	095	a	medicina	5.05.02.00-0 Medicina Veterinária Preventiva	\N
3218	095	a	veterinaria	5.05.02.00-0 Medicina Veterinária Preventiva	\N
3219	095	a	preventiva	5.05.02.00-0 Medicina Veterinária Preventiva	\N
3220	095	a	5.05.02.01-8	5.05.02.01-8 Epidemiologia Animal	\N
3221	095	a	epidemiologia	5.05.02.01-8 Epidemiologia Animal	\N
3222	095	a	animal	5.05.02.01-8 Epidemiologia Animal	\N
3223	095	a	5.05.02.02-6	5.05.02.02-6 Saneamento Aplicado à Saúde do Homem	\N
3224	095	a	saneamento	5.05.02.02-6 Saneamento Aplicado à Saúde do Homem	\N
3225	095	a	aplicado	5.05.02.02-6 Saneamento Aplicado à Saúde do Homem	\N
3226	095	a	saude	5.05.02.02-6 Saneamento Aplicado à Saúde do Homem	\N
3227	095	a	do	5.05.02.02-6 Saneamento Aplicado à Saúde do Homem	\N
3228	095	a	homem	5.05.02.02-6 Saneamento Aplicado à Saúde do Homem	\N
3229	095	a	5.05.02.03-4	5.05.02.03-4 Doenças Infecciosas de Animais	\N
3230	095	a	doencas	5.05.02.03-4 Doenças Infecciosas de Animais	\N
3231	095	a	infecciosas	5.05.02.03-4 Doenças Infecciosas de Animais	\N
3232	095	a	de	5.05.02.03-4 Doenças Infecciosas de Animais	\N
3233	095	a	animais	5.05.02.03-4 Doenças Infecciosas de Animais	\N
3234	095	a	5.05.02.04-2	5.05.02.04-2 Doenças Parasitárias de Animais	\N
3235	095	a	doencas	5.05.02.04-2 Doenças Parasitárias de Animais	\N
3236	095	a	parasitarias	5.05.02.04-2 Doenças Parasitárias de Animais	\N
3237	095	a	de	5.05.02.04-2 Doenças Parasitárias de Animais	\N
3238	095	a	animais	5.05.02.04-2 Doenças Parasitárias de Animais	\N
3239	095	a	5.05.02.05-0	5.05.02.05-0 Saúde Animal (Programas Sanitários)	\N
3240	095	a	saude	5.05.02.05-0 Saúde Animal (Programas Sanitários)	\N
3241	095	a	animal	5.05.02.05-0 Saúde Animal (Programas Sanitários)	\N
3242	095	a	(programas	5.05.02.05-0 Saúde Animal (Programas Sanitários)	\N
3243	095	a	sanitarios)	5.05.02.05-0 Saúde Animal (Programas Sanitários)	\N
3244	095	a	5.05.03.00-6	5.05.03.00-6 Patologia Animal	\N
3245	095	a	patologia	5.05.03.00-6 Patologia Animal	\N
3246	095	a	animal	5.05.03.00-6 Patologia Animal	\N
3247	095	a	5.05.03.01-4	5.05.03.01-4 Patologia Aviária	\N
3248	095	a	patologia	5.05.03.01-4 Patologia Aviária	\N
3249	095	a	aviaria	5.05.03.01-4 Patologia Aviária	\N
3250	095	a	5.05.03.02-2	5.05.03.02-2 Anatomia Patologia Animal	\N
3251	095	a	anatomia	5.05.03.02-2 Anatomia Patologia Animal	\N
3252	095	a	patologia	5.05.03.02-2 Anatomia Patologia Animal	\N
3253	095	a	animal	5.05.03.02-2 Anatomia Patologia Animal	\N
3254	095	a	5.05.03.03-0	5.05.03.03-0 Patologia Clínica Animal	\N
3255	095	a	patologia	5.05.03.03-0 Patologia Clínica Animal	\N
3256	095	a	clinica	5.05.03.03-0 Patologia Clínica Animal	\N
3257	095	a	animal	5.05.03.03-0 Patologia Clínica Animal	\N
3258	095	a	5.05.04.00-2	5.05.04.00-2 Reprodução Animal	\N
3259	095	a	reproducao	5.05.04.00-2 Reprodução Animal	\N
3260	095	a	animal	5.05.04.00-2 Reprodução Animal	\N
3261	095	a	5.05.04.01-0	5.05.04.01-0 Ginecologia e Andrologia Animal	\N
3262	095	a	ginecologia	5.05.04.01-0 Ginecologia e Andrologia Animal	\N
3263	095	a	andrologia	5.05.04.01-0 Ginecologia e Andrologia Animal	\N
3264	095	a	animal	5.05.04.01-0 Ginecologia e Andrologia Animal	\N
3265	095	a	5.05.04.02-9	5.05.04.02-9 Inseminação Artificial Animal	\N
3266	095	a	inseminacao	5.05.04.02-9 Inseminação Artificial Animal	\N
3267	095	a	artificial	5.05.04.02-9 Inseminação Artificial Animal	\N
3268	095	a	animal	5.05.04.02-9 Inseminação Artificial Animal	\N
3269	095	a	5.05.04.03-7	5.05.04.03-7 Fisiopatologia da Reprodução Animal	\N
3270	095	a	fisiopatologia	5.05.04.03-7 Fisiopatologia da Reprodução Animal	\N
3271	095	a	da	5.05.04.03-7 Fisiopatologia da Reprodução Animal	\N
3272	095	a	reproducao	5.05.04.03-7 Fisiopatologia da Reprodução Animal	\N
3273	095	a	animal	5.05.04.03-7 Fisiopatologia da Reprodução Animal	\N
3274	095	a	5.05.05.00-9	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3275	095	a	inspecao	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3276	095	a	de	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3277	095	a	produtos	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3278	095	a	de	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3279	095	a	origem	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3280	095	a	animal	5.05.05.00-9 Inspeção de Produtos de Origem Animal	\N
3281	095	a	5.06.00.00-1	5.06.00.00-1 Recursos Pesqueiros e Engenharia de Pesca	\N
3282	095	a	recursos	5.06.00.00-1 Recursos Pesqueiros e Engenharia de Pesca	\N
3283	095	a	pesqueiros	5.06.00.00-1 Recursos Pesqueiros e Engenharia de Pesca	\N
3284	095	a	engenharia	5.06.00.00-1 Recursos Pesqueiros e Engenharia de Pesca	\N
3285	095	a	de	5.06.00.00-1 Recursos Pesqueiros e Engenharia de Pesca	\N
3286	095	a	pesca	5.06.00.00-1 Recursos Pesqueiros e Engenharia de Pesca	\N
3287	095	a	5.06.01.00-8	5.06.01.00-8 Recursos Pesqueiros Marinhos	\N
3288	095	a	recursos	5.06.01.00-8 Recursos Pesqueiros Marinhos	\N
3289	095	a	pesqueiros	5.06.01.00-8 Recursos Pesqueiros Marinhos	\N
3290	095	a	marinhos	5.06.01.00-8 Recursos Pesqueiros Marinhos	\N
3291	095	a	5.06.01.01-6	5.06.01.01-6 Fatores Abióticos do Mar	\N
3292	095	a	fatores	5.06.01.01-6 Fatores Abióticos do Mar	\N
3293	095	a	abioticos	5.06.01.01-6 Fatores Abióticos do Mar	\N
3294	095	a	do	5.06.01.01-6 Fatores Abióticos do Mar	\N
3295	095	a	mar	5.06.01.01-6 Fatores Abióticos do Mar	\N
3296	095	a	5.06.01.02-4	5.06.01.02-4 Avaliação de Estoques Pesqueiros Marinhos	\N
3297	095	a	avaliacao	5.06.01.02-4 Avaliação de Estoques Pesqueiros Marinhos	\N
3298	095	a	de	5.06.01.02-4 Avaliação de Estoques Pesqueiros Marinhos	\N
3299	095	a	estoques	5.06.01.02-4 Avaliação de Estoques Pesqueiros Marinhos	\N
3300	095	a	pesqueiros	5.06.01.02-4 Avaliação de Estoques Pesqueiros Marinhos	\N
3301	095	a	marinhos	5.06.01.02-4 Avaliação de Estoques Pesqueiros Marinhos	\N
3302	095	a	5.06.01.03-2	5.06.01.03-2 Exploração Pesqueira Marinha	\N
3303	095	a	exploracao	5.06.01.03-2 Exploração Pesqueira Marinha	\N
3304	095	a	pesqueira	5.06.01.03-2 Exploração Pesqueira Marinha	\N
3305	095	a	marinha	5.06.01.03-2 Exploração Pesqueira Marinha	\N
3306	095	a	5.06.01.04-0	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3552	095	a	especiais	6.01.04.00-7 Direitos Especiais	\N
3307	095	a	manejo	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3308	095	a	conservacao	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3309	095	a	de	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3310	095	a	recursos	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3311	095	a	pesqueiros	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3312	095	a	marinhos	5.06.01.04-0 Manejo e Conservação de Recursos Pesqueiros Marinhos	\N
3313	095	a	5.06.02.00-4	5.06.02.00-4 Recursos Pesqueiros de Águas Interiores	\N
3314	095	a	recursos	5.06.02.00-4 Recursos Pesqueiros de Águas Interiores	\N
3315	095	a	pesqueiros	5.06.02.00-4 Recursos Pesqueiros de Águas Interiores	\N
3316	095	a	de	5.06.02.00-4 Recursos Pesqueiros de Águas Interiores	\N
3317	095	a	aguas	5.06.02.00-4 Recursos Pesqueiros de Águas Interiores	\N
3318	095	a	interiores	5.06.02.00-4 Recursos Pesqueiros de Águas Interiores	\N
3319	095	a	5.06.02.01-2	5.06.02.01-2 Fatores Abióticos de Águas Interiores	\N
3320	095	a	fatores	5.06.02.01-2 Fatores Abióticos de Águas Interiores	\N
3321	095	a	abioticos	5.06.02.01-2 Fatores Abióticos de Águas Interiores	\N
3322	095	a	de	5.06.02.01-2 Fatores Abióticos de Águas Interiores	\N
3323	095	a	aguas	5.06.02.01-2 Fatores Abióticos de Águas Interiores	\N
3324	095	a	interiores	5.06.02.01-2 Fatores Abióticos de Águas Interiores	\N
3325	095	a	5.06.02.02-0	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3326	095	a	avaliacao	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3327	095	a	de	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3328	095	a	estoques	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3329	095	a	pesqueiros	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3330	095	a	de	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3331	095	a	aguas	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3332	095	a	interiores	5.06.02.02-0 Avaliação de Estoques Pesqueiros de Águas Interiores	\N
3333	095	a	5.06.02.03-9	5.06.02.03-9 Explotação Pesqueira de Águas Interiores	\N
3334	095	a	explotacao	5.06.02.03-9 Explotação Pesqueira de Águas Interiores	\N
3335	095	a	pesqueira	5.06.02.03-9 Explotação Pesqueira de Águas Interiores	\N
3336	095	a	de	5.06.02.03-9 Explotação Pesqueira de Águas Interiores	\N
3337	095	a	aguas	5.06.02.03-9 Explotação Pesqueira de Águas Interiores	\N
3338	095	a	interiores	5.06.02.03-9 Explotação Pesqueira de Águas Interiores	\N
3339	095	a	5.06.02.04-7	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3340	095	a	manejo	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3341	095	a	conservacao	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3342	095	a	de	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3343	095	a	recursos	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3344	095	a	pesqueiros	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3345	095	a	de	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3346	095	a	aguas	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3347	095	a	interiores	5.06.02.04-7 Manejo e Conservação de Recursos Pesqueiros de Águas Interiores	\N
3348	095	a	5.06.03.00-0	5.06.03.00-0 Aqüicultura	\N
3349	095	a	aquicultura	5.06.03.00-0 Aqüicultura	\N
3350	095	a	5.06.03.01-9	5.06.03.01-9 Maricultura	\N
3351	095	a	maricultura	5.06.03.01-9 Maricultura	\N
3352	095	a	5.06.03.02-7	5.06.03.02-7 Carcinocultura	\N
3353	095	a	carcinocultura	5.06.03.02-7 Carcinocultura	\N
3354	095	a	5.06.03.03-5	5.06.03.03-5 Ostreicultura	\N
3355	095	a	ostreicultura	5.06.03.03-5 Ostreicultura	\N
3356	095	a	5.06.03.04-3	5.06.03.04-3 Piscicultura	\N
3357	095	a	piscicultura	5.06.03.04-3 Piscicultura	\N
3358	095	a	5.06.04.00-7	5.06.04.00-7 Engenharia de Pesca	\N
3359	095	a	engenharia	5.06.04.00-7 Engenharia de Pesca	\N
3360	095	a	de	5.06.04.00-7 Engenharia de Pesca	\N
3361	095	a	pesca	5.06.04.00-7 Engenharia de Pesca	\N
3362	095	a	5.07.00.00-6	5.07.00.00-6 Ciência e Tecnologia de Alimentos	\N
3363	095	a	ciencia	5.07.00.00-6 Ciência e Tecnologia de Alimentos	\N
3364	095	a	tecnologia	5.07.00.00-6 Ciência e Tecnologia de Alimentos	\N
3365	095	a	de	5.07.00.00-6 Ciência e Tecnologia de Alimentos	\N
3366	095	a	alimentos	5.07.00.00-6 Ciência e Tecnologia de Alimentos	\N
3367	095	a	5.07.01.00-2	5.07.01.00-2 Ciência de Alimentos	\N
3368	095	a	ciencia	5.07.01.00-2 Ciência de Alimentos	\N
3369	095	a	de	5.07.01.00-2 Ciência de Alimentos	\N
3370	095	a	alimentos	5.07.01.00-2 Ciência de Alimentos	\N
3371	095	a	5.07.01.01-0	5.07.01.01-0 Valor Nutritivo de Alimentos	\N
3372	095	a	valor	5.07.01.01-0 Valor Nutritivo de Alimentos	\N
3373	095	a	nutritivo	5.07.01.01-0 Valor Nutritivo de Alimentos	\N
3374	095	a	de	5.07.01.01-0 Valor Nutritivo de Alimentos	\N
3375	095	a	alimentos	5.07.01.01-0 Valor Nutritivo de Alimentos	\N
3376	095	a	5.07.01.02-9	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3377	095	a	quimica,	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3378	095	a	fisica,	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3379	095	a	fisico-quimica	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3380	095	a	bioquimica	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3381	095	a	dos	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
4969	095	a	musica	8.03.03.00-5 Música	\N
3382	095	a	alim.	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3383	095	a	das	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3384	095	a	mat.-primas	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3385	095	a	alimentares	5.07.01.02-9 Química, Física, Físico-Química e Bioquímica dos Alim. e das Mat.-Primas Alimentares	\N
3386	095	a	5.07.01.03-7	5.07.01.03-7 Microbiologia de Alimentos	\N
3387	095	a	microbiologia	5.07.01.03-7 Microbiologia de Alimentos	\N
3388	095	a	de	5.07.01.03-7 Microbiologia de Alimentos	\N
3389	095	a	alimentos	5.07.01.03-7 Microbiologia de Alimentos	\N
3390	095	a	5.07.01.04-5	5.07.01.04-5 Fisiologia Pós-Colheita	\N
3391	095	a	fisiologia	5.07.01.04-5 Fisiologia Pós-Colheita	\N
3392	095	a	pos-colheita	5.07.01.04-5 Fisiologia Pós-Colheita	\N
3393	095	a	5.07.01.05-3	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3394	095	a	toxicidade	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3395	095	a	residuos	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3396	095	a	de	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3397	095	a	pesticidas	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3398	095	a	em	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3399	095	a	alimentos	5.07.01.05-3 Toxicidade e Resíduos de Pesticidas em Alimentos	\N
3400	095	a	5.07.01.06-1	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3401	095	a	avaliacao	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3402	095	a	controle	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3403	095	a	de	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3404	095	a	qualidade	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3405	095	a	de	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3406	095	a	alimentos	5.07.01.06-1 Avaliação e Controle de Qualidade de Alimentos	\N
3407	095	a	5.07.01.07-0	5.07.01.07-0 Padrões, Legislação e Fiscalização de Alimentos	\N
3408	095	a	padroes,	5.07.01.07-0 Padrões, Legislação e Fiscalização de Alimentos	\N
3409	095	a	legislacao	5.07.01.07-0 Padrões, Legislação e Fiscalização de Alimentos	\N
3410	095	a	fiscalizacao	5.07.01.07-0 Padrões, Legislação e Fiscalização de Alimentos	\N
3411	095	a	de	5.07.01.07-0 Padrões, Legislação e Fiscalização de Alimentos	\N
3412	095	a	alimentos	5.07.01.07-0 Padrões, Legislação e Fiscalização de Alimentos	\N
3413	095	a	5.07.02.00-9	5.07.02.00-9 Tecnologia de Alimentos	\N
3414	095	a	tecnologia	5.07.02.00-9 Tecnologia de Alimentos	\N
3415	095	a	de	5.07.02.00-9 Tecnologia de Alimentos	\N
3416	095	a	alimentos	5.07.02.00-9 Tecnologia de Alimentos	\N
3417	095	a	5.07.02.01-7	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3418	095	a	tecnologia	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3419	095	a	de	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3420	095	a	produtos	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3421	095	a	de	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3422	095	a	origem	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3423	095	a	animal	5.07.02.01-7 Tecnologia de Produtos de Origem Animal	\N
3424	095	a	5.07.02.02-5	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3425	095	a	tecnologia	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3426	095	a	de	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3427	095	a	produtos	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3428	095	a	de	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3429	095	a	origem	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3430	095	a	vegetal	5.07.02.02-5 Tecnologia de Produtos de Origem Vegetal	\N
3431	095	a	5.07.02.03-3	5.07.02.03-3 Tecnologia das Bebidas	\N
3432	095	a	tecnologia	5.07.02.03-3 Tecnologia das Bebidas	\N
3433	095	a	das	5.07.02.03-3 Tecnologia das Bebidas	\N
3434	095	a	bebidas	5.07.02.03-3 Tecnologia das Bebidas	\N
3435	095	a	5.07.02.04-1	5.07.02.04-1 Tecnologia de Alimentos Dietéticos e Nutricionais	\N
3436	095	a	tecnologia	5.07.02.04-1 Tecnologia de Alimentos Dietéticos e Nutricionais	\N
3437	095	a	de	5.07.02.04-1 Tecnologia de Alimentos Dietéticos e Nutricionais	\N
3438	095	a	alimentos	5.07.02.04-1 Tecnologia de Alimentos Dietéticos e Nutricionais	\N
3439	095	a	dieteticos	5.07.02.04-1 Tecnologia de Alimentos Dietéticos e Nutricionais	\N
3440	095	a	nutricionais	5.07.02.04-1 Tecnologia de Alimentos Dietéticos e Nutricionais	\N
3441	095	a	5.07.02.05-0	5.07.02.05-0 Aproveitamento de Subprodutos	\N
3442	095	a	aproveitamento	5.07.02.05-0 Aproveitamento de Subprodutos	\N
3443	095	a	de	5.07.02.05-0 Aproveitamento de Subprodutos	\N
3444	095	a	subprodutos	5.07.02.05-0 Aproveitamento de Subprodutos	\N
3445	095	a	5.07.02.06-8	5.07.02.06-8 Embalagens de Produtos Alimentares	\N
3446	095	a	embalagens	5.07.02.06-8 Embalagens de Produtos Alimentares	\N
3447	095	a	de	5.07.02.06-8 Embalagens de Produtos Alimentares	\N
3448	095	a	produtos	5.07.02.06-8 Embalagens de Produtos Alimentares	\N
3449	095	a	alimentares	5.07.02.06-8 Embalagens de Produtos Alimentares	\N
3450	095	a	5.07.03.00-5	5.07.03.00-5 Engenharia de Alimentos	\N
3451	095	a	engenharia	5.07.03.00-5 Engenharia de Alimentos	\N
3452	095	a	de	5.07.03.00-5 Engenharia de Alimentos	\N
3453	095	a	alimentos	5.07.03.00-5 Engenharia de Alimentos	\N
3454	095	a	5.07.03.01-3	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3455	095	a	instalacoes	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3456	095	a	industriais	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3457	095	a	de	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3458	095	a	producao	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3459	095	a	de	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3460	095	a	alimentos	5.07.03.01-3 Instalações Industriais de Produção de Alimentos	\N
3461	095	a	5.07.03.02-1	5.07.03.02-1 Armazenamento de Alimentos	\N
3462	095	a	armazenamento	5.07.03.02-1 Armazenamento de Alimentos	\N
3463	095	a	de	5.07.03.02-1 Armazenamento de Alimentos	\N
3464	095	a	alimentos	5.07.03.02-1 Armazenamento de Alimentos	\N
3465	095	a	6.00.00.00-7	6.00.00.00-7 Ciências Sociais Aplicadas	\N
3466	095	a	ciencias	6.00.00.00-7 Ciências Sociais Aplicadas	\N
3467	095	a	sociais	6.00.00.00-7 Ciências Sociais Aplicadas	\N
3468	095	a	aplicadas	6.00.00.00-7 Ciências Sociais Aplicadas	\N
3469	095	a	6.01.00.00-1	6.01.00.00-1 Direito	\N
3470	095	a	direito	6.01.00.00-1 Direito	\N
3471	095	a	6.01.01.00-8	6.01.01.00-8 Teoria do Direito	\N
3472	095	a	teoria	6.01.01.00-8 Teoria do Direito	\N
3473	095	a	do	6.01.01.00-8 Teoria do Direito	\N
3474	095	a	direito	6.01.01.00-8 Teoria do Direito	\N
3475	095	a	6.01.01.01-6	6.01.01.01-6 Teoria Geral do Direito	\N
3476	095	a	teoria	6.01.01.01-6 Teoria Geral do Direito	\N
3477	095	a	geral	6.01.01.01-6 Teoria Geral do Direito	\N
3478	095	a	do	6.01.01.01-6 Teoria Geral do Direito	\N
3479	095	a	direito	6.01.01.01-6 Teoria Geral do Direito	\N
3480	095	a	6.01.01.02-4	6.01.01.02-4 Teoria Geral do Processo	\N
3481	095	a	teoria	6.01.01.02-4 Teoria Geral do Processo	\N
3482	095	a	geral	6.01.01.02-4 Teoria Geral do Processo	\N
3483	095	a	do	6.01.01.02-4 Teoria Geral do Processo	\N
3484	095	a	processo	6.01.01.02-4 Teoria Geral do Processo	\N
3485	095	a	6.01.01.03-2	6.01.01.03-2 Teoria do Estado	\N
3486	095	a	teoria	6.01.01.03-2 Teoria do Estado	\N
3487	095	a	do	6.01.01.03-2 Teoria do Estado	\N
3488	095	a	estado	6.01.01.03-2 Teoria do Estado	\N
3489	095	a	6.01.01.04-0	6.01.01.04-0 História do Direito	\N
3490	095	a	historia	6.01.01.04-0 História do Direito	\N
3491	095	a	do	6.01.01.04-0 História do Direito	\N
3492	095	a	direito	6.01.01.04-0 História do Direito	\N
3493	095	a	6.01.01.05-9	6.01.01.05-9 Filosofia do Direito	\N
3494	095	a	filosofia	6.01.01.05-9 Filosofia do Direito	\N
3495	095	a	do	6.01.01.05-9 Filosofia do Direito	\N
3496	095	a	direito	6.01.01.05-9 Filosofia do Direito	\N
3497	095	a	6.01.01.06-7	6.01.01.06-7 Lógica Jurídica	\N
3498	095	a	logica	6.01.01.06-7 Lógica Jurídica	\N
3499	095	a	juridica	6.01.01.06-7 Lógica Jurídica	\N
3500	095	a	6.01.01.07-5	6.01.01.07-5 Sociologia Jurídica	\N
3501	095	a	sociologia	6.01.01.07-5 Sociologia Jurídica	\N
3502	095	a	juridica	6.01.01.07-5 Sociologia Jurídica	\N
3503	095	a	6.01.01.08-3	6.01.01.08-3 Antropologia Jurídica	\N
3504	095	a	antropologia	6.01.01.08-3 Antropologia Jurídica	\N
3505	095	a	juridica	6.01.01.08-3 Antropologia Jurídica	\N
3506	095	a	6.01.02.00-4	6.01.02.00-4 Direito Público	\N
3507	095	a	direito	6.01.02.00-4 Direito Público	\N
3508	095	a	publico	6.01.02.00-4 Direito Público	\N
3509	095	a	6.01.02.01-2	6.01.02.01-2 Direito Tributário	\N
3510	095	a	direito	6.01.02.01-2 Direito Tributário	\N
3511	095	a	tributario	6.01.02.01-2 Direito Tributário	\N
3512	095	a	6.01.02.02-0	6.01.02.02-0 Direito Penal	\N
3513	095	a	direito	6.01.02.02-0 Direito Penal	\N
3514	095	a	penal	6.01.02.02-0 Direito Penal	\N
3515	095	a	6.01.02.03-9	6.01.02.03-9 Direito Processual Penal	\N
3516	095	a	direito	6.01.02.03-9 Direito Processual Penal	\N
3517	095	a	processual	6.01.02.03-9 Direito Processual Penal	\N
3518	095	a	penal	6.01.02.03-9 Direito Processual Penal	\N
3519	095	a	6.01.02.04-7	6.01.02.04-7 Direito Processual Civil	\N
3520	095	a	direito	6.01.02.04-7 Direito Processual Civil	\N
3521	095	a	processual	6.01.02.04-7 Direito Processual Civil	\N
3522	095	a	civil	6.01.02.04-7 Direito Processual Civil	\N
3523	095	a	6.01.02.05-5	6.01.02.05-5 Direito Constitucional	\N
3524	095	a	direito	6.01.02.05-5 Direito Constitucional	\N
3525	095	a	constitucional	6.01.02.05-5 Direito Constitucional	\N
3526	095	a	6.01.02.06-3	6.01.02.06-3 Direito Administrativo	\N
3527	095	a	direito	6.01.02.06-3 Direito Administrativo	\N
3528	095	a	administrativo	6.01.02.06-3 Direito Administrativo	\N
3529	095	a	6.01.02.07-1	6.01.02.07-1 Direito Internacional Público	\N
3530	095	a	direito	6.01.02.07-1 Direito Internacional Público	\N
3531	095	a	internacional	6.01.02.07-1 Direito Internacional Público	\N
3532	095	a	publico	6.01.02.07-1 Direito Internacional Público	\N
3533	095	a	6.01.03.00-0	6.01.03.00-0 Direito Privado	\N
3534	095	a	direito	6.01.03.00-0 Direito Privado	\N
3535	095	a	privado	6.01.03.00-0 Direito Privado	\N
3536	095	a	6.01.03.01-9	6.01.03.01-9 Direito Civil	\N
3537	095	a	direito	6.01.03.01-9 Direito Civil	\N
3538	095	a	civil	6.01.03.01-9 Direito Civil	\N
3539	095	a	6.01.03.02-7	6.01.03.02-7 Direito Comercial	\N
3540	095	a	direito	6.01.03.02-7 Direito Comercial	\N
3541	095	a	comercial	6.01.03.02-7 Direito Comercial	\N
3542	095	a	6.01.03.03-5	6.01.03.03-5 Direito do Trabalho	\N
3543	095	a	direito	6.01.03.03-5 Direito do Trabalho	\N
3544	095	a	do	6.01.03.03-5 Direito do Trabalho	\N
3545	095	a	trabalho	6.01.03.03-5 Direito do Trabalho	\N
3546	095	a	6.01.03.04-3	6.01.03.04-3 Direito Internacional Privado	\N
3547	095	a	direito	6.01.03.04-3 Direito Internacional Privado	\N
3548	095	a	internacional	6.01.03.04-3 Direito Internacional Privado	\N
3549	095	a	privado	6.01.03.04-3 Direito Internacional Privado	\N
3550	095	a	6.01.04.00-7	6.01.04.00-7 Direitos Especiais	\N
3551	095	a	direitos	6.01.04.00-7 Direitos Especiais	\N
3553	095	a	6.02.00.00-6	6.02.00.00-6 Administração	\N
3554	095	a	administracao	6.02.00.00-6 Administração	\N
3555	095	a	6.02.01.00-2	6.02.01.00-2 Administração de Empresas	\N
3556	095	a	administracao	6.02.01.00-2 Administração de Empresas	\N
3557	095	a	de	6.02.01.00-2 Administração de Empresas	\N
3558	095	a	empresas	6.02.01.00-2 Administração de Empresas	\N
3559	095	a	6.02.01.01-0	6.02.01.01-0 Administração da Produção	\N
3560	095	a	administracao	6.02.01.01-0 Administração da Produção	\N
3561	095	a	da	6.02.01.01-0 Administração da Produção	\N
3562	095	a	producao	6.02.01.01-0 Administração da Produção	\N
3563	095	a	6.02.01.02-9	6.02.01.02-9 Administração Financeira	\N
3564	095	a	administracao	6.02.01.02-9 Administração Financeira	\N
3565	095	a	financeira	6.02.01.02-9 Administração Financeira	\N
3566	095	a	6.02.01.03-7	6.02.01.03-7 Mercadologia	\N
3567	095	a	mercadologia	6.02.01.03-7 Mercadologia	\N
3568	095	a	6.02.01.04-5	6.02.01.04-5 Negócios Internacionais	\N
3569	095	a	negocios	6.02.01.04-5 Negócios Internacionais	\N
3570	095	a	internacionais	6.02.01.04-5 Negócios Internacionais	\N
3571	095	a	6.02.01.05-3	6.02.01.05-3 Administração de Recursos Humanos	\N
3572	095	a	administracao	6.02.01.05-3 Administração de Recursos Humanos	\N
3573	095	a	de	6.02.01.05-3 Administração de Recursos Humanos	\N
3574	095	a	recursos	6.02.01.05-3 Administração de Recursos Humanos	\N
3575	095	a	humanos	6.02.01.05-3 Administração de Recursos Humanos	\N
3576	095	a	6.02.02.00-9	6.02.02.00-9 Administração Pública	\N
3577	095	a	administracao	6.02.02.00-9 Administração Pública	\N
3578	095	a	publica	6.02.02.00-9 Administração Pública	\N
3579	095	a	6.02.02.01-7	6.02.02.01-7 Contabilidade e Financas Públicas	\N
3580	095	a	contabilidade	6.02.02.01-7 Contabilidade e Financas Públicas	\N
3581	095	a	financas	6.02.02.01-7 Contabilidade e Financas Públicas	\N
3582	095	a	publicas	6.02.02.01-7 Contabilidade e Financas Públicas	\N
3583	095	a	6.02.02.02-5	6.02.02.02-5 Organizações Públicas	\N
3584	095	a	organizacoes	6.02.02.02-5 Organizações Públicas	\N
3585	095	a	publicas	6.02.02.02-5 Organizações Públicas	\N
3586	095	a	6.02.02.03-3	6.02.02.03-3 Política e Planejamento Governamentais	\N
3587	095	a	politica	6.02.02.03-3 Política e Planejamento Governamentais	\N
3588	095	a	planejamento	6.02.02.03-3 Política e Planejamento Governamentais	\N
3589	095	a	governamentais	6.02.02.03-3 Política e Planejamento Governamentais	\N
3590	095	a	6.02.02.04-1	6.02.02.04-1 Administração de Pessoal	\N
3591	095	a	administracao	6.02.02.04-1 Administração de Pessoal	\N
3592	095	a	de	6.02.02.04-1 Administração de Pessoal	\N
3593	095	a	pessoal	6.02.02.04-1 Administração de Pessoal	\N
3594	095	a	6.02.03.00-5	6.02.03.00-5 Administração de Setores Específicos	\N
3595	095	a	administracao	6.02.03.00-5 Administração de Setores Específicos	\N
3596	095	a	de	6.02.03.00-5 Administração de Setores Específicos	\N
3597	095	a	setores	6.02.03.00-5 Administração de Setores Específicos	\N
3598	095	a	especificos	6.02.03.00-5 Administração de Setores Específicos	\N
3599	095	a	6.02.04.00-1	6.02.04.00-1 Ciências Contábeis	\N
3600	095	a	ciencias	6.02.04.00-1 Ciências Contábeis	\N
3601	095	a	contabeis	6.02.04.00-1 Ciências Contábeis	\N
3602	095	a	6.03.00.00-0	6.03.00.00-0 Economia	\N
3603	095	a	economia	6.03.00.00-0 Economia	\N
3604	095	a	6.03.01.00-7	6.03.01.00-7 Teoria Econômica	\N
3605	095	a	teoria	6.03.01.00-7 Teoria Econômica	\N
3606	095	a	economica	6.03.01.00-7 Teoria Econômica	\N
3607	095	a	6.03.01.01-5	6.03.01.01-5 Economia Geral	\N
3608	095	a	economia	6.03.01.01-5 Economia Geral	\N
3609	095	a	geral	6.03.01.01-5 Economia Geral	\N
3610	095	a	6.03.01.02-3	6.03.01.02-3 Teoria Geral da Economia	\N
3611	095	a	teoria	6.03.01.02-3 Teoria Geral da Economia	\N
3612	095	a	geral	6.03.01.02-3 Teoria Geral da Economia	\N
3613	095	a	da	6.03.01.02-3 Teoria Geral da Economia	\N
3614	095	a	economia	6.03.01.02-3 Teoria Geral da Economia	\N
3615	095	a	6.03.01.03-1	6.03.01.03-1 História do Pensamento Econômico	\N
3616	095	a	historia	6.03.01.03-1 História do Pensamento Econômico	\N
3617	095	a	do	6.03.01.03-1 História do Pensamento Econômico	\N
3618	095	a	pensamento	6.03.01.03-1 História do Pensamento Econômico	\N
3619	095	a	economico	6.03.01.03-1 História do Pensamento Econômico	\N
3620	095	a	6.03.01.04-0	6.03.01.04-0 História Econômica	\N
3621	095	a	historia	6.03.01.04-0 História Econômica	\N
3622	095	a	economica	6.03.01.04-0 História Econômica	\N
3623	095	a	6.03.01.05-8	6.03.01.05-8 Sistemas Econômicos	\N
3624	095	a	sistemas	6.03.01.05-8 Sistemas Econômicos	\N
3625	095	a	economicos	6.03.01.05-8 Sistemas Econômicos	\N
3626	095	a	6.03.02.00-3	6.03.02.00-3 Métodos Quantitativos em Economia	\N
3627	095	a	metodos	6.03.02.00-3 Métodos Quantitativos em Economia	\N
3628	095	a	quantitativos	6.03.02.00-3 Métodos Quantitativos em Economia	\N
3629	095	a	em	6.03.02.00-3 Métodos Quantitativos em Economia	\N
3630	095	a	economia	6.03.02.00-3 Métodos Quantitativos em Economia	\N
3631	095	a	6.03.02.01-1	6.03.02.01-1 Métodos e Modelos Matemáticos, Econométricos e Estatísticos	\N
3632	095	a	metodos	6.03.02.01-1 Métodos e Modelos Matemáticos, Econométricos e Estatísticos	\N
3633	095	a	modelos	6.03.02.01-1 Métodos e Modelos Matemáticos, Econométricos e Estatísticos	\N
3634	095	a	matematicos,	6.03.02.01-1 Métodos e Modelos Matemáticos, Econométricos e Estatísticos	\N
3635	095	a	econometricos	6.03.02.01-1 Métodos e Modelos Matemáticos, Econométricos e Estatísticos	\N
3636	095	a	estatisticos	6.03.02.01-1 Métodos e Modelos Matemáticos, Econométricos e Estatísticos	\N
3637	095	a	6.03.02.02-0	6.03.02.02-0 Estatística Sócio-Econômica	\N
3638	095	a	estatistica	6.03.02.02-0 Estatística Sócio-Econômica	\N
3639	095	a	socio-economica	6.03.02.02-0 Estatística Sócio-Econômica	\N
3640	095	a	6.03.02.03-8	6.03.02.03-8 Contabilidade Nacional	\N
3641	095	a	contabilidade	6.03.02.03-8 Contabilidade Nacional	\N
3642	095	a	nacional	6.03.02.03-8 Contabilidade Nacional	\N
3643	095	a	6.03.02.04-6	6.03.02.04-6 Economia Matemática	\N
3644	095	a	economia	6.03.02.04-6 Economia Matemática	\N
3645	095	a	matematica	6.03.02.04-6 Economia Matemática	\N
3646	095	a	6.03.03.00-0	6.03.03.00-0 Economia Monetária e Fiscal	\N
3647	095	a	economia	6.03.03.00-0 Economia Monetária e Fiscal	\N
3648	095	a	monetaria	6.03.03.00-0 Economia Monetária e Fiscal	\N
3649	095	a	fiscal	6.03.03.00-0 Economia Monetária e Fiscal	\N
3650	095	a	6.03.03.01-8	6.03.03.01-8 Teoria Monetária e Financeira	\N
3651	095	a	teoria	6.03.03.01-8 Teoria Monetária e Financeira	\N
3652	095	a	monetaria	6.03.03.01-8 Teoria Monetária e Financeira	\N
3653	095	a	financeira	6.03.03.01-8 Teoria Monetária e Financeira	\N
3654	095	a	6.03.03.02-6	6.03.03.02-6 Instituições Monetárias e Financeiras do Brasil	\N
3655	095	a	instituicoes	6.03.03.02-6 Instituições Monetárias e Financeiras do Brasil	\N
3656	095	a	monetarias	6.03.03.02-6 Instituições Monetárias e Financeiras do Brasil	\N
3657	095	a	financeiras	6.03.03.02-6 Instituições Monetárias e Financeiras do Brasil	\N
3658	095	a	do	6.03.03.02-6 Instituições Monetárias e Financeiras do Brasil	\N
3659	095	a	brasil	6.03.03.02-6 Instituições Monetárias e Financeiras do Brasil	\N
3660	095	a	6.03.03.03-4	6.03.03.03-4 Financas Públicas Internas	\N
3661	095	a	financas	6.03.03.03-4 Financas Públicas Internas	\N
3662	095	a	publicas	6.03.03.03-4 Financas Públicas Internas	\N
3663	095	a	internas	6.03.03.03-4 Financas Públicas Internas	\N
3664	095	a	6.03.03.04-2	6.03.03.04-2 Política Fiscal do Brasil	\N
3665	095	a	politica	6.03.03.04-2 Política Fiscal do Brasil	\N
3666	095	a	fiscal	6.03.03.04-2 Política Fiscal do Brasil	\N
3667	095	a	do	6.03.03.04-2 Política Fiscal do Brasil	\N
3668	095	a	brasil	6.03.03.04-2 Política Fiscal do Brasil	\N
3669	095	a	6.03.04.00-6	6.03.04.00-6 Crescimento, Flutuações e Planejamento Econômico	\N
3670	095	a	crescimento,	6.03.04.00-6 Crescimento, Flutuações e Planejamento Econômico	\N
3671	095	a	flutuacoes	6.03.04.00-6 Crescimento, Flutuações e Planejamento Econômico	\N
3672	095	a	planejamento	6.03.04.00-6 Crescimento, Flutuações e Planejamento Econômico	\N
3673	095	a	economico	6.03.04.00-6 Crescimento, Flutuações e Planejamento Econômico	\N
3674	095	a	6.03.04.01-4	6.03.04.01-4 Crescimento e Desenvolvimento Econômico	\N
3675	095	a	crescimento	6.03.04.01-4 Crescimento e Desenvolvimento Econômico	\N
3676	095	a	desenvolvimento	6.03.04.01-4 Crescimento e Desenvolvimento Econômico	\N
3677	095	a	economico	6.03.04.01-4 Crescimento e Desenvolvimento Econômico	\N
3678	095	a	6.03.04.02-2	6.03.04.02-2 Teoria e Política de Planejamento Econômico	\N
3679	095	a	teoria	6.03.04.02-2 Teoria e Política de Planejamento Econômico	\N
3680	095	a	politica	6.03.04.02-2 Teoria e Política de Planejamento Econômico	\N
3681	095	a	de	6.03.04.02-2 Teoria e Política de Planejamento Econômico	\N
3682	095	a	planejamento	6.03.04.02-2 Teoria e Política de Planejamento Econômico	\N
3683	095	a	economico	6.03.04.02-2 Teoria e Política de Planejamento Econômico	\N
3684	095	a	6.03.04.03-0	6.03.04.03-0 Flutuações Cíclicas e Projeções Econômicas	\N
3685	095	a	flutuacoes	6.03.04.03-0 Flutuações Cíclicas e Projeções Econômicas	\N
3686	095	a	ciclicas	6.03.04.03-0 Flutuações Cíclicas e Projeções Econômicas	\N
3687	095	a	projecoes	6.03.04.03-0 Flutuações Cíclicas e Projeções Econômicas	\N
3688	095	a	economicas	6.03.04.03-0 Flutuações Cíclicas e Projeções Econômicas	\N
3689	095	a	6.03.04.04-9	6.03.04.04-9 Inflação	\N
3690	095	a	inflacao	6.03.04.04-9 Inflação	\N
3691	095	a	6.03.05.00-2	6.03.05.00-2 Economia Internacional	\N
3692	095	a	economia	6.03.05.00-2 Economia Internacional	\N
3693	095	a	internacional	6.03.05.00-2 Economia Internacional	\N
3694	095	a	6.03.05.01-0	6.03.05.01-0 Teoria do Comércio Internacional	\N
3695	095	a	teoria	6.03.05.01-0 Teoria do Comércio Internacional	\N
3696	095	a	do	6.03.05.01-0 Teoria do Comércio Internacional	\N
3697	095	a	comercio	6.03.05.01-0 Teoria do Comércio Internacional	\N
3698	095	a	internacional	6.03.05.01-0 Teoria do Comércio Internacional	\N
3699	095	a	6.03.05.02-9	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3700	095	a	relacoes	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3701	095	a	do	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3702	095	a	comercio;	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3703	095	a	politica	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3704	095	a	comercial;	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3705	095	a	integracao	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3706	095	a	economica	6.03.05.02-9 Relações do Comércio; Política Comercial; Integração Econômica	\N
3707	095	a	6.03.05.03-7	6.03.05.03-7 Balanço de Pagamentos; Financas Internacionais	\N
3708	095	a	balanco	6.03.05.03-7 Balanço de Pagamentos; Financas Internacionais	\N
3709	095	a	de	6.03.05.03-7 Balanço de Pagamentos; Financas Internacionais	\N
3710	095	a	pagamentos;	6.03.05.03-7 Balanço de Pagamentos; Financas Internacionais	\N
3711	095	a	financas	6.03.05.03-7 Balanço de Pagamentos; Financas Internacionais	\N
3712	095	a	internacionais	6.03.05.03-7 Balanço de Pagamentos; Financas Internacionais	\N
3713	095	a	6.03.05.04-5	6.03.05.04-5 Investimentos Internacionais e Ajuda Externa	\N
3714	095	a	investimentos	6.03.05.04-5 Investimentos Internacionais e Ajuda Externa	\N
3715	095	a	internacionais	6.03.05.04-5 Investimentos Internacionais e Ajuda Externa	\N
3716	095	a	ajuda	6.03.05.04-5 Investimentos Internacionais e Ajuda Externa	\N
3717	095	a	externa	6.03.05.04-5 Investimentos Internacionais e Ajuda Externa	\N
3718	095	a	6.03.06.00-9	6.03.06.00-9 Economia dos Recursos Humanos	\N
3719	095	a	economia	6.03.06.00-9 Economia dos Recursos Humanos	\N
3720	095	a	dos	6.03.06.00-9 Economia dos Recursos Humanos	\N
3721	095	a	recursos	6.03.06.00-9 Economia dos Recursos Humanos	\N
3722	095	a	humanos	6.03.06.00-9 Economia dos Recursos Humanos	\N
3723	095	a	6.03.06.01-7	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3724	095	a	treinamento	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3725	095	a	alocacao	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3726	095	a	de	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3727	095	a	mao-de-obra;	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3728	095	a	oferta	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3729	095	a	de	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3730	095	a	mao-de-obra	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3731	095	a	forca	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3732	095	a	de	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3733	095	a	trabalho	6.03.06.01-7 Treinamento e Alocação de Mão-de-Obra; Oferta de Mão-de-Obra e Força de Trabalho	\N
3734	095	a	6.03.06.02-5	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3735	095	a	mercado	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3736	095	a	de	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3737	095	a	trabalho;	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3738	095	a	politica	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3739	095	a	do	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3740	095	a	governo	6.03.06.02-5 Mercado de Trabalho; Política do Governo	\N
3741	095	a	6.03.06.03-3	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3742	095	a	sindicatos,	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3743	095	a	dissidios	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3744	095	a	coletivos,	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3745	095	a	relacoes	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3746	095	a	de	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3747	095	a	emprego	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3748	095	a	(empregador/empregado)	6.03.06.03-3 Sindicatos, Dissídios Coletivos, Relações de Emprego (Empregador/Empregado)	\N
3749	095	a	6.03.06.04-1	6.03.06.04-1 Capital Humano	\N
3750	095	a	capital	6.03.06.04-1 Capital Humano	\N
3751	095	a	humano	6.03.06.04-1 Capital Humano	\N
3752	095	a	6.03.06.05-0	6.03.06.05-0 Demografia Econômica	\N
3753	095	a	demografia	6.03.06.05-0 Demografia Econômica	\N
3754	095	a	economica	6.03.06.05-0 Demografia Econômica	\N
3755	095	a	6.03.07.00-5	6.03.07.00-5 Economia Industrial	\N
3756	095	a	economia	6.03.07.00-5 Economia Industrial	\N
3757	095	a	industrial	6.03.07.00-5 Economia Industrial	\N
3758	095	a	6.03.07.01-3	6.03.07.01-3 Organização Industrial e Estudos Industriais	\N
3759	095	a	organizacao	6.03.07.01-3 Organização Industrial e Estudos Industriais	\N
3760	095	a	industrial	6.03.07.01-3 Organização Industrial e Estudos Industriais	\N
3761	095	a	estudos	6.03.07.01-3 Organização Industrial e Estudos Industriais	\N
3762	095	a	industriais	6.03.07.01-3 Organização Industrial e Estudos Industriais	\N
3763	095	a	6.03.07.02-1	6.03.07.02-1 Mudança Tecnologica	\N
3764	095	a	mudanca	6.03.07.02-1 Mudança Tecnologica	\N
3765	095	a	tecnologica	6.03.07.02-1 Mudança Tecnologica	\N
3766	095	a	6.03.08.00-1	6.03.08.00-1 Economia do Bem-Estar Social	\N
3767	095	a	economia	6.03.08.00-1 Economia do Bem-Estar Social	\N
3768	095	a	do	6.03.08.00-1 Economia do Bem-Estar Social	\N
3769	095	a	bem-estar	6.03.08.00-1 Economia do Bem-Estar Social	\N
3770	095	a	social	6.03.08.00-1 Economia do Bem-Estar Social	\N
3771	095	a	6.03.08.01-0	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3772	095	a	economia	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3773	095	a	dos	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3774	095	a	programas	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3775	095	a	de	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3776	095	a	bem-estar	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3777	095	a	social	6.03.08.01-0 Economia dos Programas de Bem-Estar Social	\N
3778	095	a	6.03.08.02-8	6.03.08.02-8 Economia do Consumidor	\N
3779	095	a	economia	6.03.08.02-8 Economia do Consumidor	\N
3780	095	a	do	6.03.08.02-8 Economia do Consumidor	\N
3781	095	a	consumidor	6.03.08.02-8 Economia do Consumidor	\N
3782	095	a	6.03.09.00-8	6.03.09.00-8 Economia Regional e Urbana	\N
3783	095	a	economia	6.03.09.00-8 Economia Regional e Urbana	\N
3784	095	a	regional	6.03.09.00-8 Economia Regional e Urbana	\N
3785	095	a	urbana	6.03.09.00-8 Economia Regional e Urbana	\N
3786	095	a	6.03.09.01-6	6.03.09.01-6 Economia Regional	\N
3787	095	a	economia	6.03.09.01-6 Economia Regional	\N
3788	095	a	regional	6.03.09.01-6 Economia Regional	\N
3789	095	a	6.03.09.02-4	6.03.09.02-4 Economia Urbana	\N
3790	095	a	economia	6.03.09.02-4 Economia Urbana	\N
3791	095	a	urbana	6.03.09.02-4 Economia Urbana	\N
3792	095	a	6.03.09.03-2	6.03.09.03-2 Renda e Tributação	\N
3793	095	a	renda	6.03.09.03-2 Renda e Tributação	\N
3794	095	a	tributacao	6.03.09.03-2 Renda e Tributação	\N
3795	095	a	6.03.10.00-6	6.03.10.00-6 Economias Agrária e dos Recursos Naturais	\N
3796	095	a	economias	6.03.10.00-6 Economias Agrária e dos Recursos Naturais	\N
3797	095	a	agraria	6.03.10.00-6 Economias Agrária e dos Recursos Naturais	\N
3798	095	a	dos	6.03.10.00-6 Economias Agrária e dos Recursos Naturais	\N
3799	095	a	recursos	6.03.10.00-6 Economias Agrária e dos Recursos Naturais	\N
3800	095	a	naturais	6.03.10.00-6 Economias Agrária e dos Recursos Naturais	\N
3801	095	a	6.03.10.01-4	6.03.10.01-4 Economia Agrária	\N
3802	095	a	economia	6.03.10.01-4 Economia Agrária	\N
3803	095	a	agraria	6.03.10.01-4 Economia Agrária	\N
3804	095	a	6.03.10.02-2	6.03.10.02-2 Economia dos Recursos Naturais	\N
3805	095	a	economia	6.03.10.02-2 Economia dos Recursos Naturais	\N
3806	095	a	dos	6.03.10.02-2 Economia dos Recursos Naturais	\N
3807	095	a	recursos	6.03.10.02-2 Economia dos Recursos Naturais	\N
3808	095	a	naturais	6.03.10.02-2 Economia dos Recursos Naturais	\N
3809	095	a	6.04.00.00-5	6.04.00.00-5 Arquitetura e Urbanismo	\N
3810	095	a	arquitetura	6.04.00.00-5 Arquitetura e Urbanismo	\N
3811	095	a	urbanismo	6.04.00.00-5 Arquitetura e Urbanismo	\N
3812	095	a	6.04.01.00-1	6.04.01.00-1 Fundamentos de Arquitetura e Urbanismo	\N
3813	095	a	fundamentos	6.04.01.00-1 Fundamentos de Arquitetura e Urbanismo	\N
3814	095	a	de	6.04.01.00-1 Fundamentos de Arquitetura e Urbanismo	\N
3815	095	a	arquitetura	6.04.01.00-1 Fundamentos de Arquitetura e Urbanismo	\N
3816	095	a	urbanismo	6.04.01.00-1 Fundamentos de Arquitetura e Urbanismo	\N
3817	095	a	6.04.01.01-0	6.04.01.01-0 História da Arquitetura e Urbanismo	\N
3818	095	a	historia	6.04.01.01-0 História da Arquitetura e Urbanismo	\N
3819	095	a	da	6.04.01.01-0 História da Arquitetura e Urbanismo	\N
3820	095	a	arquitetura	6.04.01.01-0 História da Arquitetura e Urbanismo	\N
3821	095	a	urbanismo	6.04.01.01-0 História da Arquitetura e Urbanismo	\N
3822	095	a	6.04.01.02-8	6.04.01.02-8 Teoria da Arquitetura	\N
3823	095	a	teoria	6.04.01.02-8 Teoria da Arquitetura	\N
3824	095	a	da	6.04.01.02-8 Teoria da Arquitetura	\N
3825	095	a	arquitetura	6.04.01.02-8 Teoria da Arquitetura	\N
3826	095	a	6.04.01.03-6	6.04.01.03-6 História do Urbanismo	\N
3827	095	a	historia	6.04.01.03-6 História do Urbanismo	\N
3828	095	a	do	6.04.01.03-6 História do Urbanismo	\N
3829	095	a	urbanismo	6.04.01.03-6 História do Urbanismo	\N
3830	095	a	6.04.01.04-4	6.04.01.04-4 Teoria do Urbanismo	\N
3831	095	a	teoria	6.04.01.04-4 Teoria do Urbanismo	\N
3832	095	a	do	6.04.01.04-4 Teoria do Urbanismo	\N
3833	095	a	urbanismo	6.04.01.04-4 Teoria do Urbanismo	\N
3834	095	a	6.04.02.00-8	6.04.02.00-8 Projeto de Arquitetuta e Urbanismo	\N
3835	095	a	projeto	6.04.02.00-8 Projeto de Arquitetuta e Urbanismo	\N
3836	095	a	de	6.04.02.00-8 Projeto de Arquitetuta e Urbanismo	\N
3837	095	a	arquitetuta	6.04.02.00-8 Projeto de Arquitetuta e Urbanismo	\N
3838	095	a	urbanismo	6.04.02.00-8 Projeto de Arquitetuta e Urbanismo	\N
3839	095	a	6.04.02.01-6	6.04.02.01-6 Planejamento e Projetos da Edificação	\N
3840	095	a	planejamento	6.04.02.01-6 Planejamento e Projetos da Edificação	\N
3841	095	a	projetos	6.04.02.01-6 Planejamento e Projetos da Edificação	\N
3842	095	a	da	6.04.02.01-6 Planejamento e Projetos da Edificação	\N
3843	095	a	edificacao	6.04.02.01-6 Planejamento e Projetos da Edificação	\N
3844	095	a	6.04.02.02-4	6.04.02.02-4 Planejamento e Projeto do Espaço Urbano	\N
3845	095	a	planejamento	6.04.02.02-4 Planejamento e Projeto do Espaço Urbano	\N
3846	095	a	projeto	6.04.02.02-4 Planejamento e Projeto do Espaço Urbano	\N
3847	095	a	do	6.04.02.02-4 Planejamento e Projeto do Espaço Urbano	\N
3848	095	a	espaco	6.04.02.02-4 Planejamento e Projeto do Espaço Urbano	\N
3849	095	a	urbano	6.04.02.02-4 Planejamento e Projeto do Espaço Urbano	\N
3850	095	a	6.04.02.03-2	6.04.02.03-2 Planejamento e Projeto do Equipamento	\N
3851	095	a	planejamento	6.04.02.03-2 Planejamento e Projeto do Equipamento	\N
3852	095	a	projeto	6.04.02.03-2 Planejamento e Projeto do Equipamento	\N
3853	095	a	do	6.04.02.03-2 Planejamento e Projeto do Equipamento	\N
3854	095	a	equipamento	6.04.02.03-2 Planejamento e Projeto do Equipamento	\N
3855	095	a	6.04.03.00-4	6.04.03.00-4 Tecnologia de Arquitetura e Urbanismo	\N
3856	095	a	tecnologia	6.04.03.00-4 Tecnologia de Arquitetura e Urbanismo	\N
3857	095	a	de	6.04.03.00-4 Tecnologia de Arquitetura e Urbanismo	\N
3858	095	a	arquitetura	6.04.03.00-4 Tecnologia de Arquitetura e Urbanismo	\N
3859	095	a	urbanismo	6.04.03.00-4 Tecnologia de Arquitetura e Urbanismo	\N
3860	095	a	6.04.03.01-2	6.04.03.01-2 Adequação Ambiental	\N
3861	095	a	adequacao	6.04.03.01-2 Adequação Ambiental	\N
3862	095	a	ambiental	6.04.03.01-2 Adequação Ambiental	\N
3863	095	a	6.04.04.00-0	6.04.04.00-0 Paisagismo	\N
3864	095	a	paisagismo	6.04.04.00-0 Paisagismo	\N
3865	095	a	6.04.04.01-9	6.04.04.01-9 Desenvolvimento Histórico do Paisagismo	\N
3866	095	a	desenvolvimento	6.04.04.01-9 Desenvolvimento Histórico do Paisagismo	\N
3867	095	a	historico	6.04.04.01-9 Desenvolvimento Histórico do Paisagismo	\N
3868	095	a	do	6.04.04.01-9 Desenvolvimento Histórico do Paisagismo	\N
3869	095	a	paisagismo	6.04.04.01-9 Desenvolvimento Histórico do Paisagismo	\N
3870	095	a	6.04.04.02-7	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3871	095	a	conceituacao	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3872	095	a	de	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3873	095	a	paisagismo	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3874	095	a	metodologia	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3875	095	a	do	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3876	095	a	paisagismo	6.04.04.02-7 Conceituação de Paisagismo e Metodologia do Paisagismo	\N
3877	095	a	6.04.04.03-5	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3878	095	a	estudos	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3879	095	a	de	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3880	095	a	organizacao	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3881	095	a	do	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3882	095	a	espaco	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3883	095	a	exterior	6.04.04.03-5 Estudos de Organização do Espaço Exterior	\N
3884	095	a	6.04.04.04-3	6.04.04.04-3 Projetos de Espaços Livres Urbanos	\N
3885	095	a	projetos	6.04.04.04-3 Projetos de Espaços Livres Urbanos	\N
3886	095	a	de	6.04.04.04-3 Projetos de Espaços Livres Urbanos	\N
3887	095	a	espacos	6.04.04.04-3 Projetos de Espaços Livres Urbanos	\N
3888	095	a	livres	6.04.04.04-3 Projetos de Espaços Livres Urbanos	\N
3889	095	a	urbanos	6.04.04.04-3 Projetos de Espaços Livres Urbanos	\N
3890	095	a	6.05.00.00-0	6.05.00.00-0 Planejamento Urbano e Regional	\N
3891	095	a	planejamento	6.05.00.00-0 Planejamento Urbano e Regional	\N
3892	095	a	urbano	6.05.00.00-0 Planejamento Urbano e Regional	\N
3893	095	a	regional	6.05.00.00-0 Planejamento Urbano e Regional	\N
3894	095	a	6.05.01.00-6	6.05.01.00-6 Fundamentos do Planejamento Urbano e Regional	\N
3895	095	a	fundamentos	6.05.01.00-6 Fundamentos do Planejamento Urbano e Regional	\N
3896	095	a	do	6.05.01.00-6 Fundamentos do Planejamento Urbano e Regional	\N
3897	095	a	planejamento	6.05.01.00-6 Fundamentos do Planejamento Urbano e Regional	\N
3898	095	a	urbano	6.05.01.00-6 Fundamentos do Planejamento Urbano e Regional	\N
3899	095	a	regional	6.05.01.00-6 Fundamentos do Planejamento Urbano e Regional	\N
3900	095	a	6.05.01.01-4	6.05.01.01-4 Teoria do Planejamento Urbano e Regional	\N
3901	095	a	teoria	6.05.01.01-4 Teoria do Planejamento Urbano e Regional	\N
3902	095	a	do	6.05.01.01-4 Teoria do Planejamento Urbano e Regional	\N
3903	095	a	planejamento	6.05.01.01-4 Teoria do Planejamento Urbano e Regional	\N
3904	095	a	urbano	6.05.01.01-4 Teoria do Planejamento Urbano e Regional	\N
3905	095	a	regional	6.05.01.01-4 Teoria do Planejamento Urbano e Regional	\N
3906	095	a	6.05.01.02-2	6.05.01.02-2 Teoria da Urbanização	\N
3907	095	a	teoria	6.05.01.02-2 Teoria da Urbanização	\N
3908	095	a	da	6.05.01.02-2 Teoria da Urbanização	\N
3909	095	a	urbanizacao	6.05.01.02-2 Teoria da Urbanização	\N
3910	095	a	6.05.01.03-0	6.05.01.03-0 Política Urbana	\N
3911	095	a	politica	6.05.01.03-0 Política Urbana	\N
3912	095	a	urbana	6.05.01.03-0 Política Urbana	\N
3913	095	a	6.05.01.04-9	6.05.01.04-9 História Urbana	\N
3914	095	a	historia	6.05.01.04-9 História Urbana	\N
3915	095	a	urbana	6.05.01.04-9 História Urbana	\N
3916	095	a	6.05.02.00-2	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3917	095	a	metodos	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3918	095	a	tecnicas	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3919	095	a	do	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3920	095	a	planejamento	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3921	095	a	urbano	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3922	095	a	regional	6.05.02.00-2 Métodos e Técnicas do Planejamento Urbano e Regional	\N
3923	095	a	6.05.02.01-0	6.05.02.01-0 Informação, Cadastro e Mapeamento	\N
3924	095	a	informacao,	6.05.02.01-0 Informação, Cadastro e Mapeamento	\N
3925	095	a	cadastro	6.05.02.01-0 Informação, Cadastro e Mapeamento	\N
3926	095	a	mapeamento	6.05.02.01-0 Informação, Cadastro e Mapeamento	\N
3927	095	a	6.05.02.02-9	6.05.02.02-9 Técnica de Previsão Urbana e Regional	\N
3928	095	a	tecnica	6.05.02.02-9 Técnica de Previsão Urbana e Regional	\N
3929	095	a	de	6.05.02.02-9 Técnica de Previsão Urbana e Regional	\N
3930	095	a	previsao	6.05.02.02-9 Técnica de Previsão Urbana e Regional	\N
3931	095	a	urbana	6.05.02.02-9 Técnica de Previsão Urbana e Regional	\N
3932	095	a	regional	6.05.02.02-9 Técnica de Previsão Urbana e Regional	\N
3933	095	a	6.05.02.03-7	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3934	095	a	tecnicas	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3935	095	a	de	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3936	095	a	analise	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3937	095	a	avaliacao	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3938	095	a	urbana	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3939	095	a	regional	6.05.02.03-7 Técnicas de Análise e Avaliação Urbana e Regional	\N
3940	095	a	6.05.02.04-5	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3941	095	a	tecnicas	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3942	095	a	de	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3943	095	a	planejamento	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3944	095	a	projeto	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3945	095	a	urbanos	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3946	095	a	regionais	6.05.02.04-5 Técnicas de Planejamento e Projeto Urbanos e Regionais	\N
3947	095	a	6.05.03.00-9	6.05.03.00-9 Serviços Urbanos e Regionais	\N
3948	095	a	servicos	6.05.03.00-9 Serviços Urbanos e Regionais	\N
3949	095	a	urbanos	6.05.03.00-9 Serviços Urbanos e Regionais	\N
3950	095	a	regionais	6.05.03.00-9 Serviços Urbanos e Regionais	\N
3951	095	a	6.05.03.01-7	6.05.03.01-7 Administração Municipal e Urbana	\N
3952	095	a	administracao	6.05.03.01-7 Administração Municipal e Urbana	\N
3953	095	a	municipal	6.05.03.01-7 Administração Municipal e Urbana	\N
3954	095	a	urbana	6.05.03.01-7 Administração Municipal e Urbana	\N
3955	095	a	6.05.03.02-5	6.05.03.02-5 Estudos da Habitação	\N
3956	095	a	estudos	6.05.03.02-5 Estudos da Habitação	\N
3957	095	a	da	6.05.03.02-5 Estudos da Habitação	\N
3958	095	a	habitacao	6.05.03.02-5 Estudos da Habitação	\N
3959	095	a	6.05.03.03-3	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3960	095	a	aspectos	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3961	095	a	sociais	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3962	095	a	do	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3963	095	a	planejamento	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3964	095	a	urbano	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3965	095	a	regional	6.05.03.03-3 Aspectos Sociais do Planejamento Urbano e Regional	\N
3966	095	a	6.05.03.04-1	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3967	095	a	aspectos	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3968	095	a	economicos	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3969	095	a	do	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3970	095	a	planejamento	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3971	095	a	urbano	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3972	095	a	regional	6.05.03.04-1 Aspectos Econômicos do Planejamento Urbano e Regional	\N
3973	095	a	6.05.03.05-0	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3974	095	a	aspectos	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3975	095	a	fisico-ambientais	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3976	095	a	do	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3977	095	a	planejamento	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3978	095	a	urbano	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3979	095	a	regional	6.05.03.05-0 Aspectos Físico-Ambientais do Planejamento Urbano e Regional	\N
3980	095	a	6.05.03.06-8	6.05.03.06-8 Serviços Comunitários	\N
3981	095	a	servicos	6.05.03.06-8 Serviços Comunitários	\N
3982	095	a	comunitarios	6.05.03.06-8 Serviços Comunitários	\N
3983	095	a	6.05.03.07-6	6.05.03.07-6 Infra-Estruturas Urbanas e Regionais	\N
3984	095	a	infra-estruturas	6.05.03.07-6 Infra-Estruturas Urbanas e Regionais	\N
3985	095	a	urbanas	6.05.03.07-6 Infra-Estruturas Urbanas e Regionais	\N
3986	095	a	regionais	6.05.03.07-6 Infra-Estruturas Urbanas e Regionais	\N
3987	095	a	6.05.03.08-4	6.05.03.08-4 Transporte e Tráfego Urbano e Regional	\N
3988	095	a	transporte	6.05.03.08-4 Transporte e Tráfego Urbano e Regional	\N
3989	095	a	trafego	6.05.03.08-4 Transporte e Tráfego Urbano e Regional	\N
3990	095	a	urbano	6.05.03.08-4 Transporte e Tráfego Urbano e Regional	\N
3991	095	a	regional	6.05.03.08-4 Transporte e Tráfego Urbano e Regional	\N
3992	095	a	6.05.03.09-2	6.05.03.09-2 Legislação Urbana e Regional	\N
3993	095	a	legislacao	6.05.03.09-2 Legislação Urbana e Regional	\N
3994	095	a	urbana	6.05.03.09-2 Legislação Urbana e Regional	\N
3995	095	a	regional	6.05.03.09-2 Legislação Urbana e Regional	\N
3996	095	a	6.06.00.00-4	6.06.00.00-4 Demografia	\N
3997	095	a	demografia	6.06.00.00-4 Demografia	\N
3998	095	a	6.06.01.00-0	6.06.01.00-0 Distribuição Espacial	\N
3999	095	a	distribuicao	6.06.01.00-0 Distribuição Espacial	\N
4000	095	a	espacial	6.06.01.00-0 Distribuição Espacial	\N
4001	095	a	6.06.01.01-9	6.06.01.01-9 Distribuição Espacial Geral	\N
4002	095	a	distribuicao	6.06.01.01-9 Distribuição Espacial Geral	\N
4003	095	a	espacial	6.06.01.01-9 Distribuição Espacial Geral	\N
4004	095	a	geral	6.06.01.01-9 Distribuição Espacial Geral	\N
4005	095	a	6.06.01.02-7	6.06.01.02-7 Distribuição Espacial Urbana	\N
4006	095	a	distribuicao	6.06.01.02-7 Distribuição Espacial Urbana	\N
4007	095	a	espacial	6.06.01.02-7 Distribuição Espacial Urbana	\N
4008	095	a	urbana	6.06.01.02-7 Distribuição Espacial Urbana	\N
4009	095	a	6.06.01.03-5	6.06.01.03-5 Distribuição Espacial Rural	\N
4010	095	a	distribuicao	6.06.01.03-5 Distribuição Espacial Rural	\N
4011	095	a	espacial	6.06.01.03-5 Distribuição Espacial Rural	\N
4012	095	a	rural	6.06.01.03-5 Distribuição Espacial Rural	\N
4013	095	a	6.06.02.00-7	6.06.02.00-7 Tendência Populacional	\N
4014	095	a	tendencia	6.06.02.00-7 Tendência Populacional	\N
4015	095	a	populacional	6.06.02.00-7 Tendência Populacional	\N
4016	095	a	6.06.02.01-5	6.06.02.01-5 Tendências Passadas	\N
4017	095	a	tendencias	6.06.02.01-5 Tendências Passadas	\N
4018	095	a	passadas	6.06.02.01-5 Tendências Passadas	\N
4019	095	a	6.06.02.02-3	6.06.02.02-3 Taxas e Estimativas Correntes	\N
4020	095	a	taxas	6.06.02.02-3 Taxas e Estimativas Correntes	\N
4021	095	a	estimativas	6.06.02.02-3 Taxas e Estimativas Correntes	\N
4022	095	a	correntes	6.06.02.02-3 Taxas e Estimativas Correntes	\N
4023	095	a	6.06.02.03-1	6.06.02.03-1 Projeções	\N
4024	095	a	projecoes	6.06.02.03-1 Projeções	\N
4025	095	a	6.06.03.00-3	6.06.03.00-3 Componentes da Dinâmica Demográfica	\N
4026	095	a	componentes	6.06.03.00-3 Componentes da Dinâmica Demográfica	\N
4027	095	a	da	6.06.03.00-3 Componentes da Dinâmica Demográfica	\N
4028	095	a	dinamica	6.06.03.00-3 Componentes da Dinâmica Demográfica	\N
4029	095	a	demografica	6.06.03.00-3 Componentes da Dinâmica Demográfica	\N
4030	095	a	6.06.03.01-1	6.06.03.01-1 Fecundidade	\N
4031	095	a	fecundidade	6.06.03.01-1 Fecundidade	\N
4032	095	a	6.06.03.02-0	6.06.03.02-0 Mortalidade	\N
4033	095	a	mortalidade	6.06.03.02-0 Mortalidade	\N
4034	095	a	6.06.03.03-8	6.06.03.03-8 Migração	\N
4035	095	a	migracao	6.06.03.03-8 Migração	\N
4036	095	a	6.06.04.00-0	6.06.04.00-0 Nupcialidade e Família	\N
4037	095	a	nupcialidade	6.06.04.00-0 Nupcialidade e Família	\N
4038	095	a	familia	6.06.04.00-0 Nupcialidade e Família	\N
4039	095	a	6.06.04.01-8	6.06.04.01-8 Casamento e Divórcio	\N
4040	095	a	casamento	6.06.04.01-8 Casamento e Divórcio	\N
4041	095	a	divorcio	6.06.04.01-8 Casamento e Divórcio	\N
4042	095	a	6.06.04.02-6	6.06.04.02-6 Família e Reprodução	\N
4043	095	a	familia	6.06.04.02-6 Família e Reprodução	\N
4044	095	a	reproducao	6.06.04.02-6 Família e Reprodução	\N
4045	095	a	6.06.05.00-6	6.06.05.00-6 Demografia Histórica	\N
4046	095	a	demografia	6.06.05.00-6 Demografia Histórica	\N
4047	095	a	historica	6.06.05.00-6 Demografia Histórica	\N
4048	095	a	6.06.05.01-4	6.06.05.01-4 Distribuição Espacial	\N
4049	095	a	distribuicao	6.06.05.01-4 Distribuição Espacial	\N
4050	095	a	espacial	6.06.05.01-4 Distribuição Espacial	\N
4051	095	a	6.06.05.02-2	6.06.05.02-2 Natalidade, Mortalidade, Migração	\N
4052	095	a	natalidade,	6.06.05.02-2 Natalidade, Mortalidade, Migração	\N
4053	095	a	mortalidade,	6.06.05.02-2 Natalidade, Mortalidade, Migração	\N
4054	095	a	migracao	6.06.05.02-2 Natalidade, Mortalidade, Migração	\N
4055	095	a	6.06.05.03-0	6.06.05.03-0 Nupcialidade e Família	\N
4056	095	a	nupcialidade	6.06.05.03-0 Nupcialidade e Família	\N
4057	095	a	familia	6.06.05.03-0 Nupcialidade e Família	\N
4058	095	a	6.06.05.04-9	6.06.05.04-9 Métodos e Técnicas de Demografia Histórica	\N
4059	095	a	metodos	6.06.05.04-9 Métodos e Técnicas de Demografia Histórica	\N
4060	095	a	tecnicas	6.06.05.04-9 Métodos e Técnicas de Demografia Histórica	\N
4061	095	a	de	6.06.05.04-9 Métodos e Técnicas de Demografia Histórica	\N
4062	095	a	demografia	6.06.05.04-9 Métodos e Técnicas de Demografia Histórica	\N
4063	095	a	historica	6.06.05.04-9 Métodos e Técnicas de Demografia Histórica	\N
4064	095	a	6.06.06.00-2	6.06.06.00-2 Política Pública e População	\N
4065	095	a	politica	6.06.06.00-2 Política Pública e População	\N
4066	095	a	publica	6.06.06.00-2 Política Pública e População	\N
4067	095	a	populacao	6.06.06.00-2 Política Pública e População	\N
4068	095	a	6.06.06.01-0	6.06.06.01-0 Política Populacional	\N
4069	095	a	politica	6.06.06.01-0 Política Populacional	\N
4070	095	a	populacional	6.06.06.01-0 Política Populacional	\N
4071	095	a	6.06.06.02-9	6.06.06.02-9 Políticas de Redistribuição de População	\N
4072	095	a	politicas	6.06.06.02-9 Políticas de Redistribuição de População	\N
4073	095	a	de	6.06.06.02-9 Políticas de Redistribuição de População	\N
4074	095	a	redistribuicao	6.06.06.02-9 Políticas de Redistribuição de População	\N
4075	095	a	de	6.06.06.02-9 Políticas de Redistribuição de População	\N
4076	095	a	populacao	6.06.06.02-9 Políticas de Redistribuição de População	\N
4077	095	a	6.06.06.03-7	6.06.06.03-7 Políticas de Planejamento Familiar	\N
4078	095	a	politicas	6.06.06.03-7 Políticas de Planejamento Familiar	\N
4079	095	a	de	6.06.06.03-7 Políticas de Planejamento Familiar	\N
4080	095	a	planejamento	6.06.06.03-7 Políticas de Planejamento Familiar	\N
4081	095	a	familiar	6.06.06.03-7 Políticas de Planejamento Familiar	\N
4082	095	a	6.06.07.00-9	6.06.07.00-9 Fontes de Dados Demográficos	\N
4083	095	a	fontes	6.06.07.00-9 Fontes de Dados Demográficos	\N
4084	095	a	de	6.06.07.00-9 Fontes de Dados Demográficos	\N
4085	095	a	dados	6.06.07.00-9 Fontes de Dados Demográficos	\N
4086	095	a	demograficos	6.06.07.00-9 Fontes de Dados Demográficos	\N
4087	095	a	6.07.00.00-9	6.07.00.00-9 Ciência da Informação	\N
4088	095	a	ciencia	6.07.00.00-9 Ciência da Informação	\N
4089	095	a	da	6.07.00.00-9 Ciência da Informação	\N
4090	095	a	informacao	6.07.00.00-9 Ciência da Informação	\N
4091	095	a	6.07.01.00-5	6.07.01.00-5 Teoria da Informação	\N
4092	095	a	teoria	6.07.01.00-5 Teoria da Informação	\N
4093	095	a	da	6.07.01.00-5 Teoria da Informação	\N
4094	095	a	informacao	6.07.01.00-5 Teoria da Informação	\N
4095	095	a	6.07.01.01-3	6.07.01.01-3 Teoria Geral da Informação	\N
4096	095	a	teoria	6.07.01.01-3 Teoria Geral da Informação	\N
4097	095	a	geral	6.07.01.01-3 Teoria Geral da Informação	\N
4098	095	a	da	6.07.01.01-3 Teoria Geral da Informação	\N
4099	095	a	informacao	6.07.01.01-3 Teoria Geral da Informação	\N
4100	095	a	6.07.01.02-1	6.07.01.02-1 Processos da Comunicação	\N
4101	095	a	processos	6.07.01.02-1 Processos da Comunicação	\N
4102	095	a	da	6.07.01.02-1 Processos da Comunicação	\N
4103	095	a	comunicacao	6.07.01.02-1 Processos da Comunicação	\N
4104	095	a	6.07.01.03-0	6.07.01.03-0 Representação da Informação	\N
4105	095	a	representacao	6.07.01.03-0 Representação da Informação	\N
4106	095	a	da	6.07.01.03-0 Representação da Informação	\N
4107	095	a	informacao	6.07.01.03-0 Representação da Informação	\N
4108	095	a	6.07.02.00-1	6.07.02.00-1 Biblioteconomia	\N
4109	095	a	biblioteconomia	6.07.02.00-1 Biblioteconomia	\N
4110	095	a	6.07.02.01-0	6.07.02.01-0 Teoria da Classificação	\N
4111	095	a	teoria	6.07.02.01-0 Teoria da Classificação	\N
4112	095	a	da	6.07.02.01-0 Teoria da Classificação	\N
4113	095	a	classificacao	6.07.02.01-0 Teoria da Classificação	\N
4114	095	a	6.07.02.02-8	6.07.02.02-8 Métodos Quantitativos. Bibliometria	\N
4115	095	a	metodos	6.07.02.02-8 Métodos Quantitativos. Bibliometria	\N
4116	095	a	quantitativos.	6.07.02.02-8 Métodos Quantitativos. Bibliometria	\N
4117	095	a	bibliometria	6.07.02.02-8 Métodos Quantitativos. Bibliometria	\N
4118	095	a	6.07.02.03-6	6.07.02.03-6 Técnicas de Recuperação de Informação	\N
4119	095	a	tecnicas	6.07.02.03-6 Técnicas de Recuperação de Informação	\N
4120	095	a	de	6.07.02.03-6 Técnicas de Recuperação de Informação	\N
4121	095	a	recuperacao	6.07.02.03-6 Técnicas de Recuperação de Informação	\N
4122	095	a	de	6.07.02.03-6 Técnicas de Recuperação de Informação	\N
4123	095	a	informacao	6.07.02.03-6 Técnicas de Recuperação de Informação	\N
4124	095	a	6.07.02.04-4	6.07.02.04-4 Processos de Disseminação da Informação	\N
4125	095	a	processos	6.07.02.04-4 Processos de Disseminação da Informação	\N
4126	095	a	de	6.07.02.04-4 Processos de Disseminação da Informação	\N
4127	095	a	disseminacao	6.07.02.04-4 Processos de Disseminação da Informação	\N
4128	095	a	da	6.07.02.04-4 Processos de Disseminação da Informação	\N
4129	095	a	informacao	6.07.02.04-4 Processos de Disseminação da Informação	\N
4130	095	a	6.07.03.00-8	6.07.03.00-8 Arquivologia	\N
4131	095	a	arquivologia	6.07.03.00-8 Arquivologia	\N
4132	095	a	6.07.03.01-6	6.07.03.01-6 Organização de Arquivos	\N
4133	095	a	organizacao	6.07.03.01-6 Organização de Arquivos	\N
4134	095	a	de	6.07.03.01-6 Organização de Arquivos	\N
4135	095	a	arquivos	6.07.03.01-6 Organização de Arquivos	\N
4136	095	a	6.08.00.00-3	6.08.00.00-3 Museologia	\N
4137	095	a	museologia	6.08.00.00-3 Museologia	\N
4138	095	a	6.09.00.00-8	6.09.00.00-8 Comunicação	\N
4139	095	a	comunicacao	6.09.00.00-8 Comunicação	\N
4140	095	a	6.09.01.00-4	6.09.01.00-4 Teoria da Comunicação	\N
4141	095	a	teoria	6.09.01.00-4 Teoria da Comunicação	\N
4142	095	a	da	6.09.01.00-4 Teoria da Comunicação	\N
4143	095	a	comunicacao	6.09.01.00-4 Teoria da Comunicação	\N
4144	095	a	6.09.02.00-0	6.09.02.00-0 Jornalismo e Editoração	\N
4145	095	a	jornalismo	6.09.02.00-0 Jornalismo e Editoração	\N
4146	095	a	editoracao	6.09.02.00-0 Jornalismo e Editoração	\N
4147	095	a	6.09.02.01-9	6.09.02.01-9 Teoria e Ética do Jornalismo	\N
4148	095	a	teoria	6.09.02.01-9 Teoria e Ética do Jornalismo	\N
4149	095	a	etica	6.09.02.01-9 Teoria e Ética do Jornalismo	\N
4150	095	a	do	6.09.02.01-9 Teoria e Ética do Jornalismo	\N
4151	095	a	jornalismo	6.09.02.01-9 Teoria e Ética do Jornalismo	\N
4152	095	a	6.09.02.02-7	6.09.02.02-7 Organização Editorial de Jornais	\N
4153	095	a	organizacao	6.09.02.02-7 Organização Editorial de Jornais	\N
4154	095	a	editorial	6.09.02.02-7 Organização Editorial de Jornais	\N
4155	095	a	de	6.09.02.02-7 Organização Editorial de Jornais	\N
4156	095	a	jornais	6.09.02.02-7 Organização Editorial de Jornais	\N
4157	095	a	6.09.02.03-5	6.09.02.03-5 Organização Comercial de Jornais	\N
4158	095	a	organizacao	6.09.02.03-5 Organização Comercial de Jornais	\N
4159	095	a	comercial	6.09.02.03-5 Organização Comercial de Jornais	\N
4160	095	a	de	6.09.02.03-5 Organização Comercial de Jornais	\N
4161	095	a	jornais	6.09.02.03-5 Organização Comercial de Jornais	\N
4162	095	a	6.09.02.04-3	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4163	095	a	jornalismo	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4164	095	a	especializado	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4165	095	a	(comunitario,	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4166	095	a	rural,	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4167	095	a	empresarial,	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4168	095	a	cientifico)	6.09.02.04-3 Jornalismo Especializado (Comunitário, Rural, Empresarial, Científico)	\N
4169	095	a	6.09.03.00-7	6.09.03.00-7 Rádio e Televisão	\N
4170	095	a	radio	6.09.03.00-7 Rádio e Televisão	\N
4171	095	a	televisao	6.09.03.00-7 Rádio e Televisão	\N
4172	095	a	6.09.03.01-5	6.09.03.01-5 Radiodifusão	\N
4173	095	a	radiodifusao	6.09.03.01-5 Radiodifusão	\N
4174	095	a	6.09.03.02-3	6.09.03.02-3 Videodifusão	\N
4175	095	a	videodifusao	6.09.03.02-3 Videodifusão	\N
4176	095	a	6.09.04.00-3	6.09.04.00-3 Relações Públicas e Propaganda	\N
4177	095	a	relacoes	6.09.04.00-3 Relações Públicas e Propaganda	\N
4178	095	a	publicas	6.09.04.00-3 Relações Públicas e Propaganda	\N
4179	095	a	propaganda	6.09.04.00-3 Relações Públicas e Propaganda	\N
4180	095	a	6.09.05.00-0	6.09.05.00-0 Comunicação Visual	\N
4181	095	a	comunicacao	6.09.05.00-0 Comunicação Visual	\N
4182	095	a	visual	6.09.05.00-0 Comunicação Visual	\N
4183	095	a	6.10.00.00-0	6.10.00.00-0 Serviço Social	\N
4184	095	a	servico	6.10.00.00-0 Serviço Social	\N
4185	095	a	social	6.10.00.00-0 Serviço Social	\N
4186	095	a	6.10.01.00-7	6.10.01.00-7 Fundamentos do Serviço Social	\N
4187	095	a	fundamentos	6.10.01.00-7 Fundamentos do Serviço Social	\N
4188	095	a	do	6.10.01.00-7 Fundamentos do Serviço Social	\N
4189	095	a	servico	6.10.01.00-7 Fundamentos do Serviço Social	\N
4190	095	a	social	6.10.01.00-7 Fundamentos do Serviço Social	\N
4191	095	a	6.10.02.00-3	6.10.02.00-3 Serviço Social Aplicado	\N
4192	095	a	servico	6.10.02.00-3 Serviço Social Aplicado	\N
4193	095	a	social	6.10.02.00-3 Serviço Social Aplicado	\N
4194	095	a	aplicado	6.10.02.00-3 Serviço Social Aplicado	\N
4195	095	a	6.10.02.01-1	6.10.02.01-1 Serviço Social do Trabalho	\N
4196	095	a	servico	6.10.02.01-1 Serviço Social do Trabalho	\N
4197	095	a	social	6.10.02.01-1 Serviço Social do Trabalho	\N
4198	095	a	do	6.10.02.01-1 Serviço Social do Trabalho	\N
4199	095	a	trabalho	6.10.02.01-1 Serviço Social do Trabalho	\N
4200	095	a	6.10.02.02-0	6.10.02.02-0 Serviço Social da Educação	\N
4201	095	a	servico	6.10.02.02-0 Serviço Social da Educação	\N
4202	095	a	social	6.10.02.02-0 Serviço Social da Educação	\N
4203	095	a	da	6.10.02.02-0 Serviço Social da Educação	\N
4204	095	a	educacao	6.10.02.02-0 Serviço Social da Educação	\N
4205	095	a	6.10.02.03-8	6.10.02.03-8 Serviço Social do Menor	\N
4206	095	a	servico	6.10.02.03-8 Serviço Social do Menor	\N
4207	095	a	social	6.10.02.03-8 Serviço Social do Menor	\N
4208	095	a	do	6.10.02.03-8 Serviço Social do Menor	\N
4209	095	a	menor	6.10.02.03-8 Serviço Social do Menor	\N
4210	095	a	6.10.02.04-6	6.10.02.04-6 Serviço Social da Saúde	\N
4211	095	a	servico	6.10.02.04-6 Serviço Social da Saúde	\N
4212	095	a	social	6.10.02.04-6 Serviço Social da Saúde	\N
4213	095	a	da	6.10.02.04-6 Serviço Social da Saúde	\N
4214	095	a	saude	6.10.02.04-6 Serviço Social da Saúde	\N
4215	095	a	6.10.02.05-4	6.10.02.05-4 Serviço Social da Habitação	\N
4216	095	a	servico	6.10.02.05-4 Serviço Social da Habitação	\N
4217	095	a	social	6.10.02.05-4 Serviço Social da Habitação	\N
4218	095	a	da	6.10.02.05-4 Serviço Social da Habitação	\N
4219	095	a	habitacao	6.10.02.05-4 Serviço Social da Habitação	\N
4220	095	a	6.11.00.00-5	6.11.00.00-5 Economia Doméstica	\N
4221	095	a	economia	6.11.00.00-5 Economia Doméstica	\N
4222	095	a	domestica	6.11.00.00-5 Economia Doméstica	\N
4223	095	a	6.12.00.00-0	6.12.00.00-0 Desenho Industrial	\N
4224	095	a	desenho	6.12.00.00-0 Desenho Industrial	\N
4225	095	a	industrial	6.12.00.00-0 Desenho Industrial	\N
4226	095	a	6.12.01.00-6	6.12.01.00-6 Programação Visual	\N
4227	095	a	programacao	6.12.01.00-6 Programação Visual	\N
4228	095	a	visual	6.12.01.00-6 Programação Visual	\N
4229	095	a	6.12.02.00-2	6.12.02.00-2 Desenho de Produto	\N
4230	095	a	desenho	6.12.02.00-2 Desenho de Produto	\N
4231	095	a	de	6.12.02.00-2 Desenho de Produto	\N
4232	095	a	produto	6.12.02.00-2 Desenho de Produto	\N
4233	095	a	6.13.00.00-4	6.13.00.00-4 Turismo	\N
4234	095	a	turismo	6.13.00.00-4 Turismo	\N
4235	095	a	7.00.00.00-0	7.00.00.00-0 Ciências Humanas	\N
4236	095	a	ciencias	7.00.00.00-0 Ciências Humanas	\N
4237	095	a	humanas	7.00.00.00-0 Ciências Humanas	\N
4238	095	a	7.01.00.00-4	7.01.00.00-4 Filosofia	\N
4239	095	a	filosofia	7.01.00.00-4 Filosofia	\N
4240	095	a	7.01.01.00-0	7.01.01.00-0 História da Filosofia	\N
4241	095	a	historia	7.01.01.00-0 História da Filosofia	\N
4242	095	a	da	7.01.01.00-0 História da Filosofia	\N
4243	095	a	filosofia	7.01.01.00-0 História da Filosofia	\N
4244	095	a	7.01.02.00-7	7.01.02.00-7 Metafísica	\N
4245	095	a	metafisica	7.01.02.00-7 Metafísica	\N
4246	095	a	7.01.03.00-3	7.01.03.00-3 Lógica	\N
4247	095	a	logica	7.01.03.00-3 Lógica	\N
4248	095	a	7.01.04.00-0	7.01.04.00-0 Ética	\N
4249	095	a	etica	7.01.04.00-0 Ética	\N
4250	095	a	7.01.05.00-6	7.01.05.00-6 Epistemologia	\N
4251	095	a	epistemologia	7.01.05.00-6 Epistemologia	\N
4252	095	a	7.01.06.00-2	7.01.06.00-2 Filosofia Brasileira	\N
4253	095	a	filosofia	7.01.06.00-2 Filosofia Brasileira	\N
4254	095	a	brasileira	7.01.06.00-2 Filosofia Brasileira	\N
4255	095	a	7.02.00.00-9	7.02.00.00-9 Sociologia	\N
4256	095	a	sociologia	7.02.00.00-9 Sociologia	\N
4257	095	a	7.02.01.00-5	7.02.01.00-5 Fundamentos da Sociologia	\N
4258	095	a	fundamentos	7.02.01.00-5 Fundamentos da Sociologia	\N
4259	095	a	da	7.02.01.00-5 Fundamentos da Sociologia	\N
4260	095	a	sociologia	7.02.01.00-5 Fundamentos da Sociologia	\N
4261	095	a	7.02.01.01-3	7.02.01.01-3 Teoria Sociológica	\N
4262	095	a	teoria	7.02.01.01-3 Teoria Sociológica	\N
4263	095	a	sociologica	7.02.01.01-3 Teoria Sociológica	\N
4264	095	a	7.02.01.02-1	7.02.01.02-1 História da Sociologia	\N
4265	095	a	historia	7.02.01.02-1 História da Sociologia	\N
4266	095	a	da	7.02.01.02-1 História da Sociologia	\N
4267	095	a	sociologia	7.02.01.02-1 História da Sociologia	\N
4268	095	a	7.02.02.00-1	7.02.02.00-1 Sociologia do Conhecimento	\N
4269	095	a	sociologia	7.02.02.00-1 Sociologia do Conhecimento	\N
4270	095	a	do	7.02.02.00-1 Sociologia do Conhecimento	\N
4271	095	a	conhecimento	7.02.02.00-1 Sociologia do Conhecimento	\N
4272	095	a	7.02.03.00-8	7.02.03.00-8 Sociologia do Desenvolvimento	\N
4273	095	a	sociologia	7.02.03.00-8 Sociologia do Desenvolvimento	\N
4274	095	a	do	7.02.03.00-8 Sociologia do Desenvolvimento	\N
4275	095	a	desenvolvimento	7.02.03.00-8 Sociologia do Desenvolvimento	\N
4276	095	a	7.02.04.00-4	7.02.04.00-4 Sociologia Urbana	\N
4277	095	a	sociologia	7.02.04.00-4 Sociologia Urbana	\N
4278	095	a	urbana	7.02.04.00-4 Sociologia Urbana	\N
4279	095	a	7.02.05.00-0	7.02.05.00-0 Sociologia Rural	\N
4280	095	a	sociologia	7.02.05.00-0 Sociologia Rural	\N
4281	095	a	rural	7.02.05.00-0 Sociologia Rural	\N
4282	095	a	7.02.06.00-7	7.02.06.00-7 Sociologia da Saúde	\N
4283	095	a	sociologia	7.02.06.00-7 Sociologia da Saúde	\N
4284	095	a	da	7.02.06.00-7 Sociologia da Saúde	\N
4285	095	a	saude	7.02.06.00-7 Sociologia da Saúde	\N
4286	095	a	7.02.07.00-3	7.02.07.00-3 Outras Sociologias Específicas	\N
4287	095	a	outras	7.02.07.00-3 Outras Sociologias Específicas	\N
4288	095	a	sociologias	7.02.07.00-3 Outras Sociologias Específicas	\N
4289	095	a	especificas	7.02.07.00-3 Outras Sociologias Específicas	\N
4290	095	a	7.03.00.00-3	7.03.00.00-3 Antropologia	\N
4291	095	a	antropologia	7.03.00.00-3 Antropologia	\N
4292	095	a	7.03.01.00-0	7.03.01.00-0 Teoria Antropológica	\N
4293	095	a	teoria	7.03.01.00-0 Teoria Antropológica	\N
4294	095	a	antropologica	7.03.01.00-0 Teoria Antropológica	\N
4295	095	a	7.03.02.00-6	7.03.02.00-6 Etnologia Indígena	\N
4296	095	a	etnologia	7.03.02.00-6 Etnologia Indígena	\N
4297	095	a	indigena	7.03.02.00-6 Etnologia Indígena	\N
4298	095	a	7.03.03.00-2	7.03.03.00-2 Antropologia Urbana	\N
4299	095	a	antropologia	7.03.03.00-2 Antropologia Urbana	\N
4300	095	a	urbana	7.03.03.00-2 Antropologia Urbana	\N
4301	095	a	7.03.04.00-9	7.03.04.00-9 Antropologia Rural	\N
4302	095	a	antropologia	7.03.04.00-9 Antropologia Rural	\N
4303	095	a	rural	7.03.04.00-9 Antropologia Rural	\N
4304	095	a	7.03.05.00-5	7.03.05.00-5 Antropologia das Populações Afro-Brasileiras	\N
4305	095	a	antropologia	7.03.05.00-5 Antropologia das Populações Afro-Brasileiras	\N
4306	095	a	das	7.03.05.00-5 Antropologia das Populações Afro-Brasileiras	\N
4307	095	a	populacoes	7.03.05.00-5 Antropologia das Populações Afro-Brasileiras	\N
4308	095	a	afro-brasileiras	7.03.05.00-5 Antropologia das Populações Afro-Brasileiras	\N
4309	095	a	7.04.00.00-8	7.04.00.00-8 Arqueologia	\N
4310	095	a	arqueologia	7.04.00.00-8 Arqueologia	\N
4311	095	a	7.04.01.00-4	7.04.01.00-4 Teoria e Método em Arqueologia	\N
4312	095	a	teoria	7.04.01.00-4 Teoria e Método em Arqueologia	\N
4313	095	a	metodo	7.04.01.00-4 Teoria e Método em Arqueologia	\N
4314	095	a	em	7.04.01.00-4 Teoria e Método em Arqueologia	\N
4315	095	a	arqueologia	7.04.01.00-4 Teoria e Método em Arqueologia	\N
4316	095	a	7.04.02.00-0	7.04.02.00-0 Arqueologia Pré-Histórica	\N
4317	095	a	arqueologia	7.04.02.00-0 Arqueologia Pré-Histórica	\N
4318	095	a	pre-historica	7.04.02.00-0 Arqueologia Pré-Histórica	\N
4319	095	a	7.04.03.00-7	7.04.03.00-7 Arqueologia Histórica	\N
4320	095	a	arqueologia	7.04.03.00-7 Arqueologia Histórica	\N
4321	095	a	historica	7.04.03.00-7 Arqueologia Histórica	\N
4322	095	a	7.05.00.00-2	7.05.00.00-2 História	\N
4323	095	a	historia	7.05.00.00-2 História	\N
4324	095	a	7.05.01.00-9	7.05.01.00-9 Teoria e Filosofia da História	\N
4325	095	a	teoria	7.05.01.00-9 Teoria e Filosofia da História	\N
4326	095	a	filosofia	7.05.01.00-9 Teoria e Filosofia da História	\N
4327	095	a	da	7.05.01.00-9 Teoria e Filosofia da História	\N
4328	095	a	historia	7.05.01.00-9 Teoria e Filosofia da História	\N
4329	095	a	7.05.02.00-5	7.05.02.00-5 História Antiga e Medieval	\N
4330	095	a	historia	7.05.02.00-5 História Antiga e Medieval	\N
4331	095	a	antiga	7.05.02.00-5 História Antiga e Medieval	\N
4332	095	a	medieval	7.05.02.00-5 História Antiga e Medieval	\N
4333	095	a	7.05.03.00-1	7.05.03.00-1 História Moderna e Contemporânea	\N
4334	095	a	historia	7.05.03.00-1 História Moderna e Contemporânea	\N
4335	095	a	moderna	7.05.03.00-1 História Moderna e Contemporânea	\N
4336	095	a	contemporanea	7.05.03.00-1 História Moderna e Contemporânea	\N
4337	095	a	7.05.04.00-8	7.05.04.00-8 História da América	\N
4338	095	a	historia	7.05.04.00-8 História da América	\N
4339	095	a	da	7.05.04.00-8 História da América	\N
4340	095	a	america	7.05.04.00-8 História da América	\N
4341	095	a	7.05.04.01-6	7.05.04.01-6 História dos Estados Unidos	\N
4342	095	a	historia	7.05.04.01-6 História dos Estados Unidos	\N
4343	095	a	dos	7.05.04.01-6 História dos Estados Unidos	\N
4344	095	a	estados	7.05.04.01-6 História dos Estados Unidos	\N
4345	095	a	unidos	7.05.04.01-6 História dos Estados Unidos	\N
4346	095	a	7.05.04.02-4	7.05.04.02-4 História Latino-Americana	\N
4347	095	a	historia	7.05.04.02-4 História Latino-Americana	\N
4348	095	a	latino-americana	7.05.04.02-4 História Latino-Americana	\N
4349	095	a	7.05.05.00-4	7.05.05.00-4 História do Brasil	\N
4350	095	a	historia	7.05.05.00-4 História do Brasil	\N
4351	095	a	do	7.05.05.00-4 História do Brasil	\N
4352	095	a	brasil	7.05.05.00-4 História do Brasil	\N
4353	095	a	7.05.05.01-2	7.05.05.01-2 História do Brasil Colônia	\N
4354	095	a	historia	7.05.05.01-2 História do Brasil Colônia	\N
4355	095	a	do	7.05.05.01-2 História do Brasil Colônia	\N
4356	095	a	brasil	7.05.05.01-2 História do Brasil Colônia	\N
4357	095	a	colonia	7.05.05.01-2 História do Brasil Colônia	\N
4358	095	a	7.05.05.02-0	7.05.05.02-0 História do Brasil Império	\N
4359	095	a	historia	7.05.05.02-0 História do Brasil Império	\N
4360	095	a	do	7.05.05.02-0 História do Brasil Império	\N
4361	095	a	brasil	7.05.05.02-0 História do Brasil Império	\N
4362	095	a	imperio	7.05.05.02-0 História do Brasil Império	\N
4363	095	a	7.05.05.03-9	7.05.05.03-9 História do Brasil República	\N
4364	095	a	historia	7.05.05.03-9 História do Brasil República	\N
4365	095	a	do	7.05.05.03-9 História do Brasil República	\N
4366	095	a	brasil	7.05.05.03-9 História do Brasil República	\N
4367	095	a	republica	7.05.05.03-9 História do Brasil República	\N
4368	095	a	7.05.05.04-7	7.05.05.04-7 História Regional do Brasil	\N
4369	095	a	historia	7.05.05.04-7 História Regional do Brasil	\N
4370	095	a	regional	7.05.05.04-7 História Regional do Brasil	\N
4371	095	a	do	7.05.05.04-7 História Regional do Brasil	\N
4372	095	a	brasil	7.05.05.04-7 História Regional do Brasil	\N
4373	095	a	7.05.06.00-0	7.05.06.00-0 História das Ciências	\N
4374	095	a	historia	7.05.06.00-0 História das Ciências	\N
4375	095	a	das	7.05.06.00-0 História das Ciências	\N
4376	095	a	ciencias	7.05.06.00-0 História das Ciências	\N
4377	095	a	7.06.00.00-7	7.06.00.00-7 Geografia	\N
4378	095	a	geografia	7.06.00.00-7 Geografia	\N
4379	095	a	7.06.01.00-3	7.06.01.00-3 Geografia Humana	\N
4380	095	a	geografia	7.06.01.00-3 Geografia Humana	\N
4381	095	a	humana	7.06.01.00-3 Geografia Humana	\N
4382	095	a	7.06.01.01-1	7.06.01.01-1 Geografia da População	\N
4383	095	a	geografia	7.06.01.01-1 Geografia da População	\N
4384	095	a	da	7.06.01.01-1 Geografia da População	\N
4385	095	a	populacao	7.06.01.01-1 Geografia da População	\N
4386	095	a	7.06.01.02-0	7.06.01.02-0 Geografia Agrária	\N
4387	095	a	geografia	7.06.01.02-0 Geografia Agrária	\N
4388	095	a	agraria	7.06.01.02-0 Geografia Agrária	\N
4389	095	a	7.06.01.03-8	7.06.01.03-8 Geografia Urbana	\N
4390	095	a	geografia	7.06.01.03-8 Geografia Urbana	\N
4391	095	a	urbana	7.06.01.03-8 Geografia Urbana	\N
4392	095	a	7.06.01.04-6	7.06.01.04-6 Geografia Econômica	\N
4393	095	a	geografia	7.06.01.04-6 Geografia Econômica	\N
4394	095	a	economica	7.06.01.04-6 Geografia Econômica	\N
4395	095	a	7.06.01.05-4	7.06.01.05-4 Geografia Política	\N
4396	095	a	geografia	7.06.01.05-4 Geografia Política	\N
4397	095	a	politica	7.06.01.05-4 Geografia Política	\N
4398	095	a	7.06.02.00-0	7.06.02.00-0 Geografia Regional	\N
4399	095	a	geografia	7.06.02.00-0 Geografia Regional	\N
4400	095	a	regional	7.06.02.00-0 Geografia Regional	\N
4401	095	a	7.06.02.01-8	7.06.02.01-8 Teoria do Desenvolvimento Regional	\N
4402	095	a	teoria	7.06.02.01-8 Teoria do Desenvolvimento Regional	\N
4403	095	a	do	7.06.02.01-8 Teoria do Desenvolvimento Regional	\N
4404	095	a	desenvolvimento	7.06.02.01-8 Teoria do Desenvolvimento Regional	\N
4405	095	a	regional	7.06.02.01-8 Teoria do Desenvolvimento Regional	\N
4406	095	a	7.06.02.02-6	7.06.02.02-6 Regionalização	\N
4407	095	a	regionalizacao	7.06.02.02-6 Regionalização	\N
4408	095	a	7.06.02.03-4	7.06.02.03-4 Análise Regional	\N
4409	095	a	analise	7.06.02.03-4 Análise Regional	\N
4410	095	a	regional	7.06.02.03-4 Análise Regional	\N
4411	095	a	7.07.00.00-1	7.07.00.00-1 Psicologia	\N
4412	095	a	psicologia	7.07.00.00-1 Psicologia	\N
4413	095	a	7.07.01.00-8	7.07.01.00-8 Fundamentos e Medidas da Psicologia	\N
4414	095	a	fundamentos	7.07.01.00-8 Fundamentos e Medidas da Psicologia	\N
4415	095	a	medidas	7.07.01.00-8 Fundamentos e Medidas da Psicologia	\N
4416	095	a	da	7.07.01.00-8 Fundamentos e Medidas da Psicologia	\N
4417	095	a	psicologia	7.07.01.00-8 Fundamentos e Medidas da Psicologia	\N
4418	095	a	7.07.01.01-6	7.07.01.01-6 História, Teorias e Sistemas em Psicologia	\N
4419	095	a	historia,	7.07.01.01-6 História, Teorias e Sistemas em Psicologia	\N
4420	095	a	teorias	7.07.01.01-6 História, Teorias e Sistemas em Psicologia	\N
4421	095	a	sistemas	7.07.01.01-6 História, Teorias e Sistemas em Psicologia	\N
4422	095	a	em	7.07.01.01-6 História, Teorias e Sistemas em Psicologia	\N
4423	095	a	psicologia	7.07.01.01-6 História, Teorias e Sistemas em Psicologia	\N
4424	095	a	7.07.01.02-4	7.07.01.02-4 Metodologia, Instrumentação e Equipamento em Psicologia	\N
4425	095	a	metodologia,	7.07.01.02-4 Metodologia, Instrumentação e Equipamento em Psicologia	\N
4426	095	a	instrumentacao	7.07.01.02-4 Metodologia, Instrumentação e Equipamento em Psicologia	\N
4427	095	a	equipamento	7.07.01.02-4 Metodologia, Instrumentação e Equipamento em Psicologia	\N
4428	095	a	em	7.07.01.02-4 Metodologia, Instrumentação e Equipamento em Psicologia	\N
4429	095	a	psicologia	7.07.01.02-4 Metodologia, Instrumentação e Equipamento em Psicologia	\N
4430	095	a	7.07.01.03-2	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4431	095	a	construcao	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4432	095	a	validade	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4433	095	a	de	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4434	095	a	testes,	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4435	095	a	escalas	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4436	095	a	outras	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4437	095	a	medidas	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4438	095	a	psicologicas	7.07.01.03-2 Construção e Validade de Testes, Escalas e Outras Medidas Psicológicas	\N
4439	095	a	7.07.01.04-0	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4440	095	a	tecnicas	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4441	095	a	de	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4442	095	a	processamento	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4443	095	a	estatistico,	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4444	095	a	matematico	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4445	095	a	computacional	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4446	095	a	em	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4447	095	a	psicologia	7.07.01.04-0 Técnicas de Processamento Estatístico, Matemático e Computacional em Psicologia	\N
4448	095	a	7.07.02.00-4	7.07.02.00-4 Psicologia Experimental	\N
4449	095	a	psicologia	7.07.02.00-4 Psicologia Experimental	\N
4450	095	a	experimental	7.07.02.00-4 Psicologia Experimental	\N
4451	095	a	7.07.02.01-2	7.07.02.01-2 Processos Perceptuais e Motores	\N
4452	095	a	processos	7.07.02.01-2 Processos Perceptuais e Motores	\N
4453	095	a	perceptuais	7.07.02.01-2 Processos Perceptuais e Motores	\N
4454	095	a	motores	7.07.02.01-2 Processos Perceptuais e Motores	\N
4455	095	a	7.07.02.02-0	7.07.02.02-0 Processos de Aprendizagem, Memória e Motivação	\N
4456	095	a	processos	7.07.02.02-0 Processos de Aprendizagem, Memória e Motivação	\N
4457	095	a	de	7.07.02.02-0 Processos de Aprendizagem, Memória e Motivação	\N
4458	095	a	aprendizagem,	7.07.02.02-0 Processos de Aprendizagem, Memória e Motivação	\N
4459	095	a	memoria	7.07.02.02-0 Processos de Aprendizagem, Memória e Motivação	\N
4460	095	a	motivacao	7.07.02.02-0 Processos de Aprendizagem, Memória e Motivação	\N
4461	095	a	7.07.02.03-9	7.07.02.03-9 Processos Cognitivos e Atencionais	\N
4462	095	a	processos	7.07.02.03-9 Processos Cognitivos e Atencionais	\N
4463	095	a	cognitivos	7.07.02.03-9 Processos Cognitivos e Atencionais	\N
4464	095	a	atencionais	7.07.02.03-9 Processos Cognitivos e Atencionais	\N
4465	095	a	7.07.02.04-7	7.07.02.04-7 Estados Subjetivos e Emoção	\N
4466	095	a	estados	7.07.02.04-7 Estados Subjetivos e Emoção	\N
4467	095	a	subjetivos	7.07.02.04-7 Estados Subjetivos e Emoção	\N
4468	095	a	emocao	7.07.02.04-7 Estados Subjetivos e Emoção	\N
4469	095	a	7.07.03.00-0	7.07.03.00-0 Psicologia Fisiológica	\N
4470	095	a	psicologia	7.07.03.00-0 Psicologia Fisiológica	\N
4471	095	a	fisiologica	7.07.03.00-0 Psicologia Fisiológica	\N
4472	095	a	7.07.03.01-9	7.07.03.01-9 Neurologia, Eletrofisiologia e Comportamento	\N
4473	095	a	neurologia,	7.07.03.01-9 Neurologia, Eletrofisiologia e Comportamento	\N
4474	095	a	eletrofisiologia	7.07.03.01-9 Neurologia, Eletrofisiologia e Comportamento	\N
4475	095	a	comportamento	7.07.03.01-9 Neurologia, Eletrofisiologia e Comportamento	\N
4476	095	a	7.07.03.02-7	7.07.03.02-7 Processos Psico-Fisiológicos	\N
4477	095	a	processos	7.07.03.02-7 Processos Psico-Fisiológicos	\N
4478	095	a	psico-fisiologicos	7.07.03.02-7 Processos Psico-Fisiológicos	\N
4479	095	a	7.07.03.03-5	7.07.03.03-5 Estimulação Elétrica e com Drogas; Comportamento	\N
4480	095	a	estimulacao	7.07.03.03-5 Estimulação Elétrica e com Drogas; Comportamento	\N
4481	095	a	eletrica	7.07.03.03-5 Estimulação Elétrica e com Drogas; Comportamento	\N
4482	095	a	com	7.07.03.03-5 Estimulação Elétrica e com Drogas; Comportamento	\N
4483	095	a	drogas;	7.07.03.03-5 Estimulação Elétrica e com Drogas; Comportamento	\N
4484	095	a	comportamento	7.07.03.03-5 Estimulação Elétrica e com Drogas; Comportamento	\N
4485	095	a	7.07.03.04-3	7.07.03.04-3 Psicobiologia	\N
4486	095	a	psicobiologia	7.07.03.04-3 Psicobiologia	\N
4487	095	a	7.07.04.00-7	7.07.04.00-7 Psicologia Comparativa	\N
4488	095	a	psicologia	7.07.04.00-7 Psicologia Comparativa	\N
4489	095	a	comparativa	7.07.04.00-7 Psicologia Comparativa	\N
4490	095	a	7.07.04.01-5	7.07.04.01-5 Estudos Naturalísticos do Comportamento Animal	\N
4491	095	a	estudos	7.07.04.01-5 Estudos Naturalísticos do Comportamento Animal	\N
4492	095	a	naturalisticos	7.07.04.01-5 Estudos Naturalísticos do Comportamento Animal	\N
4493	095	a	do	7.07.04.01-5 Estudos Naturalísticos do Comportamento Animal	\N
4494	095	a	comportamento	7.07.04.01-5 Estudos Naturalísticos do Comportamento Animal	\N
4495	095	a	animal	7.07.04.01-5 Estudos Naturalísticos do Comportamento Animal	\N
4496	095	a	7.07.04.02-3	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4497	095	a	mecanismos	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4498	095	a	instintivos	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4499	095	a	processos	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4500	095	a	sociais	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4501	095	a	em	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4502	095	a	animais	7.07.04.02-3 Mecanismos Instintivos e Processos Sociais em Animais	\N
4503	095	a	7.07.05.00-3	7.07.05.00-3 Psicologia Social	\N
4504	095	a	psicologia	7.07.05.00-3 Psicologia Social	\N
4505	095	a	social	7.07.05.00-3 Psicologia Social	\N
4506	095	a	7.07.05.01-1	7.07.05.01-1 Relações Interpessoais	\N
4507	095	a	relacoes	7.07.05.01-1 Relações Interpessoais	\N
4508	095	a	interpessoais	7.07.05.01-1 Relações Interpessoais	\N
4509	095	a	7.07.05.02-0	7.07.05.02-0 Processos Grupais e de Comunicação	\N
4510	095	a	processos	7.07.05.02-0 Processos Grupais e de Comunicação	\N
4511	095	a	grupais	7.07.05.02-0 Processos Grupais e de Comunicação	\N
4512	095	a	de	7.07.05.02-0 Processos Grupais e de Comunicação	\N
4513	095	a	comunicacao	7.07.05.02-0 Processos Grupais e de Comunicação	\N
4514	095	a	7.07.05.03-8	7.07.05.03-8 Papéis e Estruturas Sociais; Indivíduo	\N
4515	095	a	papeis	7.07.05.03-8 Papéis e Estruturas Sociais; Indivíduo	\N
4516	095	a	estruturas	7.07.05.03-8 Papéis e Estruturas Sociais; Indivíduo	\N
4517	095	a	sociais;	7.07.05.03-8 Papéis e Estruturas Sociais; Indivíduo	\N
4518	095	a	individuo	7.07.05.03-8 Papéis e Estruturas Sociais; Indivíduo	\N
4519	095	a	7.07.06.00-0	7.07.06.00-0 Psicologia Cognitiva	\N
4520	095	a	psicologia	7.07.06.00-0 Psicologia Cognitiva	\N
4521	095	a	cognitiva	7.07.06.00-0 Psicologia Cognitiva	\N
4522	095	a	7.07.07.00-6	7.07.07.00-6 Psicologia do Desenvolvimento Humano	\N
4523	095	a	psicologia	7.07.07.00-6 Psicologia do Desenvolvimento Humano	\N
4524	095	a	do	7.07.07.00-6 Psicologia do Desenvolvimento Humano	\N
4525	095	a	desenvolvimento	7.07.07.00-6 Psicologia do Desenvolvimento Humano	\N
4526	095	a	humano	7.07.07.00-6 Psicologia do Desenvolvimento Humano	\N
4527	095	a	7.07.07.01-4	7.07.07.01-4 Processos Perceptuais e Cognitivos; Desenvolvimento	\N
4528	095	a	processos	7.07.07.01-4 Processos Perceptuais e Cognitivos; Desenvolvimento	\N
4529	095	a	perceptuais	7.07.07.01-4 Processos Perceptuais e Cognitivos; Desenvolvimento	\N
4530	095	a	cognitivos;	7.07.07.01-4 Processos Perceptuais e Cognitivos; Desenvolvimento	\N
4531	095	a	desenvolvimento	7.07.07.01-4 Processos Perceptuais e Cognitivos; Desenvolvimento	\N
4532	095	a	7.07.07.02-2	7.07.07.02-2 Desenvolvimento Social e da Personalidade	\N
4533	095	a	desenvolvimento	7.07.07.02-2 Desenvolvimento Social e da Personalidade	\N
4534	095	a	social	7.07.07.02-2 Desenvolvimento Social e da Personalidade	\N
4535	095	a	da	7.07.07.02-2 Desenvolvimento Social e da Personalidade	\N
4536	095	a	personalidade	7.07.07.02-2 Desenvolvimento Social e da Personalidade	\N
4537	095	a	7.07.08.00-2	7.07.08.00-2 Psicologia do Ensino e da Aprendizagem	\N
4538	095	a	psicologia	7.07.08.00-2 Psicologia do Ensino e da Aprendizagem	\N
4539	095	a	do	7.07.08.00-2 Psicologia do Ensino e da Aprendizagem	\N
4540	095	a	ensino	7.07.08.00-2 Psicologia do Ensino e da Aprendizagem	\N
4541	095	a	da	7.07.08.00-2 Psicologia do Ensino e da Aprendizagem	\N
4542	095	a	aprendizagem	7.07.08.00-2 Psicologia do Ensino e da Aprendizagem	\N
4543	095	a	7.07.08.01-0	7.07.08.01-0 Planejamento Institucional	\N
4544	095	a	planejamento	7.07.08.01-0 Planejamento Institucional	\N
4545	095	a	institucional	7.07.08.01-0 Planejamento Institucional	\N
4546	095	a	7.07.08.02-9	7.07.08.02-9 Programação de Condições de Ensino	\N
4547	095	a	programacao	7.07.08.02-9 Programação de Condições de Ensino	\N
4548	095	a	de	7.07.08.02-9 Programação de Condições de Ensino	\N
4549	095	a	condicoes	7.07.08.02-9 Programação de Condições de Ensino	\N
4550	095	a	de	7.07.08.02-9 Programação de Condições de Ensino	\N
4551	095	a	ensino	7.07.08.02-9 Programação de Condições de Ensino	\N
4552	095	a	7.07.08.03-7	7.07.08.03-7 Treinamento de Pessoal	\N
4553	095	a	treinamento	7.07.08.03-7 Treinamento de Pessoal	\N
4554	095	a	de	7.07.08.03-7 Treinamento de Pessoal	\N
4555	095	a	pessoal	7.07.08.03-7 Treinamento de Pessoal	\N
4556	095	a	7.07.08.04-5	7.07.08.04-5 Aprendizagem e Desempenho Acadêmicos	\N
4557	095	a	aprendizagem	7.07.08.04-5 Aprendizagem e Desempenho Acadêmicos	\N
4558	095	a	desempenho	7.07.08.04-5 Aprendizagem e Desempenho Acadêmicos	\N
4559	095	a	academicos	7.07.08.04-5 Aprendizagem e Desempenho Acadêmicos	\N
4560	095	a	7.07.08.05-3	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4561	095	a	ensino	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4562	095	a	aprendizagem	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4563	095	a	na	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4564	095	a	sala	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4565	095	a	de	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4566	095	a	aula	7.07.08.05-3 Ensino e Aprendizagem na Sala de Aula	\N
4567	095	a	7.07.09.00-9	7.07.09.00-9 Psicologia do Trabalho e Organizacional	\N
4568	095	a	psicologia	7.07.09.00-9 Psicologia do Trabalho e Organizacional	\N
4569	095	a	do	7.07.09.00-9 Psicologia do Trabalho e Organizacional	\N
4570	095	a	trabalho	7.07.09.00-9 Psicologia do Trabalho e Organizacional	\N
4571	095	a	organizacional	7.07.09.00-9 Psicologia do Trabalho e Organizacional	\N
4572	095	a	7.07.09.01-7	7.07.09.01-7 Análise Institucional	\N
4573	095	a	analise	7.07.09.01-7 Análise Institucional	\N
4574	095	a	institucional	7.07.09.01-7 Análise Institucional	\N
4575	095	a	7.07.09.02-5	7.07.09.02-5 Recrutamento e Seleção de Pessoal	\N
4576	095	a	recrutamento	7.07.09.02-5 Recrutamento e Seleção de Pessoal	\N
4577	095	a	selecao	7.07.09.02-5 Recrutamento e Seleção de Pessoal	\N
4578	095	a	de	7.07.09.02-5 Recrutamento e Seleção de Pessoal	\N
4579	095	a	pessoal	7.07.09.02-5 Recrutamento e Seleção de Pessoal	\N
4580	095	a	7.07.09.03-3	7.07.09.03-3 Treinamento e Avaliação	\N
4581	095	a	treinamento	7.07.09.03-3 Treinamento e Avaliação	\N
4582	095	a	avaliacao	7.07.09.03-3 Treinamento e Avaliação	\N
4583	095	a	7.07.09.04-1	7.07.09.04-1 Fatores Humanos no Trabalho	\N
4584	095	a	fatores	7.07.09.04-1 Fatores Humanos no Trabalho	\N
4585	095	a	humanos	7.07.09.04-1 Fatores Humanos no Trabalho	\N
4586	095	a	no	7.07.09.04-1 Fatores Humanos no Trabalho	\N
4587	095	a	trabalho	7.07.09.04-1 Fatores Humanos no Trabalho	\N
4588	095	a	7.07.09.05-0	7.07.09.05-0 Planejamento Ambiental e Comportamento Humano	\N
4589	095	a	planejamento	7.07.09.05-0 Planejamento Ambiental e Comportamento Humano	\N
4590	095	a	ambiental	7.07.09.05-0 Planejamento Ambiental e Comportamento Humano	\N
4591	095	a	comportamento	7.07.09.05-0 Planejamento Ambiental e Comportamento Humano	\N
4592	095	a	humano	7.07.09.05-0 Planejamento Ambiental e Comportamento Humano	\N
4593	095	a	7.07.10.00-7	7.07.10.00-7 Tratamento e Prevenção Psicológica	\N
4594	095	a	tratamento	7.07.10.00-7 Tratamento e Prevenção Psicológica	\N
4595	095	a	prevencao	7.07.10.00-7 Tratamento e Prevenção Psicológica	\N
4596	095	a	psicologica	7.07.10.00-7 Tratamento e Prevenção Psicológica	\N
4597	095	a	7.07.10.01-5	7.07.10.01-5 Intervenção Terapêutica	\N
4598	095	a	intervencao	7.07.10.01-5 Intervenção Terapêutica	\N
4599	095	a	terapeutica	7.07.10.01-5 Intervenção Terapêutica	\N
4600	095	a	7.07.10.02-3	7.07.10.02-3 Programas de Atendimento Comunitário	\N
4601	095	a	programas	7.07.10.02-3 Programas de Atendimento Comunitário	\N
4602	095	a	de	7.07.10.02-3 Programas de Atendimento Comunitário	\N
4603	095	a	atendimento	7.07.10.02-3 Programas de Atendimento Comunitário	\N
4604	095	a	comunitario	7.07.10.02-3 Programas de Atendimento Comunitário	\N
4605	095	a	7.07.10.03-1	7.07.10.03-1 Treinamento e Reabilitação	\N
4606	095	a	treinamento	7.07.10.03-1 Treinamento e Reabilitação	\N
4607	095	a	reabilitacao	7.07.10.03-1 Treinamento e Reabilitação	\N
4608	095	a	7.07.10.04-0	7.07.10.04-0 Desvios da Conduta	\N
4609	095	a	desvios	7.07.10.04-0 Desvios da Conduta	\N
4610	095	a	da	7.07.10.04-0 Desvios da Conduta	\N
4611	095	a	conduta	7.07.10.04-0 Desvios da Conduta	\N
4612	095	a	7.07.10.05-8	7.07.10.05-8 Distúrbios da Linguagem	\N
4613	095	a	disturbios	7.07.10.05-8 Distúrbios da Linguagem	\N
4614	095	a	da	7.07.10.05-8 Distúrbios da Linguagem	\N
4615	095	a	linguagem	7.07.10.05-8 Distúrbios da Linguagem	\N
4616	095	a	7.07.10.06-6	7.07.10.06-6 Distúrbios Psicossomáticos	\N
4617	095	a	disturbios	7.07.10.06-6 Distúrbios Psicossomáticos	\N
4618	095	a	psicossomaticos	7.07.10.06-6 Distúrbios Psicossomáticos	\N
4619	095	a	7.08.00.00-6	7.08.00.00-6 Educação	\N
4620	095	a	educacao	7.08.00.00-6 Educação	\N
4621	095	a	7.08.01.00-2	7.08.01.00-2 Fundamentos da Educação	\N
4622	095	a	fundamentos	7.08.01.00-2 Fundamentos da Educação	\N
4623	095	a	da	7.08.01.00-2 Fundamentos da Educação	\N
4624	095	a	educacao	7.08.01.00-2 Fundamentos da Educação	\N
4625	095	a	7.08.01.01-0	7.08.01.01-0 Filosofia da Educação	\N
4626	095	a	filosofia	7.08.01.01-0 Filosofia da Educação	\N
4627	095	a	da	7.08.01.01-0 Filosofia da Educação	\N
4628	095	a	educacao	7.08.01.01-0 Filosofia da Educação	\N
4629	095	a	7.08.01.02-9	7.08.01.02-9 História da Educação	\N
4630	095	a	historia	7.08.01.02-9 História da Educação	\N
4631	095	a	da	7.08.01.02-9 História da Educação	\N
4632	095	a	educacao	7.08.01.02-9 História da Educação	\N
4633	095	a	7.08.01.03-7	7.08.01.03-7 Sociologia da Educação	\N
4634	095	a	sociologia	7.08.01.03-7 Sociologia da Educação	\N
4635	095	a	da	7.08.01.03-7 Sociologia da Educação	\N
4636	095	a	educacao	7.08.01.03-7 Sociologia da Educação	\N
4637	095	a	7.08.01.04-5	7.08.01.04-5 Antropologia Educacional	\N
4638	095	a	antropologia	7.08.01.04-5 Antropologia Educacional	\N
4639	095	a	educacional	7.08.01.04-5 Antropologia Educacional	\N
4640	095	a	7.08.01.05-3	7.08.01.05-3 Economia da Educação	\N
4641	095	a	economia	7.08.01.05-3 Economia da Educação	\N
4642	095	a	da	7.08.01.05-3 Economia da Educação	\N
4643	095	a	educacao	7.08.01.05-3 Economia da Educação	\N
4644	095	a	7.08.01.06-1	7.08.01.06-1 Psicologia Educacional	\N
4645	095	a	psicologia	7.08.01.06-1 Psicologia Educacional	\N
4646	095	a	educacional	7.08.01.06-1 Psicologia Educacional	\N
4647	095	a	7.08.02.00-9	7.08.02.00-9 Administração Educacional	\N
4648	095	a	administracao	7.08.02.00-9 Administração Educacional	\N
4649	095	a	educacional	7.08.02.00-9 Administração Educacional	\N
4650	095	a	7.08.02.01-7	7.08.02.01-7 Administração de Sistemas Educacionais	\N
4651	095	a	administracao	7.08.02.01-7 Administração de Sistemas Educacionais	\N
4652	095	a	de	7.08.02.01-7 Administração de Sistemas Educacionais	\N
4653	095	a	sistemas	7.08.02.01-7 Administração de Sistemas Educacionais	\N
4654	095	a	educacionais	7.08.02.01-7 Administração de Sistemas Educacionais	\N
4655	095	a	7.08.02.02-5	7.08.02.02-5 Administração de Unidades Educativas	\N
4656	095	a	administracao	7.08.02.02-5 Administração de Unidades Educativas	\N
4657	095	a	de	7.08.02.02-5 Administração de Unidades Educativas	\N
4658	095	a	unidades	7.08.02.02-5 Administração de Unidades Educativas	\N
4659	095	a	educativas	7.08.02.02-5 Administração de Unidades Educativas	\N
4660	095	a	7.08.03.00-5	7.08.03.00-5 Planejamento e Avaliação Educacional	\N
4661	095	a	planejamento	7.08.03.00-5 Planejamento e Avaliação Educacional	\N
4662	095	a	avaliacao	7.08.03.00-5 Planejamento e Avaliação Educacional	\N
4663	095	a	educacional	7.08.03.00-5 Planejamento e Avaliação Educacional	\N
4664	095	a	7.08.03.01-3	7.08.03.01-3 Política Educacional	\N
4665	095	a	politica	7.08.03.01-3 Política Educacional	\N
4666	095	a	educacional	7.08.03.01-3 Política Educacional	\N
4667	095	a	7.08.03.02-1	7.08.03.02-1 Planejamento Educacional	\N
4668	095	a	planejamento	7.08.03.02-1 Planejamento Educacional	\N
4669	095	a	educacional	7.08.03.02-1 Planejamento Educacional	\N
4670	095	a	7.08.03.03-0	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4671	095	a	avaliacao	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4672	095	a	de	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4673	095	a	sistemas,	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4674	095	a	instituicoes,	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4675	095	a	planos	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4676	095	a	programas	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4677	095	a	educacionais	7.08.03.03-0 Avaliação de Sistemas, Instituições, Planos e Programas Educacionais	\N
4678	095	a	7.08.04.00-1	7.08.04.00-1 Ensino-Aprendizagem	\N
4679	095	a	ensino-aprendizagem	7.08.04.00-1 Ensino-Aprendizagem	\N
4680	095	a	7.08.04.01-0	7.08.04.01-0 Teorias da Instrução	\N
4681	095	a	teorias	7.08.04.01-0 Teorias da Instrução	\N
4682	095	a	da	7.08.04.01-0 Teorias da Instrução	\N
4683	095	a	instrucao	7.08.04.01-0 Teorias da Instrução	\N
4684	095	a	7.08.04.02-8	7.08.04.02-8 Métodos e Técnicas de Ensino	\N
4685	095	a	metodos	7.08.04.02-8 Métodos e Técnicas de Ensino	\N
4686	095	a	tecnicas	7.08.04.02-8 Métodos e Técnicas de Ensino	\N
4687	095	a	de	7.08.04.02-8 Métodos e Técnicas de Ensino	\N
4688	095	a	ensino	7.08.04.02-8 Métodos e Técnicas de Ensino	\N
4689	095	a	7.08.04.03-6	7.08.04.03-6 Tecnologia Educacional	\N
4690	095	a	tecnologia	7.08.04.03-6 Tecnologia Educacional	\N
4691	095	a	educacional	7.08.04.03-6 Tecnologia Educacional	\N
4692	095	a	7.08.04.04-4	7.08.04.04-4 Avaliação da Aprendizagem	\N
4693	095	a	avaliacao	7.08.04.04-4 Avaliação da Aprendizagem	\N
4694	095	a	da	7.08.04.04-4 Avaliação da Aprendizagem	\N
4695	095	a	aprendizagem	7.08.04.04-4 Avaliação da Aprendizagem	\N
4696	095	a	7.08.05.00-8	7.08.05.00-8 Currículo	\N
4697	095	a	curriculo	7.08.05.00-8 Currículo	\N
4698	095	a	7.08.05.01-6	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4699	095	a	teoria	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4700	095	a	geral	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4701	095	a	de	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4702	095	a	planejamento	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4703	095	a	desenvolvimento	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4704	095	a	curricular	7.08.05.01-6 Teoria Geral de Planejamento e Desenvolvimento Curricular	\N
4705	095	a	7.08.05.02-4	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4706	095	a	curriculos	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4707	095	a	especificos	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4708	095	a	para	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4709	095	a	niveis	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4710	095	a	tipos	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4711	095	a	de	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4712	095	a	educacao	7.08.05.02-4 Currículos Específicos para Níveis e Tipos de Educação	\N
4713	095	a	7.08.06.00-4	7.08.06.00-4 Orientação e Aconselhamento	\N
4714	095	a	orientacao	7.08.06.00-4 Orientação e Aconselhamento	\N
4715	095	a	aconselhamento	7.08.06.00-4 Orientação e Aconselhamento	\N
4716	095	a	7.08.06.01-2	7.08.06.01-2 Orientação Educacional	\N
4717	095	a	orientacao	7.08.06.01-2 Orientação Educacional	\N
4718	095	a	educacional	7.08.06.01-2 Orientação Educacional	\N
4719	095	a	7.08.06.02-0	7.08.06.02-0 Orientação Vocacional	\N
4720	095	a	orientacao	7.08.06.02-0 Orientação Vocacional	\N
4721	095	a	vocacional	7.08.06.02-0 Orientação Vocacional	\N
4722	095	a	7.08.07.00-0	7.08.07.00-0 Tópicos Específicos de Educação	\N
4723	095	a	topicos	7.08.07.00-0 Tópicos Específicos de Educação	\N
4724	095	a	especificos	7.08.07.00-0 Tópicos Específicos de Educação	\N
4725	095	a	de	7.08.07.00-0 Tópicos Específicos de Educação	\N
4726	095	a	educacao	7.08.07.00-0 Tópicos Específicos de Educação	\N
4727	095	a	7.08.07.01-9	7.08.07.01-9 Educação de Adultos	\N
4728	095	a	educacao	7.08.07.01-9 Educação de Adultos	\N
4729	095	a	de	7.08.07.01-9 Educação de Adultos	\N
4730	095	a	adultos	7.08.07.01-9 Educação de Adultos	\N
4731	095	a	7.08.07.02-7	7.08.07.02-7 Educação Permanente	\N
4732	095	a	educacao	7.08.07.02-7 Educação Permanente	\N
4733	095	a	permanente	7.08.07.02-7 Educação Permanente	\N
4734	095	a	7.08.07.03-5	7.08.07.03-5 Educação Rural	\N
4735	095	a	educacao	7.08.07.03-5 Educação Rural	\N
4736	095	a	rural	7.08.07.03-5 Educação Rural	\N
4737	095	a	7.08.07.04-3	7.08.07.04-3 Educação em Periferias Urbanas	\N
4738	095	a	educacao	7.08.07.04-3 Educação em Periferias Urbanas	\N
4739	095	a	em	7.08.07.04-3 Educação em Periferias Urbanas	\N
4740	095	a	periferias	7.08.07.04-3 Educação em Periferias Urbanas	\N
4741	095	a	urbanas	7.08.07.04-3 Educação em Periferias Urbanas	\N
4742	095	a	7.08.07.05-1	7.08.07.05-1 Educação Especial	\N
4743	095	a	educacao	7.08.07.05-1 Educação Especial	\N
4744	095	a	especial	7.08.07.05-1 Educação Especial	\N
4745	095	a	7.08.07.06-0	7.08.07.06-0 Educação Pré-Escolar	\N
4746	095	a	educacao	7.08.07.06-0 Educação Pré-Escolar	\N
4747	095	a	pre-escolar	7.08.07.06-0 Educação Pré-Escolar	\N
4748	095	a	7.08.07.07-8	7.08.07.07-8 Ensino Profissionalizante	\N
4749	095	a	ensino	7.08.07.07-8 Ensino Profissionalizante	\N
4750	095	a	profissionalizante	7.08.07.07-8 Ensino Profissionalizante	\N
4751	095	a	7.09.00.00-0	7.09.00.00-0 Ciência Política	\N
4752	095	a	ciencia	7.09.00.00-0 Ciência Política	\N
4753	095	a	politica	7.09.00.00-0 Ciência Política	\N
4754	095	a	7.09.01.00-7	7.09.01.00-7 Teoria Política	\N
4755	095	a	teoria	7.09.01.00-7 Teoria Política	\N
4756	095	a	politica	7.09.01.00-7 Teoria Política	\N
4757	095	a	7.09.01.01-5	7.09.01.01-5 Teoria Política Clássica	\N
4758	095	a	teoria	7.09.01.01-5 Teoria Política Clássica	\N
4759	095	a	politica	7.09.01.01-5 Teoria Política Clássica	\N
4760	095	a	classica	7.09.01.01-5 Teoria Política Clássica	\N
4761	095	a	7.09.01.02-3	7.09.01.02-3 Teoria Política Medieval	\N
4762	095	a	teoria	7.09.01.02-3 Teoria Política Medieval	\N
4763	095	a	politica	7.09.01.02-3 Teoria Política Medieval	\N
4764	095	a	medieval	7.09.01.02-3 Teoria Política Medieval	\N
4765	095	a	7.09.01.03-1	7.09.01.03-1 Teoria Política Moderna	\N
4766	095	a	teoria	7.09.01.03-1 Teoria Política Moderna	\N
4767	095	a	politica	7.09.01.03-1 Teoria Política Moderna	\N
4768	095	a	moderna	7.09.01.03-1 Teoria Política Moderna	\N
4769	095	a	7.09.01.04-0	7.09.01.04-0 Teoria Política Contemporânea	\N
4770	095	a	teoria	7.09.01.04-0 Teoria Política Contemporânea	\N
4771	095	a	politica	7.09.01.04-0 Teoria Política Contemporânea	\N
4772	095	a	contemporanea	7.09.01.04-0 Teoria Política Contemporânea	\N
4773	095	a	7.09.02.00-3	7.09.02.00-3 Estado e Governo	\N
4774	095	a	estado	7.09.02.00-3 Estado e Governo	\N
4775	095	a	governo	7.09.02.00-3 Estado e Governo	\N
4776	095	a	7.09.02.01-1	7.09.02.01-1 Estrutura e Transformação do Estado	\N
4777	095	a	estrutura	7.09.02.01-1 Estrutura e Transformação do Estado	\N
4778	095	a	transformacao	7.09.02.01-1 Estrutura e Transformação do Estado	\N
4779	095	a	do	7.09.02.01-1 Estrutura e Transformação do Estado	\N
4780	095	a	estado	7.09.02.01-1 Estrutura e Transformação do Estado	\N
4781	095	a	7.09.02.02-0	7.09.02.02-0 Sistemas Governamentais Comparados	\N
4782	095	a	sistemas	7.09.02.02-0 Sistemas Governamentais Comparados	\N
4783	095	a	governamentais	7.09.02.02-0 Sistemas Governamentais Comparados	\N
4784	095	a	comparados	7.09.02.02-0 Sistemas Governamentais Comparados	\N
4785	095	a	7.09.02.03-8	7.09.02.03-8 Relações Intergovernamentais	\N
4786	095	a	relacoes	7.09.02.03-8 Relações Intergovernamentais	\N
4787	095	a	intergovernamentais	7.09.02.03-8 Relações Intergovernamentais	\N
4788	095	a	7.09.02.04-6	7.09.02.04-6 Estudos do Poder Local	\N
4789	095	a	estudos	7.09.02.04-6 Estudos do Poder Local	\N
4790	095	a	do	7.09.02.04-6 Estudos do Poder Local	\N
4791	095	a	poder	7.09.02.04-6 Estudos do Poder Local	\N
4792	095	a	local	7.09.02.04-6 Estudos do Poder Local	\N
4793	095	a	7.09.02.05-4	7.09.02.05-4 Instituições Governamentais Específicas	\N
4794	095	a	instituicoes	7.09.02.05-4 Instituições Governamentais Específicas	\N
4795	095	a	governamentais	7.09.02.05-4 Instituições Governamentais Específicas	\N
4796	095	a	especificas	7.09.02.05-4 Instituições Governamentais Específicas	\N
4797	095	a	7.09.03.00-0	7.09.03.00-0 Comportamento Político	\N
4798	095	a	comportamento	7.09.03.00-0 Comportamento Político	\N
4799	095	a	politico	7.09.03.00-0 Comportamento Político	\N
4800	095	a	7.09.03.01-8	7.09.03.01-8 Estudos Eleitorais e Partidos Políticos	\N
4801	095	a	estudos	7.09.03.01-8 Estudos Eleitorais e Partidos Políticos	\N
4802	095	a	eleitorais	7.09.03.01-8 Estudos Eleitorais e Partidos Políticos	\N
4803	095	a	partidos	7.09.03.01-8 Estudos Eleitorais e Partidos Políticos	\N
4804	095	a	politicos	7.09.03.01-8 Estudos Eleitorais e Partidos Políticos	\N
4805	095	a	7.09.03.02-6	7.09.03.02-6 Atitude e Ideologias Políticas	\N
4806	095	a	atitude	7.09.03.02-6 Atitude e Ideologias Políticas	\N
4807	095	a	ideologias	7.09.03.02-6 Atitude e Ideologias Políticas	\N
4808	095	a	politicas	7.09.03.02-6 Atitude e Ideologias Políticas	\N
4809	095	a	7.09.03.03-4	7.09.03.03-4 Conflitos e Coalizões Políticas	\N
4810	095	a	conflitos	7.09.03.03-4 Conflitos e Coalizões Políticas	\N
4811	095	a	coalizoes	7.09.03.03-4 Conflitos e Coalizões Políticas	\N
4812	095	a	politicas	7.09.03.03-4 Conflitos e Coalizões Políticas	\N
4813	095	a	7.09.03.04-2	7.09.03.04-2 Comportamento Legislativo	\N
4814	095	a	comportamento	7.09.03.04-2 Comportamento Legislativo	\N
4815	095	a	legislativo	7.09.03.04-2 Comportamento Legislativo	\N
4816	095	a	7.09.03.05-0	7.09.03.05-0 Classes Sociais e Grupos de Interesse	\N
4817	095	a	classes	7.09.03.05-0 Classes Sociais e Grupos de Interesse	\N
4818	095	a	sociais	7.09.03.05-0 Classes Sociais e Grupos de Interesse	\N
4819	095	a	grupos	7.09.03.05-0 Classes Sociais e Grupos de Interesse	\N
4820	095	a	de	7.09.03.05-0 Classes Sociais e Grupos de Interesse	\N
4821	095	a	interesse	7.09.03.05-0 Classes Sociais e Grupos de Interesse	\N
4822	095	a	7.09.04.00-6	7.09.04.00-6 Políticas Públicas	\N
4823	095	a	politicas	7.09.04.00-6 Políticas Públicas	\N
4824	095	a	publicas	7.09.04.00-6 Políticas Públicas	\N
4825	095	a	7.09.04.01-4	7.09.04.01-4 Análise do Processo Decisório	\N
4826	095	a	analise	7.09.04.01-4 Análise do Processo Decisório	\N
4827	095	a	do	7.09.04.01-4 Análise do Processo Decisório	\N
4828	095	a	processo	7.09.04.01-4 Análise do Processo Decisório	\N
4829	095	a	decisorio	7.09.04.01-4 Análise do Processo Decisório	\N
4830	095	a	7.09.04.02-2	7.09.04.02-2 Análise Institucional	\N
4831	095	a	analise	7.09.04.02-2 Análise Institucional	\N
4832	095	a	institucional	7.09.04.02-2 Análise Institucional	\N
4833	095	a	7.09.04.03-0	7.09.04.03-0 Técnicas de Antecipação	\N
4834	095	a	tecnicas	7.09.04.03-0 Técnicas de Antecipação	\N
4835	095	a	de	7.09.04.03-0 Técnicas de Antecipação	\N
4836	095	a	antecipacao	7.09.04.03-0 Técnicas de Antecipação	\N
4837	095	a	7.09.05.00-2	7.09.05.00-2 Política Internacional	\N
4838	095	a	politica	7.09.05.00-2 Política Internacional	\N
4839	095	a	internacional	7.09.05.00-2 Política Internacional	\N
4840	095	a	7.09.05.01-0	7.09.05.01-0 Política Externa do Brasil	\N
4841	095	a	politica	7.09.05.01-0 Política Externa do Brasil	\N
4842	095	a	externa	7.09.05.01-0 Política Externa do Brasil	\N
4843	095	a	do	7.09.05.01-0 Política Externa do Brasil	\N
4844	095	a	brasil	7.09.05.01-0 Política Externa do Brasil	\N
4845	095	a	7.09.05.02-9	7.09.05.02-9 Organizações Internacionais	\N
4846	095	a	organizacoes	7.09.05.02-9 Organizações Internacionais	\N
4847	095	a	internacionais	7.09.05.02-9 Organizações Internacionais	\N
4848	095	a	7.09.05.03-7	7.09.05.03-7 Integração Internacional, Conflito, Guerra e Paz	\N
4849	095	a	integracao	7.09.05.03-7 Integração Internacional, Conflito, Guerra e Paz	\N
4850	095	a	internacional,	7.09.05.03-7 Integração Internacional, Conflito, Guerra e Paz	\N
4851	095	a	conflito,	7.09.05.03-7 Integração Internacional, Conflito, Guerra e Paz	\N
4852	095	a	guerra	7.09.05.03-7 Integração Internacional, Conflito, Guerra e Paz	\N
4853	095	a	paz	7.09.05.03-7 Integração Internacional, Conflito, Guerra e Paz	\N
4854	095	a	7.09.05.04-5	7.09.05.04-5 Relações Internacionais, Bilaterais e Multilaterais	\N
4855	095	a	relacoes	7.09.05.04-5 Relações Internacionais, Bilaterais e Multilaterais	\N
4856	095	a	internacionais,	7.09.05.04-5 Relações Internacionais, Bilaterais e Multilaterais	\N
4857	095	a	bilaterais	7.09.05.04-5 Relações Internacionais, Bilaterais e Multilaterais	\N
4858	095	a	multilaterais	7.09.05.04-5 Relações Internacionais, Bilaterais e Multilaterais	\N
4859	095	a	7.10.00.00-3	7.10.00.00-3 Teologia	\N
4860	095	a	teologia	7.10.00.00-3 Teologia	\N
4861	095	a	7.10.01.00-0	7.10.01.00-0 História da Teologia	\N
4862	095	a	historia	7.10.01.00-0 História da Teologia	\N
4863	095	a	da	7.10.01.00-0 História da Teologia	\N
4864	095	a	teologia	7.10.01.00-0 História da Teologia	\N
4865	095	a	7.10.02.00-6	7.10.02.00-6 Teologia Moral	\N
4866	095	a	teologia	7.10.02.00-6 Teologia Moral	\N
4867	095	a	moral	7.10.02.00-6 Teologia Moral	\N
4868	095	a	7.10.03.00-2	7.10.03.00-2 Teologia Sistemática	\N
4869	095	a	teologia	7.10.03.00-2 Teologia Sistemática	\N
4870	095	a	sistematica	7.10.03.00-2 Teologia Sistemática	\N
4871	095	a	7.10.04.00-9	7.10.04.00-9 Teologia Pastoral	\N
4872	095	a	teologia	7.10.04.00-9 Teologia Pastoral	\N
4873	095	a	pastoral	7.10.04.00-9 Teologia Pastoral	\N
4874	095	a	8.00.00.00-2	8.00.00.00-2 Lingüística, Letras e Artes	\N
4875	095	a	linguistica,	8.00.00.00-2 Lingüística, Letras e Artes	\N
4876	095	a	letras	8.00.00.00-2 Lingüística, Letras e Artes	\N
4877	095	a	artes	8.00.00.00-2 Lingüística, Letras e Artes	\N
4878	095	a	8.01.00.00-7	8.01.00.00-7 Lingüística	\N
4879	095	a	linguistica	8.01.00.00-7 Lingüística	\N
4880	095	a	8.01.01.00-3	8.01.01.00-3 Teoria e Análise Lingüística	\N
4881	095	a	teoria	8.01.01.00-3 Teoria e Análise Lingüística	\N
4882	095	a	analise	8.01.01.00-3 Teoria e Análise Lingüística	\N
4883	095	a	linguistica	8.01.01.00-3 Teoria e Análise Lingüística	\N
4884	095	a	8.01.02.00-0	8.01.02.00-0 Fisiologia da Linguagem	\N
4885	095	a	fisiologia	8.01.02.00-0 Fisiologia da Linguagem	\N
4886	095	a	da	8.01.02.00-0 Fisiologia da Linguagem	\N
4887	095	a	linguagem	8.01.02.00-0 Fisiologia da Linguagem	\N
4888	095	a	8.01.03.00-6	8.01.03.00-6 Lingüística Histórica	\N
4889	095	a	linguistica	8.01.03.00-6 Lingüística Histórica	\N
4890	095	a	historica	8.01.03.00-6 Lingüística Histórica	\N
4891	095	a	8.01.04.00-2	8.01.04.00-2 Sociolingüística e Dialetologia	\N
4892	095	a	sociolinguistica	8.01.04.00-2 Sociolingüística e Dialetologia	\N
4893	095	a	dialetologia	8.01.04.00-2 Sociolingüística e Dialetologia	\N
4894	095	a	8.01.05.00-9	8.01.05.00-9 Psicolingüística	\N
4895	095	a	psicolinguistica	8.01.05.00-9 Psicolingüística	\N
4896	095	a	8.01.06.00-5	8.01.06.00-5 Lingüística Aplicada	\N
4897	095	a	linguistica	8.01.06.00-5 Lingüística Aplicada	\N
4898	095	a	aplicada	8.01.06.00-5 Lingüística Aplicada	\N
4899	095	a	8.02.00.00-1	8.02.00.00-1 Letras	\N
4900	095	a	letras	8.02.00.00-1 Letras	\N
4901	095	a	8.02.01.00-8	8.02.01.00-8 Língua Portuguesa	\N
4902	095	a	lingua	8.02.01.00-8 Língua Portuguesa	\N
4903	095	a	portuguesa	8.02.01.00-8 Língua Portuguesa	\N
4904	095	a	8.02.02.00-4	8.02.02.00-4 Línguas Estrangeiras Modernas	\N
4905	095	a	linguas	8.02.02.00-4 Línguas Estrangeiras Modernas	\N
4906	095	a	estrangeiras	8.02.02.00-4 Línguas Estrangeiras Modernas	\N
4907	095	a	modernas	8.02.02.00-4 Línguas Estrangeiras Modernas	\N
4908	095	a	8.02.03.00-0	8.02.03.00-0 Línguas Clássicas	\N
4909	095	a	linguas	8.02.03.00-0 Línguas Clássicas	\N
4910	095	a	classicas	8.02.03.00-0 Línguas Clássicas	\N
4911	095	a	8.02.04.00-7	8.02.04.00-7 Línguas Indígenas	\N
4912	095	a	linguas	8.02.04.00-7 Línguas Indígenas	\N
4913	095	a	indigenas	8.02.04.00-7 Línguas Indígenas	\N
4914	095	a	8.02.05.00-3	8.02.05.00-3 Teoria Literária	\N
4915	095	a	teoria	8.02.05.00-3 Teoria Literária	\N
4916	095	a	literaria	8.02.05.00-3 Teoria Literária	\N
4917	095	a	8.02.06.00-0	8.02.06.00-0 Literatura Brasileira	\N
4918	095	a	literatura	8.02.06.00-0 Literatura Brasileira	\N
4919	095	a	brasileira	8.02.06.00-0 Literatura Brasileira	\N
4920	095	a	8.02.07.00-6	8.02.07.00-6 Outras Literaturas Vernáculas	\N
4921	095	a	outras	8.02.07.00-6 Outras Literaturas Vernáculas	\N
4922	095	a	literaturas	8.02.07.00-6 Outras Literaturas Vernáculas	\N
4923	095	a	vernaculas	8.02.07.00-6 Outras Literaturas Vernáculas	\N
4924	095	a	8.02.08.00-2	8.02.08.00-2 Literaturas Estrangeiras Modernas	\N
4925	095	a	literaturas	8.02.08.00-2 Literaturas Estrangeiras Modernas	\N
4926	095	a	estrangeiras	8.02.08.00-2 Literaturas Estrangeiras Modernas	\N
4927	095	a	modernas	8.02.08.00-2 Literaturas Estrangeiras Modernas	\N
4928	095	a	8.02.09.00-9	8.02.09.00-9 Literaturas Clássicas	\N
4929	095	a	literaturas	8.02.09.00-9 Literaturas Clássicas	\N
4930	095	a	classicas	8.02.09.00-9 Literaturas Clássicas	\N
4931	095	a	8.02.10.00-7	8.02.10.00-7 Literatura Comparada	\N
4932	095	a	literatura	8.02.10.00-7 Literatura Comparada	\N
4933	095	a	comparada	8.02.10.00-7 Literatura Comparada	\N
4934	095	a	8.03.00.00-6	8.03.00.00-6 Artes	\N
4935	095	a	artes	8.03.00.00-6 Artes	\N
4936	095	a	8.03.01.00-2	8.03.01.00-2 Fundamentos e Crítica das Artes	\N
4937	095	a	fundamentos	8.03.01.00-2 Fundamentos e Crítica das Artes	\N
4938	095	a	critica	8.03.01.00-2 Fundamentos e Crítica das Artes	\N
4939	095	a	das	8.03.01.00-2 Fundamentos e Crítica das Artes	\N
4940	095	a	artes	8.03.01.00-2 Fundamentos e Crítica das Artes	\N
4941	095	a	8.03.01.01-0	8.03.01.01-0 Teoria da Arte	\N
4942	095	a	teoria	8.03.01.01-0 Teoria da Arte	\N
4943	095	a	da	8.03.01.01-0 Teoria da Arte	\N
4944	095	a	arte	8.03.01.01-0 Teoria da Arte	\N
4945	095	a	8.03.01.02-9	8.03.01.02-9 História da Arte	\N
4946	095	a	historia	8.03.01.02-9 História da Arte	\N
4947	095	a	da	8.03.01.02-9 História da Arte	\N
4948	095	a	arte	8.03.01.02-9 História da Arte	\N
4949	095	a	8.03.01.03-7	8.03.01.03-7 Crítica da Arte	\N
4950	095	a	critica	8.03.01.03-7 Crítica da Arte	\N
4951	095	a	da	8.03.01.03-7 Crítica da Arte	\N
4952	095	a	arte	8.03.01.03-7 Crítica da Arte	\N
4953	095	a	8.03.02.00-9	8.03.02.00-9 Artes Plásticas	\N
4954	095	a	artes	8.03.02.00-9 Artes Plásticas	\N
4955	095	a	plasticas	8.03.02.00-9 Artes Plásticas	\N
4956	095	a	8.03.02.01-7	8.03.02.01-7 Pintura	\N
4957	095	a	pintura	8.03.02.01-7 Pintura	\N
4958	095	a	8.03.02.02-5	8.03.02.02-5 Desenho	\N
4959	095	a	desenho	8.03.02.02-5 Desenho	\N
4960	095	a	8.03.02.03-3	8.03.02.03-3 Gravura	\N
4961	095	a	gravura	8.03.02.03-3 Gravura	\N
4962	095	a	8.03.02.04-1	8.03.02.04-1 Escultura	\N
4963	095	a	escultura	8.03.02.04-1 Escultura	\N
4964	095	a	8.03.02.05-0	8.03.02.05-0 Cerâmica	\N
4965	095	a	ceramica	8.03.02.05-0 Cerâmica	\N
4966	095	a	8.03.02.06-8	8.03.02.06-8 Tecelagem	\N
4967	095	a	tecelagem	8.03.02.06-8 Tecelagem	\N
4968	095	a	8.03.03.00-5	8.03.03.00-5 Música	\N
4970	095	a	8.03.03.01-3	8.03.03.01-3 Regência	\N
4971	095	a	regencia	8.03.03.01-3 Regência	\N
4972	095	a	8.03.03.02-1	8.03.03.02-1 Instrumentação Musical	\N
4973	095	a	instrumentacao	8.03.03.02-1 Instrumentação Musical	\N
4974	095	a	musical	8.03.03.02-1 Instrumentação Musical	\N
4975	095	a	8.03.03.03-0	8.03.03.03-0 Composição Musical	\N
4976	095	a	composicao	8.03.03.03-0 Composição Musical	\N
4977	095	a	musical	8.03.03.03-0 Composição Musical	\N
4978	095	a	8.03.03.04-8	8.03.03.04-8 Canto	\N
4979	095	a	canto	8.03.03.04-8 Canto	\N
4980	095	a	8.03.04.00-1	8.03.04.00-1 Dança	\N
4981	095	a	danca	8.03.04.00-1 Dança	\N
4982	095	a	8.03.04.01-0	8.03.04.01-0 Execução da Dança	\N
4983	095	a	execucao	8.03.04.01-0 Execução da Dança	\N
4984	095	a	da	8.03.04.01-0 Execução da Dança	\N
4985	095	a	danca	8.03.04.01-0 Execução da Dança	\N
4986	095	a	8.03.04.02-8	8.03.04.02-8 Coreografia	\N
4987	095	a	coreografia	8.03.04.02-8 Coreografia	\N
4988	095	a	8.03.05.00-8	8.03.05.00-8 Teatro	\N
4989	095	a	teatro	8.03.05.00-8 Teatro	\N
4990	095	a	8.03.05.01-6	8.03.05.01-6 Dramaturgia	\N
4991	095	a	dramaturgia	8.03.05.01-6 Dramaturgia	\N
4992	095	a	8.03.05.02-4	8.03.05.02-4 Direção Teatral	\N
4993	095	a	direcao	8.03.05.02-4 Direção Teatral	\N
4994	095	a	teatral	8.03.05.02-4 Direção Teatral	\N
4995	095	a	8.03.05.03-2	8.03.05.03-2 Cenografia	\N
4996	095	a	cenografia	8.03.05.03-2 Cenografia	\N
4997	095	a	8.03.05.04-0	8.03.05.04-0 Interpretação Teatral	\N
4998	095	a	interpretacao	8.03.05.04-0 Interpretação Teatral	\N
4999	095	a	teatral	8.03.05.04-0 Interpretação Teatral	\N
5000	095	a	8.03.06.00-4	8.03.06.00-4 Ópera	\N
5001	095	a	opera	8.03.06.00-4 Ópera	\N
5002	095	a	8.03.07.00-0	8.03.07.00-0 Fotografia	\N
5003	095	a	fotografia	8.03.07.00-0 Fotografia	\N
5004	095	a	8.03.08.00-7	8.03.08.00-7 Cinema	\N
5005	095	a	cinema	8.03.08.00-7 Cinema	\N
5006	095	a	8.03.08.01-5	8.03.08.01-5 Administração e Produção de Filmes	\N
5007	095	a	administracao	8.03.08.01-5 Administração e Produção de Filmes	\N
5008	095	a	producao	8.03.08.01-5 Administração e Produção de Filmes	\N
5009	095	a	de	8.03.08.01-5 Administração e Produção de Filmes	\N
5010	095	a	filmes	8.03.08.01-5 Administração e Produção de Filmes	\N
5011	095	a	8.03.08.02-3	8.03.08.02-3 Roteiro e Direção Cinematográficos	\N
5012	095	a	roteiro	8.03.08.02-3 Roteiro e Direção Cinematográficos	\N
5013	095	a	direcao	8.03.08.02-3 Roteiro e Direção Cinematográficos	\N
5014	095	a	cinematograficos	8.03.08.02-3 Roteiro e Direção Cinematográficos	\N
5015	095	a	8.03.08.03-1	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5016	095	a	tecnicas	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5017	095	a	de	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5018	095	a	registro	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5019	095	a	processamento	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5020	095	a	de	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5021	095	a	filmes	8.03.08.03-1 Técnicas de Registro e Processamento de Filmes	\N
5022	095	a	8.03.08.04-0	8.03.08.04-0 Interpretação Cinematográfica	\N
5023	095	a	interpretacao	8.03.08.04-0 Interpretação Cinematográfica	\N
5024	095	a	cinematografica	8.03.08.04-0 Interpretação Cinematográfica	\N
5025	095	a	8.03.09.00-3	8.03.09.00-3 Artes do Vídeo	\N
5026	095	a	artes	8.03.09.00-3 Artes do Vídeo	\N
5027	095	a	do	8.03.09.00-3 Artes do Vídeo	\N
5028	095	a	video	8.03.09.00-3 Artes do Vídeo	\N
5029	095	a	8.03.10.00-1	8.03.10.00-1 Educação Artística	\N
5030	095	a	educacao	8.03.10.00-1 Educação Artística	\N
5031	095	a	artistica	8.03.10.00-1 Educação Artística	\N
5032	095	a	9.00.00.00-5	9.00.00.00-5 Outros	\N
5033	095	a	outros	9.00.00.00-5 Outros	\N
5034	095	a	9.01.00.00-0	9.01.00.00-0 Administração Hospitalar	\N
5035	095	a	administracao	9.01.00.00-0 Administração Hospitalar	\N
5036	095	a	hospitalar	9.01.00.00-0 Administração Hospitalar	\N
5037	095	a	9.02.00.00-4	9.02.00.00-4 Administração Rural	\N
5038	095	a	administracao	9.02.00.00-4 Administração Rural	\N
5039	095	a	rural	9.02.00.00-4 Administração Rural	\N
5040	095	a	9.03.00.00-9	9.03.00.00-9 Carreira Militar	\N
5041	095	a	carreira	9.03.00.00-9 Carreira Militar	\N
5042	095	a	militar	9.03.00.00-9 Carreira Militar	\N
5043	095	a	9.04.00.00-3	9.04.00.00-3 Carreira Religiosa	\N
5044	095	a	carreira	9.04.00.00-3 Carreira Religiosa	\N
5045	095	a	religiosa	9.04.00.00-3 Carreira Religiosa	\N
5046	095	a	9.05.00.00-8	9.05.00.00-8 Ciências	\N
5047	095	a	ciencias	9.05.00.00-8 Ciências	\N
5048	095	a	9.06.00.00-2	9.06.00.00-2 Biomedicina	\N
5049	095	a	biomedicina	9.06.00.00-2 Biomedicina	\N
5050	095	a	9.07.00.00-7	9.07.00.00-7 Ciências Atuariais	\N
5051	095	a	ciencias	9.07.00.00-7 Ciências Atuariais	\N
5052	095	a	atuariais	9.07.00.00-7 Ciências Atuariais	\N
5053	095	a	9.08.00.00-1	9.08.00.00-1 Ciências Sociais	\N
5054	095	a	ciencias	9.08.00.00-1 Ciências Sociais	\N
5055	095	a	sociais	9.08.00.00-1 Ciências Sociais	\N
5056	095	a	9.09.00.00-6	9.09.00.00-6 Decoração	\N
5057	095	a	decoracao	9.09.00.00-6 Decoração	\N
5058	095	a	9.10.00.00-9	9.10.00.00-9 Desenho de Moda	\N
5059	095	a	desenho	9.10.00.00-9 Desenho de Moda	\N
5060	095	a	de	9.10.00.00-9 Desenho de Moda	\N
5061	095	a	moda	9.10.00.00-9 Desenho de Moda	\N
5062	095	a	9.11.00.00-3	9.11.00.00-3 Desenho de Projetos	\N
5063	095	a	desenho	9.11.00.00-3 Desenho de Projetos	\N
5064	095	a	de	9.11.00.00-3 Desenho de Projetos	\N
5065	095	a	projetos	9.11.00.00-3 Desenho de Projetos	\N
5066	095	a	9.12.00.00-8	9.12.00.00-8 Diplomacia	\N
5067	095	a	diplomacia	9.12.00.00-8 Diplomacia	\N
5068	095	a	9.13.00.00-2	9.13.00.00-2 Engenharia de Agrimensura	\N
5069	095	a	engenharia	9.13.00.00-2 Engenharia de Agrimensura	\N
5070	095	a	de	9.13.00.00-2 Engenharia de Agrimensura	\N
5071	095	a	agrimensura	9.13.00.00-2 Engenharia de Agrimensura	\N
5072	095	a	9.14.00.00-7	9.14.00.00-7 Engenharia Cartográfica	\N
5073	095	a	engenharia	9.14.00.00-7 Engenharia Cartográfica	\N
5074	095	a	cartografica	9.14.00.00-7 Engenharia Cartográfica	\N
5075	095	a	9.15.00.00-1	9.15.00.00-1 Engenharia de Armamentos	\N
5076	095	a	engenharia	9.15.00.00-1 Engenharia de Armamentos	\N
5077	095	a	de	9.15.00.00-1 Engenharia de Armamentos	\N
5078	095	a	armamentos	9.15.00.00-1 Engenharia de Armamentos	\N
5079	095	a	9.16.00.00-6	9.16.00.00-6 Engenharia Mecatrônica	\N
5080	095	a	engenharia	9.16.00.00-6 Engenharia Mecatrônica	\N
5081	095	a	mecatronica	9.16.00.00-6 Engenharia Mecatrônica	\N
5082	095	a	9.17.00.00-0	9.17.00.00-0 Engenharia Têxtil	\N
5083	095	a	engenharia	9.17.00.00-0 Engenharia Têxtil	\N
5084	095	a	textil	9.17.00.00-0 Engenharia Têxtil	\N
5085	095	a	9.18.00.00-5	9.18.00.00-5 Estudos Sociais	\N
5086	095	a	estudos	9.18.00.00-5 Estudos Sociais	\N
5087	095	a	sociais	9.18.00.00-5 Estudos Sociais	\N
5088	095	a	9.19.00.00-0	9.19.00.00-0 História Natural	\N
5089	095	a	historia	9.19.00.00-0 História Natural	\N
5090	095	a	natural	9.19.00.00-0 História Natural	\N
5091	095	a	9.20.00.00-2	9.20.00.00-2 Química Industrial	\N
5092	095	a	quimica	9.20.00.00-2 Química Industrial	\N
5093	095	a	industrial	9.20.00.00-2 Química Industrial	\N
5094	095	a	9.21.00.00-7	9.21.00.00-7 Relações Internacionais	\N
5095	095	a	relacoes	9.21.00.00-7 Relações Internacionais	\N
5096	095	a	internacionais	9.21.00.00-7 Relações Internacionais	\N
5097	095	a	9.22.00.00-1	9.22.00.00-1 Relações Publicas	\N
5098	095	a	relacoes	9.22.00.00-1 Relações Publicas	\N
5099	095	a	publicas	9.22.00.00-1 Relações Publicas	\N
5100	095	a	9.23.00.00-6	9.23.00.00-6 Secretariado Executivo	\N
5101	095	a	secretariado	9.23.00.00-6 Secretariado Executivo	\N
5102	095	a	executivo	9.23.00.00-6 Secretariado Executivo	\N
\.


--
-- TOC entry 2680 (class 0 OID 0)
-- Dependencies: 197
-- Name: biblio_idx_autocomplete_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('biblio_idx_autocomplete_id_seq', 5103, false);


--
-- TOC entry 2578 (class 0 OID 16632)
-- Dependencies: 198 2636
-- Data for Name: biblio_idx_fields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_idx_fields (record_id, indexing_group_id, word, datafield) FROM stdin;
\.


--
-- TOC entry 2579 (class 0 OID 16638)
-- Dependencies: 199 2636
-- Data for Name: biblio_idx_sort; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_idx_sort (record_id, indexing_group_id, phrase, ignore_chars_count) FROM stdin;
0	1		0
\.


--
-- TOC entry 2580 (class 0 OID 16644)
-- Dependencies: 200 2636
-- Data for Name: biblio_indexing_groups; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_indexing_groups (id, translation_key, datafields, sortable, default_sort, created, created_by, modified, modified_by) FROM stdin;
4	subject	650_a_x_y_z,600_a_x_y_z,610_a_x_y_z,611_a_x_y_z,630_a_x_y_z,651_a_x_y_z,699_a_x_y_z	f	f	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
5	isbn	020_a	f	f	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
6	issn	022_a	f	f	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
1	author	100_a,110_a,111_a,700_a,710_a,711_a	t	f	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
0	all	\N	f	f	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
2	year	260_c	t	f	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
7	publisher	260_b	t	f	2016-06-04 19:36:53.393	\N	2016-06-04 19:36:53.393	\N
8	series	490_a	t	f	2016-06-04 19:36:53.393	\N	2016-06-04 19:36:53.393	\N
3	title	245_a_b,243_a_f,240_a,730_a,740_a_n_p,830_a_v,250_a,130_a	t	t	2013-04-13 13:45:00.977717	\N	2013-04-13 13:45:00.977717	\N
\.


--
-- TOC entry 2681 (class 0 OID 0)
-- Dependencies: 201
-- Name: biblio_indexing_groups_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('biblio_indexing_groups_id_seq', 8, true);


--
-- TOC entry 2582 (class 0 OID 16656)
-- Dependencies: 202 2636
-- Data for Name: biblio_records; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_records (id, iso2709, material, database, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2682 (class 0 OID 0)
-- Dependencies: 203
-- Name: biblio_records_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('biblio_records_id_seq', 1, false);


--
-- TOC entry 2584 (class 0 OID 16667)
-- Dependencies: 204 2636
-- Data for Name: biblio_search_results; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_search_results (search_id, indexing_group_id, record_id) FROM stdin;
\.


--
-- TOC entry 2585 (class 0 OID 16670)
-- Dependencies: 205 2636
-- Data for Name: biblio_searches; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY biblio_searches (id, parameters, created, created_by) FROM stdin;
\.


--
-- TOC entry 2683 (class 0 OID 0)
-- Dependencies: 206
-- Name: biblio_searches_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('biblio_searches_id_seq', 1, false);


--
-- TOC entry 2587 (class 0 OID 16679)
-- Dependencies: 207 2636
-- Data for Name: configurations; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY configurations (key, value, type, required, modified, modified_by) FROM stdin;
setup.new_library	false	boolean	f	2016-06-05 18:33:18.897	0
\.


--
-- TOC entry 2588 (class 0 OID 16688)
-- Dependencies: 208 2636
-- Data for Name: digital_media; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY digital_media (id, name, blob, content_type, size, created, created_by) FROM stdin;
\.


--
-- TOC entry 2684 (class 0 OID 0)
-- Dependencies: 209
-- Name: digital_media_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('digital_media_id_seq', 1, false);


--
-- TOC entry 2590 (class 0 OID 16697)
-- Dependencies: 210 2636
-- Data for Name: holding_creation_counter; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY holding_creation_counter (id, user_name, user_login, created, created_by) FROM stdin;
\.


--
-- TOC entry 2685 (class 0 OID 0)
-- Dependencies: 211
-- Name: holding_creation_counter_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('holding_creation_counter_id_seq', 1, false);


--
-- TOC entry 2592 (class 0 OID 16703)
-- Dependencies: 212 2636
-- Data for Name: holding_form_datafields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY holding_form_datafields (datafield, collapsed, repeatable, indicator_1, indicator_2, material_type, created, created_by, modified, modified_by) FROM stdin;
949	f	f			holdings	2014-02-08 15:07:07.222864	\N	2014-02-08 15:07:07.222864	\N
541	f	t	_,0,1		holdings	2014-02-08 15:07:07.222864	\N	2014-02-08 15:07:07.222864	\N
090	f	f			holdings	2014-02-08 15:07:07.222864	\N	2014-02-08 15:07:07.222864	\N
852	f	t	_,0,1,2,4,5,6,8	0,1,2	holdings	2014-02-08 15:07:07.222864	\N	2014-02-08 15:07:07.222864	\N
856	f	t			holdings	2014-02-08 15:07:07.222864	\N	2014-02-08 15:07:07.222864	\N
\.


--
-- TOC entry 2593 (class 0 OID 16713)
-- Dependencies: 213 2636
-- Data for Name: holding_form_subfields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY holding_form_subfields (datafield, subfield, collapsed, repeatable, created, created_by, modified, modified_by, autocomplete_type) FROM stdin;
949	a	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	a	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	b	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	c	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	d	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	e	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	f	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	h	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	n	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	o	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
541	3	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
090	a	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
090	b	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
090	c	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
090	d	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	a	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	b	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	c	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	e	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	j	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	n	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	q	f	f	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	x	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
852	z	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
856	d	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
856	f	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
856	u	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
856	y	f	t	2014-02-08 15:10:19.847594	\N	2014-02-08 15:10:19.847594	\N	disabled
\.


--
-- TOC entry 2594 (class 0 OID 16724)
-- Dependencies: 214 2636
-- Data for Name: lending_fines; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY lending_fines (id, lending_id, user_id, fine_value, payment_date, created, created_by) FROM stdin;
\.


--
-- TOC entry 2686 (class 0 OID 0)
-- Dependencies: 215
-- Name: lending_fines_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('lending_fines_id_seq', 1, false);


--
-- TOC entry 2596 (class 0 OID 16730)
-- Dependencies: 216 2636
-- Data for Name: lendings; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY lendings (id, holding_id, user_id, previous_lending_id, expected_return_date, return_date, created, created_by) FROM stdin;
\.


--
-- TOC entry 2687 (class 0 OID 0)
-- Dependencies: 217
-- Name: lendings_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('lendings_id_seq', 1, false);


--
-- TOC entry 2598 (class 0 OID 16736)
-- Dependencies: 218 2636
-- Data for Name: logins; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY logins (id, login, employee, password, created, created_by, modified, modified_by) FROM stdin;
1	admin	t	C4wx3TpMHnSwdk1bUQ/V6qwAQmw=	2014-05-18 15:46:31.632	1	2014-05-18 15:46:31.632	\N
\.


--
-- TOC entry 2688 (class 0 OID 0)
-- Dependencies: 219
-- Name: logins_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('logins_id_seq', 2, false);


--
-- TOC entry 2600 (class 0 OID 16747)
-- Dependencies: 220 2636
-- Data for Name: orders; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY orders (id, info, status, invoice_number, receipt_date, total_value, delivered_quantity, terms_of_payment, deadline_date, created, created_by, modified, modified_by, quotation_id) FROM stdin;
\.


--
-- TOC entry 2689 (class 0 OID 0)
-- Dependencies: 221
-- Name: orders_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('orders_id_seq', 1, false);


--
-- TOC entry 2602 (class 0 OID 16759)
-- Dependencies: 222 2636
-- Data for Name: permissions; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY permissions (login_id, permission) FROM stdin;
\.


--
-- TOC entry 2604 (class 0 OID 16764)
-- Dependencies: 224 2636
-- Data for Name: quotations; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY quotations (id, supplier_id, response_date, expiration_date, delivery_time, info, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2690 (class 0 OID 0)
-- Dependencies: 223
-- Name: quotations_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('quotations_id_seq', 1, false);


--
-- TOC entry 2691 (class 0 OID 0)
-- Dependencies: 225
-- Name: request_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('request_id_seq', 1, false);


--
-- TOC entry 2606 (class 0 OID 16775)
-- Dependencies: 226 2636
-- Data for Name: request_quotation; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY request_quotation (request_id, quotation_id, quotation_quantity, unit_value, response_quantity) FROM stdin;
\.


--
-- TOC entry 2607 (class 0 OID 16781)
-- Dependencies: 227 2636
-- Data for Name: requests; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY requests (id, requester, author, item_title, item_subtitle, edition_number, publisher, info, status, quantity, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2608 (class 0 OID 16790)
-- Dependencies: 228 2636
-- Data for Name: reservations; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY reservations (id, record_id, user_id, expires, created, created_by) FROM stdin;
\.


--
-- TOC entry 2692 (class 0 OID 0)
-- Dependencies: 229
-- Name: reservations_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('reservations_id_seq', 1, false);


--
-- TOC entry 2693 (class 0 OID 0)
-- Dependencies: 230
-- Name: supplier_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('supplier_id_seq', 1, false);


--
-- TOC entry 2611 (class 0 OID 16798)
-- Dependencies: 231 2636
-- Data for Name: suppliers; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY suppliers (id, trademark, supplier_name, supplier_number, vat_registration_number, address, address_number, address_complement, area, city, state, country, zip_code, telephone_1, telephone_2, telephone_3, telephone_4, contact_1, contact_2, contact_3, contact_4, info, url, email, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2612 (class 0 OID 16807)
-- Dependencies: 232 2636
-- Data for Name: translations; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY translations (language, key, text, created, created_by, modified, modified_by, user_created) FROM stdin;
\.


--
-- TOC entry 2613 (class 0 OID 16816)
-- Dependencies: 233 2636
-- Data for Name: users; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY users (id, name, type, photo_id, status, login_id, created, created_by, modified, modified_by, user_card_printed, name_ascii) FROM stdin;
\.


--
-- TOC entry 2614 (class 0 OID 16825)
-- Dependencies: 234 2636
-- Data for Name: users_fields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY users_fields (key, type, required, max_length, sort_order, created, created_by, modified, modified_by) FROM stdin;
email	string	t	0	1	2013-04-13 13:47:34.765388	\N	2013-04-13 13:47:34.765388	\N
gender	list	f	2	2	2014-06-07 12:51:14.565458	\N	2014-06-07 12:51:14.565458	\N
phone_cel	string	f	25	3	2014-06-07 12:47:50.811875	\N	2014-06-07 12:47:50.811875	\N
phone_home	string	f	25	4	2014-06-07 12:47:33.283702	\N	2014-06-07 12:47:33.283702	\N
phone_work	string	f	25	5	2014-06-07 12:47:42.779511	\N	2014-06-07 12:47:42.779511	\N
obs	text	f	0	1002	2013-04-13 13:47:34.765388	\N	2013-04-13 13:47:34.765388	\N
id_cpf	string	f	20	8	2014-06-07 12:46:47.409991	\N	2014-06-07 12:46:47.409991	\N
address	string	f	500	9	2014-06-07 12:41:23.221671	\N	2014-06-07 12:41:23.221671	\N
address_number	string	f	100	10	2014-06-07 12:42:30.610671	\N	2014-06-07 12:42:30.610671	\N
address_complement	string	f	100	11	2014-06-07 12:44:27.624027	\N	2014-06-07 12:44:27.624027	\N
address_zip	string	f	20	12	2014-06-07 12:45:05.425222	\N	2014-06-07 12:45:05.425222	\N
address_city	string	f	100	13	2014-06-07 12:45:21.458004	\N	2014-06-07 12:45:21.458004	\N
address_state	string	f	100	14	2014-06-07 12:45:31.657995	\N	2014-06-07 12:45:31.657995	\N
birthday	date	f	0	15	2014-06-07 12:50:08.933974	\N	2014-06-07 12:50:08.933974	\N
id_rg	string	f	20	7	2014-06-07 12:46:30.386262	\N	2014-06-07 12:46:30.386262	\N
phone_work_extension	string	f	10	6	2014-06-07 12:53:42.743594	\N	2014-06-07 12:53:42.743594	\N
\.


--
-- TOC entry 2694 (class 0 OID 0)
-- Dependencies: 235
-- Name: users_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('users_id_seq', 1, false);


--
-- TOC entry 2616 (class 0 OID 16837)
-- Dependencies: 236 2636
-- Data for Name: users_types; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY users_types (id, name, description, lending_limit, reservation_limit, lending_time_limit, reservation_time_limit, fine_value, created, created_by, modified, modified_by) FROM stdin;
1	Leitor	Leitores	3	3	15	10	0	2014-05-18 15:46:31.379	1	2014-05-18 15:46:31.379	\N
2	Funcionário	Funcionários	99	99	365	365	0	2014-05-18 15:46:31.379	1	2014-05-18 15:46:31.379	\N
\.


--
-- TOC entry 2695 (class 0 OID 0)
-- Dependencies: 237
-- Name: users_types_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('users_types_id_seq', 3, false);


--
-- TOC entry 2618 (class 0 OID 16848)
-- Dependencies: 238 2636
-- Data for Name: users_values; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY users_values (user_id, key, value, ascii) FROM stdin;
\.


--
-- TOC entry 2635 (class 0 OID 17216)
-- Dependencies: 255 2636
-- Data for Name: versions; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY versions (installed_versions) FROM stdin;
4.0.0b
4.0.1b
4.0.2b
4.0.3b
4.0.4b
4.0.5b
4.0.6b
4.0.7b
4.0.8b
4.0.9b
4.0.10b
4.0.11b
4.0.12b
4.1.0
4.1.1
4.1.2
4.1.3
4.1.4
4.1.5
4.1.6
4.1.7
4.1.8
4.1.9
4.1.10
4.1.10a
4.1.11
4.1.11a
\.


--
-- TOC entry 2619 (class 0 OID 16854)
-- Dependencies: 239 2636
-- Data for Name: vocabulary_brief_formats; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_brief_formats (datafield, format, sort_order, created, created_by, modified, modified_by) FROM stdin;
040	${a}_{- }${b}	1	2014-03-20 12:26:27.691	\N	2014-03-20 12:26:27.691	\N
150	${a}_{- }${i}_{; }${x}	2	2014-03-20 12:28:43.529	\N	2014-03-20 12:28:43.529	\N
450	${a}_{; }${x}	4	2014-03-20 12:29:58.601	\N	2014-03-20 12:29:58.601	\N
550	${a}_{; }${x}	5	2014-03-20 12:30:37.837	\N	2014-03-20 12:30:37.837	\N
670	${a}	6	2014-03-20 12:30:52.156	\N	2014-03-20 12:30:52.156	\N
680	${a}	7	2014-03-20 12:31:13.64	\N	2014-03-20 12:31:13.64	\N
685	${a}	8	2014-03-20 12:31:24.135	\N	2014-03-20 12:31:24.135	\N
750	${a}_{; }${x}_{; }${y}_{; }${z}	9	2014-03-20 12:32:37.881	\N	2014-03-20 12:32:37.881	\N
913	${a}	10	2014-03-20 12:32:57.598	\N	2014-03-20 12:32:57.598	\N
360	${a}_{; }${x}	3	2014-03-20 13:03:12.684	\N	2014-03-20 13:03:12.684	\N
\.


--
-- TOC entry 2620 (class 0 OID 16862)
-- Dependencies: 240 2636
-- Data for Name: vocabulary_form_datafields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_form_datafields (datafield, collapsed, repeatable, indicator_1, indicator_2, material_type, created, created_by, modified, modified_by) FROM stdin;
040	f	f				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
150	f	f				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
450	f	t				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
550	f	t				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
360	f	t				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
670	f	f				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
680	f	t				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
685	f	t				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
750	f	f	0,1,2	0,4		2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
913	f	f				2014-02-08 15:29:41.844864	\N	2014-02-08 15:29:41.844864	\N
\.


--
-- TOC entry 2621 (class 0 OID 16872)
-- Dependencies: 241 2636
-- Data for Name: vocabulary_form_subfields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_form_subfields (datafield, subfield, collapsed, repeatable, created, created_by, modified, modified_by, autocomplete_type) FROM stdin;
040	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
040	b	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
040	c	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
040	d	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
040	e	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
150	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
150	i	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
150	x	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
150	y	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
150	z	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
450	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
550	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
550	x	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
550	y	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
550	z	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
360	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
360	x	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
360	y	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
360	z	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
670	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
680	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
685	i	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
750	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
750	x	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
750	y	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
750	z	f	t	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
913	a	f	f	2014-02-08 15:30:23.272565	\N	2014-02-08 15:30:23.272565	\N	disabled
\.


--
-- TOC entry 2622 (class 0 OID 16883)
-- Dependencies: 242 2636
-- Data for Name: vocabulary_idx_autocomplete; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_idx_autocomplete (id, datafield, subfield, word, phrase, record_id) FROM stdin;
\.


--
-- TOC entry 2696 (class 0 OID 0)
-- Dependencies: 243
-- Name: vocabulary_idx_autocomplete_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('vocabulary_idx_autocomplete_id_seq', 1, false);


--
-- TOC entry 2624 (class 0 OID 16891)
-- Dependencies: 244 2636
-- Data for Name: vocabulary_idx_fields; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_idx_fields (record_id, indexing_group_id, word, datafield) FROM stdin;
\.


--
-- TOC entry 2625 (class 0 OID 16897)
-- Dependencies: 245 2636
-- Data for Name: vocabulary_idx_sort; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_idx_sort (record_id, indexing_group_id, phrase, ignore_chars_count) FROM stdin;
\.


--
-- TOC entry 2626 (class 0 OID 16903)
-- Dependencies: 246 2636
-- Data for Name: vocabulary_indexing_groups; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_indexing_groups (id, translation_key, datafields, sortable, default_sort, created, created_by, modified, modified_by) FROM stdin;
0	all	\N	f	f	2014-03-04 11:16:16.428	\N	2014-03-04 11:16:16.428	\N
1	te_term	150_a	t	t	2014-03-04 11:16:31.24	\N	2014-03-04 11:16:31.24	\N
2	up_term	450_a	t	f	2014-03-04 11:16:48.069	\N	2014-03-04 11:16:48.069	\N
3	tg_term	550_a	t	f	2014-03-04 11:16:59.899	\N	2014-03-04 11:16:59.899	\N
4	vt_ta_term	360_a	t	f	2014-03-04 11:17:18.848	\N	2014-03-04 11:17:18.848	\N
\.


--
-- TOC entry 2697 (class 0 OID 0)
-- Dependencies: 247
-- Name: vocabulary_indexing_groups_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('vocabulary_indexing_groups_id_seq', 5, false);


--
-- TOC entry 2628 (class 0 OID 16915)
-- Dependencies: 248 2636
-- Data for Name: vocabulary_records; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_records (id, iso2709, material, database, created, created_by, modified, modified_by) FROM stdin;
\.


--
-- TOC entry 2698 (class 0 OID 0)
-- Dependencies: 249
-- Name: vocabulary_records_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('vocabulary_records_id_seq', 1, false);


--
-- TOC entry 2630 (class 0 OID 16926)
-- Dependencies: 250 2636
-- Data for Name: vocabulary_search_results; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_search_results (search_id, indexing_group_id, record_id) FROM stdin;
\.


--
-- TOC entry 2631 (class 0 OID 16929)
-- Dependencies: 251 2636
-- Data for Name: vocabulary_searches; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY vocabulary_searches (id, parameters, created, created_by) FROM stdin;
\.


--
-- TOC entry 2699 (class 0 OID 0)
-- Dependencies: 252
-- Name: vocabulary_searches_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('vocabulary_searches_id_seq', 1, false);


--
-- TOC entry 2633 (class 0 OID 16938)
-- Dependencies: 253 2636
-- Data for Name: z3950_addresses; Type: TABLE DATA; Schema: single; Owner: biblivre
--

COPY z3950_addresses (id, name, url, port, collection) FROM stdin;
1	Universidad de Chile - Santiago, Chile	unicornio.uchile.cl	2200	default
2	Université Laval - Quebec, Canadá	ariane2.ulaval.ca	2200	default
3	Brunel University - Londres, Reino Unido	library.brunel.ac.uk	2200	default
4	Acadia University - Nova Escócia, Canada	jasper.acadiau.ca	2200	default
5	Carnegie Mellon University - Pittsburgh, PA - EUA	webcat.library.cmu.edu	2200	unicorn
6	New York Public Library - EUA	catalog.nypl.org	210	INNOPAC
7	Biblioteca Nacional da Espanha - Madrid	sigb.bne.es	2200	default
8	Library of Congress Online Catalog - EUA	140.147.249.67	210	LCDB
9	South University New Orleans, EUA	suno.louislibraries.org	7705	default
10	Penn State University, EUA	zcat.libraries.psu.edu	2200	default
11	The Fletcher School, Tufts University, EUA	fletcher.louislibraries.org	8205	default
12	Univerdidad de Madrid, Espanha	marte.biblioteca.upm.es	2200	default
\.


--
-- TOC entry 2700 (class 0 OID 0)
-- Dependencies: 254
-- Name: z3950_addresses_id_seq; Type: SEQUENCE SET; Schema: single; Owner: biblivre
--

SELECT pg_catalog.setval('z3950_addresses_id_seq', 13, false);


SET search_path = global, pg_catalog;

--
-- TOC entry 2268 (class 2606 OID 16454)
-- Dependencies: 163 163 2637
-- Name: PK_configurations; Type: CONSTRAINT; Schema: global; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY configurations
    ADD CONSTRAINT "PK_configurations" PRIMARY KEY (key);


--
-- TOC entry 2270 (class 2606 OID 16456)
-- Dependencies: 164 164 2637
-- Name: PK_logins; Type: CONSTRAINT; Schema: global; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY logins
    ADD CONSTRAINT "PK_logins" PRIMARY KEY (id);


--
-- TOC entry 2274 (class 2606 OID 16458)
-- Dependencies: 168 168 2637
-- Name: PK_schemas; Type: CONSTRAINT; Schema: global; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY schemas
    ADD CONSTRAINT "PK_schemas" PRIMARY KEY (schema);


--
-- TOC entry 2276 (class 2606 OID 16460)
-- Dependencies: 169 169 169 2637
-- Name: PK_translations; Type: CONSTRAINT; Schema: global; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY translations
    ADD CONSTRAINT "PK_translations" PRIMARY KEY (language, key);


--
-- TOC entry 2278 (class 2606 OID 16462)
-- Dependencies: 170 170 2637
-- Name: PK_versions; Type: CONSTRAINT; Schema: global; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY versions
    ADD CONSTRAINT "PK_versions" PRIMARY KEY (installed_versions);


--
-- TOC entry 2272 (class 2606 OID 16464)
-- Dependencies: 164 164 2637
-- Name: UN_logins; Type: CONSTRAINT; Schema: global; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY logins
    ADD CONSTRAINT "UN_logins" UNIQUE (login);


SET search_path = single, pg_catalog;

--
-- TOC entry 2280 (class 2606 OID 16972)
-- Dependencies: 172 172 2637
-- Name: PK_access_cards; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY access_cards
    ADD CONSTRAINT "PK_access_cards" PRIMARY KEY (id);


--
-- TOC entry 2286 (class 2606 OID 16974)
-- Dependencies: 174 174 2637
-- Name: PK_access_control; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY access_control
    ADD CONSTRAINT "PK_access_control" PRIMARY KEY (id);


--
-- TOC entry 2289 (class 2606 OID 16976)
-- Dependencies: 175 175 2637
-- Name: PK_authorities_brief_formats; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_brief_formats
    ADD CONSTRAINT "PK_authorities_brief_formats" PRIMARY KEY (datafield);


--
-- TOC entry 2291 (class 2606 OID 16978)
-- Dependencies: 176 176 2637
-- Name: PK_authorities_form_datafields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_form_datafields
    ADD CONSTRAINT "PK_authorities_form_datafields" PRIMARY KEY (datafield);


--
-- TOC entry 2293 (class 2606 OID 16980)
-- Dependencies: 177 177 177 2637
-- Name: PK_authorities_form_subfields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_form_subfields
    ADD CONSTRAINT "PK_authorities_form_subfields" PRIMARY KEY (datafield, subfield);


--
-- TOC entry 2297 (class 2606 OID 16982)
-- Dependencies: 178 178 2637
-- Name: PK_authorities_idx_autocomplete; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_idx_autocomplete
    ADD CONSTRAINT "PK_authorities_idx_autocomplete" PRIMARY KEY (id);


--
-- TOC entry 2300 (class 2606 OID 16984)
-- Dependencies: 180 180 180 180 180 2637
-- Name: PK_authorities_idx_fields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_idx_fields
    ADD CONSTRAINT "PK_authorities_idx_fields" PRIMARY KEY (record_id, indexing_group_id, word, datafield);


--
-- TOC entry 2302 (class 2606 OID 16986)
-- Dependencies: 181 181 181 2637
-- Name: PK_authorities_idx_sort; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_idx_sort
    ADD CONSTRAINT "PK_authorities_idx_sort" PRIMARY KEY (record_id, indexing_group_id);


--
-- TOC entry 2304 (class 2606 OID 16988)
-- Dependencies: 182 182 2637
-- Name: PK_authorities_indexing_groups; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_indexing_groups
    ADD CONSTRAINT "PK_authorities_indexing_groups" PRIMARY KEY (id);


--
-- TOC entry 2306 (class 2606 OID 16990)
-- Dependencies: 184 184 2637
-- Name: PK_authorities_records; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_records
    ADD CONSTRAINT "PK_authorities_records" PRIMARY KEY (id);


--
-- TOC entry 2309 (class 2606 OID 16992)
-- Dependencies: 186 186 186 186 2637
-- Name: PK_authorities_search_results; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_search_results
    ADD CONSTRAINT "PK_authorities_search_results" PRIMARY KEY (search_id, indexing_group_id, record_id);


--
-- TOC entry 2311 (class 2606 OID 16994)
-- Dependencies: 187 187 2637
-- Name: PK_authorities_searches; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY authorities_searches
    ADD CONSTRAINT "PK_authorities_searches" PRIMARY KEY (id);


--
-- TOC entry 2313 (class 2606 OID 16996)
-- Dependencies: 189 189 2637
-- Name: PK_backups; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY backups
    ADD CONSTRAINT "PK_backups" PRIMARY KEY (id);


--
-- TOC entry 2315 (class 2606 OID 16998)
-- Dependencies: 191 191 2637
-- Name: PK_biblio_brief_formats; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_brief_formats
    ADD CONSTRAINT "PK_biblio_brief_formats" PRIMARY KEY (datafield);


--
-- TOC entry 2317 (class 2606 OID 17000)
-- Dependencies: 192 192 2637
-- Name: PK_biblio_form_datafields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_form_datafields
    ADD CONSTRAINT "PK_biblio_form_datafields" PRIMARY KEY (datafield);


--
-- TOC entry 2319 (class 2606 OID 17002)
-- Dependencies: 193 193 193 2637
-- Name: PK_biblio_form_subfields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_form_subfields
    ADD CONSTRAINT "PK_biblio_form_subfields" PRIMARY KEY (datafield, subfield);


--
-- TOC entry 2328 (class 2606 OID 17004)
-- Dependencies: 196 196 2637
-- Name: PK_biblio_idx_autocomplete; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_idx_autocomplete
    ADD CONSTRAINT "PK_biblio_idx_autocomplete" PRIMARY KEY (id);


--
-- TOC entry 2331 (class 2606 OID 17006)
-- Dependencies: 198 198 198 198 198 2637
-- Name: PK_biblio_idx_fields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_idx_fields
    ADD CONSTRAINT "PK_biblio_idx_fields" PRIMARY KEY (record_id, indexing_group_id, word, datafield);


--
-- TOC entry 2333 (class 2606 OID 17008)
-- Dependencies: 199 199 199 2637
-- Name: PK_biblio_idx_sort; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_idx_sort
    ADD CONSTRAINT "PK_biblio_idx_sort" PRIMARY KEY (record_id, indexing_group_id);


--
-- TOC entry 2335 (class 2606 OID 17010)
-- Dependencies: 200 200 2637
-- Name: PK_biblio_indexing_groups; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_indexing_groups
    ADD CONSTRAINT "PK_biblio_indexing_groups" PRIMARY KEY (id);


--
-- TOC entry 2337 (class 2606 OID 17012)
-- Dependencies: 202 202 2637
-- Name: PK_biblio_records; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_records
    ADD CONSTRAINT "PK_biblio_records" PRIMARY KEY (id);


--
-- TOC entry 2340 (class 2606 OID 17014)
-- Dependencies: 204 204 204 204 2637
-- Name: PK_biblio_search_results; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_search_results
    ADD CONSTRAINT "PK_biblio_search_results" PRIMARY KEY (search_id, indexing_group_id, record_id);


--
-- TOC entry 2342 (class 2606 OID 17016)
-- Dependencies: 205 205 2637
-- Name: PK_biblio_searches; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_searches
    ADD CONSTRAINT "PK_biblio_searches" PRIMARY KEY (id);


--
-- TOC entry 2344 (class 2606 OID 17018)
-- Dependencies: 207 207 2637
-- Name: PK_configurations; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY configurations
    ADD CONSTRAINT "PK_configurations" PRIMARY KEY (key);


--
-- TOC entry 2346 (class 2606 OID 17020)
-- Dependencies: 208 208 2637
-- Name: PK_digital_media; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY digital_media
    ADD CONSTRAINT "PK_digital_media" PRIMARY KEY (id);


--
-- TOC entry 2348 (class 2606 OID 17022)
-- Dependencies: 210 210 2637
-- Name: PK_holding_creation_counter; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY holding_creation_counter
    ADD CONSTRAINT "PK_holding_creation_counter" PRIMARY KEY (id);


--
-- TOC entry 2350 (class 2606 OID 17024)
-- Dependencies: 212 212 2637
-- Name: PK_holding_form_datafields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY holding_form_datafields
    ADD CONSTRAINT "PK_holding_form_datafields" PRIMARY KEY (datafield);


--
-- TOC entry 2352 (class 2606 OID 17026)
-- Dependencies: 213 213 213 2637
-- Name: PK_holding_form_subfields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY holding_form_subfields
    ADD CONSTRAINT "PK_holding_form_subfields" PRIMARY KEY (datafield, subfield);


--
-- TOC entry 2354 (class 2606 OID 17028)
-- Dependencies: 214 214 2637
-- Name: PK_lending_fines; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY lending_fines
    ADD CONSTRAINT "PK_lending_fines" PRIMARY KEY (id);


--
-- TOC entry 2358 (class 2606 OID 17030)
-- Dependencies: 218 218 2637
-- Name: PK_logins; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY logins
    ADD CONSTRAINT "PK_logins" PRIMARY KEY (id);


--
-- TOC entry 2362 (class 2606 OID 17032)
-- Dependencies: 220 220 2637
-- Name: PK_order; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT "PK_order" PRIMARY KEY (id);


--
-- TOC entry 2364 (class 2606 OID 17034)
-- Dependencies: 222 222 222 2637
-- Name: PK_permissions; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY permissions
    ADD CONSTRAINT "PK_permissions" PRIMARY KEY (login_id, permission);


--
-- TOC entry 2366 (class 2606 OID 17036)
-- Dependencies: 224 224 2637
-- Name: PK_quotations; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY quotations
    ADD CONSTRAINT "PK_quotations" PRIMARY KEY (id);


--
-- TOC entry 2370 (class 2606 OID 17038)
-- Dependencies: 227 227 2637
-- Name: PK_request; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY requests
    ADD CONSTRAINT "PK_request" PRIMARY KEY (id);


--
-- TOC entry 2368 (class 2606 OID 17040)
-- Dependencies: 226 226 226 2637
-- Name: PK_request_quotation; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY request_quotation
    ADD CONSTRAINT "PK_request_quotation" PRIMARY KEY (request_id, quotation_id);


--
-- TOC entry 2374 (class 2606 OID 17042)
-- Dependencies: 231 231 2637
-- Name: PK_supplier; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY suppliers
    ADD CONSTRAINT "PK_supplier" PRIMARY KEY (id);


--
-- TOC entry 2376 (class 2606 OID 17044)
-- Dependencies: 232 232 232 2637
-- Name: PK_translations; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY translations
    ADD CONSTRAINT "PK_translations" PRIMARY KEY (language, key);


--
-- TOC entry 2381 (class 2606 OID 17046)
-- Dependencies: 234 234 2637
-- Name: PK_users_fields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY users_fields
    ADD CONSTRAINT "PK_users_fields" PRIMARY KEY (key);


--
-- TOC entry 2383 (class 2606 OID 17048)
-- Dependencies: 236 236 2637
-- Name: PK_users_types; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY users_types
    ADD CONSTRAINT "PK_users_types" PRIMARY KEY (id);


--
-- TOC entry 2385 (class 2606 OID 17050)
-- Dependencies: 238 238 238 2637
-- Name: PK_users_values; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY users_values
    ADD CONSTRAINT "PK_users_values" PRIMARY KEY (user_id, key);


--
-- TOC entry 2413 (class 2606 OID 17223)
-- Dependencies: 255 255 2637
-- Name: PK_versions; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY versions
    ADD CONSTRAINT "PK_versions" PRIMARY KEY (installed_versions);


--
-- TOC entry 2387 (class 2606 OID 17052)
-- Dependencies: 239 239 2637
-- Name: PK_vocabulary_brief_formats; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_brief_formats
    ADD CONSTRAINT "PK_vocabulary_brief_formats" PRIMARY KEY (datafield);


--
-- TOC entry 2389 (class 2606 OID 17054)
-- Dependencies: 240 240 2637
-- Name: PK_vocabulary_form_datafields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_form_datafields
    ADD CONSTRAINT "PK_vocabulary_form_datafields" PRIMARY KEY (datafield);


--
-- TOC entry 2391 (class 2606 OID 17056)
-- Dependencies: 241 241 241 2637
-- Name: PK_vocabulary_form_subfields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_form_subfields
    ADD CONSTRAINT "PK_vocabulary_form_subfields" PRIMARY KEY (datafield, subfield);


--
-- TOC entry 2395 (class 2606 OID 17058)
-- Dependencies: 242 242 2637
-- Name: PK_vocabulary_idx_autocomplete; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_idx_autocomplete
    ADD CONSTRAINT "PK_vocabulary_idx_autocomplete" PRIMARY KEY (id);


--
-- TOC entry 2398 (class 2606 OID 17060)
-- Dependencies: 244 244 244 244 244 2637
-- Name: PK_vocabulary_idx_fields; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_idx_fields
    ADD CONSTRAINT "PK_vocabulary_idx_fields" PRIMARY KEY (record_id, indexing_group_id, word, datafield);


--
-- TOC entry 2400 (class 2606 OID 17062)
-- Dependencies: 245 245 245 2637
-- Name: PK_vocabulary_idx_sort; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_idx_sort
    ADD CONSTRAINT "PK_vocabulary_idx_sort" PRIMARY KEY (record_id, indexing_group_id);


--
-- TOC entry 2402 (class 2606 OID 17064)
-- Dependencies: 246 246 2637
-- Name: PK_vocabulary_indexing_groups; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_indexing_groups
    ADD CONSTRAINT "PK_vocabulary_indexing_groups" PRIMARY KEY (id);


--
-- TOC entry 2404 (class 2606 OID 17066)
-- Dependencies: 248 248 2637
-- Name: PK_vocabulary_records; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_records
    ADD CONSTRAINT "PK_vocabulary_records" PRIMARY KEY (id);


--
-- TOC entry 2407 (class 2606 OID 17068)
-- Dependencies: 250 250 250 250 2637
-- Name: PK_vocabulary_search_results; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_search_results
    ADD CONSTRAINT "PK_vocabulary_search_results" PRIMARY KEY (search_id, indexing_group_id, record_id);


--
-- TOC entry 2409 (class 2606 OID 17070)
-- Dependencies: 251 251 2637
-- Name: PK_vocabulary_searches; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY vocabulary_searches
    ADD CONSTRAINT "PK_vocabulary_searches" PRIMARY KEY (id);


--
-- TOC entry 2411 (class 2606 OID 17072)
-- Dependencies: 253 253 2637
-- Name: PK_z3950_addresses; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY z3950_addresses
    ADD CONSTRAINT "PK_z3950_addresses" PRIMARY KEY (id);


--
-- TOC entry 2282 (class 2606 OID 17074)
-- Dependencies: 172 172 2637
-- Name: UN_access_cards; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY access_cards
    ADD CONSTRAINT "UN_access_cards" UNIQUE (code);


--
-- TOC entry 2360 (class 2606 OID 17076)
-- Dependencies: 218 218 2637
-- Name: UN_logins; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY logins
    ADD CONSTRAINT "UN_logins" UNIQUE (login);


--
-- TOC entry 2324 (class 2606 OID 17078)
-- Dependencies: 194 194 2637
-- Name: pk_biblio_holdings; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY biblio_holdings
    ADD CONSTRAINT pk_biblio_holdings PRIMARY KEY (id);


--
-- TOC entry 2356 (class 2606 OID 17080)
-- Dependencies: 216 216 2637
-- Name: pk_lendings; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY lendings
    ADD CONSTRAINT pk_lendings PRIMARY KEY (id);


--
-- TOC entry 2372 (class 2606 OID 17082)
-- Dependencies: 228 228 2637
-- Name: pk_reservations; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY reservations
    ADD CONSTRAINT pk_reservations PRIMARY KEY (id);


--
-- TOC entry 2379 (class 2606 OID 17084)
-- Dependencies: 233 233 2637
-- Name: users_pkey; Type: CONSTRAINT; Schema: single; Owner: biblivre; Tablespace: 
--

ALTER TABLE ONLY users
    ADD CONSTRAINT users_pkey PRIMARY KEY (id);


--
-- TOC entry 2283 (class 1259 OID 17085)
-- Dependencies: 174 2637
-- Name: FKI_access_control_access_cards; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "FKI_access_control_access_cards" ON access_control USING btree (access_card_id);


--
-- TOC entry 2284 (class 1259 OID 17086)
-- Dependencies: 174 2637
-- Name: FKI_access_control_users; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "FKI_access_control_users" ON access_control USING btree (user_id);


--
-- TOC entry 2294 (class 1259 OID 17087)
-- Dependencies: 178 2637
-- Name: IX_authorities_idx_autocomplete_record_id; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_authorities_idx_autocomplete_record_id" ON authorities_idx_autocomplete USING btree (record_id);


--
-- TOC entry 2295 (class 1259 OID 17088)
-- Dependencies: 178 178 178 2637
-- Name: IX_authorities_idx_autocomplete_word; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_authorities_idx_autocomplete_word" ON authorities_idx_autocomplete USING btree (datafield, subfield, word varchar_pattern_ops);


--
-- TOC entry 2298 (class 1259 OID 17089)
-- Dependencies: 180 2637
-- Name: IX_authorities_idx_fields_word; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_authorities_idx_fields_word" ON authorities_idx_fields USING btree (word varchar_pattern_ops);


--
-- TOC entry 2307 (class 1259 OID 17090)
-- Dependencies: 186 186 2637
-- Name: IX_authorities_search_results; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_authorities_search_results" ON authorities_search_results USING btree (search_id, record_id);


--
-- TOC entry 2320 (class 1259 OID 17091)
-- Dependencies: 194 2637
-- Name: IX_biblio_holdings_accession_number; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE UNIQUE INDEX "IX_biblio_holdings_accession_number" ON biblio_holdings USING btree (accession_number);


--
-- TOC entry 2321 (class 1259 OID 17092)
-- Dependencies: 194 194 2637
-- Name: IX_biblio_holdings_biblio_record; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_biblio_holdings_biblio_record" ON biblio_holdings USING btree (record_id, database);


--
-- TOC entry 2322 (class 1259 OID 17093)
-- Dependencies: 194 194 2637
-- Name: IX_biblio_holdings_location_d; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_biblio_holdings_location_d" ON biblio_holdings USING btree (record_id, location_d);


--
-- TOC entry 2325 (class 1259 OID 17094)
-- Dependencies: 196 2637
-- Name: IX_biblio_idx_autocomplete_record_id; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_biblio_idx_autocomplete_record_id" ON biblio_idx_autocomplete USING btree (record_id);


--
-- TOC entry 2326 (class 1259 OID 17095)
-- Dependencies: 196 196 196 2637
-- Name: IX_biblio_idx_autocomplete_word; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_biblio_idx_autocomplete_word" ON biblio_idx_autocomplete USING btree (datafield, subfield, word varchar_pattern_ops);


--
-- TOC entry 2329 (class 1259 OID 17096)
-- Dependencies: 198 2637
-- Name: IX_biblio_idx_fields_word; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_biblio_idx_fields_word" ON biblio_idx_fields USING btree (word varchar_pattern_ops);


--
-- TOC entry 2338 (class 1259 OID 17097)
-- Dependencies: 204 204 2637
-- Name: IX_biblio_search_results; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_biblio_search_results" ON biblio_search_results USING btree (search_id, record_id);


--
-- TOC entry 2377 (class 1259 OID 17098)
-- Dependencies: 233 2637
-- Name: IX_users_name; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_users_name" ON users USING btree (name varchar_pattern_ops);


--
-- TOC entry 2392 (class 1259 OID 17099)
-- Dependencies: 242 2637
-- Name: IX_vocabulary_idx_autocomplete_record_id; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_vocabulary_idx_autocomplete_record_id" ON vocabulary_idx_autocomplete USING btree (record_id);


--
-- TOC entry 2393 (class 1259 OID 17100)
-- Dependencies: 242 242 242 2637
-- Name: IX_vocabulary_idx_autocomplete_word; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_vocabulary_idx_autocomplete_word" ON vocabulary_idx_autocomplete USING btree (datafield, subfield, word varchar_pattern_ops);


--
-- TOC entry 2396 (class 1259 OID 17101)
-- Dependencies: 244 2637
-- Name: IX_vocabulary_idx_fields_word; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_vocabulary_idx_fields_word" ON vocabulary_idx_fields USING btree (word varchar_pattern_ops);


--
-- TOC entry 2405 (class 1259 OID 17102)
-- Dependencies: 250 250 2637
-- Name: IX_vocabulary_search_results; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX "IX_vocabulary_search_results" ON vocabulary_search_results USING btree (search_id, record_id);


--
-- TOC entry 2287 (class 1259 OID 17103)
-- Dependencies: 174 174 2637
-- Name: ix_access_control_departure_time_user_id; Type: INDEX; Schema: single; Owner: biblivre; Tablespace: 
--

CREATE INDEX ix_access_control_departure_time_user_id ON access_control USING btree (departure_time, user_id);


--
-- TOC entry 2435 (class 2620 OID 17104)
-- Dependencies: 182 269 2637
-- Name: TRIGGER_clear_authorities_indexing_type; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_clear_authorities_indexing_type" AFTER DELETE ON authorities_indexing_groups FOR EACH ROW EXECUTE PROCEDURE clear_indexing_type('authorities');


--
-- TOC entry 2436 (class 2620 OID 17105)
-- Dependencies: 270 184 2637
-- Name: TRIGGER_clear_authorities_record; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_clear_authorities_record" AFTER DELETE ON authorities_records FOR EACH ROW EXECUTE PROCEDURE clear_record('authorities');


--
-- TOC entry 2437 (class 2620 OID 17106)
-- Dependencies: 269 200 2637
-- Name: TRIGGER_clear_biblio_indexing_type; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_clear_biblio_indexing_type" AFTER DELETE ON biblio_indexing_groups FOR EACH ROW EXECUTE PROCEDURE clear_indexing_type('biblio');


--
-- TOC entry 2438 (class 2620 OID 17107)
-- Dependencies: 270 202 2637
-- Name: TRIGGER_clear_biblio_record; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_clear_biblio_record" AFTER DELETE ON biblio_records FOR EACH ROW EXECUTE PROCEDURE clear_record('biblio');


--
-- TOC entry 2440 (class 2620 OID 17108)
-- Dependencies: 246 269 2637
-- Name: TRIGGER_clear_vocabulary_indexing_type; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_clear_vocabulary_indexing_type" AFTER DELETE ON vocabulary_indexing_groups FOR EACH ROW EXECUTE PROCEDURE clear_indexing_type('vocabulary');


--
-- TOC entry 2441 (class 2620 OID 17109)
-- Dependencies: 248 270 2637
-- Name: TRIGGER_clear_vocabulary_record; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_clear_vocabulary_record" AFTER DELETE ON vocabulary_records FOR EACH ROW EXECUTE PROCEDURE clear_record('vocabulary');


--
-- TOC entry 2439 (class 2620 OID 17110)
-- Dependencies: 268 208 2637
-- Name: TRIGGER_digital_media_lo; Type: TRIGGER; Schema: single; Owner: biblivre
--

CREATE TRIGGER "TRIGGER_digital_media_lo" BEFORE DELETE ON digital_media FOR EACH ROW EXECUTE PROCEDURE global.unlink();


--
-- TOC entry 2414 (class 2606 OID 17111)
-- Dependencies: 172 174 2279 2637
-- Name: FK_access_control_access_cards; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY access_control
    ADD CONSTRAINT "FK_access_control_access_cards" FOREIGN KEY (access_card_id) REFERENCES access_cards(id) ON DELETE CASCADE;


--
-- TOC entry 2415 (class 2606 OID 17116)
-- Dependencies: 2378 233 174 2637
-- Name: FK_access_control_users; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY access_control
    ADD CONSTRAINT "FK_access_control_users" FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE;


--
-- TOC entry 2416 (class 2606 OID 17121)
-- Dependencies: 177 2290 176 2637
-- Name: FK_authorities_form_subfields_authorities_form_datafields; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY authorities_form_subfields
    ADD CONSTRAINT "FK_authorities_form_subfields_authorities_form_datafields" FOREIGN KEY (datafield) REFERENCES authorities_form_datafields(datafield) ON DELETE CASCADE;


--
-- TOC entry 2417 (class 2606 OID 17126)
-- Dependencies: 2316 192 193 2637
-- Name: FK_biblio_form_subfields_biblio_form_datafields; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_form_subfields
    ADD CONSTRAINT "FK_biblio_form_subfields_biblio_form_datafields" FOREIGN KEY (datafield) REFERENCES biblio_form_datafields(datafield) ON DELETE CASCADE;


--
-- TOC entry 2419 (class 2606 OID 17131)
-- Dependencies: 2349 212 213 2637
-- Name: FK_holding_form_subfields_holding_form_datafields; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY holding_form_subfields
    ADD CONSTRAINT "FK_holding_form_subfields_holding_form_datafields" FOREIGN KEY (datafield) REFERENCES holding_form_datafields(datafield) ON DELETE CASCADE;


--
-- TOC entry 2420 (class 2606 OID 17136)
-- Dependencies: 216 2355 214 2637
-- Name: FK_lending_fines_lendings; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lending_fines
    ADD CONSTRAINT "FK_lending_fines_lendings" FOREIGN KEY (lending_id) REFERENCES lendings(id) ON DELETE CASCADE;


--
-- TOC entry 2421 (class 2606 OID 17141)
-- Dependencies: 2378 233 214 2637
-- Name: FK_lending_fines_users; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lending_fines
    ADD CONSTRAINT "FK_lending_fines_users" FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE;


--
-- TOC entry 2425 (class 2606 OID 17181)
-- Dependencies: 224 2365 220 2637
-- Name: FK_orders_quotations; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY orders
    ADD CONSTRAINT "FK_orders_quotations" FOREIGN KEY (quotation_id) REFERENCES quotations(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 2426 (class 2606 OID 17146)
-- Dependencies: 2357 218 222 2637
-- Name: FK_permissions_logins; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY permissions
    ADD CONSTRAINT "FK_permissions_logins" FOREIGN KEY (login_id) REFERENCES logins(id) ON DELETE CASCADE;


--
-- TOC entry 2427 (class 2606 OID 17151)
-- Dependencies: 224 2373 231 2637
-- Name: FK_quotations_suppliers; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY quotations
    ADD CONSTRAINT "FK_quotations_suppliers" FOREIGN KEY (supplier_id) REFERENCES suppliers(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 2428 (class 2606 OID 17156)
-- Dependencies: 2365 224 226 2637
-- Name: FK_request_quotation_quotations; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY request_quotation
    ADD CONSTRAINT "FK_request_quotation_quotations" FOREIGN KEY (quotation_id) REFERENCES quotations(id) ON DELETE CASCADE;


--
-- TOC entry 2429 (class 2606 OID 17161)
-- Dependencies: 227 2369 226 2637
-- Name: FK_request_quotation_requests; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY request_quotation
    ADD CONSTRAINT "FK_request_quotation_requests" FOREIGN KEY (request_id) REFERENCES requests(id) ON DELETE CASCADE;


--
-- TOC entry 2432 (class 2606 OID 17166)
-- Dependencies: 238 2378 233 2637
-- Name: FK_users_values_users; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY users_values
    ADD CONSTRAINT "FK_users_values_users" FOREIGN KEY (user_id) REFERENCES users(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 2433 (class 2606 OID 17171)
-- Dependencies: 238 2380 234 2637
-- Name: FK_users_values_users_fields; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY users_values
    ADD CONSTRAINT "FK_users_values_users_fields" FOREIGN KEY (key) REFERENCES users_fields(key) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 2434 (class 2606 OID 17176)
-- Dependencies: 2388 241 240 2637
-- Name: FK_vocabulary_form_subfields_vocabulary_form_datafields; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY vocabulary_form_subfields
    ADD CONSTRAINT "FK_vocabulary_form_subfields_vocabulary_form_datafields" FOREIGN KEY (datafield) REFERENCES vocabulary_form_datafields(datafield) ON DELETE CASCADE;


--
-- TOC entry 2418 (class 2606 OID 17186)
-- Dependencies: 2336 194 202 2637
-- Name: fk_biblio_holdings_biblio_records; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY biblio_holdings
    ADD CONSTRAINT fk_biblio_holdings_biblio_records FOREIGN KEY (record_id) REFERENCES biblio_records(id) ON DELETE CASCADE;


--
-- TOC entry 2422 (class 2606 OID 17191)
-- Dependencies: 194 2323 216 2637
-- Name: fk_lendings_biblio_holdings; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lendings
    ADD CONSTRAINT fk_lendings_biblio_holdings FOREIGN KEY (holding_id) REFERENCES biblio_holdings(id) ON DELETE CASCADE;


--
-- TOC entry 2423 (class 2606 OID 17196)
-- Dependencies: 216 216 2355 2637
-- Name: fk_lendings_lendings; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lendings
    ADD CONSTRAINT fk_lendings_lendings FOREIGN KEY (previous_lending_id) REFERENCES lendings(id) ON DELETE CASCADE;


--
-- TOC entry 2424 (class 2606 OID 17201)
-- Dependencies: 2378 216 233 2637
-- Name: fk_lendings_users; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY lendings
    ADD CONSTRAINT fk_lendings_users FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE;


--
-- TOC entry 2430 (class 2606 OID 17206)
-- Dependencies: 2378 228 233 2637
-- Name: fk_lendings_users; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY reservations
    ADD CONSTRAINT fk_lendings_users FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE;


--
-- TOC entry 2431 (class 2606 OID 17211)
-- Dependencies: 202 228 2336 2637
-- Name: fk_reservations_biblio_records; Type: FK CONSTRAINT; Schema: single; Owner: biblivre
--

ALTER TABLE ONLY reservations
    ADD CONSTRAINT fk_reservations_biblio_records FOREIGN KEY (record_id) REFERENCES biblio_records(id) ON DELETE CASCADE;


--
-- TOC entry 2642 (class 0 OID 0)
-- Dependencies: 5
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


-- Completed on 2016-06-05 18:56:38

--
-- PostgreSQL database dump complete
--

